<?php
/**
 * Profecient Essential Asset Class
 *
 * @package profecient-essential
 * @author jegtheme
 * @since 1.0.0
 */

namespace Profecient\Essential\Assets;

use Profecient\Essential\Options\Settings;
/**
 * Class Asset
 *
 * @package Profecient\Essential\Assets
 */
class Asset {
	/**
	 * Class instance
	 *
	 * @var Asset
	 */
	private static $instance;

	/**
	 * Frontend ajax endpoint
	 *
	 * @var string
	 */
	private $endpoint = 'profecient-ajax-request';

	/**
	 * Block ajax prefix
	 *
	 * @var string
	 */
	public static $element_ajax_prefix = 'profecient_element_ajax_';

	/**
	 * Get class instance
	 *
	 * @return Asset
	 */
	public static function instance() {
		if ( null === static::$instance ) {
			static::$instance = new static();
		}

		return static::$instance;
	}

	/**
	 * Class constructor
	 */
	private function __construct() {
		$this->load_hook();
	}

	/**
	 * Load Hook
	 */
	private function load_hook() {
		add_action( 'wp_enqueue_scripts', array( $this, 'register_styles' ) );
		add_action( 'wp_enqueue_scripts', array( $this, 'register_scripts' ) );
		add_action( 'elementor/frontend/after_register_styles', array( $this, 'load_frontend_assets' ), 98 );
		add_action( 'wp_enqueue_scripts', array( $this, 'load_frontend_scripts' ), 98 );
		add_action( 'elementor/editor/after_enqueue_styles', array( $this, 'load_editor_assets' ) );
	}

	/**
	 * Register Frontend Styles
	 */
	public function register_styles() {
		wp_register_style( 'profecient-essential-templates', PROFECIENT_ESSENTIAL_URL . '/assets/css/templates.css', array(), PROFECIENT_ESSENTIAL_VERSION );
	}

	/**
	 * Register Frontend Scripts
	 */
	public function register_scripts() {
		wp_register_script( 'profecient-essential-templates', PROFECIENT_ESSENTIAL_URL . '/assets/js/templates.js', array(), PROFECIENT_ESSENTIAL_VERSION, true );

		wp_localize_script(
			'profecient-essential-templates',
			'post_config',
			array(
				'jkit_template' => get_post_meta( get_the_ID(), 'jkit-template-type', true ),
			)
		);
	}

	/**
	 * Load frontend assets
	 */
	public function load_frontend_assets() {
		wp_enqueue_style( 'profecient-essential-elementor-widgets', PROFECIENT_ESSENTIAL_URL . '/assets/css/widgets.css', array(), PROFECIENT_ESSENTIAL_VERSION );
	}

	/**
	 * Load Frontend Scripts
	 */
	public function load_frontend_scripts() {
		wp_register_script( 'profecient-essential-hotspot', PROFECIENT_ESSENTIAL_URL . '/assets/js/widgets/hotspot.js', array( 'elementor-frontend' ), PROFECIENT_ESSENTIAL_VERSION, true );
		wp_register_script( 'profecient-essential-back-to-top', PROFECIENT_ESSENTIAL_URL . '/assets/js/widgets/back-to-top.js', array( 'elementor-frontend' ), PROFECIENT_ESSENTIAL_VERSION, true );
		wp_register_script( 'profecient-essential-single-product-images', PROFECIENT_ESSENTIAL_URL . '/assets/js/widgets/single-product-images.js', array( 'elementor-frontend', 'zoom' ), PROFECIENT_ESSENTIAL_VERSION, true );
		wp_register_script( 'profecient-essential-menu-cart', PROFECIENT_ESSENTIAL_URL . '/assets/js/widgets/menu-cart.js', array( 'elementor-frontend' ), PROFECIENT_ESSENTIAL_VERSION, true );
		wp_register_script( 'profecient-essential-account-page', PROFECIENT_ESSENTIAL_URL . '/assets/js/widgets/woocommerce-account-page.js', array( 'elementor-frontend' ), PROFECIENT_ESSENTIAL_VERSION, true );
		wp_register_script( 'profecient-essential-checkout-page', PROFECIENT_ESSENTIAL_URL . '/assets/js/widgets/woocommerce-checkout-page.js', array( 'elementor-frontend' ), PROFECIENT_ESSENTIAL_VERSION, true );
		wp_register_script( 'profecient-essential-timeline', PROFECIENT_ESSENTIAL_URL . '/assets/js/widgets/timeline.js', array( 'elementor-frontend' ), PROFECIENT_ESSENTIAL_VERSION, true );
		wp_register_script( 'profecient-essential-text-marquee', PROFECIENT_ESSENTIAL_URL . '/assets/js/widgets/text-marquee.js', array( 'elementor-frontend' ), PROFECIENT_ESSENTIAL_VERSION, true );
		wp_register_script( 'profecient-essential-horizontal-accordion', PROFECIENT_ESSENTIAL_URL . '/assets/js/widgets/horizontal-accordion.js', array( 'elementor-frontend' ), PROFECIENT_ESSENTIAL_VERSION, true );
		wp_register_script( 'profecient-essential-charts', PROFECIENT_ESSENTIAL_URL . '/assets/js/widgets/charts.js', array( 'elementor-frontend' ), PROFECIENT_ESSENTIAL_VERSION, true );

		wp_register_script( 'profecient-element-pagination', PROFECIENT_ESSENTIAL_URL . '/assets/js/widgets/post-pagination.js', array( 'elementor-frontend' ), PROFECIENT_ESSENTIAL_VERSION, true );
		wp_localize_script( 'profecient-element-pagination', 'profecient_element_pagination_option', $this->localize_script() );

		wp_add_inline_script( 'elementor-frontend', $this->ajax_url() );
	}

	/**
	 * Get Elementor custom settings
	 *
	 * @param string $name custom section name.
	 *
	 * @return array
	 */
	public static function get_elementor_custom_settings( $name, $settings = false ) {
		if ( ! is_array( $settings ) ) {
			$settings = self::get_elementor_page_settings();
		}
		$custom_settings = array();
		foreach ( $settings as $id => $value ) {
			if ( strpos( $id, $name ) !== false ) {
				$custom_settings[ $id ] = $value;
			}
		}

		return $custom_settings;
	}

	/**
	 * Get elementor page settings
	 *
	 * @return array
	 */
	public static function get_elementor_page_settings() {
		$settings = array();
		if ( defined( 'ELEMENTOR_VERSION' ) ) {
			$post_id = get_the_ID();

			$page_settings_manager = \Elementor\Core\Settings\Manager::get_settings_managers( 'page' );

			$page_settings_model = $page_settings_manager->get_model( $post_id );

			$settings = $page_settings_model->get_settings();
		}

		return $settings;
	}

	/**
	 * Load editor assets
	 */
	public function load_editor_assets() {
		wp_enqueue_style( 'profecient-essential-elementor-editor', PROFECIENT_ESSENTIAL_URL . '/assets/css/editor.css', array(), PROFECIENT_ESSENTIAL_VERSION );
	}

	/**
	 * Localize script
	 *
	 * @return array
	 */
	private function localize_script() {
		$option['element_prefix'] = self::$element_ajax_prefix;

		return $option;
	}

	/**
	 * Add ajax URL
	 */
	private function ajax_url() {
		if ( ! is_admin() ) {
			$ajax_url = add_query_arg( array( $this->endpoint => 'profecient_elements' ), esc_url( home_url( '/' ) ) );
			return 'var profecient_ajax_url = "' . esc_url( $ajax_url ) . '", profecient_nonce = "' . profecient_create_global_nonce() . '";';
		}

		return null;
	}
}
