<?php
/**
 * Init class
 *
 * @package profecient-essential
 * @author jegtheme
 * @since 1.0.0
 */

namespace Profecient\Essential;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

use Profecient\Essential\Assets\Asset;
use Profecient\Essential\Dashboard\Dashboard;
use Profecient\Essential\Elementor\Elementor;

class Init {
	/**
	 * Class instance
	 *
	 * @var Init
	 */
	private static $instance;

	/**
	 * Dashboard instance
	 *
	 * @var Dashboard
	 */
	public $dashboard;

	/**
	 * Version
	 *
	 * @var string
	 */
	public $version = '1.0.0';

	/**
	 * Asset instance
	 *
	 * @var Asset
	 */
	public $asset;

	/**
	 * Return class instance
	 *
	 * @return Init
	 */
	public static function instance() {
		if ( null === static::$instance ) {
			static::$instance = new static();
		}

		return static::$instance;
	}

	/**
	 * Class constructor
	 */
	private function __construct() {
		$theme       = wp_get_theme();
		$text_domain = $theme->get( 'TextDomain' );
		$template    = $theme->get( 'Template' );

		if ( 'profecient-theme' === $text_domain || 'profecient-child' === $text_domain || 'profecient-theme' === $template ) {
			$this->setup_init();
		}
	}

	/**
	 * Setup Init
	 */
	private function setup_init() {

		if ( defined( 'ELEMENTOR_VERSION' ) ) {
			Elementor::instance();
		}

		if ( defined( 'JEG_ELEMENTOR_KIT' ) ) {
			JKit\Jeg_Elementor_Kit::instance();
		}

		$this->asset = Asset::instance();
	}
}
