<?php
/**
 * Jeg Elementor Kit Class
 *
 * @package profecient-essential
 * @author jegtheme
 * @since 1.0.3
 */

namespace Profecient\Essential\Elementor\Documents;

use \Elementor\Modules\PageTemplates\Module as Page_Templates_Module;

/**
 * Class Mega Menu
 *
 * @package profecient-essential
 */
class Mega_Menu extends \Elementor\Modules\Library\Documents\Page {
	/**
	 * Get document properties.
	 *
	 * Retrieve the document properties.
	 *
	 * @access public
	 * @static
	 *
	 * @return array Document properties.
	 */
	public static function get_properties() {
		$properties = parent::get_properties();

		$properties['edit_capability']           = 'edit_theme_options';
		$properties['support_kit']               = true;
		$properties['admin_tab_group']           = 'library';
		$properties['show_in_library']           = true;
		$properties['has_elements']              = true;
		$properties['support_wp_page_templates'] = true;
		$properties['support_page_layout']       = true;

		return $properties;
	}

	/**
	 * Get Document Type
	 *
	 * @return string
	 */
	public static function get_type() {
		return 'mega-menu';
	}

	/**
	 * Get Document Title
	 *
	 * @param string
	 */
	public static function get_title() {
		return esc_html__( 'JKit - Mega Menu', 'jeg-elementor-kit' );
	}

	/**
	 * Get Document Site Editor Icon
	 *
	 * @return string
	 */
	protected static function get_site_editor_icon() {
		return 'eicon-error-404';
	}

	/**
	 * Save Document.
	 *
	 * Save an Elementor document.
	 *
	 * @since 1.0.3
	 * @access public
	 *
	 * @param array $data Data.
	 *
	 * @return bool
	 */
	public function save( $data ) {
		// This is for the first time a Landing Page is created. It is done in order to load a new Landing Page with
		// 'Canvas' as the default page template.
		if ( empty( $data['settings']['template'] ) ) {
			$data['settings']['template'] = Page_Templates_Module::TEMPLATE_CANVAS;
		}

		return parent::save( $data );
	}
}
