<?php
/**
 * Jeg Elementor Kit Class
 *
 * @package jeg-elementor-kit
 *
 * @author Jegtheme
 *
 * @since 2.6.1
 */

namespace Profecient\Essential\JKit\Admin\Menu;

use \Elementor\Utils;
use \Elementor\User;
use \Elementor\Plugin;

/**
 * Class Mega Menu
 *
 * @package Jeg\Elementor_Kit
 */
class Mega_Menu {
	/**
	 * JKit Mega Menu Meta Name
	 *
	 * @var string
	 */
	private $meta_name = 'menu_item_jkit_mega_menu';

	/**
	 * Endpoint Path
	 *
	 * @var string
	 */
	const ENDPOINT = 'jeg-elementor-kit/v1/mega-menu';

	/**
	 * Class instance
	 *
	 * @var Mega_Menu
	 */
	private static $instance;

	/**
	 * Class Construct
	 */
	public function __construct() {
		$this->load_hook();
	}

	/**
	 * Load Hook
	 */
	private function load_hook() {
		// if ( apply_filters( 'jkit_load_mega_menu_option', get_option( 'jkit_mega_menu' ) ) ) {
			add_filter( 'jeg_load_form_menu', '__return_true' );
			add_filter( 'jeg_custom_menu_segment', array( $this, 'mega_menu_segment' ) );
			add_filter( 'jeg_custom_menu_field', array( $this, 'mega_menu_field' ), null, 2 );
			add_filter( 'jeg_form_menu_meta_name', array( $this, 'mega_menu_meta_name' ) );

			add_action( 'wp_ajax_jkit_create_mega_menu', array( $this, 'create_mega_menu' ) );
		// }

		add_action( 'elementor/documents/register', array( $this, 'register_document' ) );

		add_action( 'admin_enqueue_scripts', array( $this, 'load_admin_styles' ) );
	}

	/**
	 * Load Admin Styles
	 *
	 * @param string $page The current admin page.
	 */
	public function load_admin_styles( $page ) {
		if ( $page === 'nav-menus.php' ) {
			// wp_enqueue_style( 'nav-menus-page', JEG_ELEMENTOR_KIT_URL . '/assets/css/admin/nav-menu.css', array(), JEG_ELEMENTOR_KIT_VERSION );
			wp_enqueue_script( 'profecient-admin-menus', PROFECIENT_ESSENTIAL_URL . '/assets/js/admin/menus.js', array(), PROFECIENT_ESSENTIAL_VERSION, true );
		}
	}

	/**
	 * Set Demos
	 */
	public function create_mega_menu() {
		$post_type     = 'elementor_library';
		$template_type = 'mega-menu';

		if ( ! User::is_current_user_can_edit_post_type( $post_type ) ) {
			wp_send_json_error( array( 'error' ) );
		}

		$post_data = Utils::get_super_global_value( $_GET, 'post_data' ) ?? array();

		/**
		* Create new post meta data.
		*
		* Filters the meta data of any new post created.
		*
		* @since 2.0.0
		*
		* @param array $meta Post meta data.
		*/
		$meta = array();

		if ( isset( $_GET['meta'] ) && is_array( $_GET['meta'] ) ) {
			$meta = array_map( 'sanitize_text_field', wp_unslash( $_GET['meta'] ) );
		}

		$meta = apply_filters( 'elementor/admin/create_new_post/meta', $meta );

		$post_data['post_type']   = $post_type;
		$post_data['post_status'] = 'publish';
		// $post_data['page_template'] = \Elementor\Modules\PageTemplates\Module::TEMPLATE_CANVAS;

		$document = Plugin::$instance->documents->create( $template_type, $post_data, $meta );

		if ( is_wp_error( $document ) ) {
			wp_die( $document ); // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
		}

		$menu_item_db_id = $_POST['menu_id'];

		$menu_item_meta = get_post_meta( $menu_item_db_id, $this->meta_name, true );

		if ( ! is_array( $menu_item_meta ) ) {
			$menu_item_meta = array();
		}

		$menu_item_meta['jkit_mega_menu'] = $document->get_main_id();
		update_post_meta( $menu_item_db_id, $this->meta_name, $menu_item_meta );
		update_post_meta( $menu_item_meta['jkit_mega_menu'], '_wp_page_template', \Elementor\Modules\PageTemplates\Module::TEMPLATE_CANVAS );

		wp_send_json_success(
			array(
				'edit_url'    => $document->get_edit_url(),
				'template_id' => $document->get_main_id(),
			)
		);
	}

	/**
	 * Register Elementor Documents
	 */
	public function register_document( $documents_manager ) {
		$document_list = array(
			'mega-menu' => \Profecient\Essential\Elementor\Documents\Mega_Menu::get_class_full_name(),
		);

		foreach ( $document_list as $type => $class_name ) {
			$documents_manager->register_document_type( $type, $class_name );
		}
	}

	/**
	 * Class Instance
	 */
	public static function instance() {
		if ( null === static::$instance ) {
			static::$instance = new static();
		}

		return static::$instance;
	}

	/**
	 * Get JKit Mega Menu Meta Name
	 *
	 * @return string
	 */
	public function mega_menu_meta_name() {
		return $this->meta_name;
	}

	/**
	 * Add Mega Menu Segment
	 *
	 * @param array $segment Menu Segment.
	 *
	 * @return array
	 */
	public function mega_menu_segment( $segment ) {
		$segment[] = array(
			'id'   => 'jkit-mega-menu',
			'name' => esc_html__( 'JKit - Mega Menu', 'jeg-elementor-kit' ),
		);

		return $segment;
	}

	/**
	 * Get Option Value
	 *
	 * @param string $id ID Option.
	 * @param mixed  $value Value of Option.
	 * @param mixed  $default Default Value of Option.
	 */
	public function get_option_value( $id, $value, $default ) {
		return isset( $value[ $id ] ) ? $value[ $id ] : $default;
	}

	/**
	 * Add Mega Menu Fields
	 */
	public function mega_menu_field( $fields, $value ) {
		$fields['jkit_mega_menu'] = array(
			'segment'     => 'jkit-mega-menu',
			'type'        => 'select',
			'title'       => esc_html__( 'Select Mega Menu', 'jeg-elementor-kit' ),
			'description' => sprintf(
				/* Translators: 1: Tag a open 2: Tag a close */
				esc_html__( 'Please choose which Mega Menu template you\'d like to use. If no options are displayed, please create one first in Elementor Templates or %1$sclick this link%2$s.', 'jeg-elementor-kit' ),
				'<a href="#" class="jkit jkit-create-mega-menu-template" onClick="return window.megaMenu(this)">',
				'</a>'
			),
			'default'     => '',
			'options'     => call_user_func(
				function () {
					$template = jkit_get_elementor_saved_template_option(
						array(
							'meta_query'  => array(
								array(
									'key'   => '_elementor_template_type',
									'value' => 'mega-menu',
								),
							),
							'post_status' => 'publish',
						)
					);

					$options   = array();
					$options[] = esc_html__( 'Choose Mega Menu', 'jeg-elementor-kit' );

					if ( $template ) {
						foreach ( $template as $key => $value ) {
							$options[ $key ] = $value;
						}
					}

					return $options;
				}
			),
		);

		foreach ( $fields as $key => $field ) {
			$fields[ $key ]['value'] = $this->get_option_value( $key, $value, $field['default'] );
		}

		return $fields;
	}
}
