<?php
/**
 * Ajax class
 *
 * @package profecient-essential
 * @author jegtheme
 * @since 1.0.0
 */

namespace Profecient\Essential\JKit\Ajax;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

use \Jeg\Elementor_Kit\Ajax\Ajax as JKit_Ajax;
use \Jeg\Element\Element as Jeg_Element;
use \Jeg\Elementor_Kit\Elements\Views\View_Abstract;

/**
 * Class Ajax
 */
class Ajax extends JKit_Ajax {
	/**
	 * Class instance
	 *
	 * @var Ajax
	 */
	private static $instance;

	/**
	 * Frontend ajax endpoint
	 *
	 * @var string
	 */
	private $endpoint = 'profecient-ajax-request';

	/**
	 * Block ajax prefix
	 *
	 * @var string
	 */
	public static $element_ajax_prefix = 'profecient_element_ajax_';

	/**
	 * Return class instance
	 *
	 * @return Ajax
	 */
	public static function instance() {
		if ( null === static::$instance ) {
			static::$instance = new static();
		}

		return static::$instance;
	}

	/**
	 * Class constructor
	 */
	private function __construct() {
		$this->setup_init();
		$this->setup_hook();
	}

	/**
	 * Setup Classes
	 */
	private function setup_init() {
		$this->manager = Jeg_Element::instance()->manager;
	}

	/**
	 * Setup Hooks
	 */
	private function setup_hook() {
		add_action( 'parse_request', array( $this, 'element_ajax_parse_request' ) );
		add_filter( 'query_vars', array( $this, 'ajax_query_vars' ) );
	}


	/**
	 * Parse ajax request handler
	 *
	 * @param WP $wp Current WordPress environment instance (passed by reference).
	 */
	public function element_ajax_parse_request( $wp ) {
		if ( array_key_exists( $this->endpoint, $wp->query_vars ) ) {
			add_filter( 'wp_doing_ajax', array( $this, 'is_doing_ajax' ) );

			$action         = $wp->query_vars['action'];
			$element_prefix = self::$element_ajax_prefix;

			if ( 0 === strpos( $action, $element_prefix ) ) {
				$element_name = str_replace( $element_prefix, '', $action );
				$this->element_ajax( $element_name );
			}

			do_action( 'profecient_elements_ajax_' . $action );
			exit;
		}

		if ( $this->manager && isset( $_GET['wc-ajax'] ) ) {
			$instance = $this->manager->get_element_view( 'profecient_woocommerce_menu_cart' );
			$instance->wc_ajax_request();
		}
	}

	/**
	 * Register ajax query vars
	 *
	 * @param  string[] $vars The array of allowed query variable names.
	 * @return array
	 */
	public function ajax_query_vars( $vars ) {
		$vars[] = $this->endpoint;
		$vars[] = 'action';

		return $vars;
	}

	/**
	 * Handle block ajax request
	 *
	 * @param string $element_ajax Element ajax.
	 * @return mixed
	 */
	public function element_ajax( $element_ajax ) {
		$this->element_name_ajax = $element_ajax;
		$instance                = $this->manager->get_element_view( $element_ajax );

		if ( $instance instanceof View_Abstract ) {
			$instance->ajax_request();
		} else {
			return null;
		}
	}
}
