<?php
/**
 * Jeg Elementor Kit Dashboard class
 *
 * @package profecient-essential
 * @author jegtheme
 * @since 1.0.0
 */

namespace Profecient\Essential\JKit\Dashboard;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

use \Jeg\Elementor_Kit\Dashboard\Dashboard as JKitDashboard;

/**
 * Class Dashboard
 *
 * @package profecient-essential
 */
class Dashboard extends JKitDashboard {
	/**
	 * Class instance
	 *
	 * @var Dashboard
	 */
	private static $instance;

	/**
	 * Return class instance
	 *
	 * @return Dashboard
	 */
	public static function instance() {
		if ( null === static::$instance ) {
			static::$instance = new static();
		}

		return static::$instance;
	}

	/**
	 * Class constructor
	 */
	private function __construct() {
		$this->load_hook();
	}

	/**
	 * Load Hook
	 */
	private function load_hook() {
		add_filter( 'jkit_admin_menu', array( $this, 'add_admin_menu' ), 9 );
		add_filter( 'jkit_element_data_clone', array( $this, 'filter_element_data' ), 10, 3 );

		add_filter( 'jkit_template_condition_fields', array( Template\Single_Post::class, 'template_options' ), 10, 3 );
		add_filter( 'jkit_template_condition_fields', array( Template\Single_Product::class, 'template_options' ), 10, 3 );
		add_filter( 'jkit_template_condition_fields', array( Template\Archive_Template::class, 'template_options' ), 10, 3 );
		add_filter( 'jkit_template_condition_fields', array( Template\Popup_Template::class, 'template_options' ), 10, 3 );
	}

	/**
	 * Add Admin Menu in Jeg Elementor Kit
	 *
	 * @return array
	 */
	public function add_admin_menu( $menu ) {
		$menu[] = array(
			'title'    => esc_html__( 'Single Post', 'profecient-essential' ),
			'menu'     => esc_html__( 'Single Post', 'profecient-essential' ),
			'slug'     => Template\Single_Post::$template_slug,
			'action'   => array( $this, 'single_post_template' ),
			'parent'   => JKitDashboard::$templates,
			'priority' => 61.1,
			'class'    => 'jkit-child-menu',
		);

		if ( class_exists( 'WooCommerce' ) ) {
			$menu[] = array(
				'title'    => esc_html__( 'Single Product', 'profecient-essential' ),
				'menu'     => esc_html__( 'Single Product', 'profecient-essential' ),
				'slug'     => Template\Single_Product::$template_slug,
				'action'   => array( $this, 'single_product_template' ),
				'parent'   => JKitDashboard::$templates,
				'priority' => 61.1,
				'class'    => 'jkit-child-menu',
			);
		}

		$menu[] = array(
			'title'    => esc_html__( 'Archive', 'profecient-essential' ),
			'menu'     => esc_html__( 'Archive', 'profecient-essential' ),
			'slug'     => Template\Archive_Template::$template_slug,
			'action'   => array( $this, 'archive_template' ),
			'parent'   => JKitDashboard::$templates,
			'priority' => 61.2,
			'class'    => 'jkit-child-menu',
		);

		$menu[] = array(
			'title'    => esc_html__( 'Popup', 'profecient-essential' ),
			'menu'     => esc_html__( 'Popup', 'profecient-essential' ),
			'slug'     => Template\Popup_Template::$template_slug,
			'action'   => array( $this, 'popup_template' ),
			'parent'   => JKitDashboard::$templates,
			'priority' => 61.3,
			'class'    => 'jkit-child-menu',
		);

		return $menu;
	}

	/**
	 * Filter element data when cloned
	 *
	 * @param array  $value
	 * @param string $type
	 * @param string $page
	 *
	 * @return array
	 */
	public function filter_element_data( $value, $type, $page ) {
		$slugs = array(
			Template\Single_Post::$template_slug,
			Template\Single_Product::$template_slug,
			Template\Archive_Template::$template_slug,
		);

		if ( in_array( $page, $slugs ) ) {
			return jkit_get_element_data( $type, $page );
		}

		return $value;
	}

	/**
	 * Single Post Template
	 */
	public function single_post_template() {
		Template\Single_Post::instance();
	}

	/**
	 * Single Product Template
	 */
	public function single_product_template() {
		Template\Single_Product::instance();
	}

	/**
	 * Single Archive Template
	 */
	public function archive_template() {
		Template\Archive_Template::instance();
	}

	/**
	 * Single Archive Template
	 */
	public function popup_template() {
		Template\Popup_Template::instance();
	}
}
