<?php
/**
 * Jeg Elementor Kit class
 *
 * @package profecient-essential
 * @author Jegtheme
 * @since 1.1.0
 */

namespace Profecient\Essential\JKit\Dashboard\Template;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

use \Jeg\Elementor_Kit\Dashboard\Template\Template_Dashboard_Abstract;
use \Jeg\Elementor_Kit\Dashboard\Dashboard as JKit_Dashboard;

/**
 * Class Popup Template
 *
 * @package profecient-essential
 */
class Popup_Template extends Template_Dashboard_Abstract {
	/**
	 * Template Slug
	 *
	 * @var string
	 */
	public static $template_slug = 'jkit-popup-template';

	/**
	 * Class instance
	 *
	 * @var Popup_Template
	 */
	private static $instance;

	/**
	 * Return class instance
	 *
	 * @return Popup_Template
	 */
	public static function instance() {
		if ( null === static::$instance ) {
			static::$instance = new static();
		}

		return static::$instance;
	}

	/**
	 * Config
	 *
	 * @return array
	 */
	public function config() {
		$config = parent::config();

		$config['data'] = jkit_get_element_data( JKit_Dashboard::$jkit_template, self::$template_slug );
		$config['type'] = JKit_Dashboard::$jkit_template;

		return $config;
	}

	/**
	 * Template deafult title
	 *
	 * @return string
	 */
	public static function default_title() {
		return esc_html__( 'Popup Template', 'profecient-essential' );
	}

	/**
	 * Language
	 *
	 * @return array
	 */
	public function language() {
		return array_merge(
			array(
				'createfirst'         => esc_html__( 'Create Popup Template', 'profecient-essential' ),
				'createdescription'   => esc_html__( 'Add popup template to use them across your website. You can create multiple template and select where to use them.', 'profecient-essential' ),
				'addnewelement'       => esc_html__( 'Add New Template', 'profecient-essential' ),
				'createelement'       => esc_html__( 'Create Popup Template', 'profecient-essential' ),
				'createconditiondesc' => esc_html__( 'Create filter where your popup template will be shown, leave empty to show it everywhere.', 'profecient-essential' ),
				'globalelement'       => esc_html__( 'Global Popup Template', 'profecient-essential' ),
				'manageelement'       => esc_html__( 'Manage Popup Template', 'profecient-essential' ),
				'managedescription'   => esc_html__( 'Drag popup template to change sequence. Smaller sequence will prioritized to shown when criteria match.', 'profecient-essential' ),
				'activeelement'       => esc_html__( 'Active Template', 'profecient-essential' ),
				'inactiveelement'     => esc_html__( 'Inactive Template', 'profecient-essential' ),
				'inactiveelementdesc' => esc_html__( 'Drag the template below to disable the template.', 'profecient-essential' ),
				'deleteelement'       => esc_html__( 'Delete Template', 'profecient-essential' ),
			),
			parent::language()
		);
	}

	/**
	 * Template conditions
	 *
	 * @param array  $fields
	 * @param array  $value
	 * @param string $page
	 *
	 * @return array
	 */
	public static function template_options( $fields, $value = null, $page = null ) {
		if ( $page && self::$template_slug === $page ) {
			$fields['location']['title']   = esc_html__( 'Filter By', 'profecient-essential' );
			$fields['location']['default'] = 'all_site';

			if ( class_exists( 'WooCommerce' ) ) {
				$fields['location']['options']['shop_page']   = esc_html__( 'Shop Page', 'profecient-essential' );
				$fields['location']['options']['product_cat'] = esc_html__( 'Product Categories', 'profecient-essential' );
				$fields['location']['options']['product_tag'] = esc_html__( 'Product Tags', 'profecient-essential' );

				$fields['enclose']['dependency'] = array(
					array(
						'field'    => 'location',
						'operator' => 'not in',
						'value'    => array( '', 'all_site', 'shop_page' ),
					),
				);

				$fields['product_cat'] = array(
					'type'        => 'select',
					'multiple'    => 100,
					'title'       => esc_html__( 'Product Categories', 'profecient-essential' ),
					'description' => esc_html__( 'Write product category name to search.', 'profecient-essential' ),
					'ajax'        => 'jkit_find_taxonomy',
					'slug'        => 'product_cat',
					'nonce'       => jkit_create_global_nonce( 'dashboard' ),
					'options'     => call_user_func(
						function () use ( $value ) {
							if ( isset( $value['product_cat'] ) && $value['product_cat'] ) {
								return self::get_taxonomy_options( $value['product_cat'], false );
							}
						}
					),
					'dependency'  => array(
						array(
							'field'    => 'location',
							'operator' => '===',
							'value'    => 'product_cat',
						),
					),
					'default'     => '',
				);

				$fields['product_tag'] = array(
					'type'        => 'select',
					'multiple'    => 100,
					'title'       => esc_html__( 'Product Tags', 'profecient-essential' ),
					'description' => esc_html__( 'Write product tag name to search.', 'profecient-essential' ),
					'ajax'        => 'jkit_find_taxonomy',
					'slug'        => 'product_tag',
					'nonce'       => jkit_create_global_nonce( 'dashboard' ),
					'options'     => call_user_func(
						function () use ( $value ) {
							if ( isset( $value['product_tag'] ) && $value['product_tag'] ) {
								return self::get_taxonomy_options( $value['product_tag'], false );
							}
						}
					),
					'dependency'  => array(
						array(
							'field'    => 'location',
							'operator' => '===',
							'value'    => 'product_tag',
						),
					),
					'default'     => '',
				);
			}
		}

		return $fields;
	}
}
