<?php
/**
 * Jeg Elementor Kit class
 *
 * @package profecient-essential
 * @author jegtheme
 * @since 1.0.0
 */

namespace Profecient\Essential\JKit\Dashboard\Template;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

use \Jeg\Elementor_Kit\Dashboard\Template\Template_Dashboard_Abstract;
use \Jeg\Elementor_Kit\Dashboard\Dashboard as JKit_Dashboard;

/**
 * Class Single Post
 *
 * @package profecient-essential
 */
class Single_Post extends Template_Dashboard_Abstract {
	/**
	 * Template Slug
	 *
	 * @var string
	 */
	public static $template_slug = 'jkit-single-post';

	/**
	 * Class instance
	 *
	 * @var Single_Post
	 */
	private static $instance;

	/**
	 * Single_Post constructor.
	 */
	public function __construct() {
		parent::__construct();
	}

	/**
	 * Return class instance
	 *
	 * @return Single_Post
	 */
	public static function instance() {
		if ( null === static::$instance ) {
			static::$instance = new static();
		}

		return static::$instance;
	}

	/**
	 * Config
	 *
	 * @return array
	 */
	public function config() {
		$config = parent::config();

		$config['data'] = jkit_get_element_data( JKit_Dashboard::$jkit_template, self::$template_slug );
		$config['type'] = JKit_Dashboard::$jkit_template;

		return $config;
	}

	/**
	 * Template deafult title
	 *
	 * @return string
	 */
	public static function default_title() {
		return esc_html__( 'Single Post Template', 'profecient-essential' );
	}

	/**
	 * Language
	 *
	 * @return array
	 */
	public function language() {
		return array_merge(
			array(
				'createfirst'         => esc_html__( 'Create Single Post Template', 'profecient-essential' ),
				'createdescription'   => esc_html__( 'Add single post template to use them across your website. You can create multiple template and select where to use them.', 'profecient-essential' ),
				'addnewelement'       => esc_html__( 'Add New Template', 'profecient-essential' ),
				'createelement'       => esc_html__( 'Create Single Post', 'profecient-essential' ),
				'createconditiondesc' => esc_html__( 'Create filter where your single post will be shown, leave empty to show it everywhere.', 'profecient-essential' ),
				'globalelement'       => esc_html__( 'Global Single Post', 'profecient-essential' ),
				'manageelement'       => esc_html__( 'Manage Single Post', 'profecient-essential' ),
				'managedescription'   => esc_html__( 'Drag single Post to change sequence. Smaller sequence will prioritized to shown when criteria match.', 'profecient-essential' ),
				'activeelement'       => esc_html__( 'Active Template', 'profecient-essential' ),
				'inactiveelement'     => esc_html__( 'Inactive Template', 'profecient-essential' ),
				'inactiveelementdesc' => esc_html__( 'Drag the template below to disable the template.', 'profecient-essential' ),
				'deleteelement'       => esc_html__( 'Delete Template', 'profecient-essential' ),
			),
			parent::language()
		);
	}

	/**
	 * Template conditions
	 *
	 * @param array  $fields
	 * @param array  $value
	 * @param string $page
	 *
	 * @return array
	 */
	public static function template_options( $fields, $value = null, $page = null ) {
		if ( $page && self::$template_slug === $page ) {
			$fields['location']['title']                  = esc_html__( 'Filter By', 'profecient-essential' );
			$fields['location']['options']['all_site']    = esc_html__( 'All Posts', 'profecient-essential' );
			$fields['location']['options']['post_single'] = esc_html__( 'Single Post', 'profecient-essential' );
			$fields['location']['options']['category']    = esc_html__( 'Post Categories', 'profecient-essential' );
			$fields['location']['options']['post_tag']    = esc_html__( 'Post Tags', 'profecient-essential' );

			unset( $fields['location']['options']['singular'] );
			unset( $fields['location']['options']['archives'] );

			$fields['category'] = array(
				'type'        => 'select',
				'multiple'    => 100,
				'title'       => esc_html__( 'Post Categories', 'profecient-essential' ),
				'description' => esc_html__( 'Write post category name to search.', 'profecient-essential' ),
				'ajax'        => 'jkit_find_taxonomy',
				'slug'        => 'category',
				'nonce'       => jkit_create_global_nonce( 'dashboard' ),
				'options'     => call_user_func(
					function () use ( $value ) {
						if ( isset( $value['category'] ) && $value['category'] ) {
							return parent::get_taxonomy_options( $value['category'], false );
						}
					}
				),
				'dependency'  => array(
					array(
						'field'    => 'location',
						'operator' => '===',
						'value'    => 'category',
					),
				),
				'default'     => '',
			);

			$fields['post_tag'] = array(
				'type'        => 'select',
				'multiple'    => 100,
				'title'       => esc_html__( 'Post Tags', 'profecient-essential' ),
				'description' => esc_html__( 'Write post tag name to search.', 'profecient-essential' ),
				'ajax'        => 'jkit_find_taxonomy',
				'slug'        => 'post_tag',
				'nonce'       => jkit_create_global_nonce( 'dashboard' ),
				'options'     => call_user_func(
					function () use ( $value ) {
						if ( isset( $value['post_tag'] ) && $value['post_tag'] ) {
							return parent::get_taxonomy_options( $value['post_tag'], false );
						}
					}
				),
				'dependency'  => array(
					array(
						'field'    => 'location',
						'operator' => '===',
						'value'    => 'post_tag',
					),
				),
				'default'     => '',
			);

			$fields['singular_post'] = array(
				'type'        => 'select',
				'multiple'    => 100,
				'title'       => esc_html__( 'Include Post', 'profecient-essential' ),
				'description' => esc_html__( 'Write post title to search.', 'profecient-essential' ),
				'ajax'        => 'jkit_find_posts_object',
				'slug'        => 'post',
				'nonce'       => jkit_create_global_nonce( 'dashboard' ),
				'options'     => call_user_func(
					function () use ( $value ) {
						if ( isset( $value['singular_post'] ) && $value['singular_post'] ) {
							return static::get_post_options( $value['singular_post'] );
						}
					}
				),
				'dependency'  => array(
					array(
						'field'    => 'location',
						'operator' => '===',
						'value'    => 'post_single',
					),
				),
				'default'     => '',
			);

		}

		return $fields;
	}
}
