<?php
/**
 * Jeg Elementor Kit class
 *
 * @package profecient-essential
 * @author jegtheme
 * @since 1.0.0
 */

namespace Profecient\Essential\JKit\Dashboard\Template;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

use \Jeg\Elementor_Kit\Dashboard\Template\Template_Dashboard_Abstract;
use \Jeg\Elementor_Kit\Dashboard\Dashboard as JKit_Dashboard;

/**
 * Class Single Product
 *
 * @package profecient-essential
 */
class Single_Product extends Template_Dashboard_Abstract {
	/**
	 * Template Slug
	 *
	 * @var string
	 */
	public static $template_slug = 'jkit-single-product';

	/**
	 * Class instance
	 *
	 * @var Single_Product
	 */
	private static $instance;

	/**
	 * Single_Product constructor.
	 */
	public function __construct() {
		parent::__construct();
	}

	/**
	 * Return class instance
	 *
	 * @return Single_Product
	 */
	public static function instance() {
		if ( null === static::$instance ) {
			static::$instance = new static();
		}

		return static::$instance;
	}

	/**
	 * Load body class for editor
	 *
	 * @param array $classes Classes.
	 *
	 * @return array
	 */
	public static function load_body_class( $classes ) {
		if ( function_exists( 'jkit_is_preview_mode' ) ) {
			if ( jkit_is_preview_mode() || isset( $_REQUEST['preview_nonce'] ) && isset( $_REQUEST['page_id'] ) && wp_verify_nonce( $_REQUEST['preview_nonce'], 'post_preview_' . $_REQUEST['page_id'] ) ) {
				$classes[] = 'woocommerce';
			}
		}
		return $classes;
	}

	/**
	 * Config
	 *
	 * @return array
	 */
	public function config() {
		$config = parent::config();

		$config['data'] = jkit_get_element_data( JKit_Dashboard::$jkit_template, self::$template_slug );
		$config['type'] = JKit_Dashboard::$jkit_template;

		return $config;
	}

	/**
	 * Template deafult title
	 *
	 * @return string
	 */
	public static function default_title() {
		return esc_html__( 'Single Product Template', 'profecient-essential' );
	}

	/**
	 * Language
	 *
	 * @return array
	 */
	public function language() {
		return array_merge(
			array(
				'createfirst'         => esc_html__( 'Create Single Product Template', 'profecient-essential' ),
				'createdescription'   => esc_html__( 'Add single product template to use them across your website. You can create multiple template and select where to use them.', 'profecient-essential' ),
				'addnewelement'       => esc_html__( 'Add New Template', 'profecient-essential' ),
				'createelement'       => esc_html__( 'Create Single Product', 'profecient-essential' ),
				'createconditiondesc' => esc_html__( 'Create filter where your single product will be shown, leave empty to show it everywhere.', 'profecient-essential' ),
				'globalelement'       => esc_html__( 'Global Single Product', 'profecient-essential' ),
				'manageelement'       => esc_html__( 'Manage Single Product', 'profecient-essential' ),
				'managedescription'   => esc_html__( 'Drag single product to change sequence. Smaller sequence will prioritized to shown when criteria match.', 'profecient-essential' ),
				'activeelement'       => esc_html__( 'Active Template', 'profecient-essential' ),
				'inactiveelement'     => esc_html__( 'Inactive Template', 'profecient-essential' ),
				'inactiveelementdesc' => esc_html__( 'Drag the template below to disable the template.', 'profecient-essential' ),
				'deleteelement'       => esc_html__( 'Delete Template', 'profecient-essential' ),
			),
			parent::language()
		);
	}

	/**
	 * Template conditions
	 *
	 * @param array  $fields
	 * @param array  $value
	 * @param string $page
	 *
	 * @return array
	 */
	public static function template_options( $fields, $value = null, $page = null ) {
		if ( $page && self::$template_slug === $page ) {
			$fields['location']['title']                     = esc_html__( 'Filter By', 'profecient-essential' );
			$fields['location']['options']['all_site']       = esc_html__( 'All Products', 'profecient-essential' );
			$fields['location']['options']['product_single'] = esc_html__( 'Single Product', 'profecient-essential' );
			$fields['location']['options']['product_cat']    = esc_html__( 'Product Categories', 'profecient-essential' );
			$fields['location']['options']['product_tag']    = esc_html__( 'Product Tags', 'profecient-essential' );

			unset( $fields['location']['options']['archives'] );
			unset( $fields['location']['options']['singular'] );

			$fields['product_cat'] = array(
				'type'        => 'select',
				'multiple'    => 100,
				'title'       => esc_html__( 'Product Categories', 'profecient-essential' ),
				'description' => esc_html__( 'Write product category name to search.', 'profecient-essential' ),
				'ajax'        => 'jkit_find_taxonomy',
				'slug'        => 'product_cat',
				'nonce'       => jkit_create_global_nonce( 'dashboard' ),
				'options'     => call_user_func(
					function () use ( $value ) {
						if ( isset( $value['product_cat'] ) && $value['product_cat'] ) {
							return parent::get_taxonomy_options( $value['product_cat'], false );
						}
					}
				),
				'dependency'  => array(
					array(
						'field'    => 'location',
						'operator' => '===',
						'value'    => 'product_cat',
					),
				),
				'default'     => '',
			);

			$fields['product_tag'] = array(
				'type'        => 'select',
				'multiple'    => 100,
				'title'       => esc_html__( 'Product Tags', 'profecient-essential' ),
				'description' => esc_html__( 'Write product tag name to search.', 'profecient-essential' ),
				'ajax'        => 'jkit_find_taxonomy',
				'slug'        => 'product_tag',
				'nonce'       => jkit_create_global_nonce( 'dashboard' ),
				'options'     => call_user_func(
					function () use ( $value ) {
						if ( isset( $value['product_tag'] ) && $value['product_tag'] ) {
							return parent::get_taxonomy_options( $value['product_tag'], false );
						}
					}
				),
				'dependency'  => array(
					array(
						'field'    => 'location',
						'operator' => '===',
						'value'    => 'product_tag',
					),
				),
				'default'     => '',
			);

			$fields['product'] = array(
				'type'        => 'select',
				'multiple'    => 100,
				'title'       => esc_html__( 'Insert Products', 'profecient-essential' ),
				'description' => esc_html__( 'Write product title to search.', 'profecient-essential' ),
				'ajax'        => 'jkit_find_posts_object',
				'slug'        => 'product',
				'nonce'       => jkit_create_global_nonce( 'dashboard' ),
				'options'     => call_user_func(
					function () use ( $value ) {
						if ( isset( $value['product'] ) && $value['product'] ) {
							return parent::get_post_options( $value['product'] );
						}
					}
				),
				'dependency'  => array(
					array(
						'field'    => 'location',
						'operator' => '===',
						'value'    => 'product_single',
					),
				),
				'default'     => '',
			);
		}

		return $fields;
	}
}
