<?php
/**
 * Element Class
 *
 * @package profecient-essential
 * @author jegtheme
 * @since 1.0.0
 */

namespace Profecient\Essential\JKit\Elements;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

use Jeg\Elementor_Kit\Elements\Element as JKit_Element;
use Profecient\Essential\Assets\Asset;
use Profecient\Essential\JKit\Elements\Extra_Options;

/**
 * Class Element
 */
class Element extends JKit_Element {
	/**
	 * Class instance
	 *
	 * @var Element
	 */
	private static $instance;

	/**
	 * Get class instance
	 *
	 * @return Element
	 */
	public static function instance() {
		if ( null === static::$instance ) {
			static::$instance = new static();
		}

		return static::$instance;
	}

	/**
	 * Module constructor.
	 */
	private function __construct() {
		$this->setup_hook();
	}

	/**
	 * Setup Hooks
	 */
	private function setup_hook() {
		add_filter( 'jeg_register_elements', array( $this, 'register_element' ) );
		add_filter( 'profecient_register_custom_options', array( $this, 'register_custom_options' ) );
	}

	/**
	 * Register all elements
	 *
	 * @param array $elements Elements.
	 *
	 * @return array
	 */
	public function register_element( $elements ) {
		$element_config = get_option( 'jkit_elements_enable', array() );

		foreach ( $this->list_elements() as $item ) {
			$item_key = 'profecient_' . strtolower( $item );

			if ( ! isset( $element_config[ $item_key ] ) || $element_config[ $item_key ] ) {
				$namespace             = '\Profecient\Essential\JKit\Elements';
				$elements[ $item_key ] = array(
					'option'    => $namespace . '\Options\\' . $item . '_Option',
					'view'      => $namespace . '\Views\\' . $item . '_View',
					'elementor' => $namespace . '\Elementor\\' . $item . '_Elementor',
				);
			}
		}

		return $elements;
	}

	/**
	 * Register all options
	 *
	 * @param array $options Options.
	 * @return array
	 */
	public function register_custom_options( $options ) {
		foreach ( $this->list_options() as $item ) {
			$item_key             = 'profecient_' . strtolower( $item );
			$namespace            = '\Profecient\Essential\JKit\Extra_Option\Options';
			$options[ $item_key ] = array(
				'option' => $namespace . '\\' . $item . '\Module',
			);
		}

		return $options;
	}

	/**
	 * List of elements
	 *
	 * @return array
	 */
	public function list_elements( $elements = array() ) {
		array_push(
			$elements,
			'Hotspot',
			'Timeline',
			'Archive_Title',
			'Archive_Description',
			'Back_To_Top',
			'Text_Background',
			'Breadcrumb',
			'Text_Marquee',
			'Horizontal_Accordion',
			'Charts'
		);
		if ( class_exists( 'WooCommerce' ) ) {
			$woo_elements = array(
				'Product_Custom_Add_To_Cart',
				'Product_Single_Title',
				'Product_Single_Breadcrumb',
				'Product_Single_Images',
				'Product_Single_Price',
				'Product_Single_Rating',
				'Product_Single_Description',
				'Product_Single_Content',
				'Product_Single_Related',
				'Product_Single_Add_To_Cart',
				'Product_Single_Stock',
				'Product_Single_Additional_Information',
				'Product_Single_Meta',
				'Product_Single_Data_Tabs',
				'Product_Archive',
				'Woocommerce_Cart_Page',
				'Woocommerce_Checkout_Page',
				'Woocommerce_Account_Page',
				'Woocommerce_Menu_Cart',
			);
			$elements     = array_merge( $elements, $woo_elements );
		}

		return $elements;
	}

	/**
	 * Register all options
	 */
	public function list_options( $options = array() ) {
		array_push(
			$options,
			// 'Sample_Option',
			'Custom_Cursor',
			'Blend_Mode',
			'Smooth_Scroll',
			'Parallax_Effects',
			'Mouse_Effects',
			'Background_Motion_Effects',
			'Background_Parallax',
			'Background_Mouse_Effects',
		);

		return $options;
	}
}
