<?php
/**
 * Archive Description Option Class
 *
 * @package profecient-essential
 * @author jegtheme
 * @since 1.0.0
 */

namespace Profecient\Essential\JKit\Elements\Options;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

use \Jeg\Elementor_Kit\Elements\Options\Option_Abstract;

/**
 * Class Archive_Description_Option
 */
class Archive_Description_Option extends Option_Abstract {
	/**
	 * Show color scheme flag for element.
	 *
	 * @return bool
	 */
	public function show_color_scheme() {
		return false;
	}

	/**
	 * Compatibility column
	 *
	 * @return array
	 */
	public function compatible_column() {
		return array();
	}

	/**
	 * Override function to remove compatible column alert
	 */
	public function set_compatible_column_option() {}

	/**
	 * Element name
	 *
	 * @return string
	 */
	public function get_element_name() {
		return esc_html__( 'Archive Description', 'profecient-essential' );
	}

	/**
	 * Element category
	 *
	 * @return string
	 */
	public function get_category() {
		return esc_html__( 'Profecient - Archive', 'profecient-essential' );
	}

	/**
	 * Element options
	 */
	public function set_options() {
		$this->set_style_option();

		parent::set_options();
	}

	/**
	 * Style segments
	 */
	public function set_style_segment() {
		$this->segments['style_description'] = array(
			'name'      => esc_html__( 'Archive Short Description', 'profecient-essential' ),
			'priority'  => 11,
			'kit_style' => true,
		);

		parent::set_style_segment();
	}

	/**
	 * Add Additional Style.
	 */
	public function additional_style() {
		$this->options['st_description_alignment'] = array(
			'type'       => 'radio',
			'title'      => esc_html__( 'Alignment', 'profecient-essential' ),
			'segment'    => 'style_description',
			'options'    => array(
				'left'    => array(
					'title' => esc_html__( 'Left', 'profecient-essential' ),
					'icon'  => 'fas fa-align-left',
				),
				'center'  => array(
					'title' => esc_html__( 'Center', 'profecient-essential' ),
					'icon'  => 'fas fa-align-center',
				),
				'right'   => array(
					'title' => esc_html__( 'Right', 'profecient-essential' ),
					'icon'  => 'fas fa-align-right',
				),
				'justify' => array(
					'title' => esc_html__( 'Justify', 'profecient-essential' ),
					'icon'  => 'fas fa-align-justify',
				),
			),
			'responsive' => true,
			'default'    => 'left',
			'selectors'  => '.profecient-archive-description',
			'attribute'  => 'text-align',
		);

		$this->options['st_description_typography'] = array(
			'type'      => 'typography',
			'title'     => esc_html__( 'Typography', 'profecient-essential' ),
			'segment'   => 'style_description',
			'selectors' => array(
				'custom' => '{{WRAPPER}} .profecient-archive-description',
			),
		);

		$this->options['st_description_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Color', 'profecient-essential' ),
			'segment'   => 'style_description',
			'selectors' => array(
				'custom' => array(
					'{{WRAPPER}} .profecient-archive-description' => 'color: {{VALUE}};',
				),
			),
		);

		parent::additional_style();
	}
}
