<?php
/**
 * Archive Title Option Class
 *
 * @package profecient-essential
 * @author jegtheme
 * @since 1.0.0
 */

namespace Profecient\Essential\JKit\Elements\Options;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

use \Jeg\Elementor_Kit\Elements\Options\Option_Abstract;

/**
 * Class Archive_Title_Option
 */
class Archive_Title_Option extends Option_Abstract {
	/**
	 * Show color scheme flag for element.
	 *
	 * @return bool
	 */
	public function show_color_scheme() {
		return false;
	}

	/**
	 * Compatibility column
	 *
	 * @return array
	 */
	public function compatible_column() {
		return array();
	}

	/**
	 * Override function to remove compatible column alert
	 */
	public function set_compatible_column_option() {}

	/**
	 * Element name
	 *
	 * @return string
	 */
	public function get_element_name() {
		return esc_html__( 'Archive Title', 'profecient-essential' );
	}

	/**
	 * Element category
	 *
	 * @return string
	 */
	public function get_category() {
		return esc_html__( 'Profecient - Archive', 'profecient-essential' );
	}

	/**
	 * Element options
	 */
	public function set_options() {
		$this->set_style_option();
		$this->set_element_options();

		parent::set_options();
	}

	/**
	 * Style segments
	 */
	public function set_style_segment() {
		$this->segments['style_title'] = array(
			'name'      => esc_html__( 'Archive Title', 'profecient-essential' ),
			'priority'  => 11,
			'kit_style' => true,
		);

		parent::set_style_segment();
	}

	/**
	 * Set element option
	 */
	public function set_element_options() {
		$this->options['sg_title_html_tag'] = array(
			'type'    => 'select',
			'title'   => esc_html__( 'HTML Tag', 'profecient-essential' ),
			'default' => 'h2',
			'segment' => 'segment_title',
			'options' => array(
				'h1'   => 'H1',
				'h2'   => 'H2',
				'h3'   => 'H3',
				'h4'   => 'H4',
				'h5'   => 'H5',
				'h6'   => 'H6',
				'div'  => 'div',
				'span' => 'span',
				'p'    => 'p',
			),
		);

		$this->options['sg_title_link_to'] = array(
			'type'    => 'select',
			'title'   => esc_html__( 'Link To', 'profecient-essential' ),
			'default' => 'none',
			'segment' => 'segment_title',
			'options' => array(
				'none'   => esc_html__( 'None', 'profecient-essential' ),
				'home'   => esc_html__( 'Home URL', 'profecient-essential' ),
				'custom' => esc_html__( 'Custom URL', 'profecient-essential' ),
			),
		);

		$this->options['sg_title_link_to_custom'] = array(
			'type'       => 'link',
			'title'      => esc_html__( 'Link', 'profecient-essential' ),
			'segment'    => 'segment_title',
			'dependency' => array(
				array(
					'field'    => 'sg_title_link_to',
					'operator' => '==',
					'value'    => 'custom',
				),
			),
		);
	}

	/**
	 * Add Additional Style.
	 */
	public function additional_style() {
		$this->options['st_title_margin'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Margin', 'profecient-essential' ),
			'segment'   => 'style_title',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.profecient-archive-title .archive-title',
			'attribute' => 'margin',
		);

		$this->options['st_title_alignment'] = array(
			'type'       => 'radio',
			'title'      => esc_html__( 'Alignment', 'profecient-essential' ),
			'segment'    => 'style_title',
			'options'    => array(
				'left'   => array(
					'title' => esc_html__( 'Left', 'profecient-essential' ),
					'icon'  => 'fas fa-align-left',
				),
				'center' => array(
					'title' => esc_html__( 'Center', 'profecient-essential' ),
					'icon'  => 'fas fa-align-center',
				),
				'right'  => array(
					'title' => esc_html__( 'Right', 'profecient-essential' ),
					'icon'  => 'fas fa-align-right',
				),
			),
			'responsive' => true,
			'default'    => 'left',
			'selectors'  => '.profecient-archive-title',
			'attribute'  => 'text-align',
		);

		$this->options['st_title_typography'] = array(
			'type'      => 'typography',
			'title'     => esc_html__( 'Typography', 'profecient-essential' ),
			'segment'   => 'style_title',
			'selectors' => array(
				'custom' => '{{WRAPPER}} .profecient-archive-title .archive-title, {{WRAPPER}} .profecient-archive-title .archive-title a',
			),
		);

		$this->options['st_title_tabs_start'] = array(
			'type'    => 'control_tabs_start',
			'segment' => 'style_title',
		);

		$this->options['st_title_normal_tab_start'] = array(
			'type'    => 'control_tab_start',
			'title'   => esc_html__( 'Normal', 'profecient-essential' ),
			'segment' => 'style_title',
		);

		$this->options['st_title_normal_background'] = array(
			'type'      => 'background',
			'title'     => esc_html__( 'Normal Background Color', 'profecient-essential' ),
			'segment'   => 'style_title',
			'selectors' => '.profecient-archive-title',
			'options'   => array(
				'classic',
				'gradient',
			),
		);

		$this->options['st_title_normal_color'] = array(
			'type'       => 'color',
			'title'      => esc_html__( 'Normal Color', 'profecient-essential' ),
			'segment'    => 'style_title',
			'responsive' => true,
			'selectors'  => array(
				'custom' => array(
					'{{WRAPPER}} .profecient-archive-title .archive-title, {{WRAPPER}} .profecient-archive-title .archive-title a' => 'color: {{VALUE}};',
				),
			),
		);

		$this->options['st_title_normal_textshadow'] = array(
			'type'      => 'textshadow',
			'title'     => esc_html__( 'Normal Text Shadow', 'profecient-essential' ),
			'segment'   => 'style_title',
			'selectors' => array(
				'custom' => '{{WRAPPER}} .profecient-archive-title .archive-title, {{WRAPPER}} .profecient-archive-title .archive-title a',
			),
		);

		$this->options['st_title_normal_tab_end'] = array(
			'type'    => 'control_tab_end',
			'segment' => 'style_title',
		);

		$this->options['st_title_hover_tab_start'] = array(
			'type'    => 'control_tab_start',
			'title'   => esc_html__( 'Hover', 'profecient-essential' ),
			'segment' => 'style_title',
		);

		$this->options['st_title_hover_background'] = array(
			'type'      => 'background',
			'title'     => esc_html__( 'Hover Background Color', 'profecient-essential' ),
			'segment'   => 'style_title',
			'selectors' => '.profecient-archive-title:hover',
			'options'   => array(
				'classic',
				'gradient',
			),
		);

		$this->options['st_title_hover_color'] = array(
			'type'       => 'color',
			'title'      => esc_html__( 'Hover Color', 'profecient-essential' ),
			'segment'    => 'style_title',
			'responsive' => true,
			'selectors'  => array(
				'custom' => array(
					'{{WRAPPER}} .profecient-archive-title:hover .archive-title, {{WRAPPER}} .profecient-archive-title:hover .archive-title a' => 'color: {{VALUE}};',
				),
			),
		);

		$this->options['st_title_hover_textshadow'] = array(
			'type'      => 'textshadow',
			'title'     => esc_html__( 'Hover Text Shadow', 'profecient-essential' ),
			'segment'   => 'style_title',
			'selectors' => array(
				'custom' => '{{WRAPPER}} .profecient-archive-title:hover .archive-title, {{WRAPPER}} .profecient-archive-title:hover .archive-title a',
			),
		);

		$this->options['st_title_hover_animation'] = array(
			'type'    => 'hoveranimation',
			'title'   => esc_html__( 'Hover Animation', 'profecient-essential' ),
			'segment' => 'style_title',
		);

		$this->options['st_title_hover_tab_end'] = array(
			'type'    => 'control_tab_end',
			'segment' => 'style_title',
		);

		$this->options['st_title_tabs_end'] = array(
			'type'    => 'control_tabs_end',
			'segment' => 'style_title',
		);

		parent::additional_style();
	}
}
