<?php
/**
 * Back To Top Option Class
 *
 * @package profecient-essential
 * @author jegtheme
 * @since 1.0.0
 */

namespace Profecient\Essential\JKit\Elements\Options;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

use \Jeg\Elementor_Kit\Elements\Options\Option_Abstract;

/**
 * Class Back_To_Top_Option
 */
class Back_To_Top_Option extends Option_Abstract {
	/**
	 * Show color scheme flag for element.
	 *
	 * @return bool
	 */
	public function show_color_scheme() {
		return false;
	}

	/**
	 * Compatibility column
	 *
	 * @return array
	 */
	public function compatible_column() {
		return array();
	}

	/**
	 * Override function to remove compatible column alert
	 */
	public function set_compatible_column_option() {}

	/**
	 * Element name
	 *
	 * @return string
	 */
	public function get_element_name() {
		return esc_html__( 'Back To Top', 'profecient-essential' );
	}

	/**
	 * Element category
	 *
	 * @return string
	 */
	public function get_category() {
		return esc_html__( 'Profecient', 'profecient-essential' );
	}

	/**
	 * Element options
	 */
	public function set_options() {
		$this->set_style_option();
		$this->set_element_options();

		parent::set_options();
	}

	/**
	 * Option segments
	 */
	public function set_segments() {
		$this->segments['segment_settings'] = array(
			'name'     => esc_html__( 'Content Settings', 'profecient-essential' ),
			'priority' => 10,
		);

		$this->set_style_segment();
	}

	/**
	 * Style segments
	 */
	public function set_style_segment() {
		$this->segments['style_button'] = array(
			'name'      => esc_html__( 'Button', 'profecient-essential' ),
			'priority'  => 11,
			'kit_style' => true,
		);

		parent::set_style_segment();
	}

	/**
	 * Set element option
	 */
	public function set_element_options() {
		$this->options['sg_settings_icon'] = array(
			'type'    => 'iconpicker',
			'title'   => esc_html__( 'Icon', 'profecient-essential' ),
			'segment' => 'segment_settings',
			'default' => array(
				'value'   => 'far fa-arrow-alt-circle-up',
				'library' => 'fa-regular',
			),
		);

		$this->options['sg_settings_text'] = array(
			'type'    => 'text',
			'title'   => esc_html__( 'Text', 'profecient-essential' ),
			'segment' => 'segment_settings',
			'default' => esc_html__( 'Back to Top', 'profecient-essential' ),
		);

		$this->options['sg_settings_show_on_scrolled'] = array(
			'type'               => 'slider',
			'title'              => esc_html__( 'Show on Scrolled', 'profecient-essential' ),
			'segment'            => 'segment_settings',
			'responsive'         => true,
			'units'              => array( 'px', '%' ),
			'options'            => array(
				'min'  => 0,
				'max'  => 1000,
				'step' => 1,
			),
			'default'            => 20,
			'default_unit'       => '%',
			'frontend_available' => true,
		);
	}

	/**
	 * Add Additional Style.
	 */
	public function additional_style() {
		$this->options['st_button_padding'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Padding', 'profecient-essential' ),
			'segment'   => 'style_button',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.profecient-back-to-top .profecient-back-to-top-button',
			'attribute' => 'padding',
		);

		$this->options['st_button_icon_position'] = array(
			'type'       => 'radio',
			'title'      => esc_html__( 'Icon Position', 'profecient-essential' ),
			'segment'    => 'style_button',
			'default'    => 'row',
			'options'    => array(
				'row'            => array(
					'title' => esc_html__( 'Left', 'profecient-essential' ),
					'icon'  => 'eicon-h-align-left',
				),
				'column'         => array(
					'title' => esc_html__( 'Top', 'profecient-essential' ),
					'icon'  => 'eicon-v-align-top',
				),
				'row-reverse'    => array(
					'title' => esc_html__( 'right', 'profecient-essential' ),
					'icon'  => 'eicon-h-align-right',
				),
				'column-reverse' => array(
					'title' => esc_html__( 'Bottom', 'profecient-essential' ),
					'icon'  => 'eicon-v-align-bottom',
				),
			),
			'responsive' => true,
			'selectors'  => '.profecient-back-to-top .profecient-back-to-top-button',
			'attribute'  => 'flex-direction',
		);

		$this->options['st_button_position_horizontal_orientation'] = array(
			'type'    => 'radio',
			'title'   => esc_html__( 'Horizontal Orientation', 'profecient-essential' ),
			'segment' => 'style_button',
			'options' => array(
				'left'  => array(
					'title' => esc_html__( 'Left', 'profecient-essential' ),
					'icon'  => 'eicon-h-align-left',
				),
				'right' => array(
					'title' => esc_html__( 'Right', 'profecient-essential' ),
					'icon'  => 'eicon-h-align-right',
				),
			),
			'default' => 'right',
			'toggle'  => false,
		);

		$this->options['st_button_position_horizontal_offset'] = array(
			'type'       => 'slider',
			'title'      => esc_html__( 'Offset', 'profecient-essential' ),
			'segment'    => 'style_button',
			'responsive' => true,
			'units'      => array( 'px', '%', 'em' ),
			'options'    => array(
				'min'  => 0,
				'max'  => 100,
				'step' => 1,
			),
			'default'    => 8,
			'selectors'  => array(
				'custom' => array( '{{WRAPPER}} .profecient-back-to-top' => 'left: auto; right: auto; {{st_button_position_horizontal_orientation.VALUE}}: {{SIZE}}{{UNIT}};' ),
			),
		);

		$this->options['st_button_position_vertical_orientation'] = array(
			'type'    => 'radio',
			'title'   => esc_html__( 'Vertical Orientation', 'profecient-essential' ),
			'segment' => 'style_button',
			'options' => array(
				'top'    => array(
					'title' => esc_html__( 'Top', 'profecient-essential' ),
					'icon'  => 'eicon-v-align-top',
				),
				'bottom' => array(
					'title' => esc_html__( 'Bottom', 'profecient-essential' ),
					'icon'  => 'eicon-v-align-bottom',
				),
			),
			'default' => 'bottom',
			'toggle'  => false,
		);

		$this->options['st_button_position_vertical_offset'] = array(
			'type'       => 'slider',
			'title'      => esc_html__( 'Offset', 'profecient-essential' ),
			'segment'    => 'style_button',
			'responsive' => true,
			'units'      => array( 'px', '%', 'em' ),
			'options'    => array(
				'min'  => 0,
				'max'  => 100,
				'step' => 1,
			),
			'default'    => 9,
			'selectors'  => array(
				'custom' => array( '{{WRAPPER}} .profecient-back-to-top' => 'top: auto; bottom: auto; {{st_button_position_vertical_orientation.VALUE}}: {{SIZE}}{{UNIT}};' ),
			),
		);

		$this->options['st_button_typography'] = array(
			'type'      => 'typography',
			'title'     => esc_html__( 'Typography', 'profecient-essential' ),
			'segment'   => 'style_button',
			'selectors' => array(
				'custom' => '{{WRAPPER}} .profecient-back-to-top .profecient-back-to-top-button',
			),
		);

		$this->options['st_button_tabs_start'] = array(
			'type'    => 'control_tabs_start',
			'segment' => 'style_button',
		);

		$this->options['st_button_normal_tab_start'] = array(
			'type'    => 'control_tab_start',
			'title'   => esc_html__( 'Normal', 'profecient-essential' ),
			'segment' => 'style_button',
		);

		$this->options['st_button_normal_color'] = array(
			'type'       => 'color',
			'title'      => esc_html__( 'Color', 'profecient-essential' ),
			'segment'    => 'style_button',
			'responsive' => true,
			'selectors'  => array(
				'custom' => array(
					'{{WRAPPER}} .profecient-back-to-top .profecient-back-to-top-button' => 'color: {{VALUE}};',
				),
			),
		);

		$this->options['st_button_normal_background'] = array(
			'type'      => 'background',
			'title'     => esc_html__( 'Background Color', 'profecient-essential' ),
			'segment'   => 'style_button',
			'selectors' => '.profecient-back-to-top .profecient-back-to-top-button',
			'options'   => array(
				'classic',
				'gradient',
			),
		);

		$this->options['st_button_normal_border'] = array(
			'type'      => 'border',
			'title'     => esc_html__( 'Border', 'profecient-essential' ),
			'segment'   => 'style_button',
			'selectors' => '.profecient-back-to-top .profecient-back-to-top-button',
		);

		$this->options['st_button_normal_border_radius'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Border Radius', 'profecient-essential' ),
			'segment'   => 'style_button',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.profecient-back-to-top .profecient-back-to-top-button',
			'attribute' => 'border-radius',
		);

		$this->options['st_button_normal_boxshadow'] = array(
			'type'      => 'boxshadow',
			'title'     => esc_html__( 'Box Shadow', 'profecient-essential' ),
			'segment'   => 'style_button',
			'selectors' => array(
				'custom' => '{{WRAPPER}} .profecient-back-to-top .profecient-back-to-top-button',
			),
		);

		$this->options['st_button_normal_tab_end'] = array(
			'type'    => 'control_tab_end',
			'segment' => 'style_button',
		);

		$this->options['st_button_hover_tab_start'] = array(
			'type'    => 'control_tab_start',
			'title'   => esc_html__( 'Hover', 'profecient-essential' ),
			'segment' => 'style_button',
		);

		$this->options['st_button_hover_transition_duration'] = array(
			'type'      => 'slider',
			'title'     => esc_html__( 'Transition Duration', 'profecient-essential' ),
			'segment'   => 'style_button',
			'options'   => array(
				'min'  => 0,
				'max'  => 10,
				'step' => 0.1,
			),
			'selectors' => array(
				'custom' => array(
					'{{WRAPPER}} .profecient-back-to-top .profecient-back-to-top-button' => 'transition-duration: {{SIZE}}s;',
				),
			),
		);

		$this->options['st_button_hover_color'] = array(
			'type'       => 'color',
			'title'      => esc_html__( 'Color', 'profecient-essential' ),
			'segment'    => 'style_button',
			'responsive' => true,
			'selectors'  => array(
				'custom' => array(
					'{{WRAPPER}} .profecient-back-to-top .profecient-back-to-top-button:hover' => 'color: {{VALUE}};',
				),
			),
		);

		$this->options['st_button_hover_background'] = array(
			'type'      => 'background',
			'title'     => esc_html__( 'Background Color', 'profecient-essential' ),
			'segment'   => 'style_button',
			'selectors' => '.profecient-back-to-top .profecient-back-to-top-button:hover',
			'options'   => array(
				'classic',
				'gradient',
			),
		);

		$this->options['st_button_hover_border'] = array(
			'type'      => 'border',
			'title'     => esc_html__( 'Border', 'profecient-essential' ),
			'segment'   => 'style_button',
			'selectors' => '.profecient-back-to-top .profecient-back-to-top-button:hover',
		);

		$this->options['st_button_hover_border_radius'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Border Radius', 'profecient-essential' ),
			'segment'   => 'style_button',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.profecient-back-to-top .profecient-back-to-top-button:hover',
			'attribute' => 'border-radius',
		);

		$this->options['st_button_hover_boxshadow'] = array(
			'type'      => 'boxshadow',
			'title'     => esc_html__( 'Box Shadow', 'profecient-essential' ),
			'segment'   => 'style_button',
			'selectors' => array(
				'custom' => '{{WRAPPER}} .profecient-back-to-top .profecient-back-to-top-button:hover',
			),
		);

		$this->options['st_button_hover_animation'] = array(
			'type'    => 'hoveranimation',
			'title'   => esc_html__( 'Hover Animation', 'profecient-essential' ),
			'segment' => 'style_button',
		);

		$this->options['st_button_hover_tab_end'] = array(
			'type'    => 'control_tab_end',
			'segment' => 'style_button',
		);

		$this->options['st_button_tabs_end'] = array(
			'type'    => 'control_tabs_end',
			'segment' => 'style_button',
		);

		parent::additional_style();
	}
}
