<?php
/**
 * Breadcrumb Option Class
 *
 * @package profecient-essential
 * @author jegtheme
 * @since 1.0.0
 */

namespace Profecient\Essential\JKit\Elements\Options;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

use Jeg\Elementor_Kit\Elements\Options\Option_Abstract;

/**
 * Class Breadcrumb_Option
 */
class Breadcrumb_Option extends Option_Abstract {
	/**
	 * Show color scheme flag for element.
	 *
	 * @return bool
	 */
	public function show_color_scheme() {
		return false;
	}

	/**
	 * Compatibility column
	 *
	 * @return array
	 */
	public function compatible_column() {
		return array();
	}

	/**
	 * Override function to remove compatible column alert
	 */
	public function set_compatible_column_option() {
	}

	/**
	 * Element name
	 *
	 * @return string
	 */
	public function get_element_name() {
		return esc_html__( 'Breadcrumb', 'profecient-essential' );
	}

	/**
	 * Element category
	 *
	 * @return string
	 */
	public function get_category() {
		return esc_html__( 'Profecient', 'profecient-essential' );
	}

	/**
	 * Element options
	 */
	public function set_options() {
		$this->set_style_option();
		$this->set_element_options();

		parent::set_options();
	}

	/**
	 * Option segments
	 */
	public function set_segments() {
		$this->segments['segment_settings'] = array(
			'name'     => esc_html__( 'Settings', 'profecient-essential' ),
			'priority' => 10,
		);

		$this->set_style_segment();
	}

	/**
	 * Style segments
	 */
	public function set_style_segment() {
		$this->segments['style_wrapper'] = array(
			'name'      => esc_html__( 'Wrapper', 'profecient-essential' ),
			'priority'  => 10,
			'kit_style' => true,
		);

		$this->segments['style_crumbs'] = array(
			'name'      => esc_html__( 'Crumbs', 'profecient-essential' ),
			'priority'  => 11,
			'kit_style' => true,
		);

		$this->segments['style_separator'] = array(
			'name'      => esc_html__( 'Separator', 'profecient-essential' ),
			'priority'  => 12,
			'kit_style' => true,
		);

		parent::set_style_segment();
	}

	/**
	 * Set element option
	 */
	public function set_element_options() {
		$this->options['sg_settings_enable_breadcrumb_schema'] = array(
			'type'    => 'checkbox',
			'title'   => esc_html__( 'Breadcrumb Schema', 'profecient-essential' ),
			'segment' => 'segment_settings',
			'default' => 'yes',
		);
	}

	/**
	 * Add Additional Style.
	 */
	public function additional_style() {
		$this->options['st_wrapper_alignment'] = array(
			'type'       => 'radio',
			'title'      => esc_html__( 'Alignment', 'profecient-essential' ),
			'segment'    => 'style_wrapper',
			'options'    => array(
				'flex-start' => array(
					'title' => esc_html__( 'Left', 'profecient-essential' ),
					'icon'  => 'fas fa-align-left',
				),
				'center'     => array(
					'title' => esc_html__( 'Center', 'profecient-essential' ),
					'icon'  => 'fas fa-align-center',
				),
				'flex-end'   => array(
					'title' => esc_html__( 'Right', 'profecient-essential' ),
					'icon'  => 'fas fa-align-right',
				),
			),
			'responsive' => true,
			'default'    => 'left',
			'selectors'  => '.profecient-breadcrumb',
			'attribute'  => 'justify-content',
		);

		$this->options['st_crumb_text_typography'] = array(
			'type'      => 'typography',
			'title'     => esc_html__( 'Text Typography', 'profecient-essential' ),
			'segment'   => 'style_crumbs',
			'selectors' => array(
				'custom' => '{{WRAPPER}} .profecient-breadcrumb span, {{WRAPPER}} .profecient-breadcrumb span a',
			),
		);

		$this->options['st_crumb_text_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Text Color', 'profecient-essential' ),
			'segment'   => 'style_crumbs',
			'selectors' => array(
				'custom' => array(
					'{{WRAPPER}} .profecient-breadcrumb span, {{WRAPPER}} .profecient-breadcrumb span a' => 'color: {{VALUE}};',
				),
			),
		);

		$this->options['st_crumb_text_shadow'] = array(
			'type'      => 'textshadow',
			'title'     => esc_html__( 'Text Shadow', 'profecient-essential' ),
			'segment'   => 'style_crumbs',
			'selectors' => '.profecient-breadcrumb',
		);

		$this->options['st_crumb_tabs_start'] = array(
			'type'    => 'control_tabs_start',
			'segment' => 'style_crumbs',
		);

		$this->options['st_crumb_normal_tab_start'] = array(
			'type'    => 'control_tab_start',
			'title'   => esc_html__( 'Normal', 'profecient-essential' ),
			'segment' => 'style_crumbs',
		);

		$this->options['st_crumb_normal_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Link Color', 'profecient-essential' ),
			'segment'   => 'style_crumbs',
			'selectors' => array(
				'custom' => array(
					'{{WRAPPER}} .profecient-breadcrumb span a' => 'color: {{VALUE}};',
				),
			),
		);

		$this->options['st_crumb_normal_tab_end'] = array(
			'type'    => 'control_tab_end',
			'segment' => 'style_crumbs',
		);

		$this->options['st_crumb_hover_tab_start'] = array(
			'type'    => 'control_tab_start',
			'title'   => esc_html__( 'Hover', 'profecient-essential' ),
			'segment' => 'style_crumbs',
		);

		$this->options['st_crumb_hover_transition_duration'] = array(
			'type'      => 'slider',
			'title'     => esc_html__( 'Transition Duration', 'profecient-essential' ),
			'segment'   => 'style_crumbs',
			'options'   => array(
				'min'  => 0,
				'max'  => 10,
				'step' => 0.1,
			),
			'selectors' => array(
				'custom' => array(
					'{{WRAPPER}} .profecient-breadcrumb span a' => 'transition-duration: {{SIZE}}s;',
				),
			),
		);

		$this->options['st_crumb_hover_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Link Hover Color', 'profecient-essential' ),
			'segment'   => 'style_crumbs',
			'selectors' => array(
				'custom' => array(
					'{{WRAPPER}} .profecient-breadcrumb span:hover a' => 'color: {{VALUE}};',
				),
			),
		);

		$this->options['st_crumb_hover_tab_end'] = array(
			'type'    => 'control_tab_end',
			'segment' => 'style_crumbs',
		);

		$this->options['st_crumb_tabs_end'] = array(
			'type'    => 'control_tabs_end',
			'segment' => 'style_crumbs',
		);

		$this->options['st_separator_size'] = array(
			'type'      => 'slider',
			'title'     => esc_html__( 'Separator Size', 'profecient-essential' ),
			'segment'   => 'style_separator',
			'units'     => array( 'px', 'em', '%', 'rem', 'vw' ),
			'options'   => array(
				'min'  => 0,
				'max'  => 100,
				'step' => 1,
			),
			'selectors' => '.profecient-breadcrumb span > i',
			'attribute' => 'font-size',
		);

		$this->options['st_separator_gap'] = array(
			'type'      => 'slider',
			'title'     => esc_html__( 'Separator Gap', 'profecient-essential' ),
			'segment'   => 'style_separator',
			'units'     => array( 'px', 'em', '%' ),
			'options'   => array(
				'min'  => 0,
				'max'  => 200,
				'step' => 1,
			),
			'selectors' => '.profecient-breadcrumb',
			'attribute' => 'gap',
		);

		$this->options['st_separator_icon'] = array(
			'type'    => 'iconpicker',
			'title'   => esc_html__( 'Separator Icon', 'profecient-essential' ),
			'segment' => 'style_separator',
			'default' => array(
				'value'   => 'jki jki-angle-right-solid',
				'library' => 'jkiticon',
			),
		);

		$this->options['st_separator_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Separator Color', 'profecient-essential' ),
			'segment'   => 'style_separator',
			'selectors' => array(
				'custom' => array(
					'{{WRAPPER}} .profecient-breadcrumb i' => 'color: {{VALUE}};',
				),
			),
		);

		parent::additional_style();
	}
}
