<?php
/**
 * Charts Option Class
 *
 * @package profecient-essential
 * @author jegtheme
 * @since 1.0.0
 */

namespace Profecient\Essential\JKit\Elements\Options;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

use Jeg\Elementor_Kit\Elements\Options\Option_Abstract;
/**
 * Class Charts_Option
 *
 * @package Profecient\Essential\JKit\Elements\Options
 */
class Charts_Option extends Option_Abstract {
	/**
	 * Show color scheme flag for element.
	 *
	 * @return bool
	 */
	public function show_color_scheme() {
		return false;
	}

	/**
	 * Compatibility column
	 *
	 * @return array
	 */
	public function compatible_column() {
		return array();
	}

	/**
	 * Override function to remove compatible column alert
	 */
	public function set_compatible_column_option() {
	}

	/**
	 * Element name
	 *
	 * @return string
	 */
	public function get_element_name() {
		return esc_html__( 'Charts', 'profecient-essential' );
	}

	/**
	 * Element category
	 *
	 * @return string
	 */
	public function get_category() {
		return esc_html__( 'Profecient', 'profecient-essential' );
	}

	/**
	 * Element options
	 */
	public function set_options() {
		$this->set_style_option();
		$this->set_element_options();

		parent::set_options();
	}

	/**
	 * Option segments
	 */
	public function set_segments() {
		$this->segments['segment_charts_type']  = array(
			'name'     => esc_html__( 'Charts Type', 'profecient-essential' ),
			'priority' => 10,
		);
		$this->segments['segment_charts_label'] = array(
			'name'     => esc_html__( 'Charts Label', 'profecient-essential' ),
			'priority' => 11,
		);

		$this->segments['segment_charts_data'] = array(
			'name'     => esc_html__( 'Charts Data', 'profecient-essential' ),
			'priority' => 12,
		);

		$this->set_style_segment();
	}

	/**
	 * Style segments
	 */
	public function set_style_segment() {
		$this->segments['style_background'] = array(
			'name'      => esc_html__( 'Background', 'profecient-essential' ),
			'priority'  => 11,
			'kit_style' => true,
		);

		parent::set_style_segment();
	}

	/**
	 * Set element option
	 */
	public function set_element_options() {
		$this->options['st_chart_typography']       = array(
			'type'           => 'typography',
			'title'          => esc_html__( 'Label Typography', 'profecient-essential' ),
			'segment'        => 'segment_charts_type',
			'fields_options' => array(
				'font_family' => array(
					'render_type' => 'template',
				),
				'font_style'  => array(
					'render_type' => 'template',
				),
				'font_size'   => array(
					'render_type' => 'template',
				),
				'font_weight' => array(
					'render_type' => 'template',
				),
				'line_height' => array(
					'render_type' => 'template',
				),
			),
			'exclude'        => array( 'word_spacing', 'letter_spacing', 'text_decoration', 'text_transform' ),
			'selectors'      => '',
		);
		$this->options['st_chart_typography_color'] = array(
			'type'        => 'color',
			'title'       => esc_html__( 'Label Color', 'profecient-essential' ),
			'segment'     => 'segment_charts_type',
			'render_type' => 'template',
			'selectors'   => '',
		);
		$this->options['sg_chart_type']             = array(
			'type'    => 'select',
			'title'   => esc_html__( 'Chart Type', 'profecient-essential' ),
			'segment' => 'segment_charts_type',
			'default' => 'bar',
			'options' => array(
				'bar'       => esc_html__( 'Bar', 'profecient-essential' ),
				'pie'       => esc_html__( 'Pie', 'profecient-essential' ),
				'doughnut'  => esc_html__( 'Doughnut', 'profecient-essential' ),
				'line'      => esc_html__( 'Line', 'profecient-essential' ),
				'polarArea' => esc_html__( 'Polar Area', 'profecient-essential' ),
				'radar'     => esc_html__( 'Radar', 'profecient-essential' ),
			),
		);
		$this->options['sg_chart_label']            = array(
			'type'        => 'repeater',
			'title'       => esc_html__( 'Chart Label', 'profecient-essential' ),
			'segment'     => 'segment_charts_label',
			'title_field' => '{{ sg_chart_label_title }}',
			'fields'      => array(
				'sg_chart_label_title' => array(
					'type'    => 'text',
					'segment' => 'sg_chart_label',
					'title'   => esc_html__( 'Label', 'profecient-essential' ),
				),
				'st_background_color'  => array(
					'type'        => 'color',
					'title'       => esc_html__( 'Scheme Color', 'profecient-essential' ),
					'segment'     => 'sg_chart_label',
					'render_type' => 'template',
				),
			),
			'default'     => array(
				array(
					'sg_chart_label_title' => esc_html__( 'Year 2010', 'profecient-essential' ),
				),
				array(
					'sg_chart_label_title' => esc_html__( 'Year 2011', 'profecient-essential' ),
				),
				array(
					'sg_chart_label_title' => esc_html__( 'Year 2012', 'profecient-essential' ),
				),
				array(
					'sg_chart_label_title' => esc_html__( 'Year 2013', 'profecient-essential' ),
				),
				array(
					'sg_chart_label_title' => esc_html__( 'Year 2014', 'profecient-essential' ),
				),
				array(
					'sg_chart_label_title' => esc_html__( 'Year 2015', 'profecient-essential' ),
				),
				array(
					'sg_chart_label_title' => esc_html__( 'Year 2016', 'profecient-essential' ),
				),
			),
		);

		$this->options['sg_chart_data'] = array(
			'type'        => 'repeater',
			'title'       => esc_html__( 'Chart Data', 'profecient-essential' ),
			'segment'     => 'segment_charts_data',
			'title_field' => '{{ sg_chart_data_title }}',
			'fields'      => array(
				'sg_chart_data_title'  => array(
					'type'    => 'text',
					'segment' => 'sg_chart_data',
					'title'   => esc_html__( 'Data Label', 'profecient-essential' ),
				),
				'sg_chart_data_segmen' => array(
					'type'    => 'text',
					'segment' => 'sg_chart_data',
					'title'   => esc_html__( 'Data Segmen', 'profecient-essential' ),
				),
				'st_background_clr'    => array(
					'type'        => 'color',
					'title'       => esc_html__( 'Backgroud Color', 'profecient-essential' ),
					'segment'     => 'sg_chart_data',
					'render_type' => 'template',
				),
				'st_border_clr'        => array(
					'type'        => 'color',
					'title'       => esc_html__( 'Border Color', 'profecient-essential' ),
					'segment'     => 'sg_chart_data',
					'render_type' => 'template',
				),
				'st_border_width'      => array(
					'type'        => 'slider',
					'title'       => esc_html__( 'Border Width', 'profecient-essential' ),
					'segment'     => 'sg_chart_data',
					'render_type' => 'template',
					'options'     => array(
						'min'  => 0,
						'max'  => 10,
						'step' => 1,
					),
				),
				'st_border_radius'     => array(
					'type'        => 'slider',
					'title'       => esc_html__( 'Border Radius', 'profecient-essential' ),
					'segment'     => 'sg_chart_data',
					'render_type' => 'template',
					'options'     => array(
						'min'  => 0,
						'max'  => 100,
						'step' => 1,
					),
				),
			),
			'default'     => array(
				array(
					'sg_chart_data_title'  => esc_html__( 'First Data', 'profecient-essential' ),
					'sg_chart_data_segmen' => esc_html__( '10, 20, 15, 25, 22, 30, 28', 'profecient-essential' ),
				),
				array(
					'sg_chart_data_title'  => esc_html__( 'Second Data', 'profecient-essential' ),
					'sg_chart_data_segmen' => esc_html__( '20, 25, 35, 2, 50, 78, 10', 'profecient-essential' ),
				),
			),
		);
	}

	/**
	 * Add Additional Style.
	 */
	public function additional_style() {
		$this->options['st_wrapper_background'] = array(
			'type'      => 'background',
			'title'     => esc_html__( 'Background', 'profecient-essential' ),
			'segment'   => 'style_background',
			'selectors' => '.profecient-essential.profecient-charts',
			'options'   => array(
				'classic',
				'gradient',
			),
		);

		$this->options['st_wrapper_border'] = array(
			'type'      => 'border',
			'title'     => esc_html__( 'Border', 'profecient-essential' ),
			'segment'   => 'style_background',
			'selectors' => '.profecient-essential.profecient-charts',
		);

		$this->options['st_wrapper_border_radius'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Border Radius', 'profecient-essential' ),
			'segment'   => 'style_background',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.profecient-essential.profecient-charts',
			'attribute' => 'border-radius',
		);

		$this->options['st_wrapper_margin'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Margin', 'profecient-essential' ),
			'segment'   => 'style_background',
			'units'     => array( 'px', 'em' ),
			'selectors' => '.profecient-essential.profecient-charts',
			'attribute' => 'margin',
		);

		$this->options['st_wrapper_padding'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Margin', 'profecient-essential' ),
			'segment'   => 'style_background',
			'units'     => array( 'px', 'em' ),
			'selectors' => '.profecient-essential.profecient-charts',
			'attribute' => 'padding',
		);

		$this->options['st_wrapper_boxshadow'] = array(
			'type'      => 'boxshadow',
			'title'     => esc_html__( 'Box Shadow', 'profecient-essential' ),
			'segment'   => 'style_background',
			'selectors' => '.profecient-essential.profecient-charts',
		);

		parent::additional_style();
	}
}
