<?php
/**
 * Horizontal Accordion Option Class
 *
 * @package profecient-essential
 * @author jegtheme
 * @since 1.0.0
 */

namespace Profecient\Essential\JKit\Elements\Options;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

use Jeg\Elementor_Kit\Elements\Options\Option_Abstract;
/**
 * Class Horizontal Accordion_Option
 *
 * @package Profecient\Essential\JKit\Elements\Options
 */
class Horizontal_Accordion_Option extends Option_Abstract {
	/**
	 * Show color scheme flag for element.
	 *
	 * @return bool
	 */
	public function show_color_scheme() {
		return false;
	}

	/**
	 * Compatibility column
	 *
	 * @return array
	 */
	public function compatible_column() {
		return array();
	}

	/**
	 * Override function to remove compatible column alert
	 */
	public function set_compatible_column_option() {
	}

	/**
	 * Element name
	 *
	 * @return string
	 */
	public function get_element_name() {
		return esc_html__( 'Horizontal Accordion', 'profecient-essential' );
	}

	/**
	 * Element category
	 *
	 * @return string
	 */
	public function get_category() {
		return esc_html__( 'Profecient', 'profecient-essential' );
	}

	/**
	 * Element options
	 */
	public function set_options() {
		$this->set_style_option();
		$this->set_element_options();

		parent::set_options();
	}

	/**
	 * Option segments
	 */
	public function set_segments() {
		$this->segments['segment_accordion'] = array(
			'name'     => esc_html__( 'Accordion', 'profecient-essential' ),
			'priority' => 10,
		);

		$this->set_style_segment();
	}

	/**
	 * Style segments
	 */
	public function set_style_segment() {
		$this->segments['style_accordion'] = array(
			'name'      => esc_html__( 'Accordion', 'profecient-essential' ),
			'priority'  => 10,
			'kit_style' => true,
		);
		$this->segments['style_wrapper']   = array(
			'name'      => esc_html__( 'Wrapper', 'profecient-essential' ),
			'priority'  => 11,
			'kit_style' => true,
		);

		$this->segments['style_title'] = array(
			'name'      => esc_html__( 'Title', 'profecient-essential' ),
			'priority'  => 12,
			'kit_style' => true,
		);

		$this->segments['style_title_content'] = array(
			'name'      => esc_html__( 'Title Content', 'profecient-essential' ),
			'priority'  => 13,
			'kit_style' => true,
		);

		$this->segments['style_description'] = array(
			'name'      => esc_html__( 'Description', 'profecient-essential' ),
			'priority'  => 14,
			'kit_style' => true,
		);

		$this->segments['style_button'] = array(
			'name'      => esc_html__( 'Button', 'profecient-essential' ),
			'priority'  => 15,
			'kit_style' => true,
		);

		$this->segments['style_image'] = array(
			'name'      => esc_html__( 'Image', 'profecient-essential' ),
			'priority'  => 16,
			'kit_style' => true,
		);

		$this->segments['style_border'] = array(
			'name'      => esc_html__( 'Border', 'profecient-essential' ),
			'priority'  => 17,
			'kit_style' => true,
		);

		parent::set_style_segment();
	}

	/**
	 * Set element option
	 */
	public function set_element_options() {
		$this->options['sg_accordion_list'] = array(
			'type'        => 'repeater',
			'title'       => esc_html__( 'Content List', 'profecient-essential' ),
			'segment'     => 'segment_accordion',
			'title_field' => '{{ sg_accordion_list_title }}',
			'fields'      => array(
				'sg_accordion_list_title'          => array(
					'type'    => 'text',
					'segment' => 'sg_accordion_list',
					'title'   => esc_html__( 'Title', 'profecient-essential' ),
				),
				'sg_accordion_include_title'       => array(
					'type'    => 'checkbox',
					'segment' => 'sg_accordion_list',
					'title'   => esc_html__( 'Include Title On Content', 'profecient-essential' ),
				),
				'sg_accordion_include_content'     => array(
					'type'    => 'checkbox',
					'segment' => 'sg_accordion_list',
					'default' => true,
					'title'   => esc_html__( 'Add Content Description', 'profecient-essential' ),
				),
				'sg_accordion_list_content'        => array(
					'type'       => 'wysiwyg',
					'segment'    => 'sg_accordion_list',
					'title'      => esc_html__( 'Content Description', 'profecient-essential' ),
					'dependency' => array(
						array(
							'field'    => 'sg_accordion_include_content',
							'operator' => '==',
							'value'    => true,
						),
					),
				),
				'sg_accordion_include_button'      => array(
					'type'    => 'checkbox',
					'segment' => 'sg_accordion_list',
					'title'   => esc_html__( 'Add Button On Content', 'profecient-essential' ),
				),
				'sg_accordion_button_text'         => array(
					'type'       => 'text',
					'segment'    => 'sg_accordion_list',
					'default'    => 'Button',
					'title'      => esc_html__( 'Button Text', 'profecient-essential' ),
					'dependency' => array(
						array(
							'field'    => 'sg_accordion_include_button',
							'operator' => '==',
							'value'    => true,
						),
					),
				),
				'sg_accordion_button_url'          => array(
					'type'       => 'text',
					'segment'    => 'sg_accordion_list',
					'default'    => '#',
					'title'      => esc_html__( 'Button URL', 'profecient-essential' ),
					'dependency' => array(
						array(
							'field'    => 'sg_accordion_include_button',
							'operator' => '==',
							'value'    => true,
						),
					),
				),
				'sg_accordion_button_icon'         => array(
					'type'       => 'iconpicker',
					'segment'    => 'sg_accordion_list',
					'title'      => esc_html__( 'Button Icon', 'profecient-essential' ),
					'dependency' => array(
						array(
							'field'    => 'sg_accordion_include_button',
							'operator' => '==',
							'value'    => true,
						),
					),
				),
				'sg_accordion_button_icon_postion' => array(
					'type'       => 'checkbox',
					'segment'    => 'sg_accordion_list',
					'title'      => esc_html__( 'Swap Button Icon Position', 'profecient-essential' ),
					'dependency' => array(
						array(
							'field'    => 'sg_accordion_include_button',
							'operator' => '==',
							'value'    => true,
						),
					),
				),
				'sg_accordion_button_icon_gap'     => array(
					'type'       => 'slider',
					'segment'    => 'sg_accordion_list',
					'title'      => esc_html__( 'Button Icon Gap', 'profecient-essential' ),
					'options'    => array(
						'min'  => 0,
						'max'  => 50,
						'step' => 1,
					),
					'dependency' => array(
						array(
							'field'    => 'sg_accordion_include_button',
							'operator' => '==',
							'value'    => true,
						),
					),
				),
				'sg_accordion_swap_content'        => array(
					'type'    => 'checkbox',
					'segment' => 'sg_accordion_list',
					'title'   => esc_html__( 'Swap Content Position', 'profecient-essential' ),
				),
				'sg_accordion_include_image'       => array(
					'type'    => 'checkbox',
					'segment' => 'sg_accordion_list',
					'title'   => esc_html__( 'Add Image', 'profecient-essential' ),
				),
				'sg_accordion_image'               => array(
					'type'       => 'image',
					'segment'    => 'sg_accordion_list',
					'title'      => '',
					'default'    => \Elementor\Utils::get_placeholder_image_src(),
					'dependency' => array(
						array(
							'field'    => 'sg_accordion_include_image',
							'operator' => '==',
							'value'    => true,
						),
					),
				),
				'sg_accordion_image_swap'          => array(
					'type'       => 'checkbox',
					'segment'    => 'sg_accordion_list',
					'title'      => esc_html__( 'Swap Image Position', 'profecient-essential' ),
					'dependency' => array(
						array(
							'field'    => 'sg_accordion_include_image',
							'operator' => '==',
							'value'    => true,
						),
					),
				),
			),
			'default'     => array(
				array(
					'sg_accordion_list_title'   => esc_html__( 'Lorem ipsum dolor sit amet', 'profecient-essential' ),
					'sg_accordion_list_content' => esc_html__( 'Lorem ipsum dolor sit amet, consectetuer adipiscing elit. Aenean commodo ligula eget dolor. Aenean massa. Cum sociis natoque penatibus et magnis dis parturient montes, nascetur ridiculus mus. Donec quam felis, ultricies nec, pellentesque eu, pretium quis, sem. Nulla consequat massa quis enim. Donec pede justo, fringilla vel, aliquet nec, vulputate eget, arcu.', 'profecient-essential' ),
				),
				array(
					'sg_accordion_list_title'   => esc_html__( 'Far far away, behind the word mountains', 'profecient-essential' ),
					'sg_accordion_list_content' => esc_html__( 'Lorem ipsum dolor sit amet, consectetuer adipiscing elit. Aenean commodo ligula eget dolor. Aenean massa. Cum sociis natoque penatibus et magnis dis parturient montes, nascetur ridiculus mus. Donec quam felis, ultricies nec, pellentesque eu, pretium quis, sem. Nulla consequat massa quis enim. Donec pede justo, fringilla vel, aliquet nec, vulputate eget, arcu.', 'profecient-essential' ),
				),
				array(
					'sg_accordion_list_title'   => esc_html__( 'The quick, brown fox jumps over a lazy dog', 'profecient-essential' ),
					'sg_accordion_list_content' => esc_html__( 'Lorem ipsum dolor sit amet, consectetuer adipiscing elit. Aenean commodo ligula eget dolor. Aenean massa. Cum sociis natoque penatibus et magnis dis parturient montes, nascetur ridiculus mus. Donec quam felis, ultricies nec, pellentesque eu, pretium quis, sem. Nulla consequat massa quis enim. Donec pede justo, fringilla vel, aliquet nec, vulputate eget, arcu.', 'profecient-essential' ),
				),
			),
		);

		$this->options['sg_accordion_style'] = array(
			'type'    => 'select',
			'title'   => esc_html__( 'Style', 'profecient-essential' ),
			'default' => 'left',
			'segment' => 'segment_accordion',
			'options' => array(
				'right' => esc_html__( 'Right Header', 'profecient-essential' ),
				'left'  => esc_html__( 'Left Header', 'profecient-essential' ),
			),
		);
	}

	/**
	 * Add Additional Style.
	 */
	public function additional_style() {
		$this->options['st_accordion_height'] = array(
			'type'       => 'slider',
			'title'      => esc_html__( 'Horizontal Accordion Height', 'profecient-essential' ),
			'segment'    => 'style_accordion',
			'default'    => 798,
			'options'    => array(
				'min'  => 100,
				'max'  => 4000,
				'step' => 1,
			),
			'responsive' => true,
			'selectors'  => '.profecient.profecient-horizontal-accordion',
			'attribute'  => 'min-height',
		);
		$this->options['st_wrapper_margin']   = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Margin', 'profecient-essential' ),
			'segment'   => 'style_wrapper',
			'units'     => array( 'px', 'em' ),
			'selectors' => '.profecient-essential.profecient-horizontal-accordion.accordion-items-wrapper',
			'attribute' => 'margin',
		);

		$this->options['st_wrapper_open_background'] = array(
			'type'      => 'background',
			'title'     => esc_html__( 'Open Background', 'profecient-essential' ),
			'segment'   => 'style_wrapper',
			'selectors' => '.profecient-essential.profecient-horizontal-accordion .card-wrapper .card-content',
			'options'   => array(
				'classic',
				'gradient',
			),
		);

		$this->options['st_wrapper_open_border'] = array(
			'type'      => 'border',
			'title'     => esc_html__( 'Border', 'profecient-essential' ),
			'segment'   => 'style_wrapper',
			'selectors' => '.profecient-essential.profecient-horizontal-accordion .card-wrapper .card-content',
		);

		$this->options['st_wrapper_open_border_radius'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Border Radius', 'profecient-essential' ),
			'segment'   => 'style_wrapper',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.profecient-essential.profecient-horizontal-accordion .card-wrapper .card-content',
			'attribute' => 'border-radius',
		);

		$this->options['st_wrapper_open_boxshadow'] = array(
			'type'      => 'boxshadow',
			'title'     => esc_html__( 'Box Shadow', 'profecient-essential' ),
			'segment'   => 'style_wrapper',
			'selectors' => '.profecient-essential.profecient-horizontal-accordion .card-wrapper',
		);

		$this->options['st_title_typography'] = array(
			'type'      => 'typography',
			'title'     => esc_html__( 'Typography', 'profecient-essential' ),
			'segment'   => 'style_title',
			'selectors' => '.profecient-essential.profecient-horizontal-accordion .card-wrapper .card-header .title,
			{{WRAPPER}} .profecient-essential.profecient-horizontal-accordion .card-header-responsive .card-header .title',
		);

		$this->options['st_title_alignment'] = array(
			'type'       => 'radio',
			'title'      => esc_html__( 'Alignment', 'profecient-essential' ),
			'segment'    => 'style_title',
			'options'    => array(
				'center'   => array(
					'title' => esc_html__( 'Center', 'profecient-essential' ),
					'icon'  => 'fas fa-grip-lines',
				),
				'baseline' => array(
					'title' => esc_html__( 'Baseline', 'profecient-essential' ),
					'icon'  => 'eicon-v-align-top',
				),
				'end'      => array(
					'title' => esc_html__( 'End', 'profecient-essential' ),
					'icon'  => 'eicon-v-align-bottom',
				),
			),
			'responsive' => true,
			'default'    => 'baseline',
			'selectors'  => '.profecient-essential.profecient-horizontal-accordion .card-wrapper .card-header',
			'attribute'  => 'align-items',
		);

		$this->options['st_title_tabs_start'] = array(
			'type'    => 'control_tabs_start',
			'segment' => 'style_title',
		);

		$this->options['st_title_open_tab_start'] = array(
			'type'    => 'control_tab_start',
			'title'   => esc_html__( 'Open', 'profecient-essential' ),
			'segment' => 'style_title',
		);

		$this->options['st_title_open_color'] = array(
			'type'       => 'color',
			'title'      => esc_html__( 'Open Color', 'profecient-essential' ),
			'segment'    => 'style_title',
			'responsive' => true,
			'selectors'  => '.profecient-essential.profecient-horizontal-accordion .card-wrapper.expand .card-header .card-header-button,
			{{WRAPPER}} .profecient-essential.profecient-horizontal-accordion .card-header-responsive .card-header.expand .card-header-button',
		);

		$this->options['st_title_open_background'] = array(
			'type'      => 'background',
			'title'     => esc_html__( 'Open Background', 'profecient-essential' ),
			'segment'   => 'style_title',
			'selectors' => '.profecient-essential.profecient-horizontal-accordion .card-wrapper.expand .card-header,
			{{WRAPPER}} .profecient-essential.profecient-horizontal-accordion .card-header-responsive .card-header.expand',
			'options'   => array(
				'classic',
				'gradient',
			),
		);

		$this->options['st_title_open_border'] = array(
			'type'      => 'border',
			'title'     => esc_html__( 'Open Border', 'profecient-essential' ),
			'segment'   => 'style_title',
			'selectors' => '.profecient-essential.profecient-horizontal-accordion .card-wrapper.expand .card-header,
			{{WRAPPER}} .profecient-essential.profecient-horizontal-accordion .card-header-responsive .card-header.expand',
		);

		$this->options['st_title_open_border_radius'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Open Border Radius', 'profecient-essential' ),
			'segment'   => 'style_title',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.profecient-essential.profecient-horizontal-accordion .card-wrapper.expand .card-header,
			{{WRAPPER}} .profecient-essential.profecient-horizontal-accordion .card-header-responsive .card-header.expand',
			'attribute' => 'border-radius',
		);

		$this->options['st_title_open_boxshadow'] = array(
			'type'      => 'boxshadow',
			'title'     => esc_html__( 'Open Box Shadow', 'profecient-essential' ),
			'segment'   => 'style_title',
			'selectors' => '.profecient-essential.profecient-horizontal-accordion .card-wrapper.expand .card-header,
			{{WRAPPER}} .profecient-essential.profecient-horizontal-accordion .card-header-responsive .card-header.expand',
		);

		$this->options['st_title_open_margin'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Margin', 'profecient-essential' ),
			'segment'   => 'style_title',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.profecient-essential.profecient-horizontal-accordion .card-wrapper.expand .card-header,
			{{WRAPPER}} .profecient-essential.profecient-horizontal-accordion .card-header-responsive .card-header.expand',
			'attribute' => 'margin',
		);

		$this->options['st_title_open_tab_end'] = array(
			'type'    => 'control_tab_end',
			'segment' => 'style_title',
		);

		$this->options['st_title_close_tab_start'] = array(
			'type'    => 'control_tab_start',
			'title'   => esc_html__( 'Close', 'profecient-essential' ),
			'segment' => 'style_title',
		);

		$this->options['st_title_close_color'] = array(
			'type'       => 'color',
			'title'      => esc_html__( 'Close Color', 'profecient-essential' ),
			'segment'    => 'style_title',
			'responsive' => true,
			'selectors'  => '.profecient-essential.profecient-horizontal-accordion .card-wrapper:not(.expand) .card-header .card-header-button,
			{{WRAPPER}} .profecient-essential.profecient-horizontal-accordion .card-header-responsive .card-header:not(.expand) .card-header-button',

		);

		$this->options['st_title_close_background'] = array(
			'type'      => 'background',
			'title'     => esc_html__( 'Close Background', 'profecient-essential' ),
			'segment'   => 'style_title',
			'selectors' => '.profecient-essential.profecient-horizontal-accordion .card-wrapper:not(.expand) .card-header,
			{{WRAPPER}} .profecient-essential.profecient-horizontal-accordion .card-header-responsive .card-header:not(.expand)',
			'options'   => array(
				'classic',
				'gradient',
			),
		);

		$this->options['st_title_close_border'] = array(
			'type'      => 'border',
			'title'     => esc_html__( 'Close Border', 'profecient-essential' ),
			'segment'   => 'style_title',
			'selectors' => '.profecient-essential.profecient-horizontal-accordion .card-wrapper:not(.expand) .card-header,
			{{WRAPPER}} .profecient-essential.profecient-horizontal-accordion .card-header-responsive .card-header:not(.expand)',
		);

		$this->options['st_title_close_border_radius'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Close Border Radius', 'profecient-essential' ),
			'segment'   => 'style_title',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.profecient-essential.profecient-horizontal-accordion .card-wrapper:not(.expand) .card-header,
			{{WRAPPER}} .profecient-essential.profecient-horizontal-accordion .card-header-responsive .card-header:not(.expand)',
			'attribute' => 'border-radius',
		);

		$this->options['st_title_close_boxshadow'] = array(
			'type'      => 'boxshadow',
			'title'     => esc_html__( 'Close Box Shadow', 'profecient-essential' ),
			'segment'   => 'style_title',
			'selectors' => '.profecient-essential.profecient-horizontal-accordion .card-wrapper:not(.expand) .card-header,
			{{WRAPPER}} .profecient-essential.profecient-horizontal-accordion .card-header-responsive .card-header:not(.expand)',
		);

		$this->options['st_title_close_margin'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Margin', 'profecient-essential' ),
			'segment'   => 'style_title',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.profecient-essential.profecient-horizontal-accordion .card-wrapper:not(.expand) .card-header,
			{{WRAPPER}} .profecient-essential.profecient-horizontal-accordion .card-header-responsive .card-header:not(.expand)',
			'attribute' => 'margin',
		);

		$this->options['st_title_close_tab_end'] = array(
			'type'    => 'control_tab_end',
			'segment' => 'style_title',
		);

		$this->options['st_title_tabs_end'] = array(
			'type'    => 'control_tabs_end',
			'segment' => 'style_title',
		);

		$this->options['st_title_last_border'] = array(
			'type'    => 'checkbox',
			'segment' => 'style_title',
			'title'   => esc_html__( 'Override Last Title Border', 'profecient-essential' ),
		);

		$this->options['st_title_last_tabs_start'] = array(
			'type'       => 'control_tabs_start',
			'segment'    => 'style_title',
			'dependency' => array(
				array(
					'field'    => 'st_title_last_border',
					'operator' => '==',
					'value'    => true,
				),
			),
		);

		$this->options['st_title_last_open_tab_start'] = array(
			'type'       => 'control_tab_start',
			'title'      => esc_html__( 'Open', 'profecient-essential' ),
			'segment'    => 'style_title',
			'dependency' => array(
				array(
					'field'    => 'st_title_last_border',
					'operator' => '==',
					'value'    => true,
				),
			),
		);

		$this->options['st_title_last_open_border_radius'] = array(
			'type'       => 'border',
			'title'      => esc_html__( 'Open Border', 'profecient-essential' ),
			'segment'    => 'style_title',
			'selectors'  => '.profecient-essential.profecient-horizontal-accordion .card-wrapper.expand.last .card-header,
			{{WRAPPER}} .profecient-essential.profecient-horizontal-accordion .card-header-responsive .card-header.expand.last',
			'dependency' => array(
				array(
					'field'    => 'st_title_last_border',
					'operator' => '==',
					'value'    => true,
				),
			),
		);

		$this->options['st_title_last_open_tab_end'] = array(
			'type'       => 'control_tab_end',
			'segment'    => 'style_title',
			'dependency' => array(
				array(
					'field'    => 'st_title_last_border',
					'operator' => '==',
					'value'    => true,
				),
			),
		);

		$this->options['st_title_last_close_tab_start'] = array(
			'type'       => 'control_tab_start',
			'title'      => esc_html__( 'Close', 'profecient-essential' ),
			'segment'    => 'style_title',
			'dependency' => array(
				array(
					'field'    => 'st_title_last_border',
					'operator' => '==',
					'value'    => true,
				),
			),
		);

		$this->options['st_title_last_close_border'] = array(
			'type'       => 'border',
			'title'      => esc_html__( 'Close Border', 'profecient-essential' ),
			'segment'    => 'style_title',
			'selectors'  => '.profecient-essential.profecient-horizontal-accordion .card-wrapper.last:not(.expand) .card-header,
			{{WRAPPER}} .profecient-essential.profecient-horizontal-accordion .card-header-responsive .card-header.last:not(.expand)',
			'dependency' => array(
				array(
					'field'    => 'st_title_last_border',
					'operator' => '==',
					'value'    => true,
				),
			),
		);

		$this->options['st_title_last_close_tab_end'] = array(
			'type'       => 'control_tab_end',
			'segment'    => 'style_title',
			'dependency' => array(
				array(
					'field'    => 'st_title_last_border',
					'operator' => '==',
					'value'    => true,
				),
			),
		);

		$this->options['st_title_last_tabs_end'] = array(
			'type'       => 'control_tabs_end',
			'segment'    => 'style_title',
			'dependency' => array(
				array(
					'field'    => 'st_title_last_border',
					'operator' => '==',
					'value'    => true,
				),
			),
		);

		$this->options['st_title_padding'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Padding', 'profecient-essential' ),
			'segment'   => 'style_title',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.profecient-essential.profecient-horizontal-accordion .card-wrapper .card-header,
			{{WRAPPER}} .profecient-essential.profecient-horizontal-accordion .card-header-responsive .card-header',
			'attribute' => 'padding',
			'separator' => 'before',
		);

		$this->options['st_title_content_typography'] = array(
			'type'      => 'typography',
			'title'     => esc_html__( 'Typography', 'profecient-essential' ),
			'segment'   => 'style_title_content',
			'selectors' => '.profecient-essential.profecient-horizontal-accordion .card-wrapper .card-expand .card-title',
		);

		$this->options['st_title_content_color'] = array(
			'type'       => 'color',
			'title'      => esc_html__( 'Color', 'profecient-essential' ),
			'segment'    => 'style_title_content',
			'responsive' => true,
			'selectors'  => '.profecient-essential.profecient-horizontal-accordion .card-wrapper .card-expand .card-title',
		);

		$this->options['st_title_content_background'] = array(
			'type'      => 'background',
			'title'     => esc_html__( 'Background', 'profecient-essential' ),
			'segment'   => 'style_title_content',
			'selectors' => '.profecient-essential.profecient-horizontal-accordion .card-wrapper .card-expand .card-title',
			'options'   => array(
				'classic',
				'gradient',
			),
		);

		$this->options['st_title_content_border'] = array(
			'type'      => 'border',
			'title'     => esc_html__( 'Border', 'profecient-essential' ),
			'segment'   => 'style_title_content',
			'selectors' => '.profecient-essential.profecient-horizontal-accordion .card-wrapper .card-expand .card-title',
		);

		$this->options['st_title_content_border_radius'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Border Radius', 'profecient-essential' ),
			'segment'   => 'style_title_content',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.profecient-essential.profecient-horizontal-accordion .card-wrapper .card-expand .card-title',
			'attribute' => 'border-radius',
		);

		$this->options['st_title_content_boxshadow'] = array(
			'type'      => 'boxshadow',
			'title'     => esc_html__( 'Box Shadow', 'profecient-essential' ),
			'segment'   => 'style_title_content',
			'selectors' => '.profecient-essential.profecient-horizontal-accordion .card-wrapper .card-expand .card-title',
		);

		$this->options['st_title_content_margin'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Margin', 'profecient-essential' ),
			'segment'   => 'style_title_content',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.profecient-essential.profecient-horizontal-accordion .card-wrapper .card-expand .card-title',
			'attribute' => 'margin',
		);

		$this->options['st_title_content_padding'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Padding', 'profecient-essential' ),
			'segment'   => 'style_title_content',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.profecient-essential.profecient-horizontal-accordion .card-wrapper .card-expand .card-title',
			'attribute' => 'padding',
			'separator' => 'before',
		);

		$this->options['st_description_color'] = array(
			'type'       => 'color',
			'title'      => esc_html__( 'Color', 'profecient-essential' ),
			'segment'    => 'style_description',
			'responsive' => true,
			'selectors'  => '.profecient-essential.profecient-horizontal-accordion .card-expand .card-body',
		);

		$this->options['st_description_typography'] = array(
			'type'      => 'typography',
			'title'     => esc_html__( 'Typography', 'profecient-essential' ),
			'segment'   => 'style_description',
			'selectors' => '.profecient-essential.profecient-horizontal-accordion .card-expand .card-body',
		);

		$this->options['st_description_background'] = array(
			'type'      => 'background',
			'title'     => esc_html__( 'Background', 'profecient-essential' ),
			'segment'   => 'style_description',
			'selectors' => '.profecient-essential.profecient-horizontal-accordion .card-expand .card-body',
			'options'   => array(
				'classic',
				'gradient',
			),
		);

		$this->options['st_description_border'] = array(
			'type'      => 'border',
			'title'     => esc_html__( 'Border', 'profecient-essential' ),
			'segment'   => 'style_description',
			'selectors' => '.profecient-essential.profecient-horizontal-accordion .card-expand .card-body',
		);

		$this->options['st_description_border_radius'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Border Radius', 'profecient-essential' ),
			'segment'   => 'style_description',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.profecient-essential.profecient-horizontal-accordion .card-expand .card-body',
			'attribute' => 'border-radius',
		);

		$this->options['st_description_padding'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Padding', 'profecient-essential' ),
			'segment'   => 'style_description',
			'units'     => array( 'px', 'em' ),
			'selectors' => '.profecient-essential.profecient-horizontal-accordion .card-expand .card-body',
			'attribute' => 'padding',
		);

		$this->options['st_description_open_margin'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Margin', 'profecient-essential' ),
			'segment'   => 'style_description',
			'units'     => array( 'px', 'em' ),
			'selectors' => '.profecient-essential.profecient-horizontal-accordion .card-wrapper .card-expand .card-body',
			'attribute' => 'margin',
		);

		$this->options['st_button_content_typography'] = array(
			'type'      => 'typography',
			'title'     => esc_html__( 'Typography', 'profecient-essential' ),
			'segment'   => 'style_button',
			'selectors' => '.profecient-essential.profecient-horizontal-accordion .card-wrapper .card-expand .card-button',
		);

		$this->options['st_button_tabs_start'] = array(
			'type'    => 'control_tabs_start',
			'segment' => 'style_button',
		);

		$this->options['st_button_normal_tab_start'] = array(
			'type'    => 'control_tab_start',
			'title'   => esc_html__( 'Normal', 'profecient-essential' ),
			'segment' => 'style_button',
		);

		$this->options['st_button_content_color'] = array(
			'type'       => 'color',
			'title'      => esc_html__( 'Color', 'profecient-essential' ),
			'segment'    => 'style_button',
			'responsive' => true,
			'selectors'  => '.profecient-essential.profecient-horizontal-accordion .card-wrapper .card-expand .card-button',
		);

		$this->options['st_button_content_background'] = array(
			'type'      => 'background',
			'title'     => esc_html__( 'Background', 'profecient-essential' ),
			'segment'   => 'style_button',
			'selectors' => '.profecient-essential.profecient-horizontal-accordion .card-wrapper .card-expand .card-button',
			'options'   => array(
				'classic',
				'gradient',
			),
		);

		$this->options['st_button_content_border'] = array(
			'type'      => 'border',
			'title'     => esc_html__( 'Border', 'profecient-essential' ),
			'segment'   => 'style_button',
			'selectors' => '.profecient-essential.profecient-horizontal-accordion .card-wrapper .card-expand .card-button',
		);

		$this->options['st_button_content_border_radius'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Border Radius', 'profecient-essential' ),
			'segment'   => 'style_button',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.profecient-essential.profecient-horizontal-accordion .card-wrapper .card-expand .card-button',
			'attribute' => 'border-radius',
		);

		$this->options['st_button_content_padding'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Padding', 'profecient-essential' ),
			'segment'   => 'style_button',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.profecient-essential.profecient-horizontal-accordion .card-wrapper .card-expand .card-button',
			'attribute' => 'padding',
			'separator' => 'before',
		);

		$this->options['st_button_content_boxshadow'] = array(
			'type'      => 'boxshadow',
			'title'     => esc_html__( 'Box Shadow', 'profecient-essential' ),
			'segment'   => 'style_button',
			'selectors' => '.profecient-essential.profecient-horizontal-accordion .card-wrapper .card-expand .card-button',
		);

		$this->options['st_button_content_margin'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Margin', 'profecient-essential' ),
			'segment'   => 'style_button',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.profecient-essential.profecient-horizontal-accordion .card-wrapper .card-expand .card-button',
			'attribute' => 'margin',
		);

		$this->options['st_button_gap'] = array(
			'type'         => 'slider',
			'title'        => esc_html__( 'Icon gap', 'profecient-essential' ),
			'segment'      => 'style_button',
			'units'        => array( '%', 'px', 'em' ),
			'default_unit' => 'px',
			'options'      => array(
				'min'  => 0,
				'max'  => 50,
				'step' => 1,
			),
			'responsive'   => true,
			'selectors'    => '.profecient-essential.profecient-horizontal-accordion .card-wrapper .card-expand .card-button',
			'attribute'    => 'gap',
		);

		$this->options['st_button_normal_tab_end'] = array(
			'type'    => 'control_tab_end',
			'segment' => 'style_button',
		);

		$this->options['st_button_hover_tab_start'] = array(
			'type'    => 'control_tab_start',
			'title'   => esc_html__( 'Hover', 'profecient-essential' ),
			'segment' => 'style_button',
		);

		$this->options['st_button_hover_content_color'] = array(
			'type'       => 'color',
			'title'      => esc_html__( 'Color', 'profecient-essential' ),
			'segment'    => 'style_button',
			'responsive' => true,
			'selectors'  => '.profecient-essential.profecient-horizontal-accordion .card-wrapper .card-expand .card-button:hover',
		);

		$this->options['st_button_hover_content_background'] = array(
			'type'      => 'background',
			'title'     => esc_html__( 'Background', 'profecient-essential' ),
			'segment'   => 'style_button',
			'selectors' => '.profecient-essential.profecient-horizontal-accordion .card-wrapper .card-expand .card-button:hover',
			'options'   => array(
				'classic',
				'gradient',
			),
		);

		$this->options['st_button_hover_content_border'] = array(
			'type'      => 'border',
			'title'     => esc_html__( 'Border', 'profecient-essential' ),
			'segment'   => 'style_button',
			'selectors' => '.profecient-essential.profecient-horizontal-accordion .card-wrapper .card-expand .card-button:hover',
		);

		$this->options['st_button_hover_content_border_radius'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Border Radius', 'profecient-essential' ),
			'segment'   => 'style_button',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.profecient-essential.profecient-horizontal-accordion .card-wrapper .card-expand .card-button:hover',
			'attribute' => 'border-radius',
		);

		$this->options['st_button_hover_content_padding'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Padding', 'profecient-essential' ),
			'segment'   => 'style_button',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.profecient-essential.profecient-horizontal-accordion .card-wrapper .card-expand .card-button:hover',
			'attribute' => 'padding',
			'separator' => 'before',
		);

		$this->options['st_button_hover_content_boxshadow'] = array(
			'type'      => 'boxshadow',
			'title'     => esc_html__( 'Box Shadow', 'profecient-essential' ),
			'segment'   => 'style_button',
			'selectors' => '.profecient-essential.profecient-horizontal-accordion .card-wrapper .card-expand .card-button:hover',
		);

		$this->options['st_button_hover_content_margin'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Margin', 'profecient-essential' ),
			'segment'   => 'style_button',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.profecient-essential.profecient-horizontal-accordion .card-wrapper .card-expand .card-button:hover',
			'attribute' => 'margin',
		);

		$this->options['st_button_hover_gap'] = array(
			'type'         => 'slider',
			'title'        => esc_html__( 'Icon gap', 'profecient-essential' ),
			'segment'      => 'style_button',
			'units'        => array( '%', 'px', 'em' ),
			'default_unit' => 'px',
			'options'      => array(
				'min'  => 0,
				'max'  => 50,
				'step' => 1,
			),
			'responsive'   => true,
			'selectors'    => '.profecient-essential.profecient-horizontal-accordion .card-wrapper .card-expand .card-button:hover',
			'attribute'    => 'gap',
		);

		$this->options['st_button_hover_tab_end'] = array(
			'type'    => 'control_tab_end',
			'segment' => 'style_button',
		);

		$this->options['st_button_tabs_end'] = array(
			'type'    => 'control_tabs_end',
			'segment' => 'style_button',
		);

		$this->options['st_image_width'] = array(
			'type'         => 'slider',
			'title'        => esc_html__( 'Width', 'profecient-essential' ),
			'segment'      => 'style_image',
			'units'        => array( '%', 'px', 'em' ),
			'default_unit' => '%',
			'options'      => array(
				'min'  => 1,
				'max'  => 100,
				'step' => 1,
			),
			'responsive'   => true,
			'selectors'    => '.profecient-essential.profecient-horizontal-accordion .card-wrapper img',
			'attribute'    => 'width',
		);

		$this->options['st_image_max_width'] = array(
			'type'         => 'slider',
			'title'        => esc_html__( 'Max Width', 'profecient-essential' ),
			'segment'      => 'style_image',
			'units'        => array( '%', 'px', 'em' ),
			'default_unit' => '%',
			'options'      => array(
				'min'  => 1,
				'max'  => 100,
				'step' => 1,
			),
			'responsive'   => true,
			'selectors'    => '.profecient-essential.profecient-horizontal-accordion .card-wrapper img',
			'attribute'    => 'max-width',
		);

		$this->options['st_image_height'] = array(
			'type'         => 'slider',
			'title'        => esc_html__( 'Height', 'profecient-essential' ),
			'segment'      => 'style_image',
			'units'        => array( '%', 'px', 'em' ),
			'default_unit' => 'px',
			'options'      => array(
				'min'  => 1,
				'max'  => 500,
				'step' => 1,
			),
			'responsive'   => true,
			'selectors'    => '.profecient-essential.profecient-horizontal-accordion .card-wrapper img',
			'attribute'    => 'height',
		);

		$this->options['st_image_object_fit'] = array(
			'type'       => 'select',
			'title'      => esc_html__( 'Object Fit', 'profecient-essential' ),
			'segment'    => 'style_image',
			'options'    => array(
				'cover'      => esc_html__( 'Cover', 'profecient-essential' ),
				'contain'    => esc_html__( 'Contain', 'profecient-essential' ),
				'fill'       => esc_html__( 'Fill', 'profecient-essential' ),
				'scale-down' => esc_html__( 'Scale Down', 'profecient-essential' ),
				'none'       => esc_html__( 'None', 'profecient-essential' ),
			),
			'responsive' => true,
			'selectors'  => '.profecient-essential.profecient-horizontal-accordion .card-wrapper img',
			'attribute'  => 'object-fit',
		);

		$this->options['st_image_object_position'] = array(
			'type'       => 'select',
			'title'      => esc_html__( 'Object Position', 'profecient-essential' ),
			'segment'    => 'style_image',
			'options'    => array(
				'center center' => esc_html__( 'Center Center', 'profecient-essential' ),
				'center left'   => esc_html__( 'Center Left', 'profecient-essential' ),
				'center right'  => esc_html__( 'Center Right', 'profecient-essential' ),
				'top center'    => esc_html__( 'Top Center', 'profecient-essential' ),
				'top left'      => esc_html__( 'Top Left', 'profecient-essential' ),
				'top right'     => esc_html__( 'Top Right', 'profecient-essential' ),
				'bottom center' => esc_html__( 'Bottom Center', 'profecient-essential' ),
				'bottom left'   => esc_html__( 'Bottom Left', 'profecient-essential' ),
				'bottom right'  => esc_html__( 'Bottom Right', 'profecient-essential' ),
			),
			'responsive' => true,
			'selectors'  => '.profecient-essential.profecient-horizontal-accordion .card-wrapper img',
			'attribute'  => 'object-position',
			'dependency' => array(
				array(
					'field'    => 'st_image_object_fit_responsive',
					'operator' => '==',
					'value'    => 'cover',
				),
			),
		);

		$this->options['st_image_tabs_start'] = array(
			'type'    => 'control_tabs_start',
			'segment' => 'style_image',
		);

		$this->options['st_image_normal_tab_start'] = array(
			'type'    => 'control_tab_start',
			'title'   => esc_html__( 'Normal', 'profecient-essential' ),
			'segment' => 'style_image',
		);

		$this->options['st_image_opacity_normal'] = array(
			'type'         => 'slider',
			'title'        => esc_html__( 'Opacity', 'profecient-essential' ),
			'segment'      => 'style_image',
			'units'        => array( '%' ),
			'default_unit' => '%',
			'options'      => array(
				'min'  => 0,
				'max'  => 1,
				'step' => 0.1,
			),
			'responsive'   => true,
			'selectors'    => '.profecient-essential.profecient-horizontal-accordion .card-wrapper img',
			'attribute'    => 'opacity',
		);

		$this->options['st_image_filter_css_normal'] = array(
			'type'       => 'css_filter',
			'title'      => esc_html__( 'CSS Filter', 'profecient-essential' ),
			'segment'    => 'style_image',
			'responsive' => true,
			'selectors'  => '.profecient-essential.profecient-horizontal-accordion .card-wrapper img',
		);

		$this->options['st_image_normal_tab_end'] = array(
			'type'    => 'control_tab_end',
			'segment' => 'style_image',
		);

		$this->options['st_image_hover_tab_start'] = array(
			'type'    => 'control_tab_start',
			'title'   => esc_html__( 'Hover', 'profecient-essential' ),
			'segment' => 'style_image',
		);

		$this->options['st_image_opacity_hover'] = array(
			'type'         => 'slider',
			'title'        => esc_html__( 'Opacity', 'profecient-essential' ),
			'segment'      => 'style_image',
			'units'        => array( '%' ),
			'default_unit' => '%',
			'options'      => array(
				'min'  => 0,
				'max'  => 1,
				'step' => 0.1,
			),
			'responsive'   => true,
			'selectors'    => '.profecient-essential.profecient-horizontal-accordion .card-wrapper img:hover',
			'attribute'    => 'opacity',
		);

		$this->options['st_image_filter_css_hover'] = array(
			'type'       => 'css_filter',
			'title'      => esc_html__( 'CSS Filter', 'profecient-essential' ),
			'segment'    => 'style_image',
			'responsive' => true,
			'selectors'  => '.profecient-essential.profecient-horizontal-accordion .card-wrapper img:hover',
		);

		$this->options['st_image_opacity_transition'] = array(
			'type'       => 'slider',
			'title'      => esc_html__( 'Transition Durtation', 'profecient-essential' ),
			'segment'    => 'style_image',
			'options'    => array(
				'min'  => 0,
				'max'  => 5,
				'step' => 0.1,
			),
			'responsive' => true,
			'selectors'  => array(
				'custom' => array(
					'{{WRAPPER}} .profecient-essential.profecient-horizontal-accordion .card-wrapper img'   => 'transition: all {{SIZE}}s ease;',
				),
			),
		);

		$this->options['st_image_hover_tab_end'] = array(
			'type'    => 'control_tab_end',
			'segment' => 'style_image',
		);

		$this->options['st_image_tabs_end'] = array(
			'type'    => 'control_tabs_end',
			'segment' => 'style_image',
		);

		$this->options['st_image_margin'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Margin', 'profecient-essential' ),
			'segment'   => 'style_image',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.profecient-essential.profecient-horizontal-accordion .card-wrapper img',
			'attribute' => 'margin',
		);

		$this->options['st_image_padding'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Padding', 'profecient-essential' ),
			'segment'   => 'style_image',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.profecient-essential.profecient-horizontal-accordion .card-wrapper img',
			'attribute' => 'padding',
			'separator' => 'before',
		);

		$this->options['st_image_border'] = array(
			'type'      => 'border',
			'title'     => esc_html__( 'Border', 'profecient-essential' ),
			'segment'   => 'style_image',
			'selectors' => '.profecient-essential.profecient-horizontal-accordion .card-wrapper img',
		);

		$this->options['st_image_border_radius'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Border Radius', 'profecient-essential' ),
			'segment'   => 'style_image',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.profecient-essential.profecient-horizontal-accordion .card-wrapper img',
			'attribute' => 'border-radius',
		);

		$this->options['st_image_boxshadow'] = array(
			'type'      => 'boxshadow',
			'title'     => esc_html__( 'Box Shadow', 'profecient-essential' ),
			'segment'   => 'style_image',
			'selectors' => '.profecient-essential.profecient-horizontal-accordion .card-wrapper img',
		);

		$this->options['st_border_border'] = array(
			'type'      => 'border',
			'title'     => esc_html__( 'Border', 'profecient-essential' ),
			'segment'   => 'style_border',
			'selectors' => '.profecient-essential.profecient-horizontal-accordion .card-wrapper',
		);

		$this->options['st_border_border_radius'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Border Radius', 'profecient-essential' ),
			'segment'   => 'style_border',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.profecient-essential.profecient-horizontal-accordion .card-wrapper',
			'attribute' => 'border-radius',
		);

		$this->options['st_border_boxshadow'] = array(
			'type'      => 'boxshadow',
			'title'     => esc_html__( 'Box Shadow', 'profecient-essential' ),
			'segment'   => 'style_border',
			'selectors' => '.profecient-essential.profecient-horizontal-accordion .card-wrapper',
		);

		parent::additional_style();
	}
}
