<?php
/**
 * Hotspot Option Class
 *
 * @package profecient-essential
 * @author jegtheme
 * @since 1.0.0
 */

namespace Profecient\Essential\JKit\Elements\Options;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

use Jeg\Elementor_Kit\Elements\Options\Option_Abstract;

/**
 * Class Hotspot_Option
 */
class Hotspot_Option extends Option_Abstract {
	/**
	 * Show color scheme flag for element.
	 *
	 * @return bool
	 */
	public function show_color_scheme() {
		return false;
	}

	/**
	 * Compatibility column
	 *
	 * @return array
	 */
	public function compatible_column() {
		return array();
	}

	/**
	 * Override function to remove compatible column alert
	 */
	public function set_compatible_column_option() {
	}

	/**
	 * Element name
	 *
	 * @return string
	 */
	public function get_element_name() {
		return esc_html__( 'Hotspot', 'profecient-essential' );
	}

	/**
	 * Element category
	 *
	 * @return string
	 */
	public function get_category() {
		return esc_html__( 'Profecient', 'profecient-essential' );
	}

	/**
	 * Element options
	 */
	public function set_options() {
		$this->set_style_option();
		$this->set_element_options();

		parent::set_options();
	}

	/**
	 * Option segments
	 */
	public function set_segments() {
		$this->segments['segment_background'] = array(
			'name'     => esc_html__( 'Background', 'profecient-essential' ),
			'priority' => 10,
		);

		$this->segments['segment_hotspot'] = array(
			'name'     => esc_html__( 'Hotspot', 'profecient-essential' ),
			'priority' => 11,
		);

		$this->segments['segment_tooltip'] = array(
			'name'     => esc_html__( 'Tooltip', 'profecient-essential' ),
			'priority' => 12,
		);

		$this->set_style_segment();
	}

	/**
	 * Style segments
	 */
	public function set_style_segment() {
		$this->segments['style_background'] = array(
			'name'      => esc_html__( 'Background', 'profecient-essential' ),
			'priority'  => 11,
			'kit_style' => true,
		);

		$this->segments['style_hotspot'] = array(
			'name'      => esc_html__( 'Hotspot', 'profecient-essential' ),
			'priority'  => 12,
			'kit_style' => true,
		);

		$this->segments['style_tooltip'] = array(
			'name'      => esc_html__( 'Tooltip', 'profecient-essential' ),
			'priority'  => 13,
			'kit_style' => true,
		);

		parent::set_style_segment();
	}

	/**
	 * Set element option
	 */
	public function set_element_options() {
		/* Background Segment */
		$this->options['sg_background_choose'] = array(
			'type'    => 'image',
			'title'   => esc_html__( 'Choose Image ', 'profecient-essential' ),
			'segment' => 'segment_background',
			'default' => \Elementor\Utils::get_placeholder_image_src(),
		);

		$this->options['sg_background_image_size'] = array(
			'type'    => 'imagesize',
			'title'   => esc_html__( 'Image Size', 'profecient-essential' ),
			'segment' => 'segment_background',
		);

		$this->options['sg_background_image_alignment'] = array(
			'type'       => 'radio',
			'title'      => esc_html__( 'Aligment', 'profecient-essential' ),
			'segment'    => 'segment_background',
			'options'    => array(
				'left'   => array(
					'title' => esc_html__( 'Left', 'profecient-essential' ),
					'icon'  => 'fas fa-align-left',
				),
				'center' => array(
					'title' => esc_html__( 'Center', 'profecient-essential' ),
					'icon'  => 'fas fa-align-center',
				),
				'right'  => array(
					'title' => esc_html__( 'Right', 'profecient-essential' ),
					'icon'  => 'fas fa-align-right',
				),
			),
			'responsive' => true,
			'selectors'  => '.profecient-hotspot-wrapper',
			'attribute'  => 'justify-content',
			'default'    => 'center',
		);

		$this->options['sg_hotspot_item'] = array(
			'type'        => 'repeater',
			'title'       => esc_html__( 'Hotspot', 'profecient-essential' ),
			'segment'     => 'segment_hotspot',
			'title_field' => '{{ sg_hotspot_label }}',
			'fields'      => array(
				'sg_hotspot_text_tabs_start'           => array(
					'type'    => 'control_tabs_start',
					'segment' => 'sg_hotspot_item',
				),
				'sg_hotspot_text_content_tab_start'    => array(
					'type'    => 'control_tab_start',
					'title'   => esc_html__( 'Content', 'profecient-essential' ),
					'segment' => 'sg_hotspot_item',
				),
				'sg_hotspot_label'                     => array(
					'type'    => 'text',
					'title'   => esc_html__( 'Label', 'profecient-essential' ),
					'segment' => 'sg_hotspot_item',
				),
				'sg_hotspot_link'                      => array(
					'type'        => 'link',
					'title'       => esc_html__( 'Link', 'profecient-essential' ),
					'segment'     => 'sg_hotspot_item',
					'placeholder' => 'https://your-links.com/',
				),
				'sg_hotspot_icon'                      => array(
					'type'    => 'radio',
					'title'   => esc_html__( 'Icon', 'profecient-essential' ),
					'segment' => 'sg_hotspot_item',
					'default' => 'icon',
					'options' => array(
						'none' => array(
							'title' => esc_html__( 'None', 'profecient-essential' ),
							'icon'  => 'fas fa-ban',
						),
						'icon' => array(
							'title' => esc_html__( 'Icon', 'profecient-essential' ),
							'icon'  => 'fas fa-icons',
						),
					),
				),
				'sg_hotspot_icon_choose'               => array(
					'type'       => 'iconpicker',
					'title'      => esc_html__( 'Choose Icon', 'profecient-essential' ),
					'default'    => array(
						'value'   => 'fas fa-dot-circle',
						'library' => 'fa-solid',
					),
					'segment'    => 'sg_hotspot_item',
					'dependency' => array(
						array(
							'field'    => 'sg_hotspot_icon',
							'operator' => '==',
							'value'    => 'icon',
						),
					),
				),
				'sg_hotspot_icon_position'             => array(
					'type'       => 'select',
					'title'      => esc_html__( 'Icon Position', 'profecient-essential' ),
					'segment'    => 'sg_hotspot_item',
					'dependency' => array(
						array(
							'field'    => 'sg_hotspot_label!',
							'operator' => '!=',
							'value'    => '',
						),
						array(
							'field'    => 'sg_hotspot_icon',
							'operator' => '==',
							'value'    => 'icon',
						),
					),
					'options'    => array(
						'left'   => esc_html__( 'Left', 'profecient-essential' ),
						'top'    => esc_html__( 'Top', 'profecient-essential' ),
						'right'  => esc_html__( 'Right', 'profecient-essential' ),
						'bottom' => esc_html__( 'Bottom', 'profecient-essential' ),
					),
					'default'    => 'right',
				),
				'sg_hotspot_icon_gap'                  => array(
					'type'       => 'slider',
					'title'      => esc_html__( 'Icon Gap', 'profecient-essential' ),
					'segment'    => 'sg_hotspot_item',
					'dependency' => array(
						array(
							'field'    => 'sg_hotspot_label!',
							'operator' => '!=',
							'value'    => '',
						),
						array(
							'field'    => 'sg_hotspot_icon',
							'operator' => '==',
							'value'    => 'icon',
						),
					),
					'responsive' => true,
					'options'    => array(
						'min'  => 0,
						'max'  => 200,
						'step' => 1,
					),
					'selectors'  => array(
						'custom' => array( '{{WRAPPER}} {{CURRENT_ITEM}} .profecient-hotspot-button' => 'grid-gap: {{SIZE}}{{UNIT}};' ),
					),
				),
				'sg_hotspot_custom_hotspot_size'       => array(
					'type'        => 'checkbox',
					'title'       => esc_html__( 'Custom Hotspot Size', 'profecient-essential' ),
					'description' => esc_html__( 'Set custom Hotspot size.', 'profecient-essential' ),
					'segment'     => 'sg_hotspot_item',
				),
				'sg_hotspot_custom_hotspot_min_width'  => array(
					'type'       => 'slider',
					'title'      => esc_html__( 'Min Width', 'profecient-essential' ),
					'segment'    => 'sg_hotspot_item',
					'dependency' => array(
						array(
							'field'    => 'sg_hotspot_custom_hotspot_size',
							'operator' => '==',
							'value'    => true,
						),
					),
					'responsive' => true,
					'units'      => array( 'px', '%', 'em' ),
					'options'    => array(
						'min'  => 0,
						'max'  => 1000,
						'step' => 1,
					),
					'selectors'  => array(
						'custom' => array(
							'{{WRAPPER}} .profecient-hotspot .profecient-hotspot-container .profecient-hotspot-item{{CURRENT_ITEM}}  .profecient-hotspot-button' => 'min-width: {{SIZE}}{{UNIT}};',
						),
					),
				),
				'sg_hotspot_custom_hotspot_min_height' => array(
					'type'       => 'slider',
					'title'      => esc_html__( 'Min Height', 'profecient-essential' ),
					'segment'    => 'sg_hotspot_item',
					'dependency' => array(
						array(
							'field'    => 'sg_hotspot_custom_hotspot_size',
							'operator' => '==',
							'value'    => true,
						),
					),
					'responsive' => true,
					'units'      => array( 'px', '%', 'em' ),
					'options'    => array(
						'min'  => 0,
						'max'  => 1000,
						'step' => 1,
					),
					'selectors'  => array(
						'custom' => array(
							'{{WRAPPER}} .profecient-hotspot .profecient-hotspot-container .profecient-hotspot-item{{CURRENT_ITEM}}  .profecient-hotspot-button' => 'min-height: {{SIZE}}{{UNIT}};',
						),
					),
				),
				'sg_hotspot_tooltip_content'           => array(
					'type'    => 'wysiwyg',
					'title'   => esc_html__( 'Tooltip Content', 'profecient-essential' ),
					'segment' => 'sg_hotspot_item',
				),
				'sg_hotspot_text_content_tab_end'      => array(
					'type'    => 'control_tab_end',
					'segment' => 'sg_hotspot_item',
				),
				'sg_hotspot_text_position_tab_start'   => array(
					'type'    => 'control_tab_start',
					'title'   => esc_html__( 'Position', 'profecient-essential' ),
					'segment' => 'sg_hotspot_item',
				),
				'sg_hotspot_horizontal_orientation'    => array(
					'type'    => 'select',
					'title'   => esc_html__( 'Horizontal Orientation', 'profecient-essential' ),
					'segment' => 'sg_hotspot_item',
					'options' => array(
						'left'  => esc_html__( 'Left', 'profecient-essential' ),
						'right' => esc_html__( 'Right', 'profecient-essential' ),
					),
					'default' => 'right',
				),
				'sg_hotspot_horizontal_offset'         => array(
					'type'       => 'slider',
					'title'      => esc_html__( 'Offset', 'profecient-essential' ),
					'segment'    => 'sg_hotspot_item',
					'responsive' => true,
					'options'    => array(
						'min'  => 0,
						'max'  => 100,
						'step' => 1,
					),
					'default'    => 50,
					'selectors'  => array(
						'custom' => array( '{{WRAPPER}} {{CURRENT_ITEM}}' => '{{sg_hotspot_horizontal_orientation.VALUE}}: {{SIZE}}%; --profecient-hotspot-translate-x: {{SIZE}}%;' ),
					),
				),
				'sg_hotspot_vertical_orientation'      => array(
					'type'    => 'select',
					'title'   => esc_html__( 'Vertical Orientation', 'profecient-essential' ),
					'segment' => 'sg_hotspot_item',
					'options' => array(
						'top'    => esc_html__( 'Top', 'profecient-essential' ),
						'bottom' => esc_html__( 'Bottom', 'profecient-essential' ),
					),
					'default' => 'top',
				),
				'sg_hotspot_vertical_offset'           => array(
					'type'       => 'slider',
					'title'      => esc_html__( 'Offset', 'profecient-essential' ),
					'segment'    => 'sg_hotspot_item',
					'responsive' => true,
					'options'    => array(
						'min'  => 0,
						'max'  => 100,
						'step' => 1,
					),
					'default'    => 50,
					'selectors'  => array(
						'custom' => array( '{{WRAPPER}} {{CURRENT_ITEM}}' => '{{sg_hotspot_vertical_orientation.VALUE}}: {{SIZE}}%; --profecient-hotspot-translate-y: {{SIZE}}%;' ),
					),
				),
				'sg_hotspot_custom_tooltip_properties' => array(
					'type'        => 'checkbox',
					'title'       => esc_html__( 'Custom Tooltips Properties', 'profecient-essential' ),
					'description' => esc_html__( 'Set custom Tooltip.', 'profecient-essential' ),
					'segment'     => 'sg_hotspot_item',
				),
				'sg_hotspot_custom_tooltip_position'   => array(
					'type'       => 'select',
					'title'      => esc_html__( 'Position', 'profecient-essential' ),
					'segment'    => 'sg_hotspot_item',
					'dependency' => array(
						array(
							'field'    => 'sg_hotspot_custom_tooltip_properties',
							'operator' => '==',
							'value'    => true,
						),
					),
					'options'    => array(
						'left'   => esc_html__( 'Left', 'profecient-essential' ),
						'top'    => esc_html__( 'Top', 'profecient-essential' ),
						'right'  => esc_html__( 'Right', 'profecient-essential' ),
						'bottom' => esc_html__( 'Bottom', 'profecient-essential' ),
					),
					'default'    => 'right',
					'responsive' => true,
				),
				'sg_hotspot_custom_tooltip_min_width'  => array(
					'type'       => 'slider',
					'title'      => esc_html__( 'Min Width', 'profecient-essential' ),
					'segment'    => 'sg_hotspot_item',
					'dependency' => array(
						array(
							'field'    => 'sg_hotspot_custom_tooltip_properties',
							'operator' => '==',
							'value'    => true,
						),
					),
					'responsive' => true,
					'units'      => array( 'px', '%', 'em' ),
					'options'    => array(
						'min'  => 0,
						'max'  => 1000,
						'step' => 1,
					),
					'selectors'  => array(
						'custom' => array(
							'{{WRAPPER}} .profecient-hotspot .profecient-hotspot-container .profecient-hotspot-item{{CURRENT_ITEM}}  .profecient-hotspot-tooltip' => 'min-width: {{SIZE}}{{UNIT}};',
						),
					),
				),
				'sg_hotspot_text_position_tab_end'     => array(
					'type'    => 'control_tab_end',
					'segment' => 'sg_hotspot_item',
				),
			),
			'default'     => array(
				array(
					'sg_hotspot_label' => 'hotspot',
				),
			),
		);

		$this->options['sg_tooltips_position'] = array(
			'type'       => 'select',
			'title'      => 'Position',
			'segment'    => 'segment_tooltip',
			'options'    => array(
				'left'   => esc_html__( 'Left', 'profecient-essential' ),
				'top'    => esc_html__( 'Top', 'profecient-essential' ),
				'right'  => esc_html__( 'Right', 'profecient-essential' ),
				'bottom' => esc_html__( 'Bottom', 'profecient-essential' ),
			),
			'default'    => 'right',
			'responsive' => true,
		);

		$this->options['sg_tooltips_arrow'] = array(
			'type'    => 'checkbox',
			'title'   => esc_html__( 'Arrow', 'profecient-essential' ),
			'segment' => 'segment_tooltip',
			'default' => true,
		);
	}

	/**
	 * Add Additional Style.
	 */
	public function additional_style() {
		$this->options['st_background_width'] = array(
			'type'       => 'slider',
			'title'      => esc_html__( 'Width', 'profecient-essential' ),
			'segment'    => 'style_background',
			'responsive' => true,
			'units'      => array( 'px', '%', 'em' ),
			'options'    => array(
				'min'  => 0,
				'max'  => 1000,
				'step' => 1,
			),
			'selectors'  => '.profecient-hotspot .profecient-hotspot-container > img',
			'attribute'  => 'width',
		);

		$this->options['st_background_max_width'] = array(
			'type'       => 'slider',
			'title'      => esc_html__( 'Max Width', 'profecient-essential' ),
			'segment'    => 'style_background',
			'responsive' => true,
			'units'      => array( 'px', '%', 'em' ),
			'options'    => array(
				'min'  => 0,
				'max'  => 1000,
				'step' => 1,
			),
			'selectors'  => '.profecient-hotspot .profecient-hotspot-container > img',
			'attribute'  => 'max-width',
		);

		$this->options['st_background_height'] = array(
			'type'       => 'slider',
			'title'      => esc_html__( 'Height', 'profecient-essential' ),
			'segment'    => 'style_background',
			'responsive' => true,
			'units'      => array( 'px', '%', 'em' ),
			'options'    => array(
				'min'  => 0,
				'max'  => 1000,
				'step' => 1,
			),
			'selectors'  => '.profecient-hotspot .profecient-hotspot-container > img',
			'attribute'  => 'height',
		);

		$this->options['st_background_tabs_start'] = array(
			'type'    => 'control_tabs_start',
			'segment' => 'style_background',
		);

		$this->options['st_background_normal_tab_start'] = array(
			'type'    => 'control_tab_start',
			'title'   => esc_html__( 'Normal', 'profecient-essential' ),
			'segment' => 'style_background',
		);

		$this->options['st_background_normal_opacity'] = array(
			'type'       => 'slider',
			'title'      => esc_html__( 'Opacity', 'profecient-essential' ),
			'segment'    => 'style_background',
			'responsive' => true,
			'options'    => array(
				'min'  => 0,
				'max'  => 1,
				'step' => 0.01,
			),
			'selectors'  => array(
				'custom' => array(
					'{{WRAPPER}} .profecient-hotspot .profecient-hotspot-container > img' => 'opacity: {{SIZE}};',
				),
			),
		);

		$this->options['st_background_normal_filter_css'] = array(
			'type'       => 'css_filter',
			'title'      => esc_html__( 'CSS Filter', 'profecient-essential' ),
			'segment'    => 'style_background',
			'responsive' => true,
			'selectors'  => '.profecient-hotspot .profecient-hotspot-container > img',
		);

		$this->options['st_background_normal_color'] = array(
			'type'      => 'background',
			'title'     => esc_html__( 'Background Color', 'profecient-essential' ),
			'segment'   => 'style_background',
			'selectors' => '.profecient-hotspot .profecient-hotspot-container > img',
			'options'   => array(
				'classic',
				'gradient',
			),
			'exclude'   => array( 'image' ),
		);

		$this->options['st_background_normal_border_radius'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Border Radius', 'profecient-essential' ),
			'segment'   => 'style_background',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.profecient-hotspot .profecient-hotspot-container > img',
			'attribute' => 'border-radius',
		);

		$this->options['st_background_normal_border'] = array(
			'type'      => 'border',
			'title'     => esc_html__( 'Border', 'profecient-essential' ),
			'segment'   => 'style_background',
			'selectors' => '.profecient-hotspot .profecient-hotspot-container > img',
		);

		$this->options['st_background_normal_boxshadow'] = array(
			'type'      => 'boxshadow',
			'title'     => esc_html__( 'Box Shadow', 'profecient-essential' ),
			'segment'   => 'style_background',
			'selectors' => '.profecient-hotspot .profecient-hotspot-container > img',
		);

		$this->options['st_background_normal_tab_end'] = array(
			'type'    => 'control_tab_end',
			'segment' => 'style_background',
		);

		$this->options['st_background_hover_tab_start'] = array(
			'type'    => 'control_tab_start',
			'title'   => esc_html__( 'Hover', 'profecient-essential' ),
			'segment' => 'style_background',
		);

		$this->options['st_background_hover_transition_duration'] = array(
			'type'      => 'slider',
			'title'     => esc_html__( 'Transition Duration', 'profecient-essential' ),
			'segment'   => 'style_background',
			'options'   => array(
				'min'  => 0,
				'max'  => 10,
				'step' => 0.1,
			),
			'selectors' => array(
				'custom' => array(
					'{{WRAPPER}} .profecient-hotspot .profecient-hotspot-container > img' => 'transition-duration: {{SIZE}}s;',
				),
			),
		);

		$this->options['st_background_hover_opacity'] = array(
			'type'       => 'slider',
			'title'      => esc_html__( 'Opacity', 'profecient-essential' ),
			'segment'    => 'style_background',
			'responsive' => true,
			'options'    => array(
				'min'  => 0,
				'max'  => 1,
				'step' => 0.01,
			),
			'selectors'  => array(
				'custom' => array(
					'{{WRAPPER}} .profecient-hotspot .profecient-hotspot-container:hover > img' => 'opacity: {{SIZE}};',
				),
			),
		);

		$this->options['st_background_hover_filter_css'] = array(
			'type'       => 'css_filter',
			'title'      => esc_html__( 'CSS Filter', 'profecient-essential' ),
			'segment'    => 'style_background',
			'responsive' => true,
			'selectors'  => '.profecient-hotspot .profecient-hotspot-container:hover > img',
		);

		$this->options['st_background_hover_color'] = array(
			'type'      => 'background',
			'title'     => esc_html__( 'Background Color', 'profecient-essential' ),
			'segment'   => 'style_background',
			'selectors' => '.profecient-hotspot .profecient-hotspot-container:hover > img',
			'options'   => array(
				'classic',
				'gradient',
			),
			'exclude'   => array( 'image' ),
		);

		$this->options['st_background_hover_border_radius'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Border Radius', 'profecient-essential' ),
			'segment'   => 'style_background',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.profecient-hotspot .profecient-hotspot-container:hover > img',
			'attribute' => 'border-radius',
		);

		$this->options['st_background_hover_border'] = array(
			'type'      => 'border',
			'title'     => esc_html__( 'Border', 'profecient-essential' ),
			'segment'   => 'style_background',
			'selectors' => '.profecient-hotspot .profecient-hotspot-container:hover > img',
		);

		$this->options['st_background_hover_boxshadow'] = array(
			'type'      => 'boxshadow',
			'title'     => esc_html__( 'Box Shadow', 'profecient-essential' ),
			'segment'   => 'style_background',
			'selectors' => '.profecient-hotspot .profecient-hotspot-container:hover > img',
		);

		$this->options['st_background_hover_tab_end'] = array(
			'type'    => 'control_tab_end',
			'segment' => 'style_background',
		);

		$this->options['st_background_tabs_end'] = array(
			'type'    => 'control_tabs_end',
			'segment' => 'style_background',
		);

		$this->options['st_hotspot_text_heading'] = array(
			'type'    => 'heading',
			'title'   => esc_html__( 'Text', 'profecient-essential' ),
			'segment' => 'style_hotspot',
		);

		$this->options['st_hotspot_text_typography'] = array(
			'type'      => 'typography',
			'title'     => esc_html__( 'Typography', 'profecient-essential' ),
			'segment'   => 'style_hotspot',
			'selectors' => '.profecient-hotspot .profecient-hotspot-container .profecient-hotspot-item .profecient-hotspot-button',
		);

		$this->options['st_hotspot_text_tabs_start'] = array(
			'type'    => 'control_tabs_start',
			'segment' => 'style_hotspot',
		);

		$this->options['st_hotspot_text_normal_tab_start'] = array(
			'type'    => 'control_tab_start',
			'title'   => esc_html__( 'Normal', 'profecient-essential' ),
			'segment' => 'style_hotspot',
		);

		$this->options['st_hotspot_text_normal_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Color', 'profecient-essential' ),
			'segment'   => 'style_hotspot',
			'selectors' => '.profecient-hotspot .profecient-hotspot-container .profecient-hotspot-item .profecient-hotspot-button',
		);

		$this->options['st_hotspot_text_normal_tab_end'] = array(
			'type'    => 'control_tab_end',
			'segment' => 'style_hotspot',
		);

		$this->options['st_hotspot_text_hover_tab_start'] = array(
			'type'    => 'control_tab_start',
			'title'   => esc_html__( 'Hover', 'profecient-essential' ),
			'segment' => 'style_hotspot',
		);

		$this->options['t_hotspot_text_hover_transition_duration'] = array(
			'type'      => 'slider',
			'title'     => esc_html__( 'Transition Duration', 'profecient-essential' ),
			'segment'   => 'style_hotspot',
			'options'   => array(
				'min'  => 0,
				'max'  => 10,
				'step' => 0.1,
			),
			'selectors' => array(
				'custom' => array(
					'{{WRAPPER}} .profecient-hotspot .profecient-hotspot-container .profecient-hotspot-item .profecient-hotspot-button .profecient-hotspot-label' => 'transition-duration: {{SIZE}}s;',
				),
			),
		);

		$this->options['st_hotspot_text_hover_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Color', 'profecient-essential' ),
			'segment'   => 'style_hotspot',
			'selectors' => '.profecient-hotspot .profecient-hotspot-container .profecient-hotspot-item:hover .profecient-hotspot-button',
		);

		$this->options['st_hotspot_text_hover_tab_end'] = array(
			'type'    => 'control_tab_end',
			'segment' => 'style_hotspot',
		);

		$this->options['st_hotspot_text_tabs_end'] = array(
			'type'    => 'control_tabs_end',
			'segment' => 'style_hotspot',
		);

		$this->options['st_hotspot_icon_heading'] = array(
			'type'      => 'heading',
			'title'     => esc_html__( 'Icon', 'profecient-essential' ),
			'segment'   => 'style_hotspot',
			'separator' => 'before',
		);

		$this->options['st_hotspot_icon_size'] = array(
			'type'       => 'slider',
			'title'      => esc_html__( 'Size', 'profecient-essential' ),
			'segment'    => 'style_hotspot',
			'responsive' => true,
			'units'      => array( 'px', '%', 'em' ),
			'options'    => array(
				'min'  => 0,
				'max'  => 1000,
				'step' => 1,
			),
			'selectors'  => '.profecient-hotspot .profecient-hotspot-container .profecient-hotspot-item .profecient-hotspot-button .profecient-hotspot-icon',
			'attribute'  => 'font-size',
		);

		$this->options['st_hotspot_icon_tabs_start'] = array(
			'type'    => 'control_tabs_start',
			'segment' => 'style_hotspot',
		);

		$this->options['st_hotspot_icon_normal_tab_start'] = array(
			'type'    => 'control_tab_start',
			'title'   => esc_html__( 'Normal', 'profecient-essential' ),
			'segment' => 'style_hotspot',
		);

		$this->options['st_hotspot_icon_normal_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Color', 'profecient-essential' ),
			'segment'   => 'style_hotspot',
			'selectors' => '.profecient-hotspot .profecient-hotspot-container .profecient-hotspot-item .profecient-hotspot-button .profecient-hotspot-icon',
		);

		$this->options['st_hotspot_icon_normal_tab_end'] = array(
			'type'    => 'control_tab_end',
			'segment' => 'style_hotspot',
		);

		$this->options['st_hotspot_icon_hover_tab_start'] = array(
			'type'    => 'control_tab_start',
			'title'   => esc_html__( 'Hover', 'profecient-essential' ),
			'segment' => 'style_hotspot',
		);

		$this->options['t_hotspot_icon_hover_transition_duration'] = array(
			'type'      => 'slider',
			'title'     => esc_html__( 'Transition Duration', 'profecient-essential' ),
			'segment'   => 'style_hotspot',
			'options'   => array(
				'min'  => 0,
				'max'  => 10,
				'step' => 0.1,
			),
			'selectors' => array(
				'custom' => array(
					'{{WRAPPER}} .profecient-hotspot .profecient-hotspot-container .profecient-hotspot-item .profecient-hotspot-button .profecient-hotspot-icon' => 'transition-duration: {{SIZE}}s;',
				),
			),
		);

		$this->options['st_hotspot_icon_hover_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Color', 'profecient-essential' ),
			'segment'   => 'style_hotspot',
			'selectors' => '.profecient-hotspot .profecient-hotspot-container .profecient-hotspot-item:hover .profecient-hotspot-button .profecient-hotspot-icon',
		);

		$this->options['st_hotspot_icon_hover_tab_end'] = array(
			'type'    => 'control_tab_end',
			'segment' => 'style_hotspot',
		);

		$this->options['st_hotspot_icon_tabs_end'] = array(
			'type'    => 'control_tabs_end',
			'segment' => 'style_hotspot',
		);

		$this->options['st_hotspot_wrapper_heading'] = array(
			'type'      => 'heading',
			'title'     => esc_html__( 'Wrapper', 'profecient-essential' ),
			'segment'   => 'style_hotspot',
			'separator' => 'before',
		);

		$this->options['st_hotspot_wrapper_padding'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Padding', 'profecient-essential' ),
			'segment'   => 'style_hotspot',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.profecient-hotspot .profecient-hotspot-container .profecient-hotspot-item .profecient-hotspot-button',
			'attribute' => 'padding',
		);

		$this->options['st_hotspot_wrapper_min_width'] = array(
			'type'       => 'slider',
			'title'      => esc_html__( 'Min Width', 'profecient-essential' ),
			'segment'    => 'style_hotspot',
			'responsive' => true,
			'units'      => array( 'px', '%', 'em' ),
			'options'    => array(
				'min'  => 0,
				'max'  => 1000,
				'step' => 1,
			),
			'selectors'  => '.profecient-hotspot .profecient-hotspot-container .profecient-hotspot-item .profecient-hotspot-button',
			'attribute'  => 'min-width',
		);

		$this->options['st_hotspot_wrapper_min_height'] = array(
			'type'       => 'slider',
			'title'      => esc_html__( 'Min Height', 'profecient-essential' ),
			'segment'    => 'style_hotspot',
			'responsive' => true,
			'units'      => array( 'px', '%', 'em' ),
			'options'    => array(
				'min'  => 0,
				'max'  => 1000,
				'step' => 1,
			),
			'selectors'  => '.profecient-hotspot .profecient-hotspot-container .profecient-hotspot-item .profecient-hotspot-button',
			'attribute'  => 'min-height',
		);

		$this->options['st_hotspot_wrapper_tabs_start'] = array(
			'type'    => 'control_tabs_start',
			'segment' => 'style_hotspot',
		);

		$this->options['st_hotspot_wrapper_normal_tab_start'] = array(
			'type'    => 'control_tab_start',
			'title'   => esc_html__( 'Normal', 'profecient-essential' ),
			'segment' => 'style_hotspot',
		);

		$this->options['st_hotspot_wrapper_normal_background'] = array(
			'type'      => 'background',
			'title'     => esc_html__( 'Background Color', 'profecient-essential' ),
			'segment'   => 'style_hotspot',
			'selectors' => '.profecient-hotspot .profecient-hotspot-container .profecient-hotspot-item .profecient-hotspot-button',
			'options'   => array(
				'classic',
				'gradient',
			),
			'exclude'   => array( 'image' ),
		);

		$this->options['st_hotspot_wrapper_normal_border_radius'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Border Radius', 'profecient-essential' ),
			'segment'   => 'style_hotspot',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.profecient-hotspot .profecient-hotspot-container .profecient-hotspot-item .profecient-hotspot-button',
			'attribute' => 'border-radius',
		);

		$this->options['st_hotspot_wrapper_normal_border'] = array(
			'type'      => 'border',
			'title'     => esc_html__( 'Border', 'profecient-essential' ),
			'segment'   => 'style_hotspot',
			'selectors' => '.profecient-hotspot .profecient-hotspot-container .profecient-hotspot-item .profecient-hotspot-button',
		);

		$this->options['st_hotspot_wrapper_normal_boxshadow'] = array(
			'type'      => 'boxshadow',
			'title'     => esc_html__( 'Box Shadow', 'profecient-essential' ),
			'segment'   => 'style_hotspot',
			'selectors' => '.profecient-hotspot .profecient-hotspot-container .profecient-hotspot-item .profecient-hotspot-button',
		);

		$this->options['st_hotspot_wrapper_normal_tab_end'] = array(
			'type'    => 'control_tab_end',
			'segment' => 'style_hotspot',
		);

		$this->options['st_hotspot_wrapper_hover_tab_start'] = array(
			'type'    => 'control_tab_start',
			'title'   => esc_html__( 'Hover', 'profecient-essential' ),
			'segment' => 'style_hotspot',
		);

		$this->options['st_hotspot_wrapper_hover_transition_duration'] = array(
			'type'      => 'slider',
			'title'     => esc_html__( 'Transition Duration', 'profecient-essential' ),
			'segment'   => 'style_hotspot',
			'options'   => array(
				'min'  => 0,
				'max'  => 10,
				'step' => 0.1,
			),
			'selectors' => array(
				'custom' => array(
					'{{WRAPPER}} .profecient-hotspot .profecient-hotspot-container .profecient-hotspot-item .profecient-hotspot-button' => 'transition-duration: {{SIZE}}s;',
				),
			),
		);

		$this->options['st_hotspot_wrapper_hover_background'] = array(
			'type'      => 'background',
			'title'     => esc_html__( 'Background Color', 'profecient-essential' ),
			'segment'   => 'style_hotspot',
			'selectors' => '.profecient-hotspot .profecient-hotspot-container .profecient-hotspot-item:hover .profecient-hotspot-button',
			'options'   => array(
				'classic',
				'gradient',
			),
			'exclude'   => array( 'image' ),
		);

		$this->options['st_hotspot_wrapper_hover_border_radius'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Border Radius', 'profecient-essential' ),
			'segment'   => 'style_hotspot',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.profecient-hotspot .profecient-hotspot-container .profecient-hotspot-item:hover .profecient-hotspot-button',
			'attribute' => 'border-radius',
		);

		$this->options['st_hotspot_wrapper_hover_border'] = array(
			'type'      => 'border',
			'title'     => esc_html__( 'Border', 'profecient-essential' ),
			'segment'   => 'style_hotspot',
			'selectors' => '.profecient-hotspot .profecient-hotspot-container .profecient-hotspot-item:hover .profecient-hotspot-button',
		);

		$this->options['st_hotspot_wrapper_hover_boxshadow'] = array(
			'type'      => 'boxshadow',
			'title'     => esc_html__( 'Box Shadow', 'profecient-essential' ),
			'segment'   => 'style_hotspot',
			'selectors' => '.profecient-hotspot .profecient-hotspot-container .profecient-hotspot-item:hover .profecient-hotspot-button',
		);

		$this->options['st_hotspot_wrapper_hover_tab_end'] = array(
			'type'    => 'control_tab_end',
			'segment' => 'style_hotspot',
		);

		$this->options['st_hotspot_wrapper_tabs_end'] = array(
			'type'    => 'control_tabs_end',
			'segment' => 'style_hotspot',
		);

		$this->options['st_tooltip_padding'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Padding', 'profecient-essential' ),
			'segment'   => 'style_tooltip',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.profecient-hotspot .profecient-hotspot-container .profecient-hotspot-item .profecient-hotspot-tooltip',
			'attribute' => 'padding',
		);

		$this->options['st_tooltip_min_width'] = array(
			'type'       => 'slider',
			'title'      => esc_html__( 'Min Width', 'profecient-essential' ),
			'segment'    => 'style_tooltip',
			'responsive' => true,
			'units'      => array( 'px', '%', 'em' ),
			'options'    => array(
				'min'  => 0,
				'max'  => 1000,
				'step' => 1,
			),
			'selectors'  => '.profecient-hotspot .profecient-hotspot-container .profecient-hotspot-item .profecient-hotspot-tooltip',
			'attribute'  => 'min-width',
		);

		$this->options['st_tooltip_min_height'] = array(
			'type'       => 'slider',
			'title'      => esc_html__( 'Min Height', 'profecient-essential' ),
			'segment'    => 'style_tooltip',
			'responsive' => true,
			'units'      => array( 'px', '%', 'em' ),
			'options'    => array(
				'min'  => 0,
				'max'  => 1000,
				'step' => 1,
			),
			'selectors'  => '.profecient-hotspot .profecient-hotspot-container .profecient-hotspot-item .profecient-hotspot-tooltip',
			'attribute'  => 'min-height',
		);

		$this->options['st_tooltip_text_typography'] = array(
			'type'      => 'typography',
			'title'     => esc_html__( 'Typography', 'profecient-essential' ),
			'segment'   => 'style_tooltip',
			'selectors' => '.profecient-hotspot .profecient-hotspot-container .profecient-hotspot-item .profecient-hotspot-tooltip',
		);

		$this->options['st_tooltip_arrow_size'] = array(
			'type'       => 'slider',
			'title'      => esc_html__( 'Arrow Size', 'profecient-essential' ),
			'segment'    => 'style_tooltip',
			'units'      => array( 'px', '%', 'em', 'custom' ),
			'options'    => array(
				'min'  => 0,
				'max'  => 200,
				'step' => 1,
			),
			'responsive' => true,
			'selectors'  => '.profecient-hotspot .profecient-hotspot-container .profecient-hotspot-item .profecient-hotspot-tooltip',
			'attribute'  => '--arrow-size',
		);

		$this->options['st_tooltip_tabs_start'] = array(
			'type'    => 'control_tabs_start',
			'segment' => 'style_tooltip',
		);

		$this->options['st_tooltip_normal_tab_start'] = array(
			'type'    => 'control_tab_start',
			'title'   => esc_html__( 'Normal', 'profecient-essential' ),
			'segment' => 'style_tooltip',
		);

		$this->options['st_tooltip_normal_text_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Text Color', 'profecient-essential' ),
			'segment'   => 'style_tooltip',
			'selectors' => '.profecient-hotspot .profecient-hotspot-container .profecient-hotspot-item .profecient-hotspot-tooltip',
			'attribute' => 'color',
		);

		$this->options['st_tooltip_normal_arrow_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Arrow Color', 'profecient-essential' ),
			'segment'   => 'style_tooltip',
			'selectors' => array(
				'custom' => array(
					'{{WRAPPER}} .profecient-hotspot .profecient-hotspot-container .profecient-hotspot-item .profecient-hotspot-tooltip .profecient-hotspot-arrow' => 'border-color: {{VALUE}} rgba(0,0,0,0) rgba(0,0,0,0) rgba(0,0,0,0);',
				),
			),
		);

		$this->options['st_tooltip_normal_background'] = array(
			'type'      => 'background',
			'title'     => esc_html__( 'Background Color', 'profecient-essential' ),
			'segment'   => 'style_tooltip',
			'selectors' => '.profecient-hotspot .profecient-hotspot-container .profecient-hotspot-item .profecient-hotspot-tooltip',
			'options'   => array(
				'classic',
				'gradient',
			),
			'exclude'   => array( 'image' ),
		);

		$this->options['st_tooltip_normal_border_radius'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Border Radius', 'profecient-essential' ),
			'segment'   => 'style_tooltip',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.profecient-hotspot .profecient-hotspot-container .profecient-hotspot-item .profecient-hotspot-tooltip',
			'attribute' => 'border-radius',
		);

		$this->options['st_tooltip_normal_border'] = array(
			'type'      => 'border',
			'title'     => esc_html__( 'Border', 'profecient-essential' ),
			'segment'   => 'style_tooltip',
			'selectors' => '.profecient-hotspot .profecient-hotspot-container .profecient-hotspot-item .profecient-hotspot-tooltip',
		);

		$this->options['st_tooltip_normal_boxshadow'] = array(
			'type'      => 'boxshadow',
			'title'     => esc_html__( 'Box Shadow', 'profecient-essential' ),
			'segment'   => 'style_tooltip',
			'selectors' => '.profecient-hotspot .profecient-hotspot-container .profecient-hotspot-item .profecient-hotspot-tooltip',
		);

		$this->options['st_tooltip_normal_tab_end'] = array(
			'type'    => 'control_tab_end',
			'segment' => 'style_tooltip',
		);

		$this->options['st_tooltip_hover_tab_start'] = array(
			'type'    => 'control_tab_start',
			'title'   => esc_html__( 'Hover', 'profecient-essential' ),
			'segment' => 'style_tooltip',
		);

		$this->options['st_tooltip_hover_transition_duration'] = array(
			'type'      => 'slider',
			'title'     => esc_html__( 'Transition Duration', 'profecient-essential' ),
			'segment'   => 'style_tooltip',
			'options'   => array(
				'min'  => 0,
				'max'  => 10,
				'step' => 0.1,
			),
			'selectors' => array(
				'custom' => array(
					'{{WRAPPER}} .profecient-hotspot .profecient-hotspot-container .profecient-hotspot-item .profecient-hotspot-tooltip, {{WRAPPER}} .profecient-hotspot .profecient-hotspot-container .profecient-hotspot-item .profecient-hotspot-tooltip .profecient-hotspot-arrow' => 'transition-duration: {{SIZE}}s;',
				),
			),
		);

		$this->options['st_tooltip_hover_text_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Text Color', 'profecient-essential' ),
			'segment'   => 'style_tooltip',
			'selectors' => '.profecient-hotspot .profecient-hotspot-container .profecient-hotspot-item .profecient-hotspot-tooltip:hover',
			'attribute' => 'color',
		);

		$this->options['st_tooltip_hover_arrow_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Arrow Color', 'profecient-essential' ),
			'segment'   => 'style_tooltip',
			'selectors' => array(
				'custom' => array(
					'{{WRAPPER}} .profecient-hotspot .profecient-hotspot-container .profecient-hotspot-item .profecient-hotspot-tooltip:hover .profecient-hotspot-arrow' => 'border-color: {{VALUE}} rgba(0,0,0,0) rgba(0,0,0,0) rgba(0,0,0,0)',
				),
			),
		);

		$this->options['st_tooltip_hover_background'] = array(
			'type'      => 'background',
			'title'     => esc_html__( 'Background Color', 'profecient-essential' ),
			'segment'   => 'style_tooltip',
			'selectors' => '.profecient-hotspot .profecient-hotspot-container .profecient-hotspot-item .profecient-hotspot-tooltip:hover',
			'options'   => array(
				'classic',
				'gradient',
			),
			'exclude'   => array( 'image' ),
		);

		$this->options['st_tooltip_hover_border_radius'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Border Radius', 'profecient-essential' ),
			'segment'   => 'style_tooltip',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.profecient-hotspot .profecient-hotspot-container .profecient-hotspot-item .profecient-hotspot-tooltip:hover',
			'attribute' => 'border-radius',
		);

		$this->options['st_tooltip_hover_border'] = array(
			'type'      => 'border',
			'title'     => esc_html__( 'Border', 'profecient-essential' ),
			'segment'   => 'style_tooltip',
			'selectors' => '.profecient-hotspot .profecient-hotspot-container .profecient-hotspot-item .profecient-hotspot-tooltip:hover',
		);

		$this->options['st_tooltip_hover_boxshadow'] = array(
			'type'      => 'boxshadow',
			'title'     => esc_html__( 'Box Shadow', 'profecient-essential' ),
			'segment'   => 'style_tooltip',
			'selectors' => '.profecient-hotspot .profecient-hotspot-container .profecient-hotspot-item .profecient-hotspot-tooltip:hover',
		);

		$this->options['st_tooltip_hover_tab_end'] = array(
			'type'    => 'control_tab_end',
			'segment' => 'style_tooltip',
		);

		$this->options['st_tooltip_tabs_end'] = array(
			'type'    => 'control_tabs_end',
			'segment' => 'style_tooltip',
		);

		parent::additional_style();
	}
}
