<?php
/**
 * Product Custom Add To Cart Option Class
 *
 * @package profecient-essential
 * @author jegtheme
 * @since 1.0.0
 */

namespace Profecient\Essential\JKit\Elements\Options;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

use Jeg\Elementor_Kit\Elements\Options\Option_Abstract;

/**
 * Class Product_Custom_Add_To_Cart_Option
 */
class Product_Custom_Add_To_Cart_Option extends Option_Abstract {
	/**
	 * Default number of post ajax
	 *
	 * @var int
	 */
	protected $number_post_ajax = 4;

	/**
	 * Show color scheme flag for element.
	 *
	 * @return bool
	 */
	public function show_color_scheme() {
		return false;
	}

	/**
	 * Compatibility column
	 *
	 * @return array
	 */
	public function compatible_column() {
		return array();
	}

	/**
	 * Override function to remove compatible column alert
	 */
	public function set_compatible_column_option() {}

	/**
	 * Element name
	 *
	 * @return string
	 */
	public function get_element_name() {
		return esc_html__( 'Custom Add To Cart', 'profecient-essential' );
	}

	/**
	 * Element category
	 *
	 * @return string
	 */
	public function get_category() {
		return esc_html__( 'Profecient - Woocommerce', 'profecient-essential' );
	}

	/**
	 * Element options
	 */
	public function set_options() {
		$this->set_element_options();
		$this->set_style_option();

		parent::set_options();
	}

	/**
	 * Option segments
	 */
	public function set_segments() {
		$this->segments['segment_settings'] = array(
			'name'     => esc_html__( ' Settings', 'profecient-essential' ),
			'priority' => 5,
		);

		$this->set_style_segment();
	}

	/**
	 * Style segments
	 */
	public function set_style_segment() {
		$this->segments['style_button'] = array(
			'name'      => esc_html__( 'Button', 'profecient-essential' ),
			'priority'  => 11,
			'kit_style' => true,
		);

		$this->segments['style_quantity'] = array(
			'name'      => esc_html__( 'Quantity', 'profecient-essential' ),
			'priority'  => 12,
			'kit_style' => true,
		);

		$this->segments['style_variation'] = array(
			'name'      => esc_html__( 'Variation Content', 'profecient-essential' ),
			'priority'  => 13,
			'kit_style' => true,
		);

		$this->segments['style_grouped'] = array(
			'name'      => esc_html__( 'Grouped Content', 'profecient-essential' ),
			'priority'  => 14,
			'kit_style' => true,
		);

		parent::set_style_segment();
	}

	/**
	 * Set element option
	 */
	public function set_element_options() {
		$this->options['sg_settings_selected_post'] = array(
			'type'        => 'select',
			'multiple'    => 'no',
			'ajax'        => 'jeg_find_cpt',
			'options'     => 'jeg_get_cpt_option',
			'nonce'       => wp_create_nonce( 'jeg_find_cpt' ),
			'slug'        => 'product',
			'title'       => esc_html__( 'Select Product ID', 'profecient-essential' ),
			'description' => wp_kses( __( 'Tips :<br/> - You can search product id by inputing the product title, clicking search title, and you will have your product id.<br/>- You can also directly insert your product id, and click enter to add it on the list.', 'profecient-essential' ), wp_kses_allowed_html() ),
			'segment'     => 'segment_settings',
			'default'     => '',
			'label_block' => true,
		);

		$this->options['sg_settings_button_style'] = array(
			'type'    => 'select',
			'title'   => esc_html__( 'Button Style', 'profecient-essential' ),
			'options' => array(
				'form' => esc_html__( 'Form', 'profecient-essential' ),
				'ajax' => esc_html__( 'Ajax', 'profecient-essential' ),
			),
			'default' => 'ajax',
			'segment' => 'segment_settings',
		);

		$this->options['sg_settings_product_quantity'] = array(
			'type'       => 'number',
			'title'      => esc_html__( 'Product Quantity', 'profecient-essential' ),
			'options'    => array(
				'min'  => 1,
				'max'  => PHP_INT_MAX,
				'step' => 1,
			),
			'default'    => 1,
			'segment'    => 'segment_settings',
			'dependency' => array(
				array(
					'field'    => 'sg_settings_button_style',
					'operator' => '===',
					'value'    => 'ajax',
				),
			),
		);

		$this->options['sg_settings_button_icon'] = array(
			'type'    => 'iconpicker',
			'title'   => esc_html__( 'Button Icon', 'profecient-essential' ),
			'segment' => 'segment_settings',
		);

		$this->options['sg_settings_custom_add_to_cart_text'] = array(
			'type'        => 'text',
			'title'       => esc_html__( 'Custom Button Text', 'profecient-essential' ),
			'segment'     => 'segment_settings',
			'description' => 'If you fill this option, the default text from WooCommerce will be overwritten.',
		);
	}

	/**
	 * Add Additional Style.
	 */
	public function additional_style() {
		$this->options['st_button_margin'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Margin', 'profecient-essential' ),
			'segment'   => 'style_button',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.profecient-product-custom-add-to-cart .button',
			'attribute' => 'margin',
		);

		$this->options['st_button_padding'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Padding', 'profecient-essential' ),
			'segment'   => 'style_button',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.profecient-product-custom-add-to-cart .button',
			'attribute' => 'padding',
		);

		$this->options['st_button_typography'] = array(
			'type'      => 'typography',
			'title'     => esc_html__( 'Typograhpy', 'profecient-essential' ),
			'segment'   => 'style_button',
			'selectors' => '.profecient-product-custom-add-to-cart .button',
		);

		$this->options['st_button_tabs_start'] = array(
			'type'    => 'control_tabs_start',
			'segment' => 'style_button',
		);

		$this->options['st_button_normal_tab_start'] = array(
			'type'    => 'control_tab_start',
			'title'   => esc_html__( 'Normal', 'profecient-essential' ),
			'segment' => 'style_button',
		);

		$this->options['st_button_normal_text_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Color', 'profecient-essential' ),
			'segment'   => 'style_button',
			'selectors' => '.profecient-product-custom-add-to-cart .button',
		);

		$this->options['st_button_normal_background'] = array(
			'type'      => 'background',
			'title'     => esc_html__( 'Background', 'profecient-essential' ),
			'segment'   => 'style_button',
			'selectors' => '.profecient-product-custom-add-to-cart .button',
			'options'   => array(
				'classic',
				'gradient',
			),
			'exclude'   => array( 'image' ),
		);

		$this->options['st_button_normal_border_radius'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Border Radius', 'profecient-essential' ),
			'segment'   => 'style_button',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.profecient-product-custom-add-to-cart .button',
			'attribute' => 'border-radius',
		);

		$this->options['st_button_normal_border'] = array(
			'type'      => 'border',
			'title'     => esc_html__( 'Border', 'profecient-essential' ),
			'segment'   => 'style_button',
			'selectors' => '.profecient-product-custom-add-to-cart .button',
		);

		$this->options['st_button_normal_boxshadow'] = array(
			'type'      => 'boxshadow',
			'title'     => esc_html__( 'Box Shadow', 'profecient-essential' ),
			'segment'   => 'style_button',
			'selectors' => '.profecient-product-custom-add-to-cart .button',
		);

		$this->options['st_button_normal_tab_end'] = array(
			'type'    => 'control_tab_end',
			'segment' => 'style_button',
		);

		$this->options['st_button_hover_tab_start'] = array(
			'type'    => 'control_tab_start',
			'title'   => esc_html__( 'Hover', 'profecient-essential' ),
			'segment' => 'style_button',
		);

		$this->options['st_button_hover_text_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Color', 'profecient-essential' ),
			'segment'   => 'style_button',
			'selectors' => '.profecient-product-custom-add-to-cart .button:hover',
		);

		$this->options['st_button_hover_background'] = array(
			'type'      => 'background',
			'title'     => esc_html__( 'Background', 'profecient-essential' ),
			'segment'   => 'style_button',
			'selectors' => '.profecient-product-custom-add-to-cart .button:hover',
			'options'   => array(
				'classic',
				'gradient',
			),
			'exclude'   => array( 'image' ),
		);

		$this->options['st_button_hover_border_radius'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Border Radius', 'profecient-essential' ),
			'segment'   => 'style_button',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.profecient-product-custom-add-to-cart .button:hover',
			'attribute' => 'border-radius',
		);

		$this->options['st_button_hover_border'] = array(
			'type'      => 'border',
			'title'     => esc_html__( 'Border', 'profecient-essential' ),
			'segment'   => 'style_button',
			'selectors' => '.profecient-product-custom-add-to-cart .button:hover',
		);

		$this->options['st_button_hover_boxshadow'] = array(
			'type'      => 'boxshadow',
			'title'     => esc_html__( 'Box Shadow', 'profecient-essential' ),
			'segment'   => 'style_button',
			'selectors' => '.profecient-product-custom-add-to-cart .button:hover',
		);

		$this->options['st_button_hover_tab_end'] = array(
			'type'    => 'control_tab_end',
			'segment' => 'style_button',
		);

		$this->options['st_button_disabled_tab_start'] = array(
			'type'    => 'control_tab_start',
			'title'   => esc_html__( 'Disabled', 'profecient-essential' ),
			'segment' => 'style_button',
		);

		$this->options['st_button_disabled_text_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Color', 'profecient-essential' ),
			'segment'   => 'style_button',
			'selectors' => '.profecient-product-custom-add-to-cart .button.disabled',
		);

		$this->options['st_button_disabled_background'] = array(
			'type'      => 'background',
			'title'     => esc_html__( 'Background', 'profecient-essential' ),
			'segment'   => 'style_button',
			'selectors' => '.profecient-product-custom-add-to-cart .button.disabled',
			'options'   => array(
				'classic',
				'gradient',
			),
			'exclude'   => array( 'image' ),
		);

		$this->options['st_button_disabled_border_radius'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Border Radius', 'profecient-essential' ),
			'segment'   => 'style_button',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.profecient-product-custom-add-to-cart .button.disabled',
			'attribute' => 'border-radius',
		);

		$this->options['st_button_disabled_border'] = array(
			'type'      => 'border',
			'title'     => esc_html__( 'Border', 'profecient-essential' ),
			'segment'   => 'style_button',
			'selectors' => '.profecient-product-custom-add-to-cart .button.disabled',
		);

		$this->options['st_button_disabled_boxshadow'] = array(
			'type'      => 'boxshadow',
			'title'     => esc_html__( 'Box Shadow', 'profecient-essential' ),
			'segment'   => 'style_button',
			'selectors' => '.profecient-product-custom-add-to-cart .button.disabled',
		);

		$this->options['st_button_disabled_tab_end'] = array(
			'type'    => 'control_tab_end',
			'segment' => 'style_button',
		);

		$this->options['st_button_tabs_end'] = array(
			'type'    => 'control_tabs_end',
			'segment' => 'style_button',
		);

		$this->options['st_button_icon_heading'] = array(
			'type'      => 'heading',
			'title'     => esc_html__( 'Icon', 'profecient-essential' ),
			'segment'   => 'style_button',
			'separator' => 'before',
		);

		$this->options['st_button_icon_margin'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Margin', 'profecient-essential' ),
			'segment'   => 'style_button',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.profecient-product-custom-add-to-cart .button > i',
			'attribute' => 'margin',
		);

		$this->options['st_button_icon_position'] = array(
			'type'      => 'radio',
			'title'     => esc_html__( 'Position', 'profecient-essential' ),
			'segment'   => 'style_button',
			'options'   => array(
				'ltr' => array(
					'title' => esc_html__( 'Left', 'profecient-essential' ),
					'icon'  => 'eicon-h-align-left',
				),
				'rtl' => array(
					'title' => esc_html__( 'Right', 'profecient-essential' ),
					'icon'  => 'eicon-h-align-right',
				),
			),
			'default'   => 'right',
			'selectors' => '.profecient-product-custom-add-to-cart .button',
			'attribute' => 'direction',
		);

		$this->options['st_quantity_margin'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Margin', 'profecient-essential' ),
			'segment'   => 'style_quantity',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.profecient-product-custom-add-to-cart .quantity',
			'attribute' => 'margin',
		);

		$this->options['st_quantity_border_radius'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Border Radius', 'profecient-essential' ),
			'segment'   => 'style_quantity',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.profecient-product-custom-add-to-cart .quantity input',
			'attribute' => 'border-radius',
		);

		$this->options['st_quantity_border'] = array(
			'type'      => 'border',
			'title'     => esc_html__( 'Border', 'profecient-essential' ),
			'segment'   => 'style_quantity',
			'selectors' => '.profecient-product-custom-add-to-cart .quantity input',
		);

		$this->options['st_quantity_width'] = array(
			'type'      => 'slider',
			'title'     => esc_html__( 'Width', 'profecient-essential' ),
			'segment'   => 'style_quantity',
			'units'     => array( 'px', '%', 'em' ),
			'options'   => array(
				'min'  => 0,
				'max'  => 100,
				'step' => 1,
			),
			'selectors' => '.profecient-product-custom-add-to-cart .quantity input',
			'attribute' => 'width',
		);

		$this->options['st_quantity_height'] = array(
			'type'      => 'slider',
			'title'     => esc_html__( 'Height', 'profecient-essential' ),
			'segment'   => 'style_quantity',
			'units'     => array( 'px', '%', 'em' ),
			'options'   => array(
				'min'  => 0,
				'max'  => 100,
				'step' => 1,
			),
			'selectors' => '.profecient-product-custom-add-to-cart .quantity input',
			'attribute' => 'height',
		);

		$this->options['st_quantity_typography'] = array(
			'type'      => 'typography',
			'title'     => esc_html__( 'Typograhpy', 'profecient-essential' ),
			'segment'   => 'style_quantity',
			'selectors' => '.profecient-product-custom-add-to-cart .quantity input',
		);

		$this->options['st_quantity_text_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Color', 'profecient-essential' ),
			'segment'   => 'style_quantity',
			'selectors' => '.profecient-product-custom-add-to-cart .quantity input',
		);

		$this->options['st_quantity_background'] = array(
			'type'      => 'background',
			'title'     => esc_html__( 'Background', 'profecient-essential' ),
			'segment'   => 'style_quantity',
			'selectors' => '.profecient-product-custom-add-to-cart .quantity input',
			'options'   => array(
				'classic',
				'gradient',
			),
			'exclude'   => array( 'image' ),
		);

		$this->options['st_variation_table_heading'] = array(
			'type'    => 'heading',
			'title'   => 'Table',
			'segment' => 'style_variation',
		);

		$this->options['st_variation_table_typography'] = array(
			'type'      => 'typography',
			'title'     => esc_html__( 'Typograhpy', 'profecient-essential' ),
			'segment'   => 'style_variation',
			'selectors' => '.profecient-product-custom-add-to-cart table.variations',
		);

		$this->options['st_variation_table_text_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Color', 'profecient-essential' ),
			'segment'   => 'style_variation',
			'selectors' => '.profecient-product-custom-add-to-cart table.variations',
		);

		$this->options['st_variation_select_heading'] = array(
			'type'      => 'heading',
			'title'     => 'Select',
			'separator' => 'before',
			'segment'   => 'style_variation',
		);

		$this->options['st_variation_select_typography'] = array(
			'type'      => 'typography',
			'title'     => esc_html__( 'Typograhpy', 'profecient-essential' ),
			'segment'   => 'style_variation',
			'selectors' => '.profecient-product-custom-add-to-cart table.variations select',
		);

		$this->options['st_variation_select_text_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Color', 'profecient-essential' ),
			'segment'   => 'style_variation',
			'selectors' => '.profecient-product-custom-add-to-cart table.variations select',
		);

		$this->options['st_variation_select_background_color'] = array(
			'type'      => 'background',
			'title'     => esc_html__( 'Color', 'profecient-essential' ),
			'segment'   => 'style_variation',
			'selectors' => '.profecient-product-custom-add-to-cart table.variations select',
			'options'   => array(
				'classic',
				'gradient',
			),
			'exclude'   => array( 'image' ),
		);

		$this->options['st_variation_reset_heading'] = array(
			'type'      => 'heading',
			'title'     => 'Reset',
			'separator' => 'before',
			'segment'   => 'style_variation',
		);

		$this->options['st_variation_reset_typography'] = array(
			'type'      => 'typography',
			'title'     => esc_html__( 'Typograhpy', 'profecient-essential' ),
			'segment'   => 'style_variation',
			'selectors' => '.profecient-product-custom-add-to-cart .reset_variations',
		);

		$this->options['st_variation_reset_tabs_start'] = array(
			'type'    => 'control_tabs_start',
			'segment' => 'style_variation',
		);

		$this->options['st_variation_reset_normal_tab_start'] = array(
			'type'    => 'control_tab_start',
			'title'   => esc_html__( 'Normal', 'profecient-essential' ),
			'segment' => 'style_variation',
		);

		$this->options['st_variation_reset_normal_text_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Color', 'profecient-essential' ),
			'segment'   => 'style_variation',
			'selectors' => '.profecient-product-custom-add-to-cart .reset_variations',
		);

		$this->options['st_variation_reset_normal_tab_end'] = array(
			'type'    => 'control_tab_end',
			'segment' => 'style_variation',
		);

		$this->options['st_variation_reset_hover_tab_start'] = array(
			'type'    => 'control_tab_start',
			'title'   => esc_html__( 'Hover', 'profecient-essential' ),
			'segment' => 'style_variation',
		);

		$this->options['st_variation_reset_hover_text_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Color', 'profecient-essential' ),
			'segment'   => 'style_variation',
			'selectors' => '.profecient-product-custom-add-to-cart .reset_variations:hover',
		);

		$this->options['st_variation_reset_hover_tab_end'] = array(
			'type'    => 'control_tab_end',
			'segment' => 'style_variation',
		);

		$this->options['st_variation_reset_tabs_end'] = array(
			'type'    => 'control_tabs_end',
			'segment' => 'style_variation',
		);

		$this->options['st_variation_description_heading'] = array(
			'type'      => 'heading',
			'title'     => 'Description',
			'separator' => 'before',
			'segment'   => 'style_variation',
		);

		$this->options['st_variation_description_typography'] = array(
			'type'      => 'typography',
			'title'     => esc_html__( 'Typograhpy', 'profecient-essential' ),
			'segment'   => 'style_variation',
			'selectors' => '.profecient-product-custom-add-to-cart .woocommerce-variation-description',
		);

		$this->options['st_variation_description_text_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Color', 'profecient-essential' ),
			'segment'   => 'style_variation',
			'selectors' => '.profecient-product-custom-add-to-cart .woocommerce-variation-description',
		);

		$this->options['st_variation_price_heading'] = array(
			'type'      => 'heading',
			'title'     => 'Price',
			'separator' => 'before',
			'segment'   => 'style_variation',
		);

		$this->options['st_variation_price_typography'] = array(
			'type'      => 'typography',
			'title'     => esc_html__( 'Typograhpy', 'profecient-essential' ),
			'segment'   => 'style_variation',
			'selectors' => '.profecient-product-custom-add-to-cart .woocommerce-variation-price',
		);

		$this->options['st_variation_price_text_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Color', 'profecient-essential' ),
			'segment'   => 'style_variation',
			'selectors' => '.profecient-product-custom-add-to-cart .woocommerce-variation-price span.price',
		);

		$this->options['st_grouped_quantity_heading'] = array(
			'type'    => 'heading',
			'title'   => 'Quantity',
			'segment' => 'style_grouped',
		);

		$this->options['st_grouped_quantity_tabs_start'] = array(
			'type'    => 'control_tabs_start',
			'segment' => 'style_grouped',
		);

		$this->options['st_grouped_quantity_input_tab_start'] = array(
			'type'    => 'control_tab_start',
			'title'   => esc_html__( 'Input', 'profecient-essential' ),
			'segment' => 'style_grouped',
		);

		$this->options['st_grouped_quantity_input_margin'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Margin', 'profecient-essential' ),
			'segment'   => 'style_grouped',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.profecient-product-custom-add-to-cart .woocommerce-grouped-product-list .woocommerce-grouped-product-list-item__quantity input',
			'attribute' => 'margin',
		);

		$this->options['st_grouped_quantity_input_width'] = array(
			'type'      => 'slider',
			'title'     => esc_html__( 'Width', 'profecient-essential' ),
			'segment'   => 'style_grouped',
			'units'     => array( 'px', '%', 'em' ),
			'options'   => array(
				'min'  => 0,
				'max'  => 100,
				'step' => 1,
			),
			'selectors' => '.profecient-product-custom-add-to-cart .woocommerce-grouped-product-list .woocommerce-grouped-product-list-item__quantity input',
			'attribute' => 'width',
		);

		$this->options['st_grouped_quantity_input_height'] = array(
			'type'      => 'slider',
			'title'     => esc_html__( 'Height', 'profecient-essential' ),
			'segment'   => 'style_grouped',
			'units'     => array( 'px', '%', 'em' ),
			'options'   => array(
				'min'  => 0,
				'max'  => 100,
				'step' => 1,
			),
			'selectors' => '.profecient-product-custom-add-to-cart .woocommerce-grouped-product-list .woocommerce-grouped-product-list-item__quantity input',
			'attribute' => 'height',
		);

		$this->options['st_grouped_quantity_input_typography'] = array(
			'type'      => 'typography',
			'title'     => esc_html__( 'Typograhpy', 'profecient-essential' ),
			'segment'   => 'style_grouped',
			'selectors' => '.profecient-product-custom-add-to-cart .woocommerce-grouped-product-list .woocommerce-grouped-product-list-item__quantity input',
		);

		$this->options['st_grouped_quantity_input_text_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Color', 'profecient-essential' ),
			'segment'   => 'style_grouped',
			'selectors' => '.profecient-product-custom-add-to-cart .woocommerce-grouped-product-list .woocommerce-grouped-product-list-item__quantity input',
		);

		$this->options['st_grouped_quantity_input_background'] = array(
			'type'      => 'background',
			'title'     => esc_html__( 'Background', 'profecient-essential' ),
			'segment'   => 'style_grouped',
			'selectors' => '.profecient-product-custom-add-to-cart .woocommerce-grouped-product-list .woocommerce-grouped-product-list-item__quantity input',
			'options'   => array(
				'classic',
				'gradient',
			),
			'exclude'   => array( 'image' ),
		);

		$this->options['st_grouped_quantity_input_tab_end'] = array(
			'type'    => 'control_tab_end',
			'segment' => 'style_grouped',
		);

		$this->options['st_grouped_quantity_button_tab_start'] = array(
			'type'    => 'control_tab_start',
			'title'   => esc_html__( 'Button', 'profecient-essential' ),
			'segment' => 'style_grouped',
		);

		$this->options['st_grouped_quantity_button_margin'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Margin', 'profecient-essential' ),
			'segment'   => 'style_grouped',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.profecient-product-custom-add-to-cart .woocommerce-grouped-product-list .woocommerce-grouped-product-list-item__quantity .button',
			'attribute' => 'margin',
		);

		$this->options['st_grouped_quantity_button_padding'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Padding', 'profecient-essential' ),
			'segment'   => 'style_grouped',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.profecient-product-custom-add-to-cart .woocommerce-grouped-product-list .woocommerce-grouped-product-list-item__quantity .button',
			'attribute' => 'padding',
		);

		$this->options['st_grouped_quantity_button_typography'] = array(
			'type'      => 'typography',
			'title'     => esc_html__( 'Typograhpy', 'profecient-essential' ),
			'segment'   => 'style_grouped',
			'selectors' => '.profecient-product-custom-add-to-cart .woocommerce-grouped-product-list .woocommerce-grouped-product-list-item__quantity .button',
		);

		$this->options['st_grouped_quantity_button_normal_text_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Normal Color', 'profecient-essential' ),
			'segment'   => 'style_grouped',
			'selectors' => '.profecient-product-custom-add-to-cart .woocommerce-grouped-product-list .woocommerce-grouped-product-list-item__quantity .button',
		);

		$this->options['st_grouped_quantity_button_normal_background'] = array(
			'type'      => 'background',
			'title'     => esc_html__( 'Normal Background', 'profecient-essential' ),
			'segment'   => 'style_grouped',
			'selectors' => '.profecient-product-custom-add-to-cart .woocommerce-grouped-product-list .woocommerce-grouped-product-list-item__quantity .button',
			'options'   => array(
				'classic',
				'gradient',
			),
			'exclude'   => array( 'image' ),
		);

		$this->options['st_grouped_quantity_button_hover_text_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Hover Color', 'profecient-essential' ),
			'segment'   => 'style_grouped',
			'selectors' => '.profecient-product-custom-add-to-cart .woocommerce-grouped-product-list .woocommerce-grouped-product-list-item__quantity .button:hover',
		);

		$this->options['st_grouped_quantity_button_hover_background'] = array(
			'type'      => 'background',
			'title'     => esc_html__( 'Hover Background', 'profecient-essential' ),
			'segment'   => 'style_grouped',
			'selectors' => '.profecient-product-custom-add-to-cart .woocommerce-grouped-product-list .woocommerce-grouped-product-list-item__quantity .button:hover',
			'options'   => array(
				'classic',
				'gradient',
			),
			'exclude'   => array( 'image' ),
		);

		$this->options['st_grouped_quantity_button_disabled_text_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Disabled Color', 'profecient-essential' ),
			'segment'   => 'style_grouped',
			'selectors' => '.profecient-product-custom-add-to-cart .woocommerce-grouped-product-list .woocommerce-grouped-product-list-item__quantity .button.disabled',
		);

		$this->options['st_grouped_quantity_button_disabled_background'] = array(
			'type'      => 'background',
			'title'     => esc_html__( 'Disabled Background', 'profecient-essential' ),
			'segment'   => 'style_grouped',
			'selectors' => '.profecient-product-custom-add-to-cart .woocommerce-grouped-product-list .woocommerce-grouped-product-list-item__quantity .button.disabled',
			'options'   => array(
				'classic',
				'gradient',
			),
			'exclude'   => array( 'image' ),
		);

		$this->options['st_grouped_quantity_button_tab_end'] = array(
			'type'    => 'control_tab_end',
			'segment' => 'style_grouped',
		);

		$this->options['st_grouped_quantity_tabs_end'] = array(
			'type'    => 'control_tabs_end',
			'segment' => 'style_grouped',
		);

		$this->options['st_grouped_label_heading'] = array(
			'type'      => 'heading',
			'title'     => 'Label',
			'segment'   => 'style_grouped',
			'separator' => 'before',
		);

		$this->options['st_grouped_label_typography'] = array(
			'type'      => 'typography',
			'title'     => esc_html__( 'Typograhpy', 'profecient-essential' ),
			'segment'   => 'style_grouped',
			'selectors' => '.profecient-product-custom-add-to-cart .woocommerce-grouped-product-list .woocommerce-grouped-product-list-item__label',
		);

		$this->options['st_grouped_label_tabs_start'] = array(
			'type'    => 'control_tabs_start',
			'segment' => 'style_grouped',
		);

		$this->options['st_grouped_label_normal_tab_start'] = array(
			'type'    => 'control_tab_start',
			'title'   => esc_html__( 'Normal', 'profecient-essential' ),
			'segment' => 'style_grouped',
		);

		$this->options['st_grouped_label_normal_text_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Color', 'profecient-essential' ),
			'segment'   => 'style_grouped',
			'selectors' => '.profecient-product-custom-add-to-cart .woocommerce-grouped-product-list .woocommerce-grouped-product-list-item__label',
		);

		$this->options['st_grouped_label_normal_tab_end'] = array(
			'type'    => 'control_tab_end',
			'segment' => 'style_grouped',
		);

		$this->options['st_grouped_label_link_tab_start'] = array(
			'type'    => 'control_tab_start',
			'title'   => esc_html__( 'Link', 'profecient-essential' ),
			'segment' => 'style_grouped',
		);

		$this->options['st_grouped_label_link_text_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Color', 'profecient-essential' ),
			'segment'   => 'style_grouped',
			'selectors' => '.profecient-product-custom-add-to-cart .woocommerce-grouped-product-list .woocommerce-grouped-product-list-item__label a',
		);

		$this->options['st_grouped_label_link_tab_end'] = array(
			'type'    => 'control_tab_end',
			'segment' => 'style_grouped',
		);

		$this->options['st_grouped_label_link_hover_tab_start'] = array(
			'type'    => 'control_tab_start',
			'title'   => esc_html__( 'Link Hover', 'profecient-essential' ),
			'segment' => 'style_grouped',
		);

		$this->options['st_grouped_label_link_hover_text_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Color', 'profecient-essential' ),
			'segment'   => 'style_grouped',
			'selectors' => '.profecient-product-custom-add-to-cart .woocommerce-grouped-product-list .woocommerce-grouped-product-list-item__label a:hover',
		);

		$this->options['st_grouped_label_link_hover_tab_end'] = array(
			'type'    => 'control_tab_end',
			'segment' => 'style_grouped',
		);

		$this->options['st_grouped_label_tabs_end'] = array(
			'type'    => 'control_tabs_end',
			'segment' => 'style_grouped',
		);

		$this->options['st_grouped_price_heading'] = array(
			'type'      => 'heading',
			'title'     => 'Price',
			'segment'   => 'style_grouped',
			'separator' => 'before',
		);

		$this->options['st_grouped_price_padding'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Padding', 'profecient-essential' ),
			'segment'   => 'style_grouped',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.profecient-product-custom-add-to-cart .woocommerce-grouped-product-list-item__price',
			'attribute' => 'padding',
		);

		$this->options['st_grouped_price_typography'] = array(
			'type'      => 'typography',
			'title'     => esc_html__( 'Typography', 'profecient-essential' ),
			'segment'   => 'style_grouped',
			'selectors' => '.profecient-product-custom-add-to-cart .woocommerce-grouped-product-list-item__price',
		);

		$this->options['st_grouped_price_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Color', 'profecient-essential' ),
			'segment'   => 'style_grouped',
			'selectors' => '.profecient-product-custom-add-to-cart .woocommerce-grouped-product-list-item__price',
		);

		$this->options['st_grouped_price_second_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Second Color', 'profecient-essential' ),
			'segment'   => 'style_grouped',
			'selectors' => '.profecient-product-custom-add-to-cart .woocommerce-grouped-product-list-item__price del',
		);

		parent::additional_style();
	}
}
