<?php
/**
 * Product Single Add To Cart Option Class
 *
 * @package profecient-essential
 * @author jegtheme
 * @since 1.0.0
 */

namespace Profecient\Essential\JKit\Elements\Options;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

use Jeg\Elementor_Kit\Elements\Options\Option_Abstract;

/**
 * Class Product_Single_Add_To_Cart_Option
 */
class Product_Single_Add_To_Cart_Option extends Option_Abstract {
	/**
	 * Show color scheme flag for element.
	 *
	 * @return bool
	 */
	public function show_color_scheme() {
		return false;
	}

	/**
	 * Compatibility column
	 *
	 * @return array
	 */
	public function compatible_column() {
		return array();
	}

	/**
	 * Override function to remove compatible column alert
	 */
	public function set_compatible_column_option() {}

	/**
	 * Element name
	 *
	 * @return string
	 */
	public function get_element_name() {
		return esc_html__( 'Add To Cart', 'profecient-essential' );
	}

	/**
	 * Element category
	 *
	 * @return string
	 */
	public function get_category() {
		return esc_html__( 'Profecient - Single Product', 'profecient-essential' );
	}

	/**
	 * Element options
	 */
	public function set_options() {
		$this->set_style_option();
		$this->set_element_options();

		parent::set_options();
	}

	/**
	 * Option segments
	 */
	public function set_segments() {
		$this->segments['segment_settings'] = array(
			'name'     => esc_html__( 'Content Settings', 'profecient-essential' ),
			'priority' => 10,
		);

		$this->set_style_segment();
	}

	/**
	 * Style segments
	 */
	public function set_style_segment() {
		$this->segments['style_wrapper'] = array(
			'name'      => esc_html__( 'Wrapper', 'profecient-essential' ),
			'priority'  => 10,
			'kit_style' => true,
		);

		$this->segments['style_select'] = array(
			'name'       => esc_html__( 'Select Input', 'profecient-essential' ),
			'priority'   => 11,
			'kit_style'  => true,
			'dependency' => array(
				array(
					'field'    => 'sg_settings_product_type_preview',
					'operator' => '===',
					'value'    => 'variable',
				),
			),
		);

		$this->segments['style_button'] = array(
			'name'      => esc_html__( 'Button', 'profecient-essential' ),
			'priority'  => 12,
			'kit_style' => true,
		);

		$this->segments['style_quantity'] = array(
			'name'      => esc_html__( 'Quantity', 'profecient-essential' ),
			'priority'  => 13,
			'kit_style' => true,
		);

		$this->segments['style_variation'] = array(
			'name'      => esc_html__( 'Variation Content', 'profecient-essential' ),
			'priority'  => 14,
			'kit_style' => true,
		);

		$this->segments['style_grouped'] = array(
			'name'      => esc_html__( 'Grouped Content', 'profecient-essential' ),
			'priority'  => 15,
			'kit_style' => true,
		);

		parent::set_style_segment();
	}

	/**
	 * Set element option
	 */
	public function set_element_options() {
		$this->options['sg_settings_product_type_preview'] = array(
			'type'    => 'select',
			'title'   => esc_html__( 'Product Type Preview', 'profecient-essential' ),
			'default' => 'simple',
			'options' => array(
				'simple'   => esc_html__( 'Simple', 'profecient-essential' ),
				'variable' => esc_html__( 'Variable', 'profecient-essential' ),
				'external' => esc_html__( 'External', 'profecient-essential' ),
				'grouped'  => esc_html__( 'Grouped', 'profecient-essential' ),
			),
			'segment' => 'segment_settings',
		);

		$this->options['sg_settings_button_icon'] = array(
			'type'    => 'iconpicker',
			'title'   => esc_html__( 'Button Icon', 'profecient-essential' ),
			'segment' => 'segment_settings',
		);

		$this->options['sg_settings_custom_simple_single_add_to_cart_text'] = array(
			'type'        => 'text',
			'title'       => esc_html__( 'Custom Button Text', 'profecient-essential' ),
			'segment'     => 'segment_settings',
			'description' => 'If you fill this option, the default text from WooCommerce will be overwritten.',
			'dependency'  => array(
				array(
					'field'    => 'sg_settings_product_type_preview',
					'operator' => '===',
					'value'    => 'simple',
				),
			),
		);

		$this->options['sg_settings_custom_variable_single_add_to_cart_text'] = array(
			'type'        => 'text',
			'title'       => esc_html__( 'Custom Button Text', 'profecient-essential' ),
			'segment'     => 'segment_settings',
			'description' => 'If you fill this option, the default text from WooCommerce will be overwritten.',
			'dependency'  => array(
				array(
					'field'    => 'sg_settings_product_type_preview',
					'operator' => '===',
					'value'    => 'variable',
				),
			),
		);

		$this->options['sg_settings_custom_external_single_add_to_cart_text'] = array(
			'type'        => 'text',
			'title'       => esc_html__( 'Custom Button Text', 'profecient-essential' ),
			'segment'     => 'segment_settings',
			'description' => 'If you fill this option, the default text from WooCommerce will be overwritten.',
			'dependency'  => array(
				array(
					'field'    => 'sg_settings_product_type_preview',
					'operator' => '===',
					'value'    => 'external',
				),
			),
		);

		$this->options['sg_settings_custom_grouped_single_add_to_cart_text'] = array(
			'type'        => 'text',
			'title'       => esc_html__( 'Custom Button Text', 'profecient-essential' ),
			'segment'     => 'segment_settings',
			'description' => 'If you fill this option, the default text from WooCommerce will be overwritten.',
			'dependency'  => array(
				array(
					'field'    => 'sg_settings_product_type_preview',
					'operator' => '===',
					'value'    => 'grouped',
				),
			),
		);
	}

	/**
	 * Add Additional Style.
	 */
	public function additional_style() {
		$this->options['st_select_arrow_size'] = array(
			'type'         => 'slider',
			'title'        => esc_html__( 'Select\'s Arrow Size', 'profecient-essential' ),
			'segment'      => 'style_select',
			'responsive'   => true,
			'units'        => array( 'px' ),
			'default_unit' => 'px',
			'options'      => array(
				'min'  => 0,
				'max'  => 60,
				'step' => 1,
			),
			'selectors'    => array(
				'custom' => array(
					'{{WRAPPER}} .profecient-add-to-cart select' => 'background-size: {{SIZE}}{{UNIT}};',
				),
			),
		);

		$this->options['st_select_arrow_position_x'] = array(
			'type'         => 'slider',
			'title'        => esc_html__( 'Select\'s  Arrow Position X', 'profecient-essential' ),
			'segment'      => 'style_select',
			'responsive'   => true,
			'units'        => array( '%' ),
			'default_unit' => '%',
			'options'      => array(
				'min'  => 0,
				'max'  => 100,
				'step' => 1,
			),
			'selectors'    => array(
				'custom' => array(
					'{{WRAPPER}} .profecient-add-to-cart select' => '--profecient-arrow-position-x: {{SIZE}}{{UNIT}};',
				),
			),
		);

		$this->options['st_select_arrow_position_y'] = array(
			'type'         => 'slider',
			'title'        => esc_html__( 'Select\'s  Arrow Position Y', 'profecient-essential' ),
			'segment'      => 'style_select',
			'responsive'   => true,
			'units'        => array( '%' ),
			'default_unit' => '%',
			'options'      => array(
				'min'  => 0,
				'max'  => 100,
				'step' => 1,
			),
			'selectors'    => array(
				'custom' => array(
					'{{WRAPPER}} .profecient-add-to-cart select' => '--profecient-arrow-position-y: {{SIZE}}{{UNIT}};',
				),
			),
		);

		$this->options['st_wrapper_margin'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Margin', 'profecient-essential' ),
			'segment'   => 'style_wrapper',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.profecient-add-to-cart',
			'attribute' => 'margin',
		);

		$this->options['st_wrapper_padding'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Padding', 'profecient-essential' ),
			'segment'   => 'style_wrapper',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.profecient-add-to-cart',
			'attribute' => 'padding',
		);

		$this->options['st_wrapper_background'] = array(
			'type'      => 'background',
			'title'     => esc_html__( 'Background', 'profecient-essential' ),
			'segment'   => 'style_wrapper',
			'selectors' => '.profecient-add-to-cart',
			'options'   => array(
				'classic',
				'gradient',
			),
		);

		$this->options['st_button_margin'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Margin', 'profecient-essential' ),
			'segment'   => 'style_button',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.profecient-add-to-cart button.single_add_to_cart_button',
			'attribute' => 'margin',
		);

		$this->options['st_button_padding'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Padding', 'profecient-essential' ),
			'segment'   => 'style_button',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.profecient-add-to-cart button.single_add_to_cart_button',
			'attribute' => 'padding',
		);

		$this->options['st_button_typography'] = array(
			'type'      => 'typography',
			'title'     => esc_html__( 'Typograhpy', 'profecient-essential' ),
			'segment'   => 'style_button',
			'selectors' => '.profecient-add-to-cart button.single_add_to_cart_button',
		);

		$this->options['st_button_tabs_start'] = array(
			'type'    => 'control_tabs_start',
			'segment' => 'style_button',
		);

		$this->options['st_button_normal_tab_start'] = array(
			'type'    => 'control_tab_start',
			'title'   => esc_html__( 'Normal', 'profecient-essential' ),
			'segment' => 'style_button',
		);

		$this->options['st_button_normal_text_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Color', 'profecient-essential' ),
			'segment'   => 'style_button',
			'selectors' => '.profecient-add-to-cart button.single_add_to_cart_button',
		);

		$this->options['st_button_normal_background'] = array(
			'type'      => 'background',
			'title'     => esc_html__( 'Background', 'profecient-essential' ),
			'segment'   => 'style_button',
			'selectors' => '.profecient-add-to-cart button.single_add_to_cart_button',
			'options'   => array(
				'classic',
				'gradient',
			),
			'exclude'   => array( 'image' ),
		);

		$this->options['st_button_normal_border_radius'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Border Radius', 'profecient-essential' ),
			'segment'   => 'style_button',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.profecient-add-to-cart button.single_add_to_cart_button',
			'attribute' => 'border-radius',
		);

		$this->options['st_button_normal_border'] = array(
			'type'      => 'border',
			'title'     => esc_html__( 'Border', 'profecient-essential' ),
			'segment'   => 'style_button',
			'selectors' => '.profecient-add-to-cart button.single_add_to_cart_button',
		);

		$this->options['st_button_normal_boxshadow'] = array(
			'type'      => 'boxshadow',
			'title'     => esc_html__( 'Box Shadow', 'profecient-essential' ),
			'segment'   => 'style_button',
			'selectors' => '.profecient-add-to-cart button.single_add_to_cart_button',
		);

		$this->options['st_button_normal_tab_end'] = array(
			'type'    => 'control_tab_end',
			'segment' => 'style_button',
		);

		$this->options['st_button_hover_tab_start'] = array(
			'type'    => 'control_tab_start',
			'title'   => esc_html__( 'Hover', 'profecient-essential' ),
			'segment' => 'style_button',
		);

		$this->options['st_button_hover_text_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Color', 'profecient-essential' ),
			'segment'   => 'style_button',
			'selectors' => '.profecient-add-to-cart button.single_add_to_cart_button:hover',
		);

		$this->options['st_button_hover_background'] = array(
			'type'      => 'background',
			'title'     => esc_html__( 'Background', 'profecient-essential' ),
			'segment'   => 'style_button',
			'selectors' => '.profecient-add-to-cart button.single_add_to_cart_button:hover',
			'options'   => array(
				'classic',
				'gradient',
			),
			'exclude'   => array( 'image' ),
		);

		$this->options['st_button_hover_border_radius'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Border Radius', 'profecient-essential' ),
			'segment'   => 'style_button',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.profecient-add-to-cart button.single_add_to_cart_button:hover',
			'attribute' => 'border-radius',
		);

		$this->options['st_button_hover_border'] = array(
			'type'      => 'border',
			'title'     => esc_html__( 'Border', 'profecient-essential' ),
			'segment'   => 'style_button',
			'selectors' => '.profecient-add-to-cart button.single_add_to_cart_button:hover',
		);

		$this->options['st_button_hover_boxshadow'] = array(
			'type'      => 'boxshadow',
			'title'     => esc_html__( 'Box Shadow', 'profecient-essential' ),
			'segment'   => 'style_button',
			'selectors' => '.profecient-add-to-cart button.single_add_to_cart_button:hover',
		);

		$this->options['st_button_hover_tab_end'] = array(
			'type'    => 'control_tab_end',
			'segment' => 'style_button',
		);

		$this->options['st_button_disabled_tab_start'] = array(
			'type'    => 'control_tab_start',
			'title'   => esc_html__( 'Disabled', 'profecient-essential' ),
			'segment' => 'style_button',
		);

		$this->options['st_button_disabled_text_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Color', 'profecient-essential' ),
			'segment'   => 'style_button',
			'selectors' => '.profecient-add-to-cart button.single_add_to_cart_button.disabled',
		);

		$this->options['st_button_disabled_background'] = array(
			'type'      => 'background',
			'title'     => esc_html__( 'Background', 'profecient-essential' ),
			'segment'   => 'style_button',
			'selectors' => '.profecient-add-to-cart button.single_add_to_cart_button.disabled',
			'options'   => array(
				'classic',
				'gradient',
			),
			'exclude'   => array( 'image' ),
		);

		$this->options['st_button_disabled_border_radius'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Border Radius', 'profecient-essential' ),
			'segment'   => 'style_button',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.profecient-add-to-cart button.single_add_to_cart_button.disabled',
			'attribute' => 'border-radius',
		);

		$this->options['st_button_disabled_border'] = array(
			'type'      => 'border',
			'title'     => esc_html__( 'Border', 'profecient-essential' ),
			'segment'   => 'style_button',
			'selectors' => '.profecient-add-to-cart button.single_add_to_cart_button.disabled',
		);

		$this->options['st_button_disabled_boxshadow'] = array(
			'type'      => 'boxshadow',
			'title'     => esc_html__( 'Box Shadow', 'profecient-essential' ),
			'segment'   => 'style_button',
			'selectors' => '.profecient-add-to-cart button.single_add_to_cart_button.disabled',
		);

		$this->options['st_button_disabled_tab_end'] = array(
			'type'    => 'control_tab_end',
			'segment' => 'style_button',
		);

		$this->options['st_button_tabs_end'] = array(
			'type'    => 'control_tabs_end',
			'segment' => 'style_button',
		);

		$this->options['st_button_icon_heading'] = array(
			'type'      => 'heading',
			'title'     => esc_html__( 'Icon', 'profecient-essential' ),
			'segment'   => 'style_button',
			'separator' => 'before',
		);

		$this->options['st_button_icon_margin'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Margin', 'profecient-essential' ),
			'segment'   => 'style_button',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.profecient-add-to-cart button.single_add_to_cart_button > i',
			'attribute' => 'margin',
		);

		$this->options['st_button_icon_position'] = array(
			'type'      => 'radio',
			'title'     => esc_html__( 'Position', 'profecient-essential' ),
			'segment'   => 'style_button',
			'options'   => array(
				'ltr' => array(
					'title' => esc_html__( 'Left', 'profecient-essential' ),
					'icon'  => 'eicon-h-align-left',
				),
				'rtl' => array(
					'title' => esc_html__( 'Right', 'profecient-essential' ),
					'icon'  => 'eicon-h-align-right',
				),
			),
			'default'   => 'right',
			'selectors' => '.profecient-add-to-cart button.single_add_to_cart_button',
			'attribute' => 'direction',
		);

		$this->options['st_quantity_margin'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Margin', 'profecient-essential' ),
			'segment'   => 'style_quantity',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.profecient-add-to-cart .quantity',
			'attribute' => 'margin',
		);

		$this->options['st_quantity_border_radius'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Border Radius', 'profecient-essential' ),
			'segment'   => 'style_quantity',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.profecient-add-to-cart .quantity input',
			'attribute' => 'border-radius',
		);

		$this->options['st_quantity_border'] = array(
			'type'      => 'border',
			'title'     => esc_html__( 'Border', 'profecient-essential' ),
			'segment'   => 'style_quantity',
			'selectors' => '.profecient-add-to-cart .quantity input',
		);

		$this->options['st_quantity_width'] = array(
			'type'      => 'slider',
			'title'     => esc_html__( 'Width', 'profecient-essential' ),
			'segment'   => 'style_quantity',
			'units'     => array( 'px', '%', 'em' ),
			'options'   => array(
				'min'  => 0,
				'max'  => 100,
				'step' => 1,
			),
			'selectors' => '.profecient-add-to-cart .quantity input',
			'attribute' => 'width',
		);

		$this->options['st_quantity_height'] = array(
			'type'      => 'slider',
			'title'     => esc_html__( 'Height', 'profecient-essential' ),
			'segment'   => 'style_quantity',
			'units'     => array( 'px', '%', 'em' ),
			'options'   => array(
				'min'  => 0,
				'max'  => 100,
				'step' => 1,
			),
			'selectors' => '.profecient-add-to-cart form.cart .quantity input',
			'attribute' => 'height',
		);

		$this->options['st_quantity_typography'] = array(
			'type'      => 'typography',
			'title'     => esc_html__( 'Typograhpy', 'profecient-essential' ),
			'segment'   => 'style_quantity',
			'selectors' => '.profecient-add-to-cart .quantity input',
		);

		$this->options['st_quantity_text_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Color', 'profecient-essential' ),
			'segment'   => 'style_quantity',
			'selectors' => '.profecient-add-to-cart .quantity input',
		);

		$this->options['st_quantity_background'] = array(
			'type'      => 'background',
			'title'     => esc_html__( 'Background', 'profecient-essential' ),
			'segment'   => 'style_quantity',
			'selectors' => '.profecient-add-to-cart .quantity input',
			'options'   => array(
				'classic',
				'gradient',
			),
			'exclude'   => array( 'image' ),
		);

		$this->options['st_variation_table_heading'] = array(
			'type'    => 'heading',
			'title'   => 'Table',
			'segment' => 'style_variation',
		);

		$this->options['st_variation_table_typography'] = array(
			'type'      => 'typography',
			'title'     => esc_html__( 'Typograhpy', 'profecient-essential' ),
			'segment'   => 'style_variation',
			'selectors' => '.profecient-add-to-cart table.variations',
		);

		$this->options['st_variation_table_text_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Color', 'profecient-essential' ),
			'segment'   => 'style_variation',
			'selectors' => '.profecient-add-to-cart table.variations',
		);

		$this->options['st_variation_select_heading'] = array(
			'type'      => 'heading',
			'title'     => 'Select',
			'separator' => 'before',
			'segment'   => 'style_variation',
		);

		$this->options['st_variation_select_typography'] = array(
			'type'      => 'typography',
			'title'     => esc_html__( 'Typograhpy', 'profecient-essential' ),
			'segment'   => 'style_variation',
			'selectors' => '.profecient-add-to-cart table.variations select',
		);

		$this->options['st_variation_select_text_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Color', 'profecient-essential' ),
			'segment'   => 'style_variation',
			'selectors' => '.profecient-add-to-cart table.variations select',
		);

		$this->options['st_variation_select_background_color'] = array(
			'type'      => 'background',
			'title'     => esc_html__( 'Color', 'profecient-essential' ),
			'segment'   => 'style_variation',
			'selectors' => '.profecient-add-to-cart table.variations select',
			'options'   => array(
				'classic',
				'gradient',
			),
			'exclude'   => array( 'image' ),
		);

		$this->options['st_variation_reset_heading'] = array(
			'type'      => 'heading',
			'title'     => 'Reset',
			'separator' => 'before',
			'segment'   => 'style_variation',
		);

		$this->options['st_variation_reset_typography'] = array(
			'type'      => 'typography',
			'title'     => esc_html__( 'Typograhpy', 'profecient-essential' ),
			'segment'   => 'style_variation',
			'selectors' => '.profecient-add-to-cart .reset_variations',
		);

		$this->options['st_variation_reset_tabs_start'] = array(
			'type'    => 'control_tabs_start',
			'segment' => 'style_variation',
		);

		$this->options['st_variation_reset_normal_tab_start'] = array(
			'type'    => 'control_tab_start',
			'title'   => esc_html__( 'Normal', 'profecient-essential' ),
			'segment' => 'style_variation',
		);

		$this->options['st_variation_reset_normal_text_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Color', 'profecient-essential' ),
			'segment'   => 'style_variation',
			'selectors' => '.profecient-add-to-cart .reset_variations',
		);

		$this->options['st_variation_reset_normal_tab_end'] = array(
			'type'    => 'control_tab_end',
			'segment' => 'style_variation',
		);

		$this->options['st_variation_reset_hover_tab_start'] = array(
			'type'    => 'control_tab_start',
			'title'   => esc_html__( 'Hover', 'profecient-essential' ),
			'segment' => 'style_variation',
		);

		$this->options['st_variation_reset_hover_text_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Color', 'profecient-essential' ),
			'segment'   => 'style_variation',
			'selectors' => '.profecient-add-to-cart .reset_variations:hover',
		);

		$this->options['st_variation_reset_hover_tab_end'] = array(
			'type'    => 'control_tab_end',
			'segment' => 'style_variation',
		);

		$this->options['st_variation_reset_tabs_end'] = array(
			'type'    => 'control_tabs_end',
			'segment' => 'style_variation',
		);

		$this->options['st_variation_description_heading'] = array(
			'type'      => 'heading',
			'title'     => 'Description',
			'separator' => 'before',
			'segment'   => 'style_variation',
		);

		$this->options['st_variation_description_typography'] = array(
			'type'      => 'typography',
			'title'     => esc_html__( 'Typograhpy', 'profecient-essential' ),
			'segment'   => 'style_variation',
			'selectors' => '.profecient-add-to-cart .woocommerce-variation-description',
		);

		$this->options['st_variation_description_text_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Color', 'profecient-essential' ),
			'segment'   => 'style_variation',
			'selectors' => '.profecient-add-to-cart .woocommerce-variation-description',
		);

		$this->options['st_variation_price_heading'] = array(
			'type'      => 'heading',
			'title'     => 'Price',
			'separator' => 'before',
			'segment'   => 'style_variation',
		);

		$this->options['st_variation_price_typography'] = array(
			'type'      => 'typography',
			'title'     => esc_html__( 'Typograhpy', 'profecient-essential' ),
			'segment'   => 'style_variation',
			'selectors' => '.profecient-add-to-cart .woocommerce-variation-price',
		);

		$this->options['st_variation_price_text_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Color', 'profecient-essential' ),
			'segment'   => 'style_variation',
			'selectors' => '.profecient-add-to-cart .woocommerce-variation-price span.price',
		);

		$this->options['st_grouped_quantity_heading'] = array(
			'type'    => 'heading',
			'title'   => 'Quantity',
			'segment' => 'style_grouped',
		);

		$this->options['st_grouped_quantity_tabs_start'] = array(
			'type'    => 'control_tabs_start',
			'segment' => 'style_grouped',
		);

		$this->options['st_grouped_quantity_input_tab_start'] = array(
			'type'    => 'control_tab_start',
			'title'   => esc_html__( 'Input', 'profecient-essential' ),
			'segment' => 'style_grouped',
		);

		$this->options['st_grouped_quantity_input_margin'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Margin', 'profecient-essential' ),
			'segment'   => 'style_grouped',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.profecient-add-to-cart .woocommerce-grouped-product-list .woocommerce-grouped-product-list-item__quantity input',
			'attribute' => 'margin',
		);

		$this->options['st_grouped_quantity_input_width'] = array(
			'type'      => 'slider',
			'title'     => esc_html__( 'Width', 'profecient-essential' ),
			'segment'   => 'style_grouped',
			'units'     => array( 'px', '%', 'em' ),
			'options'   => array(
				'min'  => 0,
				'max'  => 100,
				'step' => 1,
			),
			'selectors' => '.profecient-add-to-cart .woocommerce-grouped-product-list .woocommerce-grouped-product-list-item__quantity input',
			'attribute' => 'width',
		);

		$this->options['st_grouped_quantity_input_height'] = array(
			'type'      => 'slider',
			'title'     => esc_html__( 'Height', 'profecient-essential' ),
			'segment'   => 'style_grouped',
			'units'     => array( 'px', '%', 'em' ),
			'options'   => array(
				'min'  => 0,
				'max'  => 100,
				'step' => 1,
			),
			'selectors' => '.profecient-add-to-cart .woocommerce-grouped-product-list .woocommerce-grouped-product-list-item__quantity input',
			'attribute' => 'height',
		);

		$this->options['st_grouped_quantity_input_typography'] = array(
			'type'      => 'typography',
			'title'     => esc_html__( 'Typograhpy', 'profecient-essential' ),
			'segment'   => 'style_grouped',
			'selectors' => '.profecient-add-to-cart .woocommerce-grouped-product-list .woocommerce-grouped-product-list-item__quantity input',
		);

		$this->options['st_grouped_quantity_input_text_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Color', 'profecient-essential' ),
			'segment'   => 'style_grouped',
			'selectors' => '.profecient-add-to-cart .woocommerce-grouped-product-list .woocommerce-grouped-product-list-item__quantity input',
		);

		$this->options['st_grouped_quantity_input_background'] = array(
			'type'      => 'background',
			'title'     => esc_html__( 'Background', 'profecient-essential' ),
			'segment'   => 'style_grouped',
			'selectors' => '.profecient-add-to-cart .woocommerce-grouped-product-list .woocommerce-grouped-product-list-item__quantity input',
			'options'   => array(
				'classic',
				'gradient',
			),
			'exclude'   => array( 'image' ),
		);

		$this->options['st_grouped_quantity_input_tab_end'] = array(
			'type'    => 'control_tab_end',
			'segment' => 'style_grouped',
		);

		$this->options['st_grouped_quantity_button_tab_start'] = array(
			'type'    => 'control_tab_start',
			'title'   => esc_html__( 'Button', 'profecient-essential' ),
			'segment' => 'style_grouped',
		);

		$this->options['st_grouped_quantity_button_margin'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Margin', 'profecient-essential' ),
			'segment'   => 'style_grouped',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.profecient-add-to-cart .woocommerce-grouped-product-list .woocommerce-grouped-product-list-item__quantity .button',
			'attribute' => 'margin',
		);

		$this->options['st_grouped_quantity_button_padding'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Padding', 'profecient-essential' ),
			'segment'   => 'style_grouped',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.profecient-add-to-cart .woocommerce-grouped-product-list .woocommerce-grouped-product-list-item__quantity .button',
			'attribute' => 'padding',
		);

		$this->options['st_grouped_quantity_button_typography'] = array(
			'type'      => 'typography',
			'title'     => esc_html__( 'Typograhpy', 'profecient-essential' ),
			'segment'   => 'style_grouped',
			'selectors' => '.profecient-add-to-cart .woocommerce-grouped-product-list .woocommerce-grouped-product-list-item__quantity .button',
		);

		$this->options['st_grouped_quantity_button_normal_text_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Normal Color', 'profecient-essential' ),
			'segment'   => 'style_grouped',
			'selectors' => '.profecient-add-to-cart .woocommerce-grouped-product-list .woocommerce-grouped-product-list-item__quantity .button',
		);

		$this->options['st_grouped_quantity_button_normal_background'] = array(
			'type'      => 'background',
			'title'     => esc_html__( 'Normal Background', 'profecient-essential' ),
			'segment'   => 'style_grouped',
			'selectors' => '.profecient-add-to-cart .woocommerce-grouped-product-list .woocommerce-grouped-product-list-item__quantity .button',
			'options'   => array(
				'classic',
				'gradient',
			),
			'exclude'   => array( 'image' ),
		);

		$this->options['st_grouped_quantity_button_hover_text_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Hover Color', 'profecient-essential' ),
			'segment'   => 'style_grouped',
			'selectors' => '.profecient-add-to-cart .woocommerce-grouped-product-list .woocommerce-grouped-product-list-item__quantity .button:hover',
		);

		$this->options['st_grouped_quantity_button_hover_background'] = array(
			'type'      => 'background',
			'title'     => esc_html__( 'Hover Background', 'profecient-essential' ),
			'segment'   => 'style_grouped',
			'selectors' => '.profecient-add-to-cart .woocommerce-grouped-product-list .woocommerce-grouped-product-list-item__quantity .button:hover',
			'options'   => array(
				'classic',
				'gradient',
			),
			'exclude'   => array( 'image' ),
		);

		$this->options['st_grouped_quantity_button_disabled_text_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Disabled Color', 'profecient-essential' ),
			'segment'   => 'style_grouped',
			'selectors' => '.profecient-add-to-cart .woocommerce-grouped-product-list .woocommerce-grouped-product-list-item__quantity .button.disabled',
		);

		$this->options['st_grouped_quantity_button_disabled_background'] = array(
			'type'      => 'background',
			'title'     => esc_html__( 'Disabled Background', 'profecient-essential' ),
			'segment'   => 'style_grouped',
			'selectors' => '.profecient-add-to-cart .woocommerce-grouped-product-list .woocommerce-grouped-product-list-item__quantity .button.disabled',
			'options'   => array(
				'classic',
				'gradient',
			),
			'exclude'   => array( 'image' ),
		);

		$this->options['st_grouped_quantity_button_tab_end'] = array(
			'type'    => 'control_tab_end',
			'segment' => 'style_grouped',
		);

		$this->options['st_grouped_quantity_tabs_end'] = array(
			'type'    => 'control_tabs_end',
			'segment' => 'style_grouped',
		);

		$this->options['st_grouped_label_heading'] = array(
			'type'      => 'heading',
			'title'     => 'Label',
			'segment'   => 'style_grouped',
			'separator' => 'before',
		);

		$this->options['st_grouped_label_typography'] = array(
			'type'      => 'typography',
			'title'     => esc_html__( 'Typograhpy', 'profecient-essential' ),
			'segment'   => 'style_grouped',
			'selectors' => '.profecient-add-to-cart .woocommerce-grouped-product-list .woocommerce-grouped-product-list-item__label',
		);

		$this->options['st_grouped_label_tabs_start'] = array(
			'type'    => 'control_tabs_start',
			'segment' => 'style_grouped',
		);

		$this->options['st_grouped_label_normal_tab_start'] = array(
			'type'    => 'control_tab_start',
			'title'   => esc_html__( 'Normal', 'profecient-essential' ),
			'segment' => 'style_grouped',
		);

		$this->options['st_grouped_label_normal_text_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Color', 'profecient-essential' ),
			'segment'   => 'style_grouped',
			'selectors' => '.profecient-add-to-cart .woocommerce-grouped-product-list .woocommerce-grouped-product-list-item__label',
		);

		$this->options['st_grouped_label_normal_tab_end'] = array(
			'type'    => 'control_tab_end',
			'segment' => 'style_grouped',
		);

		$this->options['st_grouped_label_link_tab_start'] = array(
			'type'    => 'control_tab_start',
			'title'   => esc_html__( 'Link', 'profecient-essential' ),
			'segment' => 'style_grouped',
		);

		$this->options['st_grouped_label_link_text_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Color', 'profecient-essential' ),
			'segment'   => 'style_grouped',
			'selectors' => '.profecient-add-to-cart .woocommerce-grouped-product-list .woocommerce-grouped-product-list-item__label a',
		);

		$this->options['st_grouped_label_link_tab_end'] = array(
			'type'    => 'control_tab_end',
			'segment' => 'style_grouped',
		);

		$this->options['st_grouped_label_link_hover_tab_start'] = array(
			'type'    => 'control_tab_start',
			'title'   => esc_html__( 'Link Hover', 'profecient-essential' ),
			'segment' => 'style_grouped',
		);

		$this->options['st_grouped_label_link_hover_text_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Color', 'profecient-essential' ),
			'segment'   => 'style_grouped',
			'selectors' => '.profecient-add-to-cart .woocommerce-grouped-product-list .woocommerce-grouped-product-list-item__label a:hover',
		);

		$this->options['st_grouped_label_link_hover_tab_end'] = array(
			'type'    => 'control_tab_end',
			'segment' => 'style_grouped',
		);

		$this->options['st_grouped_label_tabs_end'] = array(
			'type'    => 'control_tabs_end',
			'segment' => 'style_grouped',
		);

		$this->options['st_grouped_price_heading'] = array(
			'type'      => 'heading',
			'title'     => 'Price',
			'segment'   => 'style_grouped',
			'separator' => 'before',
		);

		$this->options['st_grouped_price_padding'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Padding', 'profecient-essential' ),
			'segment'   => 'style_grouped',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.profecient-add-to-cart .woocommerce-grouped-product-list-item__price',
			'attribute' => 'padding',
		);

		$this->options['st_grouped_price_typography'] = array(
			'type'      => 'typography',
			'title'     => esc_html__( 'Typography', 'profecient-essential' ),
			'segment'   => 'style_grouped',
			'selectors' => '.profecient-add-to-cart .woocommerce-grouped-product-list-item__price',
		);

		$this->options['st_grouped_price_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Color', 'profecient-essential' ),
			'segment'   => 'style_grouped',
			'selectors' => '.profecient-add-to-cart .woocommerce-grouped-product-list-item__price',
		);

		$this->options['st_grouped_price_second_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Second Color', 'profecient-essential' ),
			'segment'   => 'style_grouped',
			'selectors' => '.profecient-add-to-cart .woocommerce-grouped-product-list-item__price del',
		);

		parent::additional_style();
	}
}
