<?php
/**
 * Product Single Additional Information Option Class
 *
 * @package profecient-essential
 * @author jegtheme
 * @since 1.0.0
 */

namespace Profecient\Essential\JKit\Elements\Options;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

use Jeg\Elementor_Kit\Elements\Options\Option_Abstract;

/**
 * Class Product_Single_Additional_Information_Option
 */
class Product_Single_Additional_Information_Option extends Option_Abstract {
	/**
	 * Show color scheme flag for element.
	 *
	 * @return bool
	 */
	public function show_color_scheme() {
		return false;
	}

	/**
	 * Compatibility column
	 *
	 * @return array
	 */
	public function compatible_column() {
		return array();
	}

	/**
	 * Override function to remove compatible column alert
	 */
	public function set_compatible_column_option() {}

	/**
	 * Element name
	 *
	 * @return string
	 */
	public function get_element_name() {
		return esc_html__( 'Additional Information', 'profecient-essential' );
	}

	/**
	 * Element category
	 *
	 * @return string
	 */
	public function get_category() {
		return esc_html__( 'Profecient - Single Product', 'profecient-essential' );
	}

	/**
	 * Element options
	 */
	public function set_options() {
		$this->set_style_option();

		parent::set_options();
	}

	/**
	 * Option segments
	 */
	public function set_segments() {
		$this->set_style_segment();
	}

	/**
	 * Style segments
	 */
	public function set_style_segment() {
		$this->segments['style_heading'] = array(
			'name'      => esc_html__( 'Heading', 'profecient-essential' ),
			'priority'  => 10,
			'kit_style' => true,
		);

		$this->segments['style_table'] = array(
			'name'      => esc_html__( 'Table', 'profecient-essential' ),
			'priority'  => 11,
			'kit_style' => true,
		);

		$this->segments['style_label'] = array(
			'name'      => esc_html__( 'Label', 'profecient-essential' ),
			'priority'  => 12,
			'kit_style' => true,
		);

		$this->segments['style_value'] = array(
			'name'      => esc_html__( 'Value', 'profecient-essential' ),
			'priority'  => 13,
			'kit_style' => true,
		);

		parent::set_style_segment();
	}

	/**
	 * Add Additional Style.
	 */
	public function additional_style() {
		$this->options['st_heading_typography'] = array(
			'type'      => 'typography',
			'title'     => esc_html__( 'Typograhpy', 'profecient-essential' ),
			'segment'   => 'style_heading',
			'selectors' => '.profecient-additional-information h2',
		);

		$this->options['st_heading_text_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Color', 'profecient-essential' ),
			'segment'   => 'style_heading',
			'selectors' => '.profecient-additional-information h2',
		);

		$this->options['st_table_margin'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Margin', 'profecient-essential' ),
			'segment'   => 'style_table',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.profecient-additional-information table.shop_attributes',
			'attribute' => 'margin',
		);

		$this->options['st_table_border_style'] = array(
			'type'      => 'select',
			'segment'   => 'style_table',
			'title'     => esc_html__( 'Border Style', 'profecient-essential' ),
			'options'   => array(
				'solid'  => esc_html__( 'Solid', 'profecient-essential' ),
				'dashed' => esc_html__( 'Dashed', 'profecient-essential' ),
				'dotted' => esc_html__( 'Dotted', 'profecient-essential' ),
				'none'   => esc_html__( 'None', 'profecient-essential' ),
			),
			'selectors' => array(
				'custom' => array(
					'{{WRAPPER}} th.woocommerce-product-attributes-item__label, td.woocommerce-product-attributes-item__value' => 'border-style: {{VALUE}};',
				),
			),
		);

		$this->options['st_table_border_width'] = array(
			'type'       => 'slider',
			'title'      => esc_html__( 'Border Width', 'profecient-essential' ),
			'segment'    => 'style_table',
			'units'      => array( 'px', '%', 'em' ),
			'options'    => array(
				'min'  => 0,
				'max'  => 100,
				'step' => 1,
			),
			'selectors'  => array(
				'custom' => array(
					'{{WRAPPER}} th.woocommerce-product-attributes-item__label, td.woocommerce-product-attributes-item__value' => 'border-width: {{SIZE}}{{UNIT}};',
				),
			),
			'responsive' => true,
		);

		$this->options['st_table_border_color'] = array(
			'type'       => 'color',
			'title'      => esc_html__( 'Table Border Color', 'profecient-essential' ),
			'segment'    => 'style_table',
			'responsive' => true,
			'selectors'  => array(
				'custom' => array(
					'{{WRAPPER}} th.woocommerce-product-attributes-item__label, td.woocommerce-product-attributes-item__value' => 'border-color: {{VALUE}};',
				),
			),
			'dependency' => array(
				array(
					'field'    => 'st_table_border_style',
					'operator' => '==',
					'value'    => array(
						'solid',
						'dashed',
						'dotted',
					),
				),
			),
		);

		$this->options['st_table_border_radius'] = array(
			'type'       => 'dimension',
			'title'      => esc_html__( 'Border Radius', 'profecient-essential' ),
			'segment'    => 'style_table',
			'units'      => array( 'px', '%', 'em' ),
			'selectors'  => array(
				'custom' => array(
					'{{WRAPPER}} .profecient-additional-information table.woocommerce-product-attributes.shop_attributes tr:first-child th.woocommerce-product-attributes-item__label' => 'border-top-left-radius: {{TOP}}{{UNIT}};',
					'{{WRAPPER}} .profecient-additional-information table.woocommerce-product-attributes.shop_attributes tr:first-child td.woocommerce-product-attributes-item__value:last-child' => 'border-top-right-radius: {{RIGHT}}{{UNIT}};',
					'{{WRAPPER}} .profecient-additional-information table.woocommerce-product-attributes.shop_attributes tr:last-child th.woocommerce-product-attributes-item__label' => 'border-bottom-left-radius: {{BOTTOM}}{{UNIT}} ',
					'{{WRAPPER}} .profecient-additional-information table.woocommerce-product-attributes.shop_attributes tr:last-child td.woocommerce-product-attributes-item__value:last-child' => 'border-bottom-right-radius: {{LEFT}}{{UNIT}};',
				),
			),
			'dependency' => array(
				array(
					'field'    => 'st_table_border_style',
					'operator' => '==',
					'value'    => array(
						'solid',
						'dashed',
						'dotted',
					),
				),
			),
		);

		$this->options['st_table_odd_bg_color'] = array(
			'type'      => 'background',
			'title'     => esc_html__( 'Odd Background', 'profecient-essential' ),
			'segment'   => 'style_table',
			'selectors' => '.profecient-additional-information .woocommerce-product-attributes-item:nth-child(odd)',
			'options'   => array(
				'classic',
				'gradient',
			),
			'exclude'   => array( 'image' ),
		);

		$this->options['st_table_even_bg_color']  = array(
			'type'      => 'background',
			'title'     => esc_html__( 'Even Background', 'profecient-essential' ),
			'segment'   => 'style_table',
			'selectors' => '.profecient-additional-information .woocommerce-product-attributes-item:nth-child(even)',
			'options'   => array(
				'classic',
				'gradient',
			),
			'exclude'   => array( 'image' ),
		);
		$this->options['st_table_hover_bg_color'] = array(
			'type'      => 'background',
			'title'     => esc_html__( 'Hover Background', 'profecient-essential' ),
			'segment'   => 'style_table',
			'selectors' => '.profecient-additional-information .woocommerce-product-attributes-item:hover',
			'options'   => array(
				'classic',
				'gradient',
			),
			'exclude'   => array( 'image' ),
		);
		$this->options['st_label_padding']        = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Padding', 'profecient-essential' ),
			'segment'   => 'style_label',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.profecient-additional-information .woocommerce-product-attributes-item__label',
			'attribute' => 'padding',
		);

		$this->options['st_label_typography'] = array(
			'type'      => 'typography',
			'title'     => esc_html__( 'Typograhpy', 'profecient-essential' ),
			'segment'   => 'style_label',
			'selectors' => '.profecient-additional-information .woocommerce-product-attributes-item__label',
		);

		$this->options['st_label_tabs_start'] = array(
			'type'    => 'control_tabs_start',
			'segment' => 'style_label',
		);

		$this->options['st_label_normal_tab_start'] = array(
			'type'    => 'control_tab_start',
			'title'   => esc_html__( 'Normal', 'profecient-essential' ),
			'segment' => 'style_label',
		);

		$this->options['st_label_text_normal_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Color', 'profecient-essential' ),
			'segment'   => 'style_label',
			'selectors' => '.profecient-additional-information .woocommerce-product-attributes-item__label',
		);

		$this->options['st_label_normal_tab_end'] = array(
			'type'    => 'control_tab_end',
			'segment' => 'style_label',
		);

		$this->options['st_label_hover_tab_start'] = array(
			'type'    => 'control_tab_start',
			'title'   => esc_html__( 'Hover', 'profecient-essential' ),
			'segment' => 'style_label',
		);

		$this->options['st_label_text_hover_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Color', 'profecient-essential' ),
			'segment'   => 'style_label',
			'selectors' => '.profecient-additional-information .woocommerce-product-attributes-item:hover .woocommerce-product-attributes-item__label',
		);

		$this->options['st_label_hover_tab_end'] = array(
			'type'    => 'control_tab_end',
			'segment' => 'style_label',
		);

		$this->options['st_label_tabs_end'] = array(
			'type'    => 'control_tabs_end',
			'segment' => 'style_label',
		);

		$this->options['st_value_padding'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Padding', 'profecient-essential' ),
			'segment'   => 'style_value',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.profecient-additional-information .woocommerce-product-attributes-item__value',
			'attribute' => 'padding',
		);

		$this->options['st_value_typography'] = array(
			'type'      => 'typography',
			'title'     => esc_html__( 'Typograhpy', 'profecient-essential' ),
			'segment'   => 'style_value',
			'selectors' => '.profecient-additional-information .woocommerce-product-attributes-item__value',
		);

		$this->options['st_value_tabs_start'] = array(
			'type'    => 'control_tabs_start',
			'segment' => 'style_value',
		);

		$this->options['st_value_normal_tab_start'] = array(
			'type'    => 'control_tab_start',
			'title'   => esc_html__( 'Normal', 'profecient-essential' ),
			'segment' => 'style_value',
		);

		$this->options['st_value_text_normal_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Color', 'profecient-essential' ),
			'segment'   => 'style_value',
			'selectors' => '.profecient-additional-information .woocommerce-product-attributes-item__value',
		);

		$this->options['st_value_normal_tab_end'] = array(
			'type'    => 'control_tab_end',
			'segment' => 'style_value',
		);

		$this->options['st_value_hover_tab_start'] = array(
			'type'    => 'control_tab_start',
			'title'   => esc_html__( 'Hover', 'profecient-essential' ),
			'segment' => 'style_value',
		);

		$this->options['st_value_text_hover_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Color', 'profecient-essential' ),
			'segment'   => 'style_value',
			'selectors' => '.profecient-additional-information .woocommerce-product-attributes-item:hover .woocommerce-product-attributes-item__value',
		);

		$this->options['st_value_hover_tab_end'] = array(
			'type'    => 'control_tab_end',
			'segment' => 'style_value',
		);

		$this->options['st_value_tabs_end'] = array(
			'type'    => 'control_tabs_end',
			'segment' => 'style_value',
		);

		parent::additional_style();
	}
}
