<?php
/**
 * Product Single Breadcrumb Option Class
 *
 * @package profecient-essential
 * @author jegtheme
 * @since 1.0.0
 */

namespace Profecient\Essential\JKit\Elements\Options;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

use \Jeg\Elementor_Kit\Elements\Options\Option_Abstract;

/**
 * Class Product_Single_Breadcrumb_Option
 */
class Product_Single_Breadcrumb_Option extends Option_Abstract {
	/**
	 * Show color scheme flag for element.
	 *
	 * @return bool
	 */
	public function show_color_scheme() {
		return false;
	}

	/**
	 * Compatibility column
	 *
	 * @return array
	 */
	public function compatible_column() {
		return array();
	}

	/**
	 * Override function to remove compatible column alert
	 */
	public function set_compatible_column_option() {}

	/**
	 * Element name
	 *
	 * @return string
	 */
	public function get_element_name() {
		return esc_html__( 'Product Breadcrumb', 'profecient-essential' );
	}

	/**
	 * Element category
	 *
	 * @return string
	 */
	public function get_category() {
		return esc_html__( 'Profecient - Single Product', 'profecient-essential' );
	}

	/**
	 * Element options
	 */
	public function set_options() {
		$this->set_style_option();
		$this->set_element_options();

		parent::set_options();
	}

	/**
	 * Option segments
	 */
	public function set_segments() {
		$this->set_style_segment();
	}

	/**
	 * Style segments
	 */
	public function set_style_segment() {
		$this->segments['style_breadcrumb'] = array(
			'name'      => esc_html__( 'Breadcrumb Style', 'profecient-essential' ),
			'priority'  => 11,
			'kit_style' => true,
		);

		parent::set_style_segment();
	}

	/**
	 * Set element option
	 */
	public function set_element_options() {}

	/**
	 * Add Additional Style.
	 */
	public function additional_style() {
		$this->options['st_breadcrumb_alignment'] = array(
			'type'       => 'radio',
			'title'      => esc_html__( 'Alignment', 'profecient-essential' ),
			'segment'    => 'style_breadcrumb',
			'options'    => array(
				'left'   => array(
					'title' => esc_html__( 'Left', 'profecient-essential' ),
					'icon'  => 'fas fa-align-left',
				),
				'center' => array(
					'title' => esc_html__( 'Center', 'profecient-essential' ),
					'icon'  => 'fas fa-align-center',
				),
				'right'  => array(
					'title' => esc_html__( 'Right', 'profecient-essential' ),
					'icon'  => 'fas fa-align-right',
				),
			),
			'responsive' => true,
			'default'    => 'left',
			'selectors'  => '.profecient-product-breadcrumb',
			'attribute'  => 'text-align',
		);

		$this->options['st_breadcrumb_text_typography'] = array(
			'type'      => 'typography',
			'title'     => esc_html__( 'Text Typography', 'profecient-essential' ),
			'segment'   => 'style_breadcrumb',
			'selectors' => array(
				'custom' => '{{WRAPPER}} .profecient-product-breadcrumb span, {{WRAPPER}} .profecient-product-breadcrumb span a',
			),
		);

		$this->options['st_breadcrumb_text_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Text Color', 'profecient-essential' ),
			'segment'   => 'style_breadcrumb',
			'selectors' => array(
				'custom' => array(
					'{{WRAPPER}} .profecient-product-breadcrumb span, {{WRAPPER}} .profecient-product-breadcrumb span a' => 'color: {{VALUE}};',
				),
			),
		);

		$this->options['st_breadcrumb_delimiter_size'] = array(
			'type'      => 'slider',
			'title'     => esc_html__( 'Delimiter Size', 'profecient-essential' ),
			'segment'   => 'style_breadcrumb',
			'units'     => array( 'px', 'em', '%', 'rem', 'vw' ),
			'options'   => array(
				'min'  => 0,
				'max'  => 100,
				'step' => 1,
			),
			'selectors' => '.profecient-product-breadcrumb .woocommerce-breadcrumb > i',
			'attribute' => 'font-size',
		);

		$this->options['st_breadcrumb_delimiter_gap'] = array(
			'type'      => 'slider',
			'title'     => esc_html__( 'Delimiter Gap', 'profecient-essential' ),
			'segment'   => 'style_breadcrumb',
			'units'     => array( 'px', 'em', '%' ),
			'options'   => array(
				'min'  => 0,
				'max'  => 100,
				'step' => 1,
			),
			'selectors' => array(
				'custom' => array(
					'{{WRAPPER}} .profecient-product-breadcrumb .woocommerce-breadcrumb > i' => 'margin: 0px calc({{SIZE}}{{UNIT}}/2);',
				),
			),
		);

		$this->options['st_breadcrumb_delimiter_icon'] = array(
			'type'    => 'iconpicker',
			'title'   => esc_html__( 'Delimiter Icon', 'profecient-essential' ),
			'segment' => 'style_breadcrumb',
			'default' => array(
				'value'   => 'jki jki-angle-right-solid',
				'library' => 'jkiticon',
			),
		);

		$this->options['st_breadcrumb_delimiter_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Delimiter Color', 'profecient-essential' ),
			'segment'   => 'style_breadcrumb',
			'selectors' => array(
				'custom' => array(
					'{{WRAPPER}} .profecient-product-breadcrumb i' => 'color: {{VALUE}};',
				),
			),
		);

		$this->options['st_breadcrumb_tabs_start'] = array(
			'type'    => 'control_tabs_start',
			'segment' => 'style_breadcrumb',
		);

		$this->options['st_breadcrumb_normal_tab_start'] = array(
			'type'    => 'control_tab_start',
			'title'   => esc_html__( 'Normal', 'profecient-essential' ),
			'segment' => 'style_breadcrumb',
		);

		$this->options['st_breadcrumb_normal_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Link Color', 'profecient-essential' ),
			'segment'   => 'style_breadcrumb',
			'selectors' => array(
				'custom' => array(
					'{{WRAPPER}} .profecient-product-breadcrumb span a' => 'color: {{VALUE}};',
				),
			),
		);

		$this->options['st_breadcrumb_normal_tab_end'] = array(
			'type'    => 'control_tab_end',
			'segment' => 'style_breadcrumb',
		);

		$this->options['st_breadcrumb_hover_tab_start'] = array(
			'type'    => 'control_tab_start',
			'title'   => esc_html__( 'Hover', 'profecient-essential' ),
			'segment' => 'style_breadcrumb',
		);

		$this->options['st_breadcrumb_hover_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Link Hover Color', 'profecient-essential' ),
			'segment'   => 'style_breadcrumb',
			'selectors' => array(
				'custom' => array(
					'{{WRAPPER}} .profecient-product-breadcrumb span:hover a' => 'color: {{VALUE}};',
				),
			),
		);

		$this->options['st_breadcrumb_hover_tab_end'] = array(
			'type'    => 'control_tab_end',
			'segment' => 'style_breadcrumb',
		);

		$this->options['st_breadcrumb_tabs_end'] = array(
			'type'    => 'control_tabs_end',
			'segment' => 'style_breadcrumb',
		);

		parent::additional_style();
	}
}
