<?php
/**
 * Product Single Data Tabs Option Class
 *
 * @package profecient-essential
 * @author jegtheme
 * @since 1.0.0
 */

namespace Profecient\Essential\JKit\Elements\Options;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

use Jeg\Elementor_Kit\Elements\Options\Option_Abstract;

/**
 * Class Product_Single_Data_Tabs_Option
 */
class Product_Single_Data_Tabs_Option extends Option_Abstract {
	/**
	 * Show color scheme flag for element.
	 *
	 * @return bool
	 */
	public function show_color_scheme() {
		return false;
	}

	/**
	 * Compatibility column
	 *
	 * @return array
	 */
	public function compatible_column() {
		return array();
	}

	/**
	 * Override function to remove compatible column alert
	 */
	public function set_compatible_column_option() {}

	/**
	 * Element name
	 *
	 * @return string
	 */
	public function get_element_name() {
		return esc_html__( 'Data Tabs', 'profecient-essential' );
	}

	/**
	 * Element category
	 *
	 * @return string
	 */
	public function get_category() {
		return esc_html__( 'Profecient - Single Product', 'profecient-essential' );
	}

	/**
	 * Element options
	 */
	public function set_options() {
		$this->set_style_option();

		parent::set_options();
	}

	/**
	 * Option segments
	 */
	public function set_segments() {
		$this->set_style_segment();
	}

	/**
	 * Style segments
	 */
	public function set_style_segment() {
		$this->segments['style_tabs'] = array(
			'name'      => esc_html__( 'Tabs', 'profecient-essential' ),
			'priority'  => 10,
			'kit_style' => true,
		);

		$this->segments['style_panel'] = array(
			'name'      => esc_html__( 'Panel', 'profecient-essential' ),
			'priority'  => 11,
			'kit_style' => true,
		);

		$this->segments['style_additional_information'] = array(
			'name'      => esc_html__( 'Additional Information', 'profecient-essential' ),
			'priority'  => 12,
			'kit_style' => true,
		);

		$this->segments['style_reviews'] = array(
			'name'      => esc_html__( 'Reviews', 'profecient-essential' ),
			'priority'  => 13,
			'kit_style' => true,
		);

		parent::set_style_segment();
	}

	/**
	 * Add Additional Style.
	 */
	public function additional_style() {
		$this->options['st_data_tabs_tabs_wrapper_heading'] = array(
			'type'    => 'heading',
			'title'   => 'Wrapper',
			'segment' => 'style_tabs',
		);

		$this->options['st_data_tabs_tabs_wrapper_padding'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Padding', 'profecient-essential' ),
			'segment'   => 'style_tabs',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.profecient-data-tabs .wc-tabs',
			'attribute' => 'padding',
		);

		$this->options['st_data_tabs_tab_heading'] = array(
			'type'      => 'heading',
			'title'     => 'Tab',
			'segment'   => 'style_tabs',
			'separator' => 'before',
		);

		$this->options['st_data_tabs_tabs_typography'] = array(
			'type'      => 'typography',
			'title'     => esc_html__( 'Typograhpy', 'profecient-essential' ),
			'segment'   => 'style_tabs',
			'selectors' => '.profecient-data-tabs .wc-tabs li',
		);

		$this->options['st_data_tabs_tabs_margin'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Margin', 'profecient-essential' ),
			'segment'   => 'style_tabs',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.profecient-data-tabs .wc-tabs li',
			'attribute' => 'margin',
		);

		$this->options['st_data_tabs_tabs_padding'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Padding', 'profecient-essential' ),
			'segment'   => 'style_tabs',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => array(
				'custom' => array(
					'.woocommerce {{WRAPPER}} .profecient-data-tabs .wc-tabs li a' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				),
			),
		);

		$this->options['st_data_tabs_tabs_gap'] = array(
			'type'       => 'slider',
			'title'      => esc_html__( 'Gap', 'profecient-essential' ),
			'segment'    => 'style_tabs',
			'units'      => array( 'px', '%', 'em' ),
			'options'    => array(
				'min'  => -100,
				'max'  => 100,
				'step' => 1,
			),
			'responsive' => true,
			'selectors'  => array(
				'custom' => array(
					'{{WRAPPER}} .profecient-data-tabs .wc-tabs li:not(:first-child):not(:last-child)' => 'margin-left: calc({{SIZE}}{{UNIT}}/2); margin-right: calc({{SIZE}}{{UNIT}}/2);',
					'{{WRAPPER}} .profecient-data-tabs .wc-tabs li:first-child' => 'margin-right: calc({{SIZE}}{{UNIT}}/2);',
					'{{WRAPPER}} .profecient-data-tabs .wc-tabs li:last-child' => 'margin-left: calc({{SIZE}}{{UNIT}}/2);',
				),
			),
			'attribute'  => 'margin',
		);

		$this->options['st_data_tabs_tabs_tabs_start'] = array(
			'type'    => 'control_tabs_start',
			'segment' => 'style_tabs',
		);

		$this->options['st_data_tabs_tabs_normal_tab_start'] = array(
			'type'    => 'control_tab_start',
			'title'   => esc_html__( 'Normal', 'profecient-essential' ),
			'segment' => 'style_tabs',
		);

		$this->options['st_data_tabs_tabs_normal_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Color', 'profecient-essential' ),
			'segment'   => 'style_tabs',
			'selectors' => '.profecient-data-tabs .wc-tabs li a',
		);

		$this->options['st_data_tabs_tabs_normal_background'] = array(
			'type'      => 'background',
			'title'     => esc_html__( 'Background', 'profecient-essential' ),
			'segment'   => 'style_tabs',
			'options'   => array(
				'classic',
				'gradient',
			),
			'selectors' => '.profecient-data-tabs .wc-tabs li',
		);

		$this->options['st_data_tabs_tabs_normal_border_radius'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Border Radius', 'profecient-essential' ),
			'segment'   => 'style_tabs',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.profecient-data-tabs .wc-tabs li',
			'attribute' => 'border-radius',
		);

		$this->options['st_data_tabs_tabs_normal_border'] = array(
			'type'      => 'border',
			'title'     => esc_html__( 'Border', 'profecient-essential' ),
			'segment'   => 'style_tabs',
			'selectors' => '.profecient-data-tabs .wc-tabs li',
		);

		$this->options['st_data_tabs_tabs_normal_border_bottom_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Border Bottom Color', 'profecient-essential' ),
			'segment'   => 'style_tabs',
			'selectors' => array(
				'custom' => array(
					'{{WRAPPER}} .profecient-data-tabs .wc-tabs li' => 'border-bottom-color: {{VALUE}}',
				),
			),
		);

		$this->options['st_data_tabs_tabs_normal_tab_end'] = array(
			'type'    => 'control_tab_end',
			'segment' => 'style_tabs',
		);

		$this->options['st_data_tabs_tabs_hover_tab_start'] = array(
			'type'    => 'control_tab_start',
			'title'   => esc_html__( 'Hover', 'profecient-essential' ),
			'segment' => 'style_tabs',
		);

		$this->options['st_data_tabs_tabs_hover_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Color', 'profecient-essential' ),
			'segment'   => 'style_tabs',
			'selectors' => '.profecient-data-tabs .wc-tabs li:hover a',
		);

		$this->options['st_data_tabs_tabs_hover_background'] = array(
			'type'      => 'background',
			'title'     => esc_html__( 'Background', 'profecient-essential' ),
			'segment'   => 'style_tabs',
			'options'   => array(
				'classic',
				'gradient',
			),
			'selectors' => '.profecient-data-tabs .wc-tabs li:hover',
		);

		$this->options['st_data_tabs_tabs_hover_border_radius'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Border Radius', 'profecient-essential' ),
			'segment'   => 'style_tabs',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.profecient-data-tabs .wc-tabs li:hover',
			'attribute' => 'border-radius',
		);

		$this->options['st_data_tabs_tabs_hover_border'] = array(
			'type'      => 'border',
			'title'     => esc_html__( 'Border', 'profecient-essential' ),
			'segment'   => 'style_tabs',
			'selectors' => '.profecient-data-tabs .wc-tabs li:hover',
		);

		$this->options['st_data_tabs_tabs_hover_border_bottom_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Border Bottom Color', 'profecient-essential' ),
			'segment'   => 'style_tabs',
			'selectors' => array(
				'custom' => array(
					'{{WRAPPER}} .profecient-data-tabs .wc-tabs li:hover' => 'border-bottom-color: {{VALUE}}',
				),
			),
		);

		$this->options['st_data_tabs_tabs_hover_tab_end'] = array(
			'type'    => 'control_tab_end',
			'segment' => 'style_tabs',
		);

		$this->options['st_data_tabs_tabs_active_tab_start'] = array(
			'type'    => 'control_tab_start',
			'title'   => esc_html__( 'Active', 'profecient-essential' ),
			'segment' => 'style_tabs',
		);

		$this->options['st_data_tabs_tabs_active_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Color', 'profecient-essential' ),
			'segment'   => 'style_tabs',
			'selectors' => '.profecient-data-tabs .wc-tabs li.active a',
		);

		$this->options['st_data_tabs_tabs_active_background'] = array(
			'type'      => 'background',
			'title'     => esc_html__( 'Background', 'profecient-essential' ),
			'segment'   => 'style_tabs',
			'options'   => array(
				'classic',
				'gradient',
			),
			'selectors' => '.profecient-data-tabs .wc-tabs li.active',
		);

		$this->options['st_data_tabs_tabs_active_border_radius'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Border Radius', 'profecient-essential' ),
			'segment'   => 'style_tabs',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.profecient-data-tabs .wc-tabs li.active',
			'attribute' => 'border-radius',
		);

		$this->options['st_data_tabs_tabs_active_border'] = array(
			'type'      => 'border',
			'title'     => esc_html__( 'Border', 'profecient-essential' ),
			'segment'   => 'style_tabs',
			'selectors' => '.profecient-data-tabs .wc-tabs li.active',
		);

		$this->options['st_data_tabs_tabs_active_border_bottom_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Border Bottom Color', 'profecient-essential' ),
			'segment'   => 'style_tabs',
			'selectors' => array(
				'custom' => array(
					'{{WRAPPER}} .profecient-data-tabs .wc-tabs li.active' => 'border-bottom-color: {{VALUE}}',
				),
			),
		);

		$this->options['st_data_tabs_tabs_active_tab_end'] = array(
			'type'    => 'control_tab_end',
			'segment' => 'style_tabs',
		);

		$this->options['st_data_tabs_tabs_tabs_end'] = array(
			'type'    => 'control_tabs_end',
			'segment' => 'style_tabs',
		);

		$this->options['st_data_tabs_tabs_line_heading'] = array(
			'type'      => 'heading',
			'title'     => 'Line',
			'segment'   => 'style_tabs',
			'separator' => 'before',
		);

		$this->options['st_data_tabs_tabs_line_border'] = array(
			'type'      => 'border',
			'title'     => esc_html__( 'Border', 'profecient-essential' ),
			'segment'   => 'style_tabs',
			'selectors' => '.profecient-data-tabs .woocommerce-tabs ul.tabs::before',
		);

		$this->options['st_data_tabs_panel_margin'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Margin', 'profecient-essential' ),
			'segment'   => 'style_panel',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.profecient-data-tabs .woocommerce-Tabs-panel',
			'attribute' => 'margin',
		);

		$this->options['st_data_tabs_panel_content_padding'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Padding', 'profecient-essential' ),
			'segment'   => 'style_panel',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.profecient-data-tabs .woocommerce-Tabs-panel',
			'attribute' => 'padding',
		);

		$this->options['st_data_tabs_panel_content_typography'] = array(
			'type'      => 'typography',
			'title'     => esc_html__( 'Typograhpy', 'profecient-essential' ),
			'segment'   => 'style_panel',
			'selectors' => '.profecient-data-tabs .woocommerce-Tabs-panel',
		);

		$this->options['st_data_tabs_panel_content_text_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Color', 'profecient-essential' ),
			'segment'   => 'style_panel',
			'selectors' => '.profecient-data-tabs .woocommerce-Tabs-panel',
		);

		$this->options['st_data_tabs_panel_content_background'] = array(
			'type'      => 'background',
			'title'     => esc_html__( 'Background', 'profecient-essential' ),
			'segment'   => 'style_panel',
			'options'   => array(
				'classic',
				'gradient',
			),
			'selectors' => '.profecient-data-tabs .woocommerce-Tabs-panel',
		);

		$this->options['st_data_tabs_panel_content_border_radius'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Border Radius', 'profecient-essential' ),
			'segment'   => 'style_panel',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.profecient-data-tabs .woocommerce-Tabs-panel',
			'attribute' => 'border-radius',
		);

		$this->options['st_data_tabs_panel_content_border'] = array(
			'type'      => 'border',
			'title'     => esc_html__( 'Border', 'profecient-essential' ),
			'segment'   => 'style_panel',
			'selectors' => '.profecient-data-tabs .woocommerce-Tabs-panel',
		);

		$this->options['st_data_tabs_panel_heading_heading'] = array(
			'type'      => 'heading',
			'title'     => 'Heading',
			'segment'   => 'style_panel',
			'separator' => 'before',
		);

		$this->options['st_data_tabs_panel_heading_typography'] = array(
			'type'      => 'typography',
			'title'     => esc_html__( 'Typograhpy', 'profecient-essential' ),
			'segment'   => 'style_panel',
			'selectors' => '.profecient-data-tabs .woocommerce-Tabs-panel h2',
		);

		$this->options['st_data_tabs_panel_heading_text_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Color', 'profecient-essential' ),
			'segment'   => 'style_panel',
			'selectors' => '.profecient-data-tabs .woocommerce-Tabs-panel h2',
		);

		$this->options['st_data_tabs_additional_information_table_heading'] = array(
			'type'    => 'heading',
			'title'   => 'Table',
			'segment' => 'style_additional_information',
		);

		$this->options['st_data_tabs_additional_information_table_margin'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Margin', 'profecient-essential' ),
			'segment'   => 'style_additional_information',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.profecient-data-tabs .woocommerce-Tabs-panel--additional_information table.shop_attributes',
			'attribute' => 'margin',
		);

		$this->options['st_data_tabs_additional_information_table_border'] = array(
			'type'      => 'border',
			'title'     => esc_html__( 'Border', 'profecient-essential' ),
			'segment'   => 'style_additional_information',
			'selectors' => '.profecient-data-tabs .woocommerce-Tabs-panel--additional_information .woocommerce-product-attributes-item__label, {{WRAPPER}} .profecient-data-tabs .woocommerce-Tabs-panel--additional_information .woocommerce-product-attributes-item__value',
		);

		$this->options['st_data_tabs_additional_information_table_odd_bg_color'] = array(
			'type'      => 'background',
			'title'     => esc_html__( 'Odd Background', 'profecient-essential' ),
			'segment'   => 'style_additional_information',
			'selectors' => '.profecient-data-tabs .woocommerce-Tabs-panel--additional_information .woocommerce-product-attributes-item:nth-child(odd)',
			'options'   => array(
				'classic',
				'gradient',
			),
			'exclude'   => array( 'image' ),
		);

		$this->options['st_data_tabs_additional_information_table_even_bg_color'] = array(
			'type'      => 'background',
			'title'     => esc_html__( 'Even Background', 'profecient-essential' ),
			'segment'   => 'style_additional_information',
			'selectors' => '.profecient-data-tabs .woocommerce-Tabs-panel--additional_information .woocommerce-product-attributes-item:nth-child(even)',
			'options'   => array(
				'classic',
				'gradient',
			),
			'exclude'   => array( 'image' ),
		);

		$this->options['st_data_tabs_additional_information_table_hover_bg_color'] = array(
			'type'      => 'background',
			'title'     => esc_html__( 'Hover Background', 'profecient-essential' ),
			'segment'   => 'style_additional_information',
			'selectors' => '.profecient-data-tabs .woocommerce-Tabs-panel--additional_information .woocommerce-product-attributes-item:hover',
			'options'   => array(
				'classic',
				'gradient',
			),
			'exclude'   => array( 'image' ),
		);

		$this->options['st_data_tabs_additional_information_label_heading'] = array(
			'type'      => 'heading',
			'title'     => 'Label',
			'separator' => 'before',
			'segment'   => 'style_additional_information',
		);

		$this->options['st_data_tabs_additional_information_label_padding'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Padding', 'profecient-essential' ),
			'segment'   => 'style_additional_information',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.profecient-data-tabs .woocommerce-Tabs-panel--additional_information .woocommerce-product-attributes-item__label',
			'attribute' => 'padding',
		);

		$this->options['st_data_tabs_additional_information_label_typography'] = array(
			'type'      => 'typography',
			'title'     => esc_html__( 'Typograhpy', 'profecient-essential' ),
			'segment'   => 'style_additional_information',
			'selectors' => '.profecient-data-tabs .woocommerce-Tabs-panel--additional_information .woocommerce-product-attributes-item__label',
		);

		$this->options['st_data_tabs_additional_information_label_tabs_start'] = array(
			'type'    => 'control_tabs_start',
			'segment' => 'style_additional_information',
		);

		$this->options['st_data_tabs_additional_information_label_text_color_normal_tab_start'] = array(
			'type'    => 'control_tab_start',
			'title'   => esc_html__( 'Normal', 'profecient-essential' ),
			'segment' => 'style_additional_information',
		);

		$this->options['st_data_tabs_additional_information_label_text_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Color', 'profecient-essential' ),
			'segment'   => 'style_additional_information',
			'selectors' => '.profecient-data-tabs .woocommerce-Tabs-panel--additional_information .woocommerce-product-attributes-item__label',
		);

		$this->options['st_data_tabs_additional_information_label_text_color_normal_tab_end'] = array(
			'type'    => 'control_tab_end',
			'segment' => 'style_additional_information',
		);

		$this->options['st_data_tabs_additional_information_label_text_color_hover_tab_start'] = array(
			'type'    => 'control_tab_start',
			'title'   => esc_html__( 'Hover', 'profecient-essential' ),
			'segment' => 'style_additional_information',
		);

		$this->options['st_data_tabs_additional_information_label_text_color_hover'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Color', 'profecient-essential' ),
			'segment'   => 'style_additional_information',
			'selectors' => '.profecient-data-tabs .woocommerce-Tabs-panel--additional_information .woocommerce-product-attributes-item:hover .woocommerce-product-attributes-item__label',
		);

		$this->options['st_data_tabs_additional_information_label_text_color_hover_tab_end'] = array(
			'type'    => 'control_tab_end',
			'segment' => 'style_additional_information',
		);

		$this->options['st_data_tabs_additional_information_label_tabs_end'] = array(
			'type'    => 'control_tabs_end',
			'segment' => 'style_additional_information',
		);

		$this->options['st_data_tabs_additional_information_value_heading'] = array(
			'type'      => 'heading',
			'title'     => 'Value',
			'separator' => 'before',
			'segment'   => 'style_additional_information',
		);

		$this->options['st_data_tabs_additional_information_value_padding'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Padding', 'profecient-essential' ),
			'segment'   => 'style_additional_information',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.profecient-data-tabs .woocommerce-Tabs-panel--additional_information .woocommerce-product-attributes-item__value',
			'attribute' => 'padding',
		);

		$this->options['st_data_tabs_additional_information_value_typography'] = array(
			'type'      => 'typography',
			'title'     => esc_html__( 'Typograhpy', 'profecient-essential' ),
			'segment'   => 'style_additional_information',
			'selectors' => '.profecient-data-tabs .woocommerce-Tabs-panel--additional_information .woocommerce-product-attributes-item__value',
		);

		$this->options['st_data_tabs_additional_information_value_tabs_start'] = array(
			'type'    => 'control_tabs_start',
			'segment' => 'style_additional_information',
		);

		$this->options['st_data_tabs_additional_information_value_text_color_normal_tab_start'] = array(
			'type'    => 'control_tab_start',
			'title'   => esc_html__( 'Normal', 'profecient-essential' ),
			'segment' => 'style_additional_information',
		);

		$this->options['st_data_tabs_additional_information_value_text_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Color', 'profecient-essential' ),
			'segment'   => 'style_additional_information',
			'selectors' => '.profecient-data-tabs .woocommerce-Tabs-panel--additional_information .woocommerce-product-attributes-item__value',
		);

		$this->options['st_data_tabs_additional_information_value_text_color_normal_tab_end'] = array(
			'type'    => 'control_tab_end',
			'segment' => 'style_additional_information',
		);

		$this->options['st_data_tabs_additional_information_value_text_color_hover_tab_start'] = array(
			'type'    => 'control_tab_start',
			'title'   => esc_html__( 'Hover', 'profecient-essential' ),
			'segment' => 'style_additional_information',
		);

		$this->options['st_data_tabs_additional_information_value_text_color_hover'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Color', 'profecient-essential' ),
			'segment'   => 'style_additional_information',
			'selectors' => '.profecient-data-tabs .woocommerce-Tabs-panel--additional_information .woocommerce-product-attributes-item:hover .woocommerce-product-attributes-item__value',
		);

		$this->options['st_data_tabs_additional_information_value_text_color_hover_tab_end'] = array(
			'type'    => 'control_tab_end',
			'segment' => 'style_additional_information',
		);

		$this->options['st_data_tabs_additional_information_value_tabs_end'] = array(
			'type'    => 'control_tabs_end',
			'segment' => 'style_additional_information',
		);

		$this->options['st_data_tabs_reviews_meta_heading'] = array(
			'type'    => 'heading',
			'title'   => 'Meta',
			'segment' => 'style_reviews',
		);

		$this->options['st_data_tabs_panel_reviews_meta_text_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Color', 'profecient-essential' ),
			'segment'   => 'style_reviews',
			'selectors' => '.profecient-data-tabs .woocommerce-Tabs-panel--reviews #reviews #comments ol.commentlist li .meta',
		);

		$this->options['st_data_tabs_reviews_star_rating_heading'] = array(
			'type'      => 'heading',
			'title'     => 'Star',
			'separator' => 'before',
			'segment'   => 'style_reviews',
		);

		$this->options['st_data_tabs_panel_reviews_star_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Color', 'profecient-essential' ),
			'segment'   => 'style_reviews',
			'selectors' => '.profecient-data-tabs .woocommerce-Tabs-panel--reviews .comment-text .star-rating, {{WRAPPER}} .profecient-data-tabs .woocommerce-Tabs-panel--reviews #commentform .comment-form-rating .stars a',
		);

		$this->options['st_data_tabs_panel_reviews_star_second_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Second Color', 'profecient-essential' ),
			'segment'   => 'style_reviews',
			'selectors' => '.profecient-data-tabs .woocommerce-Tabs-panel--reviews .comment-text .star-rating:before',
		);

		$this->options['st_data_tabs_reviews_button_heading'] = array(
			'type'      => 'heading',
			'title'     => 'Button',
			'separator' => 'before',
			'segment'   => 'style_reviews',
		);

		$this->options['st_data_tabs_reviews_button_typography'] = array(
			'type'      => 'typography',
			'title'     => esc_html__( 'Typography', 'profecient-essential' ),
			'segment'   => 'style_reviews',
			'selectors' => '.profecient-data-tabs .woocommerce-Tabs-panel--reviews #review_form #respond .form-submit input.submit',
		);

		$this->options['st_data_tabs_panel_reviews_button_margin'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Margin', 'profecient-essential' ),
			'segment'   => 'style_reviews',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.profecient-data-tabs .woocommerce-Tabs-panel--reviews #review_form #respond .form-submit input.submit',
			'attribute' => 'margin',
		);

		$this->options['st_data_tabs_panel_reviews_button_padding'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Padding', 'profecient-essential' ),
			'segment'   => 'style_reviews',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.profecient-data-tabs .woocommerce-Tabs-panel--reviews #review_form #respond .form-submit input.submit',
			'attribute' => 'padding',
		);

		$this->options['st_data_tabs_panel_reviews_button_align'] = array(
			'type'       => 'radio',
			'title'      => esc_html__( 'Alignment', 'profecient-essential' ),
			'segment'    => 'style_reviews',
			'options'    => array(
				'left'   => array(
					'title' => esc_html__( 'Left', 'profecient-essential' ),
					'icon'  => 'fas fa-align-left',
				),
				'center' => array(
					'title' => esc_html__( 'Center', 'profecient-essential' ),
					'icon'  => 'fas fa-align-center',
				),
				'right'  => array(
					'title' => esc_html__( 'Right', 'profecient-essential' ),
					'icon'  => 'fas fa-align-right',
				),
			),
			'responsive' => true,
			'default'    => 'left',
			'selectors'  => '.profecient-data-tabs .woocommerce-Tabs-panel--reviews #review_form #respond .form-submit',
			'attribute'  => 'text-align',
		);

		$this->options['st_data_tabs_panel_reviews_button_tabs_start'] = array(
			'type'    => 'control_tabs_start',
			'segment' => 'style_reviews',
		);

		$this->options['st_data_tabs_panel_reviews_button_normal_tab_start'] = array(
			'type'    => 'control_tab_start',
			'title'   => esc_html__( 'Normal', 'profecient-essential' ),
			'segment' => 'style_reviews',
		);

		$this->options['st_data_tabs_panel_reviews_button_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Color', 'profecient-essential' ),
			'segment'   => 'style_reviews',
			'selectors' => '.profecient-data-tabs .woocommerce-Tabs-panel--reviews #review_form #respond .form-submit input.submit',
		);

		$this->options['st_data_tabs_panel_reviews_button_background'] = array(
			'type'      => 'background',
			'title'     => esc_html__( 'Background', 'profecient-essential' ),
			'segment'   => 'style_reviews',
			'options'   => array(
				'classic',
				'gradient',
			),
			'exclude'   => array( 'image' ),
			'selectors' => '.profecient-data-tabs .woocommerce-Tabs-panel--reviews #review_form #respond .form-submit input.submit',
		);

		$this->options['st_data_tabs_panel_reviews_button_border_radius'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Border Radius', 'profecient-essential' ),
			'segment'   => 'style_reviews',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.profecient-data-tabs .woocommerce-Tabs-panel--reviews #review_form #respond .form-submit input.submit',
			'attribute' => 'border-radius',
		);

		$this->options['st_data_tabs_panel_reviews_button_border'] = array(
			'type'      => 'border',
			'title'     => esc_html__( 'Border', 'profecient-essential' ),
			'segment'   => 'style_reviews',
			'selectors' => '.profecient-data-tabs .woocommerce-Tabs-panel--reviews #review_form #respond .form-submit input.submit',
		);

		$this->options['st_data_tabs_panel_reviews_button_normal_tab_end'] = array(
			'type'    => 'control_tab_end',
			'segment' => 'style_reviews',
		);

		$this->options['st_data_tabs_panel_reviews_button_hover_tab_start'] = array(
			'type'    => 'control_tab_start',
			'title'   => esc_html__( 'Hover', 'profecient-essential' ),
			'segment' => 'style_reviews',
		);

		$this->options['st_data_tabs_panel_reviews_button_hover_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Color', 'profecient-essential' ),
			'segment'   => 'style_reviews',
			'selectors' => '.profecient-data-tabs .woocommerce-Tabs-panel--reviews #review_form #respond .form-submit input.submit:hover',
		);

		$this->options['st_data_tabs_panel_reviews_button_hover_background'] = array(
			'type'      => 'background',
			'title'     => esc_html__( 'Background', 'profecient-essential' ),
			'segment'   => 'style_reviews',
			'options'   => array(
				'classic',
				'gradient',
			),
			'exclude'   => array( 'image' ),
			'selectors' => '.profecient-data-tabs .woocommerce-Tabs-panel--reviews #review_form #respond .form-submit input.submit:hover',
		);

		$this->options['st_data_tabs_panel_reviews_button_hover_border_radius'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Border Radius', 'profecient-essential' ),
			'segment'   => 'style_reviews',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.profecient-data-tabs .woocommerce-Tabs-panel--reviews #review_form #respond .form-submit input.submit:hover',
			'attribute' => 'border-radius',
		);

		$this->options['st_data_tabs_panel_reviews_button_hover_border'] = array(
			'type'      => 'border',
			'title'     => esc_html__( 'Border', 'profecient-essential' ),
			'segment'   => 'style_reviews',
			'selectors' => '.profecient-data-tabs .woocommerce-Tabs-panel--reviews #review_form #respond .form-submit input.submit:hover',
		);

		$this->options['st_data_tabs_panel_reviews_button_hover_tab_end'] = array(
			'type'    => 'control_tab_end',
			'segment' => 'style_reviews',
		);

		$this->options['st_data_tabs_panel_reviews_button_tabs_end'] = array(
			'type'    => 'control_tabs_end',
			'segment' => 'style_reviews',
		);

		parent::additional_style();
	}
}
