<?php
/**
 * Product Single Images Option Class
 *
 * @package profecient-essential
 * @author jegtheme
 * @since 1.0.0
 */

namespace Profecient\Essential\JKit\Elements\Options;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

use \Jeg\Elementor_Kit\Elements\Options\Option_Abstract;

/**
 * Class Product_Single_Images_Option
 */
class Product_Single_Images_Option extends Option_Abstract {
	/**
	 * Show color scheme flag for element.
	 *
	 * @return bool
	 */
	public function show_color_scheme() {
		return false;
	}

	/**
	 * Compatibility column
	 *
	 * @return array
	 */
	public function compatible_column() {
		return array();
	}

	/**
	 * Override function to remove compatible column alert
	 */
	public function set_compatible_column_option() {}

	/**
	 * Element name
	 *
	 * @return string
	 */
	public function get_element_name() {
		return esc_html__( 'Product Images', 'profecient-essential' );
	}

	/**
	 * Element category
	 *
	 * @return string
	 */
	public function get_category() {
		return esc_html__( 'Profecient - Single Product', 'profecient-essential' );
	}

	/**
	 * Element options
	 */
	public function set_options() {
		$this->set_style_option();

		parent::set_options();
	}

	/**
	 * Style segments
	 */
	public function set_style_segment() {
		$this->segments['style_content'] = array(
			'name'      => esc_html__( 'Product Images', 'profecient-essential' ),
			'priority'  => 11,
			'kit_style' => true,
		);

		parent::set_style_segment();
	}

	/**
	 * Add Additional Style.
	 */
	public function additional_style() {
		$this->options['st_image_padding'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Padding', 'profecient-essential' ),
			'segment'   => 'style_content',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.profecient-product-images .images img',
			'attribute' => 'padding',
		);

		$this->options['st_image_border_radius'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Border Radius', 'profecient-essential' ),
			'segment'   => 'style_content',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.profecient-product-images .images img, {{WRAPPER}} .profecient-product-images .images .woocommerce-product-gallery__image, {{WRAPPER}} .images img, {{WRAPPER}} .profecient-product-images',
			'attribute' => 'border-radius',
		);

		$this->options['st_image_border'] = array(
			'type'      => 'border',
			'title'     => esc_html__( 'Border', 'profecient-essential' ),
			'segment'   => 'style_content',
			'selectors' => '.profecient-product-images .images img',
		);

		$this->options['st_image_boxshadow'] = array(
			'type'      => 'boxshadow',
			'title'     => esc_html__( 'Box Shadow', 'profecient-essential' ),
			'segment'   => 'style_content',
			'selectors' => '.profecient-product-images',
		);

		$this->options['st_image_zoom_heading'] = array(
			'type'      => 'heading',
			'title'     => esc_html__( 'Zoom Icon', 'profecient-essential' ),
			'segment'   => 'style_content',
			'separator' => 'before',
		);

		$this->options['st_image_zoom_horizontal_orientation'] = array(
			'type'    => 'radio',
			'title'   => esc_html__( 'Horizontal Orientation', 'profecient-essential' ),
			'segment' => 'style_content',
			'options' => array(
				'left'  => array(
					'title' => esc_html__( 'Left', 'profecient-essential' ),
					'icon'  => 'eicon-h-align-left',
				),
				'right' => array(
					'title' => esc_html__( 'Right', 'profecient-essential' ),
					'icon'  => 'eicon-h-align-right',
				),
			),
			'default' => 'right',
			'toggle'  => false,
		);

		$this->options['st_image_zoom_horizontal_offset'] = array(
			'type'       => 'slider',
			'title'      => esc_html__( 'Offset', 'profecient-essential' ),
			'segment'    => 'style_content',
			'responsive' => true,
			'units'      => array( 'px', '%', 'em' ),
			'options'    => array(
				'min'  => 0,
				'max'  => 100,
				'step' => 1,
			),
			'selectors'  => array(
				'custom' => array( '{{WRAPPER}} .profecient-product-images .images .woocommerce-product-gallery__trigger' => ' left: auto; right: auto; {{st_image_zoom_horizontal_orientation.VALUE}}: {{SIZE}}{{UNIT}};' ),
			),
		);

		$this->options['st_image_zoom_vertical_orientation'] = array(
			'type'    => 'radio',
			'title'   => esc_html__( 'Vertical Orientation', 'profecient-essential' ),
			'segment' => 'style_content',
			'options' => array(
				'top'    => array(
					'title' => esc_html__( 'Top', 'profecient-essential' ),
					'icon'  => 'eicon-v-align-top',
				),
				'bottom' => array(
					'title' => esc_html__( 'Bottom', 'profecient-essential' ),
					'icon'  => 'eicon-v-align-bottom',
				),
			),
			'default' => 'top',
			'toggle'  => false,
		);

		$this->options['st_image_zoom_vertical_offset'] = array(
			'type'       => 'slider',
			'title'      => esc_html__( 'Offset', 'profecient-essential' ),
			'segment'    => 'style_content',
			'responsive' => true,
			'units'      => array( 'px', '%', 'em' ),
			'options'    => array(
				'min'  => 0,
				'max'  => 100,
				'step' => 1,
			),
			'selectors'  => array(
				'custom' => array( '{{WRAPPER}} .profecient-product-images .images .woocommerce-product-gallery__trigger' => ' top: auto; bottom: auto; {{st_image_zoom_vertical_orientation.VALUE}}: {{SIZE}}{{UNIT}};' ),
			),
		);

		$this->options['st_image_zoom_image_heading'] = array(
			'type'      => 'heading',
			'title'     => esc_html__( 'Zoom Image', 'profecient-essential' ),
			'segment'   => 'style_content',
			'separator' => 'before',
		);

		$this->options['st_image_zoom_image_background'] = array(
			'type'      => 'background',
			'title'     => esc_html__( 'Zoom Image Background Color', 'profecient-essential' ),
			'segment'   => 'style_content',
			'selectors' => '.profecient-product-images .images .woocommerce-product-gallery__wrapper .zoomImg',
			'options'   => array(
				'classic',
				'gradient',
			),
		);

		$this->options['st_image_badge_heading'] = array(
			'type'      => 'heading',
			'title'     => esc_html__( 'Badge', 'profecient-essential' ),
			'segment'   => 'style_content',
			'separator' => 'before',
		);

		$this->options['st_content_sale'] = array(
			'type'    => 'checkbox',
			'title'   => esc_html__( 'Show Sale', 'profecient-essential' ),
			'segment' => 'style_content',
			'default' => true,
		);

		$this->options['st_content_percentage'] = array(
			'type'    => 'checkbox',
			'title'   => esc_html__( 'Show Sale Percentage', 'profecient-essential' ),
			'segment' => 'style_content',
			'default' => true,
		);

		$this->options['st_sale_width'] = array(
			'type'       => 'slider',
			'title'      => esc_html__( 'Width', 'profecient-essential' ),
			'segment'    => 'style_content',
			'responsive' => true,
			'units'      => array( 'px', '%', 'em' ),
			'options'    => array(
				'min'  => 0,
				'max'  => 100,
				'step' => 1,
			),
			'selectors'  => '.profecient-product-images .onsale',
			'attribute'  => 'width',
		);

		$this->options['st_sale_height'] = array(
			'type'       => 'slider',
			'title'      => esc_html__( ' Height', 'profecient-essential' ),
			'segment'    => 'style_content',
			'responsive' => true,
			'units'      => array( 'px', '%', 'em' ),
			'options'    => array(
				'min'  => 0,
				'max'  => 100,
				'step' => 1,
			),
			'selectors'  => array(
				'custom' => array(
					'{{WRAPPER}} .profecient-product-images .onsale' => 'height: {{SIZE}}{{UNIT}}; --profecient-onsale-height: {{SIZE}}{{UNIT}};',
				),
			),
		);

		$this->options['st_sale_horizontal_offset'] = array(
			'type'       => 'slider',
			'title'      => esc_html__( 'Horizontal Offset', 'profecient-essential' ),
			'segment'    => 'style_content',
			'responsive' => true,
			'units'      => array( 'px', '%', 'em' ),
			'options'    => array(
				'min'  => 0,
				'max'  => 100,
				'step' => 1,
			),
			'default'    => 8,
			'selectors'  => array(
				'custom' => array( '{{WRAPPER}} .profecient-product-images .onsale' => 'left: {{SIZE}}{{UNIT}};' ),
			),
		);

		$this->options['st_sale_vertical_offset'] = array(
			'type'       => 'slider',
			'title'      => esc_html__( 'Vertical Offset', 'profecient-essential' ),
			'segment'    => 'style_content',
			'responsive' => true,
			'units'      => array( 'px', '%', 'em' ),
			'options'    => array(
				'min'  => 0,
				'max'  => 100,
				'step' => 1,
			),
			'default'    => 9,
			'selectors'  => array(
				'custom' => array( '{{WRAPPER}} .profecient-product-images .onsale' => 'top: {{SIZE}}{{UNIT}};' ),
			),
		);

		$this->options['st_sale_gap_offset'] = array(
			'type'       => 'slider',
			'title'      => esc_html__( 'Gap Space', 'profecient-essential' ),
			'segment'    => 'style_content',
			'responsive' => true,
			'options'    => array(
				'min'  => 0,
				'max'  => 100,
				'step' => 1,
			),
			'default'    => 5,
			'selectors'  => array(
				'custom' => array( '{{WRAPPER}} .profecient-product-images .onsale' => '--profecient-onsale-gap: {{SIZE}}px' ),
			),
		);

		$this->options['st_sale_typography'] = array(
			'type'      => 'typography',
			'title'     => esc_html__( 'Typography', 'profecient-essential' ),
			'segment'   => 'style_content',
			'selectors' => '.profecient-product-images .onsale',
		);

		$this->options['st_sale_background'] = array(
			'type'      => 'background',
			'title'     => esc_html__( 'Sale Background Color', 'profecient-essential' ),
			'segment'   => 'style_content',
			'selectors' => '.profecient-product-images .onsale.text',
			'options'   => array(
				'classic',
				'gradient',
			),
			'exclude'   => array( 'image' ),
			'separator' => 'before',
		);

		$this->options['st_sale_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Sale Badge Color', 'profecient-essential' ),
			'segment'   => 'style_content',
			'selectors' => '.profecient-product-images .onsale.text',
		);

		$this->options['st_percentage_background'] = array(
			'type'      => 'background',
			'title'     => esc_html__( 'Percentage Background Color', 'profecient-essential' ),
			'segment'   => 'style_content',
			'selectors' => '.profecient-product-images .onsale.percent',
			'options'   => array(
				'classic',
				'gradient',
			),
			'exclude'   => array( 'image' ),
			'separator' => 'before',
		);

		$this->options['st_percentage_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Percentage Badge Color', 'profecient-essential' ),
			'segment'   => 'style_content',
			'selectors' => '.profecient-product-images .onsale.percent',
		);

		$this->options['st_sale_border_radius'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Border Radius', 'profecient-essential' ),
			'segment'   => 'style_content',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.profecient-product-images .onsale',
			'attribute' => 'border-radius',
		);

		$this->options['st_sale_border'] = array(
			'type'      => 'border',
			'title'     => esc_html__( 'Border', 'profecient-essential' ),
			'segment'   => 'style_content',
			'selectors' => '.profecient-product-images .onsale',
		);

		$this->options['st_sale_boxshadow'] = array(
			'type'      => 'boxshadow',
			'title'     => esc_html__( 'Box Shadow', 'profecient-essential' ),
			'segment'   => 'style_content',
			'selectors' => '.profecient-product-images .onsale',
		);

		parent::additional_style();
	}
}
