<?php
/**
 * Product Single Meta Option Class
 *
 * @package profecient-essential
 * @author jegtheme
 * @since 1.0.0
 */

namespace Profecient\Essential\JKit\Elements\Options;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

use Jeg\Elementor_Kit\Elements\Options\Option_Abstract;

/**
 * Class Product_Single_Meta_Option
 */
class Product_Single_Meta_Option extends Option_Abstract {
	/**
	 * Show color scheme flag for element.
	 *
	 * @return bool
	 */
	public function show_color_scheme() {
		return false;
	}

	/**
	 * Compatibility column
	 *
	 * @return array
	 */
	public function compatible_column() {
		return array();
	}

	/**
	 * Override function to remove compatible column alert
	 */
	public function set_compatible_column_option() {}

	/**
	 * Element name
	 *
	 * @return string
	 */
	public function get_element_name() {
		return esc_html__( 'Product Meta', 'profecient-essential' );
	}

	/**
	 * Element category
	 *
	 * @return string
	 */
	public function get_category() {
		return esc_html__( 'Profecient - Single Product', 'profecient-essential' );
	}

	/**
	 * Element options
	 */
	public function set_options() {
		$this->set_style_option();

		parent::set_options();
	}

	/**
	 * Style segments
	 */
	public function set_style_segment() {
		$this->segments['style_content'] = array(
			'name'      => esc_html__( 'Style', 'profecient-essential' ),
			'priority'  => 11,
			'kit_style' => true,
		);

		parent::set_style_segment();
	}

	/**
	 * Add Additional Style.
	 */
	public function additional_style() {
		$this->options['st_layout'] = array(
			'type'         => 'select',
			'title'        => esc_html__( 'Layout', 'profecient-essential' ),
			'default'      => 'column',
			'segment'      => 'style_content',
			'options'      => array(
				'inline' => esc_html__( 'Inline', 'profecient-essential' ),
				'column' => esc_html__( 'Table Column', 'profecient-essential' ),
				'float'  => esc_html__( 'Table Float', 'profecient-essential' ),
			),
			'prefix_class' => 'layout-',
		);

		$this->options['st_space'] = array(
			'type'       => 'slider',
			'title'      => esc_html__( 'Row Gap', 'profecient-essential' ),
			'segment'    => 'style_content',
			'responsive' => true,
			'options'    => array(
				'min'  => 0,
				'max'  => 100,
				'step' => 1,
			),
			'selectors'  => array(
				'custom' => array(
					'{{WRAPPER}}.layout-inline .product_meta > span' => 'margin-right: calc({{SIZE}}{{UNIT}}/2); margin-left: calc({{SIZE}}{{UNIT}}/2)',
					'{{WRAPPER}}.layout-inline .product_meta' => 'margin-right: calc(-{{SIZE}}{{UNIT}}/2); margin-left: calc(-{{SIZE}}{{UNIT}}/2)',
					'{{WRAPPER}}:not(.layout-inline) .product_meta > span:not(:last-child)' => 'padding-bottom: calc({{SIZE}}{{UNIT}}/2)',
					'{{WRAPPER}}:not(.layout-inline) .product_meta > span:not(:first-child)' => 'margin-top: calc({{SIZE}}{{UNIT}}/2)',
					'body:not(.rtl) {{WRAPPER}}.layout-inline .product_meta > span:after' => 'right: calc( (-{{SIZE}}{{UNIT}}/2) + (-{{divider_weight.SIZE}}px/2) )',
					'body:not.rtl {{WRAPPER}}.layout-inline .product_meta > span:after' => 'left: calc( (-{{SIZE}}{{UNIT}}/2) - ({{divider_weight.SIZE}}px/2) )',
				),
			),
		);

		$this->options['st_label'] = array(
			'type'      => 'heading',
			'title'     => esc_html__( 'Label', 'profecient-essential' ),
			'segment'   => 'style_content',
			'separator' => 'before',
		);

		$this->options['st_label_typography'] = array(
			'type'      => 'typography',
			'title'     => esc_html__( 'Typography', 'profecient-essential' ),
			'segment'   => 'style_content',
			'selectors' => array(
				'custom' => '{{WRAPPER}} .label',
			),
		);

		$this->options['st_label_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Color', 'profecient-essential' ),
			'segment'   => 'style_content',
			'selectors' => array(
				'custom' => array(
					'{{WRAPPER}} .label' => 'color: {{VALUE}};',
				),
			),
		);

		$this->options['st_text'] = array(
			'type'      => 'heading',
			'title'     => esc_html__( 'Text', 'profecient-essential' ),
			'segment'   => 'style_content',
			'separator' => 'before',
		);

		$this->options['st_text_typography'] = array(
			'type'      => 'typography',
			'title'     => esc_html__( 'Typography', 'profecient-essential' ),
			'segment'   => 'style_content',
			'selectors' => array(
				'custom' => '{{WRAPPER}} .sku',
			),
		);

		$this->options['st_text_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Color', 'profecient-essential' ),
			'segment'   => 'style_content',
			'selectors' => array(
				'custom' => array(
					'{{WRAPPER}} .sku' => 'color: {{VALUE}};',
				),
			),
		);

		$this->options['st_link'] = array(
			'type'      => 'heading',
			'title'     => esc_html__( 'Link', 'profecient-essential' ),
			'segment'   => 'style_content',
			'separator' => 'before',
		);

		$this->options['st_link_typography'] = array(
			'type'      => 'typography',
			'title'     => esc_html__( 'Typography', 'profecient-essential' ),
			'segment'   => 'style_content',
			'selectors' => array(
				'custom' => '{{WRAPPER}} a',
			),
		);

		$this->options['st_link_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Color', 'profecient-essential' ),
			'segment'   => 'style_content',
			'selectors' => array(
				'custom' => array(
					'{{WRAPPER}} a' => 'color: {{VALUE}};',
				),
			),
		);

		parent::additional_style();
	}
}
