<?php
/**
 * Product Single Price Option Class
 *
 * @package profecient-essential
 * @author jegtheme
 * @since 1.0.0
 */

namespace Profecient\Essential\JKit\Elements\Options;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

use \Jeg\Elementor_Kit\Elements\Options\Option_Abstract;

/**
 * Class Product_Single_Price_Option
 */
class Product_Single_Price_Option extends Option_Abstract {
	/**
	 * Show color scheme flag for element.
	 *
	 * @return bool
	 */
	public function show_color_scheme() {
		return false;
	}

	/**
	 * Compatibility column
	 *
	 * @return array
	 */
	public function compatible_column() {
		return array();
	}

	/**
	 * Override function to remove compatible column alert
	 */
	public function set_compatible_column_option() {}

	/**
	 * Element name
	 *
	 * @return string
	 */
	public function get_element_name() {
		return esc_html__( 'Product Price', 'profecient-essential' );
	}

	/**
	 * Element category
	 *
	 * @return string
	 */
	public function get_category() {
		return esc_html__( 'Profecient - Single Product', 'profecient-essential' );
	}

	/**
	 * Element options
	 */
	public function set_options() {
		$this->set_style_option();

		parent::set_options();
	}

	/**
	 * Style segments
	 */
	public function set_style_segment() {
		$this->segments['style_price'] = array(
			'name'      => esc_html__( 'Product Price', 'profecient-essential' ),
			'priority'  => 11,
			'kit_style' => true,
		);

		parent::set_style_segment();
	}

	/**
	 * Add Additional Style.
	 */
	public function additional_style() {
		$this->options['st_price_margin'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Margin', 'profecient-essential' ),
			'segment'   => 'style_price',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.profecient-product-price .price',
			'attribute' => 'margin',
		);

		$this->options['st_price_alignment'] = array(
			'type'       => 'radio',
			'title'      => esc_html__( 'Alignment', 'profecient-essential' ),
			'segment'    => 'style_price',
			'options'    => array(
				'left'   => array(
					'title' => esc_html__( 'Left', 'profecient-essential' ),
					'icon'  => 'fas fa-align-left',
				),
				'center' => array(
					'title' => esc_html__( 'Center', 'profecient-essential' ),
					'icon'  => 'fas fa-align-center',
				),
				'right'  => array(
					'title' => esc_html__( 'Right', 'profecient-essential' ),
					'icon'  => 'fas fa-align-right',
				),
			),
			'responsive' => true,
			'default'    => 'left',
			'selectors'  => '.profecient-product-price',
			'attribute'  => 'text-align',
		);

		$this->options['st_price_spacing'] = array(
			'type'        => 'slider',
			'title'       => esc_html__( 'Currency Spacing', 'profecient-essential' ),
			'segment'     => 'style_price',
			'options'     => array(
				'min'  => 0,
				'max'  => 500,
				'step' => 1,
			),
			'responsive'  => true,
			'selectors'   => '.profecient-product-price .price span span',
			'attribute'   => 'padding-right',
			'description' => esc_html__( 'Set gap space for the currency.', 'profecient-essential' ),
		);

		$this->options['st_price_heading'] = array(
			'type'      => 'heading',
			'title'     => esc_html__( 'Regular Price', 'profecient-essential' ),
			'segment'   => 'style_price',
			'separator' => 'before',
		);

		$this->options['st_price_typography'] = array(
			'type'      => 'typography',
			'title'     => esc_html__( 'Typography', 'profecient-essential' ),
			'segment'   => 'style_price',
			'selectors' => array(
				'custom' => '{{WRAPPER}} .profecient-product-price .price',
			),
		);

		$this->options['st_price_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Color', 'profecient-essential' ),
			'segment'   => 'style_price',
			'selectors' => array(
				'custom' => array(
					'{{WRAPPER}} .profecient-product-price .price' => 'color: {{VALUE}};',
				),
			),
		);

		$this->options['st_price_line_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Line Color', 'profecient-essential' ),
			'segment'   => 'style_price',
			'selectors' => array(
				'custom' => array(
					'{{WRAPPER}} .profecient-product-price .price del' => 'text-decoration-color: {{VALUE}};',
				),
			),
		);

		$this->options['st_sale_price_heading'] = array(
			'type'      => 'heading',
			'title'     => esc_html__( 'Sale Price', 'profecient-essential' ),
			'segment'   => 'style_price',
			'separator' => 'before',
		);

		$this->options['st_sale_price_typography'] = array(
			'type'      => 'typography',
			'title'     => esc_html__( 'Typography', 'profecient-essential' ),
			'segment'   => 'style_price',
			'selectors' => array(
				'custom' => '{{WRAPPER}} .profecient-product-price .price ins',
			),
		);

		$this->options['st_sale_price_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Color', 'profecient-essential' ),
			'segment'   => 'style_price',
			'selectors' => array(
				'custom' => array(
					'{{WRAPPER}} .profecient-product-price .price ins' => 'color: {{VALUE}};',
				),
			),
		);

		$this->options['st_sale_price_line_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Line Color', 'profecient-essential' ),
			'segment'   => 'style_price',
			'selectors' => array(
				'custom' => array(
					'{{WRAPPER}} .profecient-product-price .price ins' => 'text-decoration-color: {{VALUE}};',
				),
			),
		);

		$this->options['st_sale_price_spacing'] = array(
			'type'        => 'slider',
			'title'       => esc_html__( 'Offset', 'profecient-essential' ),
			'segment'     => 'style_price',
			'options'     => array(
				'min'  => 0,
				'max'  => 500,
				'step' => 1,
			),
			'responsive'  => true,
			'selectors'   => '.profecient-product-price .price ins',
			'attribute'   => 'margin-left',
			'description' => esc_html__( 'Set space between regular and sale price.', 'profecient-essential' ),
		);

		parent::additional_style();
	}
}
