<?php
/**
 * Product Single Rating Option Class
 *
 * @package profecient-essential
 * @author jegtheme
 * @since 1.0.0
 */

namespace Profecient\Essential\JKit\Elements\Options;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

use \Jeg\Elementor_Kit\Elements\Options\Option_Abstract;

/**
 * Class Product_Single_Rating_Option
 */
class Product_Single_Rating_Option extends Option_Abstract {
	/**
	 * Show color scheme flag for element.
	 *
	 * @return bool
	 */
	public function show_color_scheme() {
		return false;
	}

	/**
	 * Compatibility column
	 *
	 * @return array
	 */
	public function compatible_column() {
		return array();
	}

	/**
	 * Override function to remove compatible column alert
	 */
	public function set_compatible_column_option() {}

	/**
	 * Element name
	 *
	 * @return string
	 */
	public function get_element_name() {
		return esc_html__( 'Product Rating', 'profecient-essential' );
	}

	/**
	 * Element category
	 *
	 * @return string
	 */
	public function get_category() {
		return esc_html__( 'Profecient - Single Product', 'profecient-essential' );
	}

	/**
	 * Element options
	 */
	public function set_options() {
		$this->set_style_option();

		parent::set_options();
	}

	/**
	 * Style segments
	 */
	public function set_style_segment() {
		$this->segments['style_rating'] = array(
			'name'      => esc_html__( 'Product Rating', 'profecient-essential' ),
			'priority'  => 11,
			'kit_style' => true,
		);

		parent::set_style_segment();
	}

	/**
	 * Add Additional Style.
	 */
	public function additional_style() {
		$this->options['st_rating_alignment'] = array(
			'type'       => 'radio',
			'title'      => esc_html__( 'Alignment', 'profecient-essential' ),
			'segment'    => 'style_rating',
			'options'    => array(
				'left'   => array(
					'title' => esc_html__( 'Left', 'profecient-essential' ),
					'icon'  => 'fas fa-align-left',
				),
				'center' => array(
					'title' => esc_html__( 'Center', 'profecient-essential' ),
					'icon'  => 'fas fa-align-center',
				),
				'right'  => array(
					'title' => esc_html__( 'Right', 'profecient-essential' ),
					'icon'  => 'fas fa-align-right',
				),
			),
			'responsive' => true,
			'default'    => 'left',
			'selectors'  => '.profecient-product-rating .woocommerce-product-rating',
			'attribute'  => 'justify-content',
		);

		$this->options['st_rating_typography'] = array(
			'type'      => 'typography',
			'title'     => esc_html__( 'Typography', 'profecient-essential' ),
			'segment'   => 'style_rating',
			'selectors' => array(
				'custom' => '{{WRAPPER}} .profecient-product-rating',
			),
		);

		$this->options['st_rating_star_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Star Color', 'profecient-essential' ),
			'segment'   => 'style_rating',
			'selectors' => array(
				'custom' => array(
					'{{WRAPPER}} .profecient-product-rating' => 'color: {{VALUE}};',
				),
			),
		);

		$this->options['st_rating_star_second_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Star Second Color', 'profecient-essential' ),
			'segment'   => 'style_rating',
			'selectors' => array(
				'custom' => array(
					'{{WRAPPER}} .profecient-product-rating .star-rating:before' => 'color: {{VALUE}};',
				),
			),
		);

		$this->options['st_rating_spacing'] = array(
			'type'        => 'slider',
			'title'       => esc_html__( 'Star Spacing', 'profecient-essential' ),
			'segment'     => 'style_rating',
			'options'     => array(
				'min'  => 0,
				'max'  => 500,
				'step' => 1,
			),
			'responsive'  => true,
			'selectors'   => '.profecient-product-rating .woocommerce-product-rating .star-rating',
			'attribute'   => 'margin-right',
			'description' => esc_html__( 'Set gap space for the currency.', 'profecient-essential' ),
		);

		$this->options['st_rating_tabs_start'] = array(
			'type'    => 'control_tabs_start',
			'segment' => 'style_rating',
		);

		$this->options['st_rating_normal_tab_start'] = array(
			'type'    => 'control_tab_start',
			'title'   => esc_html__( 'Normal', 'profecient-essential' ),
			'segment' => 'style_rating',
		);

		$this->options['st_rating_normal_text_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Text Color', 'profecient-essential' ),
			'segment'   => 'style_rating',
			'selectors' => array(
				'custom' => array(
					'{{WRAPPER}} .profecient-product-rating a' => 'color: {{VALUE}};',
				),
			),
		);

		$this->options['st_rating_normal_tab_end'] = array(
			'type'    => 'control_tab_end',
			'segment' => 'style_rating',
		);

		$this->options['st_rating_hover_tab_start'] = array(
			'type'    => 'control_tab_start',
			'title'   => esc_html__( 'Hover', 'profecient-essential' ),
			'segment' => 'style_rating',
		);

		$this->options['st_rating_hover_text_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Text Color', 'profecient-essential' ),
			'segment'   => 'style_rating',
			'selectors' => array(
				'custom' => array(
					'{{WRAPPER}} .profecient-product-rating a:hover' => 'color: {{VALUE}};',
				),
			),
		);

		$this->options['st_rating_hover_tab_end'] = array(
			'type'    => 'control_tab_end',
			'segment' => 'style_rating',
		);

		$this->options['st_rating_tabs_end'] = array(
			'type'    => 'control_tabs_end',
			'segment' => 'style_rating',
		);

		parent::additional_style();
	}
}
