<?php
/**
 * Product Single Related Option Class
 *
 * @package profecient-essential
 * @author jegtheme
 * @since 1.0.0
 */

namespace Profecient\Essential\JKit\Elements\Options;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

use Jeg\Elementor_Kit\Elements\Options\Option_WooCommerce_Abstract;

/**
 * Class Product_Single_Related_Option
 */
class Product_Single_Related_Option extends Option_WooCommerce_Abstract {
	/**
	 * Show color scheme flag for element.
	 *
	 * @return bool
	 */
	public function show_color_scheme() {
		return false;
	}

	/**
	 * Compatibility column
	 *
	 * @return array
	 */
	public function compatible_column() {
		return array();
	}

	/**
	 * Override function to remove compatible column alert
	 */
	public function set_compatible_column_option() {}

	/**
	 * Element name
	 *
	 * @return string
	 */
	public function get_element_name() {
		return esc_html__( 'Related Product', 'profecient-essential' );
	}

	/**
	 * Element category
	 *
	 * @return string
	 */
	public function get_category() {
		return esc_html__( 'Profecient - Single Product', 'profecient-essential' );
	}

	/**
	 * Element options
	 */
	public function set_options() {
		$this->set_style_option();
		$this->set_element_options();

		parent::set_options();
	}

	/**
	 * Option segments
	 */
	public function set_segments() {
		$this->segments['segment_settings'] = array(
			'name'     => esc_html__( 'Settings', 'profecient-essential' ),
			'priority' => 10,
		);

		$this->segments['segment_button'] = array(
			'name'     => esc_html__( 'Button', 'profecient-essential' ),
			'priority' => 11,
		);

		$this->set_style_segment();
	}

	/**
	 * Style segments
	 */
	public function set_style_segment() {
		$this->segments['style_widget_heading'] = array(
			'name'      => esc_html__( 'Heading Widget', 'profecient-essential' ),
			'priority'  => 11,
			'kit_style' => true,
		);

		$this->set_product_block_style_segment();

		unset( $this->segments['style_product_category'] );

		parent::set_style_segment();
	}

	/**
	 * Set element option
	 */
	public function set_element_options() {
		$this->options['sg_filter_posts_per_page'] = array(
			'type'    => 'slider',
			'title'   => esc_html__( 'Posts per Page', 'profecient-essential' ),
			'segment' => 'segment_settings',
			'default' => 4,
			'options' => array(
				'min'  => 1,
				'max'  => 12,
				'step' => 1,
			),
		);

		$this->options['sg_content_column'] = array(
			'type'           => 'slider',
			'title'          => esc_html__( 'Column', 'profecient-essential' ),
			'segment'        => 'segment_settings',
			'default'        => 4,
			'tablet_default' => array(
				'size' => 3,
			),
			'mobile_default' => array(
				'size' => 1,
			),
			'options'        => array(
				'min'  => 1,
				'max'  => 10,
				'step' => 1,
			),
			'responsive'     => true,
			'selectors'      => array(
				'custom' => array(
					'{{WRAPPER}} .profecient-product-related ul.products' => 'grid-template-columns: repeat({{SIZE}}, 1fr)',
				),
			),
		);

		$this->options['sg_content_row_gap'] = array(
			'type'       => 'slider',
			'title'      => esc_html__( 'Row Gap', 'profecient-essential' ),
			'segment'    => 'segment_settings',
			'units'      => array( 'px', '%', 'em' ),
			'options'    => array(
				'min'  => 0,
				'max'  => 100,
				'step' => 1,
			),
			'selectors'  => '.profecient-product-related ul.products',
			'attribute'  => 'grid-row-gap',
			'responsive' => true,
		);

		$this->options['sg_content_column_gap'] = array(
			'type'       => 'slider',
			'title'      => esc_html__( 'Column Gap', 'profecient-essential' ),
			'segment'    => 'segment_settings',
			'units'      => array( 'px', '%', 'em' ),
			'options'    => array(
				'min'  => 0,
				'max'  => 100,
				'step' => 1,
			),
			'selectors'  => '.profecient-product-related ul.products',
			'attribute'  => 'grid-column-gap',
			'responsive' => true,
		);

		$this->options['sg_content_image_size'] = array(
			'type'        => 'imagesize',
			'title'       => esc_html__( 'Product Image Size', 'profecient-essential' ),
			'segment'     => 'segment_settings',
			'label_block' => true,
			'default'     => 'woocommerce_thumbnail',
		);

		$this->options['sg_content_sale'] = array(
			'type'      => 'checkbox',
			'title'     => esc_html__( 'Show Sale', 'profecient-essential' ),
			'segment'   => 'segment_settings',
			'default'   => true,
			'separator' => 'before',
		);

		$this->options['sg_content_percentage'] = array(
			'type'    => 'checkbox',
			'title'   => esc_html__( 'Show Sale Percentage', 'profecient-essential' ),
			'segment' => 'segment_settings',
			'default' => true,
		);

		$this->options['sg_button_icon'] = array(
			'type'    => 'iconpicker',
			'title'   => esc_html__( 'Button Icon', 'profecient-essential' ),
			'segment' => 'segment_button',
		);
	}

	/**
	 * Add Additional Style.
	 */
	public function additional_style() {
		$this->options['st_heading_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Color', 'profecient-essential' ),
			'segment'   => 'style_widget_heading',
			'selectors' => '.profecient-product-related .related > h2',
			'attribute' => 'color',
		);

		$this->options['st_heading_align'] = array(
			'type'      => 'typography',
			'title'     => esc_html__( 'Typography', 'profecient-essential' ),
			'segment'   => 'style_widget_heading',
			'selectors' => '.profecient-product-related .related > h2',
		);

		$this->options['st_breadcrumb_alignment'] = array(
			'type'       => 'radio',
			'title'      => esc_html__( 'Text Align', 'profecient-essential' ),
			'segment'    => 'style_widget_heading',
			'options'    => array(
				'left'   => array(
					'title' => esc_html__( 'Left', 'profecient-essential' ),
					'icon'  => 'fas fa-align-left',
				),
				'center' => array(
					'title' => esc_html__( 'Center', 'profecient-essential' ),
					'icon'  => 'fas fa-align-center',
				),
				'right'  => array(
					'title' => esc_html__( 'Right', 'profecient-essential' ),
					'icon'  => 'fas fa-align-right',
				),
			),
			'responsive' => true,
			'default'    => 'left',
			'selectors'  => '.profecient-product-related .related > h2',
			'attribute'  => 'text-align',
		);

		$this->options['st_product_block_alignment'] = array(
			'type'       => 'radio',
			'title'      => esc_html__( 'Alignment', 'profecient-essential' ),
			'segment'    => 'style_product_block',
			'options'    => array(
				'left'   => array(
					'title' => esc_html__( 'Left', 'profecient-essential' ),
					'icon'  => 'fas fa-align-left',
				),
				'center' => array(
					'title' => esc_html__( 'Center', 'profecient-essential' ),
					'icon'  => 'fas fa-align-center',
				),
				'right'  => array(
					'title' => esc_html__( 'Right', 'profecient-essential' ),
					'icon'  => 'fas fa-align-right',
				),
			),
			'responsive' => true,
			'default'    => 'center',
			'selectors'  => array(
				'custom' => array(
					'{{WRAPPER}} .profecient-product-related .products, {{WRAPPER}} .profecient-product-related .products .button' => 'text-align: {{VALUE}}',
					'{{WRAPPER}} .profecient-product-related .star-rating' => '--rating-margin-{{VALUE}}: 0',
				),
			),
		);

		$this->options['st_product_block_tabs_start'] = array(
			'type'    => 'control_tabs_start',
			'segment' => 'style_product_block',
		);

		$this->options['st_product_block_normal_tab_start'] = array(
			'type'    => 'control_tab_start',
			'title'   => esc_html__( 'Normal', 'profecient-essential' ),
			'segment' => 'style_product_block',
		);

		$this->options['st_product_block_background'] = array(
			'type'      => 'background',
			'title'     => esc_html__( 'Background', 'profecient-essential' ),
			'segment'   => 'style_product_block',
			'options'   => array(
				'classic',
				'gradient',
			),
			'exclude'   => array( 'image' ),
			'selectors' => '.profecient-product-related .product',
		);

		$this->options['st_product_block_margin'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Margin', 'profecient-essential' ),
			'segment'   => 'style_product_block',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.profecient-product-related .product',
			'attribute' => 'margin',
		);

		$this->options['st_product_block_padding'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Padding', 'profecient-essential' ),
			'segment'   => 'style_product_block',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.profecient-product-related .product',
			'attribute' => 'padding',
		);

		$this->options['st_product_block_border_radius'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Border Radius', 'profecient-essential' ),
			'segment'   => 'style_product_block',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.profecient-product-related .product',
			'attribute' => 'border-radius',
		);

		$this->options['st_product_block_border'] = array(
			'type'      => 'border',
			'title'     => esc_html__( 'Border', 'profecient-essential' ),
			'segment'   => 'style_product_block',
			'selectors' => '.profecient-product-related .product',
		);

		$this->options['st_product_block_boxshadow'] = array(
			'type'      => 'boxshadow',
			'title'     => esc_html__( 'Box Shadow', 'profecient-essential' ),
			'segment'   => 'style_product_block',
			'selectors' => '.profecient-product-related .product',
		);

		$this->options['st_product_block_normal_tab_end'] = array(
			'type'    => 'control_tab_end',
			'segment' => 'style_product_block',
		);

		$this->options['st_product_block_hover_tab_start'] = array(
			'type'    => 'control_tab_start',
			'title'   => esc_html__( 'Hover', 'profecient-essential' ),
			'segment' => 'style_product_block',
		);

		$this->options['st_product_block_hover_background'] = array(
			'type'      => 'background',
			'title'     => esc_html__( 'Hover Background', 'profecient-essential' ),
			'segment'   => 'style_product_block',
			'options'   => array(
				'classic',
				'gradient',
			),
			'exclude'   => array( 'image' ),
			'selectors' => '.profecient-product-related .product:hover',
		);

		$this->options['st_product_block_hover_margin'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Hover Margin', 'profecient-essential' ),
			'segment'   => 'style_product_block',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.profecient-product-related .product:hover',
			'attribute' => 'margin',
		);

		$this->options['st_product_block_hover_padding'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Hover Padding', 'profecient-essential' ),
			'segment'   => 'style_product_block',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.profecient-product-related .product:hover',
			'attribute' => 'padding',
		);

		$this->options['st_product_block_hover_border_radius'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Hover Border Radius', 'profecient-essential' ),
			'segment'   => 'style_product_block',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.profecient-product-related .product:hover',
			'attribute' => 'border-radius',
		);

		$this->options['st_product_block_hover_border'] = array(
			'type'      => 'border',
			'title'     => esc_html__( 'Hover Border', 'profecient-essential' ),
			'segment'   => 'style_product_block',
			'selectors' => '.profecient-product-related .product:hover',
		);

		$this->options['st_product_block_hover_boxshadow'] = array(
			'type'      => 'boxshadow',
			'title'     => esc_html__( 'Hover Box Shadow', 'profecient-essential' ),
			'segment'   => 'style_product_block',
			'selectors' => '.profecient-product-related .product:hover',
		);

		$this->options['st_product_block_hover_tab_end'] = array(
			'type'    => 'control_tab_end',
			'segment' => 'style_product_block',
		);

		$this->options['st_product_block_tabs_end'] = array(
			'type'    => 'control_tabs_end',
			'segment' => 'style_product_block',
		);

		$this->options['st_product_image_margin'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Margin', 'profecient-essential' ),
			'segment'   => 'style_product_image',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.profecient-product-related img',
			'attribute' => 'margin',
		);

		$this->options['st_product_image_padding'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Padding', 'profecient-essential' ),
			'segment'   => 'style_product_image',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.profecient-product-related img',
			'attribute' => 'padding',
		);

		$this->options['st_product_image_tabs_start'] = array(
			'type'    => 'control_tabs_start',
			'segment' => 'style_product_image',
		);

		$this->options['st_product_image_normal_tab_start'] = array(
			'type'    => 'control_tab_start',
			'title'   => esc_html__( 'Normal', 'profecient-essential' ),
			'segment' => 'style_product_image',
		);

		$this->options['st_product_image_background'] = array(
			'type'      => 'background',
			'title'     => esc_html__( 'Background Color', 'profecient-essential' ),
			'segment'   => 'style_product_image',
			'selectors' => '.profecient-product-related img',
			'options'   => array(
				'classic',
				'gradient',
			),
			'exclude'   => array( 'image' ),
		);

		$this->options['st_product_image_border_radius'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Border Radius', 'profecient-essential' ),
			'segment'   => 'style_product_image',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.profecient-product-related img',
			'attribute' => 'border-radius',
		);

		$this->options['st_product_image_border'] = array(
			'type'      => 'border',
			'title'     => esc_html__( 'Border', 'profecient-essential' ),
			'segment'   => 'style_product_image',
			'selectors' => '.profecient-product-related img',
		);

		$this->options['st_product_image_boxshadow'] = array(
			'type'      => 'boxshadow',
			'title'     => esc_html__( 'Box Shadow', 'profecient-essential' ),
			'segment'   => 'style_product_image',
			'selectors' => '.profecient-product-related img',
		);

		$this->options['st_product_image_normal_tab_end'] = array(
			'type'    => 'control_tab_end',
			'segment' => 'style_product_image',
		);

		$this->options['st_product_image_hover_tab_start'] = array(
			'type'    => 'control_tab_start',
			'title'   => esc_html__( 'Hover', 'profecient-essential' ),
			'segment' => 'style_product_image',
		);

		$this->options['st_product_image_hover_background'] = array(
			'type'      => 'background',
			'title'     => esc_html__( 'Background Color', 'profecient-essential' ),
			'segment'   => 'style_product_image',
			'selectors' => '.profecient-product-related .product .woocommerce-LoopProduct-link:hover img',
			'options'   => array(
				'classic',
				'gradient',
			),
			'exclude'   => array( 'image' ),
		);

		$this->options['st_product_image_hover_border_radius'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Border Radius', 'profecient-essential' ),
			'segment'   => 'style_product_image',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.profecient-product-related .product .woocommerce-LoopProduct-link:hover img',
			'attribute' => 'border-radius',
		);

		$this->options['st_product_image_hover_border'] = array(
			'type'      => 'border',
			'title'     => esc_html__( 'Border', 'profecient-essential' ),
			'segment'   => 'style_product_image',
			'selectors' => '.profecient-product-related .product .woocommerce-LoopProduct-link:hover img',
		);

		$this->options['st_product_image_hover_boxshadow'] = array(
			'type'      => 'boxshadow',
			'title'     => esc_html__( 'Box Shadow', 'profecient-essential' ),
			'segment'   => 'style_product_image',
			'selectors' => '.profecient-product-related .woocommerce-LoopProduct-link:hover img',
		);

		$this->options['st_product_image_hover_tab_end'] = array(
			'type'    => 'control_tab_end',
			'segment' => 'style_product_image',
		);

		$this->options['st_product_image_tabs_end'] = array(
			'type'    => 'control_tabs_end',
			'segment' => 'style_product_image',
		);

		$this->options['st_product_title_inline_background'] = array(
			'type'      => 'checkbox',
			'title'     => esc_html__( 'Inline Background', 'profecient-essential' ),
			'segment'   => 'style_product_title',
			'default'   => '',
			'selectors' => array(
				'custom' => array(
					'{{WRAPPER}} .profecient-product-related .woocommerce-loop-product__title' => '-webkit-box-decoration-break: clone; box-decoration-break: clone; display: inline;',
				),
			),
		);

		$this->options['st_product_title_typography'] = array(
			'type'      => 'typography',
			'title'     => esc_html__( 'Typography', 'profecient-essential' ),
			'segment'   => 'style_product_title',
			'selectors' => '.profecient-product-related .woocommerce-loop-product__title',
		);

		$this->options['st_product_title_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Color', 'profecient-essential' ),
			'segment'   => 'style_product_title',
			'selectors' => '.profecient-product-related .woocommerce-loop-product__title',
		);

		$this->options['st_product_title_background'] = array(
			'type'      => 'background',
			'title'     => esc_html__( 'Background Color', 'profecient-essential' ),
			'segment'   => 'style_product_title',
			'selectors' => '.profecient-product-related .woocommerce-loop-product__title',
			'options'   => array(
				'classic',
				'gradient',
			),
			'exclude'   => array( 'image' ),
		);

		$this->options['st_product_title_margin'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Margin', 'profecient-essential' ),
			'segment'   => 'style_product_title',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.profecient-product-related .woocommerce-loop-product__title',
			'attribute' => 'margin',
		);

		$this->options['st_product_title_padding'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Padding', 'profecient-essential' ),
			'segment'   => 'style_product_title',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.profecient-product-related .woocommerce-loop-product__title',
			'attribute' => 'padding',
		);

		$this->options['st_product_title_border_radius'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Border Radius', 'profecient-essential' ),
			'segment'   => 'style_product_title',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.profecient-product-related .woocommerce-loop-product__title',
			'attribute' => 'border-radius',
		);

		$this->options['st_product_title_border'] = array(
			'type'      => 'border',
			'title'     => esc_html__( 'Border', 'profecient-essential' ),
			'segment'   => 'style_product_title',
			'selectors' => '.profecient-product-related .woocommerce-loop-product__title',
		);

		$this->options['st_product_title_boxshadow'] = array(
			'type'      => 'boxshadow',
			'title'     => esc_html__( 'Box Shadow', 'profecient-essential' ),
			'segment'   => 'style_product_title',
			'selectors' => '.profecient-product-related .woocommerce-loop-product__title',
		);

		$this->options['st_product_title_textshadow'] = array(
			'type'      => 'textshadow',
			'title'     => esc_html__( 'Text Shadow', 'profecient-essential' ),
			'segment'   => 'style_product_title',
			'selectors' => '.profecient-product-related .woocommerce-loop-product__title',
		);

		$this->options['st_product_amount_inline_background'] = array(
			'type'      => 'checkbox',
			'title'     => esc_html__( 'Inline Background', 'profecient-essential' ),
			'segment'   => 'style_product_amount',
			'default'   => '',
			'selectors' => array(
				'custom' => array(
					'{{WRAPPER}} .profecient-product-related .related ul.products li.product .price' => '-webkit-box-decoration-break: clone; box-decoration-break: clone; display: inline;',
				),
			),
		);

		$this->options['st_product_amount_typography'] = array(
			'type'      => 'typography',
			'title'     => esc_html__( 'Typography', 'profecient-essential' ),
			'segment'   => 'style_product_amount',
			'selectors' => '.profecient-product-related .related ul.products li.product .price',
		);

		$this->options['st_product_amount_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Color', 'profecient-essential' ),
			'segment'   => 'style_product_amount',
			'selectors' => '.profecient-product-related .related ul.products li.product .price',
		);

		$this->options['st_product_amount_second_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Second Color', 'profecient-essential' ),
			'segment'   => 'style_product_amount',
			'selectors' => '.profecient-product-related .related ul.products li.product .price del',
		);

		$this->options['st_product_amount_background'] = array(
			'type'      => 'background',
			'title'     => esc_html__( 'Background Color', 'profecient-essential' ),
			'segment'   => 'style_product_amount',
			'selectors' => '.profecient-product-related .related ul.products li.product .price',
			'options'   => array(
				'classic',
				'gradient',
			),
			'exclude'   => array( 'image' ),
		);

		$this->options['st_product_amount_margin'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Margin', 'profecient-essential' ),
			'segment'   => 'style_product_amount',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.profecient-product-related .related ul.products li.product .price',
			'attribute' => 'margin',
		);

		$this->options['st_product_amount_padding'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Padding', 'profecient-essential' ),
			'segment'   => 'style_product_amount',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.profecient-product-related .related ul.products li.product .price',
			'attribute' => 'padding',
		);

		$this->options['st_product_amount_border_radius'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Border Radius', 'profecient-essential' ),
			'segment'   => 'style_product_amount',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.profecient-product-related .related ul.products li.product .price',
			'attribute' => 'border-radius',
		);

		$this->options['st_product_amount_border'] = array(
			'type'      => 'border',
			'title'     => esc_html__( 'Border', 'profecient-essential' ),
			'segment'   => 'style_product_amount',
			'selectors' => '.profecient-product-related .related ul.products li.product .price',
		);

		$this->options['st_product_amount_boxshadow'] = array(
			'type'      => 'boxshadow',
			'title'     => esc_html__( 'Box Shadow', 'profecient-essential' ),
			'segment'   => 'style_product_amount',
			'selectors' => '.profecient-product-related .related ul.products li.product .price',
		);

		$this->options['st_product_amount_textshadow'] = array(
			'type'      => 'textshadow',
			'title'     => esc_html__( 'Text Shadow', 'profecient-essential' ),
			'segment'   => 'style_product_amount',
			'selectors' => '.profecient-product-related .related ul.products li.product .price',
		);

		$this->options['st_product_sale_width'] = array(
			'type'       => 'slider',
			'title'      => esc_html__( 'Width', 'profecient-essential' ),
			'segment'    => 'style_product_sale',
			'responsive' => true,
			'units'      => array( 'px', '%', 'em' ),
			'options'    => array(
				'min'  => 0,
				'max'  => 100,
				'step' => 1,
			),
			'selectors'  => '.profecient-product-related ul.products li.product span.onsale',
			'attribute'  => 'width',
		);

		$this->options['st_product_sale_height'] = array(
			'type'       => 'slider',
			'title'      => esc_html__( ' Height', 'profecient-essential' ),
			'segment'    => 'style_product_sale',
			'responsive' => true,
			'units'      => array( 'px', '%', 'em' ),
			'options'    => array(
				'min'  => 0,
				'max'  => 100,
				'step' => 1,
			),
			'selectors'  => array(
				'custom' => array(
					'{{WRAPPER}} .profecient-product-related ul.products li.product span.onsale' => 'height: {{SIZE}}{{UNIT}}; --profecient-onsale-height: {{SIZE}}{{UNIT}};',
				),
			),
		);

		$this->options['st_product_sale_horizontal_orientation'] = array(
			'type'    => 'radio',
			'title'   => esc_html__( 'Horizontal Orientation', 'profecient-essential' ),
			'segment' => 'style_product_sale',
			'options' => array(
				'left'  => array(
					'title' => esc_html__( 'Left', 'profecient-essential' ),
					'icon'  => 'eicon-h-align-left',
				),
				'right' => array(
					'title' => esc_html__( 'Right', 'profecient-essential' ),
					'icon'  => 'eicon-h-align-right',
				),
			),
			'default' => 'right',
			'toggle'  => false,
		);

		$this->options['st_product_sale_horizontal_offset'] = array(
			'type'       => 'slider',
			'title'      => esc_html__( 'Offset', 'profecient-essential' ),
			'segment'    => 'style_product_sale',
			'responsive' => true,
			'units'      => array( 'px', '%', 'em' ),
			'options'    => array(
				'min'  => 0,
				'max'  => 100,
				'step' => 1,
			),
			'selectors'  => array(
				'custom' => array( '{{WRAPPER}} .profecient-product-related ul.products li.product span.onsale' => '{{st_product_sale_horizontal_orientation.VALUE}}: {{SIZE}}{{UNIT}};' ),
			),
		);

		$this->options['st_product_sale_vertical_orientation'] = array(
			'type'    => 'radio',
			'title'   => esc_html__( 'Vertical Orientation', 'profecient-essential' ),
			'segment' => 'style_product_sale',
			'options' => array(
				'top'    => array(
					'title' => esc_html__( 'Top', 'profecient-essential' ),
					'icon'  => 'eicon-v-align-top',
				),
				'bottom' => array(
					'title' => esc_html__( 'Bottom', 'profecient-essential' ),
					'icon'  => 'eicon-v-align-bottom',
				),
			),
			'default' => 'top',
			'toggle'  => false,
		);

		$this->options['st_product_sale_vertical_offset'] = array(
			'type'       => 'slider',
			'title'      => esc_html__( 'Offset', 'profecient-essential' ),
			'segment'    => 'style_product_sale',
			'responsive' => true,
			'units'      => array( 'px', '%', 'em' ),
			'options'    => array(
				'min'  => 0,
				'max'  => 100,
				'step' => 1,
			),
			'selectors'  => array(
				'custom' => array( '{{WRAPPER}} .profecient-product-related ul.products li.product span.onsale' => '{{st_product_sale_vertical_orientation.VALUE}}: {{SIZE}}{{UNIT}};' ),
			),
		);

		$this->options['st_product_sale_gap_offset'] = array(
			'type'       => 'slider',
			'title'      => esc_html__( 'Gap', 'profecient-essential' ),
			'segment'    => 'style_product_sale',
			'responsive' => true,
			'options'    => array(
				'min'  => 0,
				'max'  => 100,
				'step' => 1,
			),
			'default'    => 5,
			'selectors'  => array(
				'custom' => array( '{{WRAPPER}} .profecient-product-related ul.products li.product span.onsale' => '--profecient-onsale-gap: {{SIZE}}px' ),
			),
		);

		$this->options['st_product_sale_typography'] = array(
			'type'      => 'typography',
			'title'     => esc_html__( 'Typography', 'profecient-essential' ),
			'segment'   => 'style_product_sale',
			'selectors' => '.profecient-product-related ul.products li.product span.onsale',
		);

		$this->options['st_product_sale_heading'] = array(
			'type'      => 'heading',
			'title'     => esc_html__( 'Sale', 'profecient-essential' ),
			'segment'   => 'style_product_sale',
			'separator' => 'before',
		);

		$this->options['st_product_sale_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Color', 'profecient-essential' ),
			'segment'   => 'style_product_sale',
			'selectors' => '.profecient-product-related ul.products li.product span.onsale.text',
		);

		$this->options['st_product_sale_background'] = array(
			'type'      => 'background',
			'title'     => esc_html__( 'Background Color', 'profecient-essential' ),
			'segment'   => 'style_product_sale',
			'selectors' => '.profecient-product-related ul.products li.product span.onsale.text',
			'options'   => array(
				'classic',
				'gradient',
			),
			'exclude'   => array( 'image' ),
		);

		$this->options['st_product_sale_percentage_heading'] = array(
			'type'      => 'heading',
			'title'     => esc_html__( 'Percetage', 'profecient-essential' ),
			'segment'   => 'style_product_sale',
			'separator' => 'before',
		);

		$this->options['st_product_sale_percentage_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Color', 'profecient-essential' ),
			'segment'   => 'style_product_sale',
			'selectors' => '.profecient-product-related ul.products li.product span.onsale.percent',
		);

		$this->options['st_product_sale_percentage_background'] = array(
			'type'      => 'background',
			'title'     => esc_html__( 'Background Color', 'profecient-essential' ),
			'segment'   => 'style_product_sale',
			'selectors' => '.profecient-product-related ul.products li.product span.onsale.percent',
			'options'   => array(
				'classic',
				'gradient',
			),
			'exclude'   => array( 'image' ),
		);

		$this->options['st_product_sale_margin'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Margin', 'profecient-essential' ),
			'segment'   => 'style_product_sale',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.profecient-product-related ul.products li.product span.onsale',
			'attribute' => 'margin',
			'separator' => 'before',
		);

		$this->options['st_product_sale_padding'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Padding', 'profecient-essential' ),
			'segment'   => 'style_product_sale',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.profecient-product-related ul.products li.product span.onsale',
			'attribute' => 'padding',
		);

		$this->options['st_product_sale_border_radius'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Border Radius', 'profecient-essential' ),
			'segment'   => 'style_product_sale',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.profecient-product-related ul.products li.product span.onsale',
			'attribute' => 'border-radius',
		);

		$this->options['st_product_sale_border'] = array(
			'type'      => 'border',
			'title'     => esc_html__( 'Border', 'profecient-essential' ),
			'segment'   => 'style_product_sale',
			'selectors' => '.profecient-product-related ul.products li.product span.onsale',
		);

		$this->options['st_product_sale_boxshadow'] = array(
			'type'      => 'boxshadow',
			'title'     => esc_html__( 'Box Shadow', 'profecient-essential' ),
			'segment'   => 'style_product_sale',
			'selectors' => '.profecient-product-related ul.products li.product span.onsale',
		);

		$this->options['st_product_sale_textshadow'] = array(
			'type'      => 'textshadow',
			'title'     => esc_html__( 'Text Shadow', 'profecient-essential' ),
			'segment'   => 'style_product_sale',
			'selectors' => '.profecient-product-related ul.products li.product span.onsale',
		);

		$this->options['st_product_rating_size'] = array(
			'type'       => 'slider',
			'title'      => esc_html__( 'Star Size', 'profecient-essential' ),
			'segment'    => 'style_product_rating',
			'default'    => 13,
			'options'    => array(
				'min'  => 0,
				'max'  => 200,
				'step' => 1,
			),
			'responsive' => true,
			'selectors'  => array(
				'custom' => array(
					'{{WRAPPER}} .profecient-product-related .star-rating' => 'font-size:{{SIZE}}px; height:{{SIZE}}px',
				),
			),
			'attribute'  => 'font-size',
		);

		$this->options['st_product_rating_margin'] = array(
			'type'               => 'dimension',
			'title'              => esc_html__( 'Margin', 'profecient-essential' ),
			'segment'            => 'style_product_rating',
			'units'              => array( 'px', '%', 'em' ),
			'allowed_dimensions' => 'vertical',
			'selectors'          => '.profecient-product-related .star-rating',
			'attribute'          => 'margin',
		);

		$this->options['st_product_rating_tabs_start'] = array(
			'type'    => 'control_tabs_start',
			'segment' => 'style_product_rating',
		);

		$this->options['st_product_rating_normal_normal_tab_start'] = array(
			'type'    => 'control_tab_start',
			'title'   => esc_html__( 'Normal', 'profecient-essential' ),
			'segment' => 'style_product_rating',
		);

		$this->options['st_product_rating_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Color', 'profecient-essential' ),
			'segment'   => 'style_product_rating',
			'selectors' => '.profecient-product-related .star-rating',
		);

		$this->options['st_product_rating_second_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Second Color', 'profecient-essential' ),
			'segment'   => 'style_product_rating',
			'selectors' => '.profecient-product-related .star-rating:before',
		);

		$this->options['st_product_rating_normal_normal_tab_end'] = array(
			'type'    => 'control_tab_end',
			'segment' => 'style_product_rating',
		);

		$this->options['st_product_rating_hover_tab_start'] = array(
			'type'    => 'control_tab_start',
			'title'   => esc_html__( 'Hover', 'profecient-essential' ),
			'segment' => 'style_product_rating',
		);

		$this->options['st_product_rating_hover_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Color', 'profecient-essential' ),
			'segment'   => 'style_product_rating',
			'selectors' => '.profecient-product-related .product > a:hover .star-rating',
		);

		$this->options['st_product_rating_hover_second_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Second Color', 'profecient-essential' ),
			'segment'   => 'style_product_rating',
			'selectors' => '.profecient-product-related .product > a:hover .star-rating:before',
		);

		$this->options['st_product_rating_hover_tab_end'] = array(
			'type'    => 'control_tab_end',
			'segment' => 'style_product_rating',
		);

		$this->options['st_product_rating_tabs_end'] = array(
			'type'    => 'control_tabs_end',
			'segment' => 'style_product_rating',
		);

		$this->options['st_product_button_margin'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Margin', 'profecient-essential' ),
			'segment'   => 'style_product_button',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.profecient-product-related .product .button',
			'attribute' => 'margin',
		);

		$this->options['st_product_button_padding'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Padding', 'profecient-essential' ),
			'segment'   => 'style_product_button',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.profecient-product-related .product .button',
			'attribute' => 'padding',
		);

		$this->options['st_product_button_typography'] = array(
			'type'      => 'typography',
			'title'     => esc_html__( 'Typography', 'profecient-essential' ),
			'segment'   => 'style_product_button',
			'selectors' => '.profecient-product-related .product .button',
		);

		$this->options['st_product_button_tabs_start'] = array(
			'type'    => 'control_tabs_start',
			'segment' => 'style_product_button',
		);

		$this->options['st_product_button_normal_tab_start'] = array(
			'type'    => 'control_tab_start',
			'title'   => esc_html__( 'Normal', 'profecient-essential' ),
			'segment' => 'style_product_button',
		);

		$this->options['st_product_button_normal_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Color', 'profecient-essential' ),
			'segment'   => 'style_product_button',
			'selectors' => '.profecient-product-related .product .button',
		);

		$this->options['st_product_button_normal_background'] = array(
			'type'      => 'background',
			'title'     => esc_html__( 'Background Color', 'profecient-essential' ),
			'segment'   => 'style_product_button',
			'selectors' => '.profecient-product-related .product .button',
			'options'   => array(
				'classic',
				'gradient',
			),
			'exclude'   => array( 'image' ),
		);

		$this->options['st_product_button_normal_border_radius'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Border Radius', 'profecient-essential' ),
			'segment'   => 'style_product_button',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.profecient-product-related .product .button',
			'attribute' => 'border-radius',
		);

		$this->options['st_product_button_normal_border'] = array(
			'type'      => 'border',
			'title'     => esc_html__( 'Border', 'profecient-essential' ),
			'segment'   => 'style_product_button',
			'selectors' => '.profecient-product-related .product .button',
		);

		$this->options['st_product_button_normal_boxshadow'] = array(
			'type'      => 'boxshadow',
			'title'     => esc_html__( 'Box Shadow', 'profecient-essential' ),
			'segment'   => 'style_product_button',
			'selectors' => '.profecient-product-related .product .button',
		);

		$this->options['st_product_button_normal_textshadow'] = array(
			'type'      => 'textshadow',
			'title'     => esc_html__( 'Text Shadow', 'profecient-essential' ),
			'segment'   => 'style_product_button',
			'selectors' => '.profecient-product-related .product .button',
		);

		$this->options['st_product_button_normal_tab_end'] = array(
			'type'    => 'control_tab_end',
			'segment' => 'style_product_button',
		);

		$this->options['st_product_button_hover_tab_start'] = array(
			'type'    => 'control_tab_start',
			'title'   => esc_html__( 'Hover', 'profecient-essential' ),
			'segment' => 'style_product_button',
		);

		$this->options['st_product_button_hover_transition_duration'] = array(
			'type'      => 'slider',
			'title'     => esc_html__( 'Transition Duration', 'profecient-essential' ),
			'segment'   => 'style_product_button',
			'options'   => array(
				'min'  => 0,
				'max'  => 10,
				'step' => 0.1,
			),
			'selectors' => array(
				'custom' => array(
					'{{WRAPPER}} .profecient-product-related .product .button' => 'transition-duration: {{SIZE}}s;',
				),
			),
		);

		$this->options['st_product_button_hover_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Color', 'profecient-essential' ),
			'segment'   => 'style_product_button',
			'selectors' => '.profecient-product-related .product .button:hover',
		);

		$this->options['st_product_button_hover_background'] = array(
			'type'      => 'background',
			'title'     => esc_html__( 'Background Color', 'profecient-essential' ),
			'segment'   => 'style_product_button',
			'selectors' => '.profecient-product-related .product .button:hover',
			'options'   => array(
				'classic',
				'gradient',
			),
			'exclude'   => array( 'image' ),
		);

		$this->options['st_product_button_hover_border_radius'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Border Radius', 'profecient-essential' ),
			'segment'   => 'style_product_button',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.profecient-product-related .product .button:hover',
			'attribute' => 'border-radius',
		);

		$this->options['st_product_button_hover_border'] = array(
			'type'      => 'border',
			'title'     => esc_html__( 'Border', 'profecient-essential' ),
			'segment'   => 'style_product_button',
			'selectors' => '.profecient-product-related .product .button:hover',
		);

		$this->options['st_product_button_hover_boxshadow'] = array(
			'type'      => 'boxshadow',
			'title'     => esc_html__( 'Box Shadow', 'profecient-essential' ),
			'segment'   => 'style_product_button',
			'selectors' => '.profecient-product-related .product .button:hover',
		);

		$this->options['st_product_button_hover_textshadow'] = array(
			'type'      => 'textshadow',
			'title'     => esc_html__( 'Text Shadow', 'profecient-essential' ),
			'segment'   => 'style_product_button',
			'selectors' => '.profecient-product-related .product .button:hover',
		);

		$this->options['st_product_button_hover_tab_end'] = array(
			'type'    => 'control_tab_end',
			'segment' => 'style_product_button',
		);

		$this->options['st_product_button_tabs_end'] = array(
			'type'    => 'control_tabs_end',
			'segment' => 'style_product_button',
		);

		$this->options['st_product_button_icon_heading'] = array(
			'type'      => 'heading',
			'title'     => esc_html__( 'Icon', 'profecient-essential' ),
			'segment'   => 'style_product_button',
			'separator' => 'before',
		);

		$this->options['st_product_button_icon_margin'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Margin', 'profecient-essential' ),
			'segment'   => 'style_product_button',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.profecient-product-related .product .button > i',
			'attribute' => 'margin',
		);

		$this->options['st_product_button_icon_position'] = array(
			'type'      => 'radio',
			'title'     => esc_html__( 'Position', 'profecient-essential' ),
			'segment'   => 'style_product_button',
			'options'   => array(
				'ltr' => array(
					'title' => esc_html__( 'Left', 'profecient-essential' ),
					'icon'  => 'eicon-h-align-left',
				),
				'rtl' => array(
					'title' => esc_html__( 'Right', 'profecient-essential' ),
					'icon'  => 'eicon-h-align-right',
				),
			),
			'default'   => 'right',
			'selectors' => '.profecient-product-related .product .button',
			'attribute' => 'direction',
		);

		parent::additional_style();
	}
}
