<?php
/**
 * Product Single Stock Option Class
 *
 * @package profecient-essential
 * @author jegtheme
 * @since 1.0.0
 */

namespace Profecient\Essential\JKit\Elements\Options;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

use Jeg\Elementor_Kit\Elements\Options\Option_Abstract;

/**
 * Class Product_Single_Stock_Option
 */
class Product_Single_Stock_Option extends Option_Abstract {
	/**
	 * Show color scheme flag for element.
	 *
	 * @return bool
	 */
	public function show_color_scheme() {
		return false;
	}

	/**
	 * Compatibility column
	 *
	 * @return array
	 */
	public function compatible_column() {
		return array();
	}

	/**
	 * Override function to remove compatible column alert
	 */
	public function set_compatible_column_option() {}

	/**
	 * Element name
	 *
	 * @return string
	 */
	public function get_element_name() {
		return esc_html__( 'Product Stock', 'profecient-essential' );
	}

	/**
	 * Element category
	 *
	 * @return string
	 */
	public function get_category() {
		return esc_html__( 'Profecient - Single Product', 'profecient-essential' );
	}

	/**
	 * Element options
	 */
	public function set_options() {
		$this->set_style_option();
		$this->set_element_options();

		parent::set_options();
	}

	/**
	 * Option segments
	 */
	public function set_segments() {
		$this->segments['segment_preview_settings'] = array(
			'name'     => esc_html__( 'Preview Settings', 'profecient-essential' ),
			'priority' => 10,
		);

		$this->set_style_segment();
	}

	/**
	 * Style segments
	 */
	public function set_style_segment() {
		$this->segments['style_stock'] = array(
			'name'      => esc_html__( 'Style Stock', 'profecient-essential' ),
			'priority'  => 10,
			'kit_style' => true,
		);

		parent::set_style_segment();
	}

	/**
	 * Set element option
	 */
	public function set_element_options() {
		$this->options['sg_preview_product_stock'] = array(
			'type'    => 'select',
			'title'   => esc_html__( 'Product Stock', 'profecient-essential' ),
			'default' => 'in-stock',
			'options' => array(
				'in-stock'               => esc_html__( 'In Stock', 'profecient-essential' ),
				'available-on-backorder' => esc_html__( 'Avaiable on Backorder', 'profecient-essential' ),
				'out-of-stock'           => esc_html__( 'Out of Stock', 'profecient-essential' ),
			),
			'segment' => 'segment_preview_settings',
		);
	}

	/**
	 * Add Additional Style.
	 */
	public function additional_style() {
		$this->options['st_stock_wrapper_heading'] = array(
			'type'    => 'heading',
			'title'   => 'Wrapper',
			'segment' => 'style_stock',
		);

		$this->options['st_stock_wrapper_margin'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Margin', 'profecient-essential' ),
			'segment'   => 'style_stock',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.profecient-single-product-stock .stock',
			'attribute' => 'margin',
		);

		$this->options['st_stock_in_stock_heading'] = array(
			'type'    => 'heading',
			'title'   => 'In Stock',
			'segment' => 'style_stock',
		);

		$this->options['st_stock_in_stock_typography'] = array(
			'type'      => 'typography',
			'title'     => esc_html__( 'Typograhpy', 'profecient-essential' ),
			'segment'   => 'style_stock',
			'selectors' => '.profecient-single-product-stock .stock',
		);

		$this->options['st_stock_in_stock_text_color']            = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Color', 'profecient-essential' ),
			'segment'   => 'style_stock',
			'selectors' => '.profecient-single-product-stock .stock',
		);
		$this->options['st_stock_available_on_backorder_heading'] = array(
			'type'    => 'heading',
			'title'   => 'Avaiable on Backorder',
			'segment' => 'style_stock',
		);

		$this->options['st_stock_available_on_backorder_typography'] = array(
			'type'      => 'typography',
			'title'     => esc_html__( 'Typograhpy', 'profecient-essential' ),
			'segment'   => 'style_stock',
			'selectors' => '.profecient-single-product-stock .available-on-backorder',
		);

		$this->options['st_stock_available_on_backorder_text_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Color', 'profecient-essential' ),
			'segment'   => 'style_stock',
			'selectors' => '.profecient-single-product-stock .available-on-backorder',
		);

		$this->options['st_stock_out_of_stock_heading'] = array(
			'type'    => 'heading',
			'title'   => 'Out of Stock',
			'segment' => 'style_stock',
		);

		$this->options['st_stock_out_of_stock_typography'] = array(
			'type'      => 'typography',
			'title'     => esc_html__( 'Typograhpy', 'profecient-essential' ),
			'segment'   => 'style_stock',
			'selectors' => '.profecient-single-product-stock .out-of-stock',
		);

		$this->options['st_stock_out_of_stock_text_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Color', 'profecient-essential' ),
			'segment'   => 'style_stock',
			'selectors' => '.profecient-single-product-stock .out-of-stock',
		);

		parent::additional_style();
	}
}
