<?php
/**
 * Text Background Option Class
 *
 * @package profecient-essential
 * @author jegtheme
 * @since 1.0.0
 */

namespace Profecient\Essential\JKit\Elements\Options;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

use \Jeg\Elementor_Kit\Elements\Options\Option_Abstract;

/**
 * Class Text_Background_Option
 */
class Text_Background_Option extends Option_Abstract {
	/**
	 * Show color scheme flag for element.
	 *
	 * @return bool
	 */
	public function show_color_scheme() {
		return false;
	}

	/**
	 * Compatibility column
	 *
	 * @return array
	 */
	public function compatible_column() {
		return array();
	}

	/**
	 * Override function to remove compatible column alert
	 */
	public function set_compatible_column_option() {}

	/**
	 * Element name
	 *
	 * @return string
	 */
	public function get_element_name() {
		return esc_html__( 'Text Background', 'profecient-essential' );
	}

	/**
	 * Element category
	 *
	 * @return string
	 */
	public function get_category() {
		return esc_html__( 'Profecient', 'profecient-essential' );
	}

	/**
	 * Element options
	 */
	public function set_options() {
		$this->set_style_option();
		$this->set_element_options();

		parent::set_options();
	}

	/**
	 * Option segments
	 */
	public function set_segments() {
		$this->segments['segment_settings'] = array(
			'name'     => esc_html__( 'Content Settings', 'profecient-essential' ),
			'priority' => 10,
		);

		$this->set_style_segment();
	}

	/**
	 * Style segments
	 */
	public function set_style_segment() {
		$this->segments['style_content'] = array(
			'name'      => esc_html__( 'Content Styles', 'profecient-essential' ),
			'priority'  => 11,
			'kit_style' => true,
		);

		parent::set_style_segment();
	}

	/**
	 * Set element option
	 */
	public function set_element_options() {
		$this->options['sg_settings_icon'] = array(
			'type'    => 'iconpicker',
			'title'   => esc_html__( 'Icon', 'profecient-essential' ),
			'segment' => 'segment_settings',
			'default' => array(
				'value'   => 'fas fa-dog',
				'library' => 'fa-solid',
			),
		);

		$this->options['sg_settings_text'] = array(
			'type'        => 'text',
			'title'       => esc_html__( 'Text', 'profecient-essential' ),
			'segment'     => 'segment_settings',
			'default'     => esc_html__( 'The quick {{brown}} fox jumps over the {{lazy}} {{profecient_icon}} dog', 'profecient-essential' ),
			'description' => esc_html__( 'Use the {{text}} format for excluded text, and use {{profecient_icon}} for add the icon above to text.', 'profecient-essential' ),
		);

		$this->options['sg_settings_text_html_tag'] = array(
			'type'    => 'select',
			'title'   => esc_html__( 'HTML Tag', 'profecient-essential' ),
			'default' => 'p',
			'segment' => 'segment_settings',
			'options' => array(
				'h1'   => 'H1',
				'h2'   => 'H2',
				'h3'   => 'H3',
				'h4'   => 'H4',
				'h5'   => 'H5',
				'h6'   => 'H6',
				'div'  => 'div',
				'span' => 'span',
				'p'    => 'p',
			),
		);
	}

	/**
	 * Add Additional Style.
	 */
	public function additional_style() {
		$this->options['st_text_typography'] = array(
			'type'      => 'typography',
			'title'     => esc_html__( 'Typography', 'profecient-essential' ),
			'segment'   => 'style_content',
			'selectors' => array(
				'custom' => '{{WRAPPER}} .profecient-text-background .text-background',
			),
		);

		$this->options['st_text_textstroke'] = array(
			'type'      => 'textstroke',
			'title'     => esc_html__( 'Text Stroke', 'profecient-essential' ),
			'segment'   => 'style_content',
			'selectors' => '.profecient-text-background .text-background',
		);

		$this->options['st_text_textshadow'] = array(
			'type'      => 'textshadow',
			'title'     => esc_html__( 'Text Shadow', 'profecient-essential' ),
			'segment'   => 'style_content',
			'selectors' => '.profecient-text-background .text-background',
		);

		$this->options['st_text_background'] = array(
			'type'           => 'background',
			'title'          => esc_html__( 'Background', 'profecient-essential' ),
			'segment'        => 'style_content',
			'selectors'      => '.profecient-text-background .text-background',
			'options'        => array(
				'classic',
			),
			'fields_options' => array(
				'background' => array(
					'default' => 'classic',
				),
				'color'      => array(
					'selectors' => array(
						'{{SELECTOR}} .exclude' => '-webkit-text-fill-color: {{VALUE}};',
					),
				),
				'image'      => array(
					'default' => array(
						'url' => \Elementor\Utils::get_placeholder_image_src(),
					),
				),
			),
		);

		parent::additional_style();
	}
}
