<?php
/**
 * Text Marquee Option Class
 *
 * @package profecient-essential
 * @author jegtheme
 * @since 1.0.0
 */

namespace Profecient\Essential\JKit\Elements\Options;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

use Jeg\Elementor_Kit\Elements\Options\Option_Abstract;

/**
 * Class Text_Marquee_Option
 *
 * @package Profecient\Essential\JKit\Elements\Options
 */
class Text_Marquee_Option extends Option_Abstract {
	/**
	 * Show color scheme flag for element.
	 *
	 * @return bool
	 */
	public function show_color_scheme() {
		return false;
	}

	/**
	 * Compatibility column
	 *
	 * @return array
	 */
	public function compatible_column() {
		return array();
	}

	/**
	 * Override function to remove compatible column alert
	 */
	public function set_compatible_column_option() {
	}

	/**
	 * Element name
	 *
	 * @return string
	 */
	public function get_element_name() {
		return esc_html__( 'Text Marquee', 'profecient-essential' );
	}

	/**
	 * Element category
	 *
	 * @return string
	 */
	public function get_category() {
		return esc_html__( 'Profecient', 'profecient-essential' );
	}

	/**
	 * Element options
	 */
	public function set_options() {
		$this->set_style_option();
		$this->set_element_options();

		parent::set_options();
	}

	/**
	 * Option segments
	 */
	public function set_segments() {
		$this->segments['segment_marquee'] = array(
			'name'     => esc_html__( 'Marquee', 'profecient-essential' ),
			'priority' => 10,
		);

		$this->segments['segment_settings'] = array(
			'name'     => esc_html__( 'Settings', 'profecient-essential' ),
			'priority' => 10,
		);

		$this->set_style_segment();
	}

	/**
	 * Style segments
	 */
	public function set_style_segment() {
		$this->segments['style_wrapper'] = array(
			'name'      => esc_html__( 'Wrapper', 'profecient-essential' ),
			'priority'  => 11,
			'kit_style' => true,
		);

		$this->segments['style_text'] = array(
			'name'      => esc_html__( 'Text', 'profecient-essential' ),
			'priority'  => 12,
			'kit_style' => true,
		);

		$this->segments['style_icon'] = array(
			'name'      => esc_html__( 'Icon', 'profecient-essential' ),
			'priority'  => 13,
			'kit_style' => true,
		);

		parent::set_style_segment();
	}

	/**
	 * Set element option
	 */
	public function set_element_options() {
		$this->options['sg_marquee_text_split_enabled'] = array(
			'type'    => 'checkbox',
			'title'   => esc_html__( 'Splited Text?', 'profecient-essential' ),
			'segment' => 'segment_marquee',
		);

		$this->options['sg_marquee_text'] = array(
			'type'       => 'text',
			'title'      => esc_html__( 'Marquee Text', 'profecient-essential' ),
			'segment'    => 'segment_marquee',
			'default'    => esc_html( 'The quick, brown fox jumps over a lazy dog ', 'profecient-essential' ),
			'dependency' => array(
				array(
					'field'    => 'sg_marquee_text_split_enabled!',
					'operator' => '==',
					'value'    => 'yes',
				),
			),
		);

		$this->options['sg_marquee_text_splited'] = array(
			'type'        => 'repeater',
			'title'       => esc_html__( 'Split Text', 'profecient-essential' ),
			'segment'     => 'segment_marquee',
			'title_field' => '{{ sg_marquee_text_split }}',
			'fields'      => array(
				'sg_marquee_text_split'      => array(
					'type'    => 'text',
					'title'   => esc_html__( 'Text', 'profecient-essential' ),
					'segment' => 'sg_marquee_text_splited',
				),
				'sg_marquee_text_icon_split' => array(
					'type'    => 'iconpicker',
					'title'   => esc_html__( 'Icon', 'profecient-essential' ),
					'segment' => 'sg_marquee_text_splited',
					'default' => array(
						'value'   => 'fas fa-chevron-down',
						'library' => 'fa-solid',
					),
				),
			),
			'default'     => array(
				array(
					'sg_marquee_text_split'      => esc_html__( ' Lorem ipsum dolor sit amet ', 'profecient-essential' ),
					'sg_marquee_text_icon_split' => array(
						'value'   => 'jki jki-running-solid',
						'library' => 'jkiticon',
					),
				),
				array(
					'sg_marquee_text_split'      => esc_html__( ' Far far away, behind the word mountains ', 'profecient-essential' ),
					'sg_marquee_text_icon_split' => array(
						'value'   => 'jki jki-running-solid',
						'library' => 'jkiticon',
					),
				),
				array(
					'sg_marquee_text_split'      => esc_html__( ' The quick, brown fox jumps over a lazy dog ', 'profecient-essential' ),
					'sg_marquee_text_icon_split' => array(
						'value'   => 'jki jki-running-solid',
						'library' => 'jkiticon',
					),
				),
			),
			'dependency'  => array(
				array(
					'field'    => 'sg_marquee_text_split_enabled',
					'operator' => '==',
					'value'    => 'yes',
				),
			),
		);

		$this->options['sg_marquee_text_html_tag'] = array(
			'type'    => 'select',
			'title'   => esc_html__( 'HTML Tag', 'profecient-essential' ),
			'segment' => 'segment_marquee',
			'options' => array(
				'h1'   => 'H1',
				'h2'   => 'H2',
				'h3'   => 'H3',
				'h4'   => 'H4',
				'h5'   => 'H5',
				'h6'   => 'H6',
				'div'  => 'div',
				'span' => 'span',
				'p'    => 'p',
			),
			'default' => 'h2',
		);

		$this->options['sg_settings_speed'] = array(
			'type'               => 'slider',
			'title'              => esc_html__( 'Speed', 'profecient-essential' ),
			'segment'            => 'segment_settings',
			'options'            => array(
				'min'  => 0.1,
				'max'  => 10,
				'step' => 0.1,
			),
			'default'            => 1,
			'responsive'         => true,
			'frontend_available' => true,
		);

		$this->options['sg_settings_direction'] = array(
			'type'               => 'radio',
			'title'              => esc_html__( 'Directions', 'profecient-essential' ),
			'segment'            => 'segment_settings',
			'options'            => array(
				'left'   => array(
					'title' => esc_html__( 'To Left', 'profecient-essential' ),
					'icon'  => 'eicon-h-align-left',
				),
				'top'    => array(
					'title' => esc_html__( 'To Top', 'profecient-essential' ),
					'icon'  => 'eicon-v-align-top',
				),
				'right'  => array(
					'title' => esc_html__( 'To Right', 'profecient-essential' ),
					'icon'  => 'eicon-h-align-right',
				),
				'bottom' => array(
					'title' => esc_html__( 'To Bottom', 'profecient-essential' ),
					'icon'  => 'eicon-v-align-bottom',
				),
			),
			'default'            => 'left',
			'frontend_available' => true,
		);
	}

	/**
	 * Add Additional Style.
	 */
	public function additional_style() {
		$this->options['st_wrapper_margin'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Margin', 'profecient-essential' ),
			'segment'   => 'style_wrapper',
			'units'     => array( 'px', 'em' ),
			'selectors' => '.profecient-text-marquee .text-marquee-wrapper',
			'attribute' => 'margin',
		);

		$this->options['st_wrapper_padding'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Padding', 'profecient-essential' ),
			'segment'   => 'style_wrapper',
			'units'     => array( 'px', 'em' ),
			'selectors' => '.profecient-text-marquee .text-marquee-wrapper',
			'attribute' => 'padding',
		);

		$this->options['st_wrapper_background'] = array(
			'type'      => 'background',
			'title'     => esc_html__( 'Background', 'profecient-essential' ),
			'segment'   => 'style_wrapper',
			'selectors' => '.profecient-text-marquee .text-marquee-wrapper',
			'options'   => array(
				'classic',
				'gradient',
			),
		);

		$this->options['st_wrapper_border'] = array(
			'type'      => 'border',
			'title'     => esc_html__( 'Border', 'profecient-essential' ),
			'segment'   => 'style_wrapper',
			'selectors' => '.profecient-text-marquee .text-marquee-wrapper',
		);

		$this->options['st_wrapper_border_radius'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Border Radius', 'profecient-essential' ),
			'segment'   => 'style_wrapper',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.profecient-text-marquee .text-marquee-wrapper',
			'attribute' => 'border-radius',
		);

		$this->options['st_wrapper_boxshadow'] = array(
			'type'      => 'boxshadow',
			'title'     => esc_html__( 'Box Shadow', 'profecient-essential' ),
			'segment'   => 'style_wrapper',
			'selectors' => '.profecient-text-marquee .text-marquee-wrapper',
		);

		$this->options['st_text_padding'] = array(
			'type'       => 'dimension',
			'title'      => esc_html__( 'Padding', 'profecient-essential' ),
			'segment'    => 'style_text',
			'units'      => array( 'px', '%', 'em' ),
			'responsive' => true,
			'selectors'  => '.profecient-text-marquee .text-marquee-wrapper .text',
			'attribute'  => 'padding',
		);

		$this->options['st_text_height'] = array(
			'type'       => 'slider',
			'title'      => esc_html__( 'Height', 'profecient-essential' ),
			'segment'    => 'style_text',
			'units'      => array( 'px', 'em', 'custom' ),
			'options'    => array(
				'min'  => 0,
				'max'  => 300,
				'step' => 1,
			),
			'responsive' => true,
			'selectors'  => '.profecient-text-marquee .text-marquee-wrapper .text-wrapper',
			'attribute'  => 'height',
		);

		$this->options['st_text_gap'] = array(
			'type'       => 'slider',
			'title'      => esc_html__( 'Gap', 'profecient-essential' ),
			'segment'    => 'style_text',
			'units'      => array( 'px', 'em', 'custom' ),
			'options'    => array(
				'min'  => 0,
				'max'  => 300,
				'step' => 1,
			),
			'responsive' => true,
			'selectors'  => '.profecient-text-marquee .text-marquee-wrapper .text-wrapper',
			'attribute'  => 'gap',
		);

		$this->options['st_text_typography'] = array(
			'type'      => 'typography',
			'title'     => esc_html__( 'Typography', 'profecient-essential' ),
			'segment'   => 'style_text',
			'selectors' => '.profecient-text-marquee .text-marquee-wrapper .text',
		);

		$this->options['st_text_color'] = array(
			'type'       => 'color',
			'title'      => esc_html__( 'Text Color', 'profecient-essential' ),
			'segment'    => 'style_text',
			'responsive' => true,
			'selectors'  => '.profecient-text-marquee .text-marquee-wrapper .text',
		);

		$this->options['st_text_background'] = array(
			'type'      => 'background',
			'title'     => esc_html__( 'Text Background', 'profecient-essential' ),
			'segment'   => 'style_text',
			'selectors' => '.profecient-text-marquee .text-marquee-wrapper .text',
			'options'   => array(
				'classic',
				'gradient',
			),
		);

		$this->options['st_text_border'] = array(
			'type'      => 'border',
			'title'     => esc_html__( 'Border', 'profecient-essential' ),
			'segment'   => 'style_text',
			'selectors' => '.profecient-text-marquee .text-marquee-wrapper .text',
		);

		$this->options['st_text_border_radius'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Border Radius', 'profecient-essential' ),
			'segment'   => 'style_text',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.profecient-text-marquee .text-marquee-wrapper .text',
			'attribute' => 'border-radius',
		);

		$this->options['st_text_boxshadow'] = array(
			'type'      => 'boxshadow',
			'title'     => esc_html__( 'Open Box Shadow', 'profecient-essential' ),
			'segment'   => 'style_text',
			'selectors' => '.profecient-text-marquee .text-marquee-wrapper .text',
		);

		$this->options['st_icon_margin'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Margin', 'profecient-essential' ),
			'segment'   => 'style_icon',
			'units'     => array( 'px', 'em' ),
			'selectors' => '.profecient-text-marquee .text-marquee-wrapper .text > i, {{WRAPPER}} .profecient-text-marquee .text-marquee-wrapper .text > svg',
			'attribute' => 'margin',
		);

		$this->options['st_icon_padding'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Padding', 'profecient-essential' ),
			'segment'   => 'style_icon',
			'units'     => array( 'px', 'em' ),
			'selectors' => '.profecient-text-marquee .text-marquee-wrapper .text > i, {{WRAPPER}} .profecient-text-marquee .text-marquee-wrapper .text > svg',
			'attribute' => 'padding',
		);

		$this->options['st_icon_size'] = array(
			'type'       => 'slider',
			'title'      => esc_html__( 'Size', 'profecient-essential' ),
			'segment'    => 'style_icon',
			'units'      => array( 'px', 'em', 'custom' ),
			'options'    => array(
				'min'  => 0,
				'max'  => 300,
				'step' => 1,
			),
			'responsive' => true,
			'selectors'  => array(
				'custom' => array(
					'{{WRAPPER}} .profecient-text-marquee .text-marquee-wrapper .text > i'     => 'font-size: {{SIZE}}{{UNIT}};',
					'{{WRAPPER}} .profecient-text-marquee .text-marquee-wrapper .text > svg' => 'width: {{SIZE}}{{UNIT}};',
				),
			),
		);

		$this->options['st_icon_color'] = array(
			'type'       => 'color',
			'title'      => esc_html__( 'Color', 'profecient-essential' ),
			'segment'    => 'style_icon',
			'responsive' => true,
			'selectors'  => array(
				'custom' => array(
					'{{WRAPPER}} .profecient-text-marquee .text-marquee-wrapper .text > i'     => 'color: {{VALUE}};',
					'{{WRAPPER}} .profecient-text-marquee .text-marquee-wrapper .text > svg' => 'fill: {{VALUE}};',
				),
			),
		);

		$this->options['st_icon_background'] = array(
			'type'      => 'background',
			'title'     => esc_html__( 'Background', 'profecient-essential' ),
			'segment'   => 'style_icon',
			'options'   => array(
				'classic',
				'gradient',
			),
			'selectors' => '.profecient-text-marquee .text-marquee-wrapper .text > i, {{WRAPPER}} .profecient-text-marquee .text-marquee-wrapper .text > svg',
		);

		$this->options['st_icon_border'] = array(
			'type'      => 'border',
			'title'     => esc_html__( 'Border', 'profecient-essential' ),
			'segment'   => 'style_icon',
			'selectors' => '.profecient-text-marquee .text-marquee-wrapper .text > i, {{WRAPPER}} .profecient-text-marquee .text-marquee-wrapper .text > svg',
		);

		$this->options['st_icon_border_radius'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Border Radius', 'profecient-essential' ),
			'segment'   => 'style_icon',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.profecient-text-marquee .text-marquee-wrapper .text > i, {{WRAPPER}} .profecient-text-marquee .text-marquee-wrapper .text > svg',
			'attribute' => 'border-radius',
		);

		$this->options['st_icon_boxshadow'] = array(
			'type'      => 'boxshadow',
			'title'     => esc_html__( 'Box Shadow', 'profecient-essential' ),
			'segment'   => 'style_icon',
			'selectors' => '.profecient-text-marquee .text-marquee-wrapper .text > i, {{WRAPPER}} .profecient-text-marquee .text-marquee-wrapper .text > svg',
		);

		parent::additional_style();
	}
}
