<?php
/**
 * Timeline Widget Option Class
 *
 * @package profecient-essential
 * @author jegtheme
 * @since 1.0.0
 */

namespace Profecient\Essential\JKit\Elements\Options;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

use Jeg\Elementor_Kit\Elements\Options\Option_Abstract;

/**
 * Class Timeline_Option
 */
class Timeline_Option extends Option_Abstract {
	/**
	 * Show color scheme flag for element.
	 *
	 * @return bool
	 */
	public function show_color_scheme() {
		return false;
	}

	/**
	 * Compatibility column
	 *
	 * @return array
	 */
	public function compatible_column() {
		return array();
	}

	/**
	 * Override function to remove compatible column alert
	 */
	public function set_compatible_column_option() {}

	/**
	 * Element name
	 *
	 * @return string
	 */
	public function get_element_name() {
		return esc_html__( 'Timeline', 'profecient-essential' );
	}

	/**
	 * Element category
	 *
	 * @return string
	 */
	public function get_category() {
		return esc_html__( 'Profecient', 'profecient-essential' );
	}

	/**
	 * Element options
	 */
	public function set_options() {
		$this->set_style_option();
		$this->set_element_options();

		parent::set_options();
	}

	/**
	 * Option segments
	 */
	public function set_segments() {
		$this->segments['segment_setting'] = array(
			'name'     => esc_html__( 'Settings', 'profecient-essential' ),
			'priority' => 10,
		);

		$this->segments['segment_items'] = array(
			'name'     => esc_html__( 'Items', 'profecient-essential' ),
			'priority' => 10,
		);

		$this->set_style_segment();
	}

	/**
	 * Set element option
	 */
	public function set_element_options() {
		$this->options['sg_layout_start'] = array(
			'type'    => 'select',
			'title'   => esc_html__( 'Layout Start', 'profecient-essential' ),
			'options' => array(
				'left'         => esc_html__( 'Left', 'profecient-essential' ),
				'right'        => esc_html__( 'Right', 'profecient-essential' ),
				'contentleft'  => esc_html__( 'Left Content', 'profecient-essential' ),
				'contentright' => esc_html__( 'Right Content', 'profecient-essential' ),
			),
			'default' => 'left',
			'segment' => 'segment_setting',
		);

		$this->options['sg_icon_position'] = array(
			'type'    => 'select',
			'title'   => esc_html__( 'Icon Position Type', 'profecient-essential' ),
			'options' => array(
				'type1' => esc_html__( 'Type 1', 'profecient-essential' ),
				'type2' => esc_html__( 'Type 2', 'profecient-essential' ),
				'type3' => esc_html__( 'Type 3', 'profecient-essential' ),
				'type4' => esc_html__( 'Type 4', 'profecient-essential' ),
				'type5' => esc_html__( 'Type 5', 'profecient-essential' ),
			),
			'default' => 'type1',
			'segment' => 'segment_setting',
		);

		$this->options['sg_vertical_spacing'] = array(
			'type'      => 'slider',
			'title'     => esc_html__( 'Gap Space', 'profecient-essential' ),
			'segment'   => 'segment_setting',
			'options'   => array(
				'min'  => 0,
				'max'  => 500,
				'step' => 1,
			),
			'default'   => 35,
			'selectors' => '.profecient-timeline .timeline-item',
			'attribute' => 'margin-bottom',
		);

		// option
		$this->options['sg_items'] = array(
			'type'        => 'repeater',
			'title'       => esc_html__( 'Timeline List', 'profecient-essential' ),
			'segment'     => 'segment_items',
			'title_field' => '<i class="{{ sg_items_icon.value }}" aria-hidden="true"></i> {{ sg_items_title }}',
			'fields'      => array(
				'sg_items_tabs_start'           => array(
					'type'    => 'control_tabs_start',
					'segment' => 'sg_items',
				),
				// content option
				'sg_items_content_tab_start'    => array(
					'type'    => 'control_tab_start',
					'title'   => esc_html__( 'Content', 'profecient-essential' ),
					'segment' => 'sg_items',
				),
				'sg_items_icon'                 => array(
					'type'    => 'iconpicker',
					'title'   => esc_html__( 'Icon', 'profecient-essential' ),
					'segment' => 'sg_items',
				),
				'sg_items_title'                => array(
					'type'    => 'text',
					'segment' => 'sg_items',
					'title'   => esc_html__( 'Title', 'profecient-essential' ),
				),
				'sg_items_subtitle'             => array(
					'type'    => 'text',
					'segment' => 'sg_items',
					'title'   => esc_html__( 'Subtitle', 'profecient-essential' ),
				),
				'sg_items_content'              => array(
					'type'    => 'textarea',
					'title'   => esc_html__( 'Content', 'profecient-essential' ),
					'segment' => 'sg_items',
				),
				'sg_items_date'                 => array(
					'type'    => 'text',
					'segment' => 'sg_items',
					'title'   => esc_html__( 'Date', 'profecient-essential' ),
				),
				'sg_items_place'                => array(
					'type'    => 'text',
					'segment' => 'sg_items',
					'title'   => esc_html__( 'Place', 'profecient-essential' ),
				),
				'sg_items_content_tab_end'      => array(
					'type'    => 'control_tab_end',
					'segment' => 'sg_items',
				),
				// style option
				'sg_items_style_tab_start'      => array(
					'type'    => 'control_tab_start',
					'title'   => esc_html__( 'Style', 'profecient-essential' ),
					'segment' => 'sg_items',
				),
				'sg_items_style'                => array(
					'type'    => 'checkbox',
					'title'   => esc_html__( 'Custom Style', 'profecient-essential' ),
					'segment' => 'sg_items',
					'default' => false,
				),
				'sg_items_normal_heading'       => array(
					'type'       => 'heading',
					'title'      => esc_html__( 'Normal', 'profecient-essential' ),
					'segment'    => 'sg_items',
					'separator'  => 'before',
					'dependency' => array(
						array(
							'field'    => 'sg_items_style',
							'operator' => '==',
							'value'    => true,
						),
					),
				),
				'sg_items_title_color'          => array(
					'type'       => 'color',
					'title'      => esc_html__( 'Title Color', 'profecient-essential' ),
					'segment'    => 'sg_items',
					'selectors'  => '.profecient-timeline .timeline-item{{CURRENT_ITEM}} .timeline-title',
					'dependency' => array(
						array(
							'field'    => 'sg_items_style',
							'operator' => '==',
							'value'    => true,
						),
					),
				),
				'sg_items_subtitle_color'       => array(
					'type'       => 'color',
					'title'      => esc_html__( 'Subtitle Color', 'profecient-essential' ),
					'segment'    => 'sg_items',
					'selectors'  => '.profecient-timeline .timeline-item{{CURRENT_ITEM}} .timeline-subtitle',
					'dependency' => array(
						array(
							'field'    => 'sg_items_style',
							'operator' => '==',
							'value'    => true,
						),
					),
				),
				'sg_items_desc_color'           => array(
					'type'       => 'color',
					'title'      => esc_html__( 'Description Color', 'profecient-essential' ),
					'segment'    => 'sg_items',
					'selectors'  => '.profecient-timeline .timeline-item{{CURRENT_ITEM}} .timeline-desc',
					'dependency' => array(
						array(
							'field'    => 'sg_items_style',
							'operator' => '==',
							'value'    => true,
						),
					),
				),
				'sg_items_icon_color'           => array(
					'type'       => 'color',
					'title'      => esc_html__( 'Icon Color', 'profecient-essential' ),
					'segment'    => 'sg_items',
					'selectors'  => '.profecient-timeline .timeline-item{{CURRENT_ITEM}} .timeline-badge',
					'dependency' => array(
						array(
							'field'    => 'sg_items_style',
							'operator' => '==',
							'value'    => true,
						),
					),
				),
				'sg_items_icon_bg'              => array(
					'type'       => 'color',
					'title'      => esc_html__( 'Icon Background Color', 'profecient-essential' ),
					'segment'    => 'sg_items',
					'selectors'  => '.profecient-timeline .timeline-item{{CURRENT_ITEM}} .timeline-badge',
					'attribute'  => 'background-color',
					'dependency' => array(
						array(
							'field'    => 'sg_items_style',
							'operator' => '==',
							'value'    => true,
						),
					),
				),
				'sg_items_content_bg'           => array(
					'type'       => 'color',
					'title'      => esc_html__( 'Content Background Color', 'profecient-essential' ),
					'segment'    => 'sg_items',
					'selectors'  => '.profecient-timeline .timeline-item{{CURRENT_ITEM}} .timeline-content',
					'attribute'  => 'background-color',
					'dependency' => array(
						array(
							'field'    => 'sg_items_style',
							'operator' => '==',
							'value'    => true,
						),
					),
				),
				'st_items_content_padding'      => array(
					'type'       => 'dimension',
					'title'      => esc_html__( 'Padding', 'profecient-essential' ),
					'segment'    => 'sg_items',
					'units'      => array( 'px', '%', 'em' ),
					'selectors'  => '.profecient-timeline .timeline-item{{CURRENT_ITEM}} .timeline-content',
					'attribute'  => 'padding',
					'dependency' => array(
						array(
							'field'    => 'sg_items_style',
							'operator' => '==',
							'value'    => true,
						),
					),
				),
				'sg_items_hover_heading'        => array(
					'type'       => 'heading',
					'title'      => esc_html__( 'Hover', 'profecient-essential' ),
					'segment'    => 'sg_items',
					'separator'  => 'before',
					'dependency' => array(
						array(
							'field'    => 'sg_items_style',
							'operator' => '==',
							'value'    => true,
						),
					),
				),
				'sg_items_title_hover_color'    => array(
					'type'       => 'color',
					'title'      => esc_html__( 'Title Color', 'profecient-essential' ),
					'segment'    => 'sg_items',
					'selectors'  => '.profecient-timeline .timeline-item:hover{{CURRENT_ITEM}} .timeline-title',
					'dependency' => array(
						array(
							'field'    => 'sg_items_style',
							'operator' => '==',
							'value'    => true,
						),
					),
				),
				'sg_items_subtitle_hover_color' => array(
					'type'       => 'color',
					'title'      => esc_html__( 'Subtitle Color', 'profecient-essential' ),
					'segment'    => 'sg_items',
					'selectors'  => '.profecient-timeline .timeline-item:hover{{CURRENT_ITEM}} .timeline-subtitle',
					'dependency' => array(
						array(
							'field'    => 'sg_items_style',
							'operator' => '==',
							'value'    => true,
						),
					),
				),
				'sg_items_desc_hover_color'     => array(
					'type'       => 'color',
					'title'      => esc_html__( 'Description Color', 'profecient-essential' ),
					'segment'    => 'sg_items',
					'selectors'  => '.profecient-timeline .timeline-item:hover{{CURRENT_ITEM}} .timeline-desc',
					'dependency' => array(
						array(
							'field'    => 'sg_items_style',
							'operator' => '==',
							'value'    => true,
						),
					),
				),
				'sg_items_icon_hover_color'     => array(
					'type'       => 'color',
					'title'      => esc_html__( 'Icon Color', 'profecient-essential' ),
					'segment'    => 'sg_items',
					'selectors'  => '.profecient-timeline .timeline-item:hover{{CURRENT_ITEM}} .timeline-badge',
					'dependency' => array(
						array(
							'field'    => 'sg_items_style',
							'operator' => '==',
							'value'    => true,
						),
					),
				),
				'sg_items_icon_hover_bg'        => array(
					'type'       => 'color',
					'title'      => esc_html__( 'Icon Background Color', 'profecient-essential' ),
					'segment'    => 'sg_items',
					'selectors'  => '.profecient-timeline .timeline-item:hover{{CURRENT_ITEM}} .timeline-badge',
					'attribute'  => 'background-color',
					'dependency' => array(
						array(
							'field'    => 'sg_items_style',
							'operator' => '==',
							'value'    => true,
						),
					),
				),
				'sg_items_content_hover_bg'     => array(
					'type'       => 'color',
					'title'      => esc_html__( 'Content Background Color', 'profecient-essential' ),
					'segment'    => 'sg_items',
					'selectors'  => '.profecient-timeline .timeline-item:hover{{CURRENT_ITEM}} .timeline-content, {{WRAPPER}} .profecient-timeline .timeline-item:hover{{CURRENT_ITEM}} .timeline-content:after',
					'attribute'  => 'background-color',
					'dependency' => array(
						array(
							'field'    => 'sg_items_style',
							'operator' => '==',
							'value'    => true,
						),
					),
				),
				'sg_items_style_tab_end'        => array(
					'type'    => 'control_tab_end',
					'segment' => 'sg_items',
				),
				'sg_items_tabs_end'             => array(
					'type'    => 'control_tabs_end',
					'segment' => 'sg_items',
				),
			),
			'default'     => array(
				array(
					'sg_items_icon'     => array(
						'value'   => 'fas fa-anchor',
						'library' => 'fa-solid',
					),
					'sg_items_date'     => 'January 3, 2023',
					'sg_items_place'    => esc_html__( 'New York', 'profecient-essential' ),
					'sg_items_title'    => esc_html__( 'Timeline 1', 'profecient-essential' ),
					'sg_items_subtitle' => esc_html__( 'Start Here', 'profecient-essential' ),
					'sg_items_content'  => esc_html__( 'Define website goals and objectives. Meet with stakeholders to identify the purpose and goals of the website.', 'profecient-essential' ),
				),
				array(
					'sg_items_icon'     => array(
						'value'   => 'fas fa-anchor',
						'library' => 'fa-solid',
					),
					'sg_items_date'     => 'January 7, 2023',
					'sg_items_place'    => esc_html__( 'New York', 'profecient-essential' ),
					'sg_items_title'    => esc_html__( 'Timeline 2', 'profecient-essential' ),
					'sg_items_subtitle' => esc_html__( 'Be Productive', 'profecient-essential' ),
					'sg_items_content'  => esc_html__( 'Conduct market research and competitive analysis. Research industry trends, customer needs, and competitors.', 'profecient-essential' ),
				),
				array(
					'sg_items_icon'     => array(
						'value'   => 'fas fa-anchor',
						'library' => 'fa-solid',
					),
					'sg_items_date'     => 'January 9, 2023',
					'sg_items_place'    => esc_html__( 'New York', 'profecient-essential' ),
					'sg_items_title'    => esc_html__( 'Timeline 3', 'profecient-essential' ),
					'sg_items_subtitle' => esc_html__( 'Be Professional', 'profecient-essential' ),
					'sg_items_content'  => esc_html__( 'Create wireframes and site architecture. Develop a site map to determine site structure and content hierarchy.', 'profecient-essential' ),
				),
			),
		);

		parent::additional_style();
	}

	/**
	 * Style segments
	 */
	public function set_style_segment() {
		$this->segments['style_content'] = array(
			'name'      => esc_html__( 'Content', 'profecient-essential' ),
			'priority'  => 11,
			'kit_style' => true,
		);

		$this->segments['style_badge'] = array(
			'name'      => esc_html__( 'Icon', 'profecient-essential' ),
			'priority'  => 11,
			'kit_style' => true,
		);

		$this->segments['style_watermark'] = array(
			'name'      => esc_html__( 'Watermark', 'profecient-essential' ),
			'priority'  => 11,
			'kit_style' => true,
		);

		$this->segments['style_timeline'] = array(
			'name'      => esc_html__( 'Timeline', 'profecient-essential' ),
			'priority'  => 11,
			'kit_style' => true,
		);

		parent::set_style_segment();
	}

	/**
	 * Add Additional Style.
	 */
	public function additional_style() {
		// Content Tab
		$this->options['st_content_border_radius'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Border Radius', 'profecient-essential' ),
			'segment'   => 'style_content',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.profecient-timeline .timeline-content',
			'attribute' => 'border-radius',
		);

		$this->options['st_content_tabs_start'] = array(
			'type'    => 'control_tabs_start',
			'segment' => 'style_content',
		);

		// normal option
		$this->options['st_content_normal_tab_start'] = array(
			'type'    => 'control_tab_start',
			'title'   => esc_html__( 'Normal', 'profecient-essential' ),
			'segment' => 'style_content',
		);

		$this->options['st_title_color_normal'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Title Color', 'profecient-essential' ),
			'segment'   => 'style_content',
			'selectors' => '.profecient-timeline .timeline-title',
		);

		$this->options['st_title_typography_normal'] = array(
			'type'      => 'typography',
			'title'     => esc_html__( 'Title Typography', 'profecient-essential' ),
			'segment'   => 'style_content',
			'selectors' => '.profecient-timeline .timeline-title',
		);

		$this->options['st_subtitle_color_normal'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Subtitle Color', 'profecient-essential' ),
			'segment'   => 'style_content',
			'selectors' => '.profecient-timeline .timeline-subtitle',
		);

		$this->options['st_subtitle_typography_normal'] = array(
			'type'      => 'typography',
			'title'     => esc_html__( 'Subtitle Typography', 'profecient-essential' ),
			'segment'   => 'style_content',
			'selectors' => '.profecient-timeline .timeline-subtitle',
		);

		$this->options['st_desc_color_normal'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Description Color', 'profecient-essential' ),
			'segment'   => 'style_content',
			'selectors' => '.profecient-timeline .timeline-desc',
		);

		$this->options['st_desc_typography_normal'] = array(
			'type'      => 'typography',
			'title'     => esc_html__( 'Description Typography', 'profecient-essential' ),
			'segment'   => 'style_content',
			'selectors' => '.profecient-timeline .timeline-desc',
		);

		$this->options['st_date_color_normal'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Date Color', 'profecient-essential' ),
			'segment'   => 'style_content',
			'selectors' => '.profecient-timeline .timeline-date',
		);

		$this->options['st_date_typography_normal'] = array(
			'type'      => 'typography',
			'title'     => esc_html__( 'Date Typography', 'profecient-essential' ),
			'segment'   => 'style_content',
			'selectors' => '.profecient-timeline .timeline-date',
		);

		$this->options['st_place_color_normal'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Place Color', 'profecient-essential' ),
			'segment'   => 'style_content',
			'selectors' => '.profecient-timeline .timeline-place',
		);

		$this->options['st_place_typography_normal'] = array(
			'type'      => 'typography',
			'title'     => esc_html__( 'Place Typography', 'profecient-essential' ),
			'segment'   => 'style_content',
			'selectors' => '.profecient-timeline .timeline-place',
		);

		$this->options['st_content_bg_normal'] = array(
			'type'      => 'background',
			'title'     => esc_html__( 'Background Color', 'profecient-essential' ),
			'segment'   => 'style_content',
			'selectors' => '.profecient-timeline .timeline-content, {{WRAPPER}} .profecient-timeline .timeline-content:after',
			'options'   => array(
				'classic',
				'gradient',
			),
		);

		$this->options['st_content_enable_boxshadow'] = array(
			'type'    => 'checkbox',
			'title'   => esc_html__( 'Enable Box Shadow', 'profecient-essential' ),
			'segment' => 'style_content',
			'default' => false,
		);

		$this->options['st_content_boxshadow'] = array(
			'type'       => 'boxshadow',
			'title'      => esc_html__( 'Box Shadow', 'profecient-essential' ),
			'segment'    => 'style_content',
			'selectors'  => '.profecient-timeline .timeline-content',
			'dependency' => array(
				array(
					'field'    => 'st_content_enable_boxshadow',
					'operator' => '==',
					'value'    => true,
				),
			),
		);

		$this->options['st_content_normal_tab_end'] = array(
			'type'    => 'control_tab_end',
			'segment' => 'style_content',
		);

		// hover option
		$this->options['st_content_hover_tab_start'] = array(
			'type'    => 'control_tab_start',
			'title'   => esc_html__( 'Hover', 'profecient-essential' ),
			'segment' => 'style_content',
		);

		$this->options['st_title_color_hover'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Title Color', 'profecient-essential' ),
			'segment'   => 'style_content',
			'selectors' => '.profecient-timeline .timeline-item:hover .timeline-title',
		);

		$this->options['st_subtitle_color_hover'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Subtitle Color', 'profecient-essential' ),
			'segment'   => 'style_content',
			'selectors' => '.profecient-timeline .timeline-item:hover .timeline-subtitle',
		);

		$this->options['st_desc_color_hover'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Description Color', 'profecient-essential' ),
			'segment'   => 'style_content',
			'selectors' => '.profecient-timeline .timeline-item:hover .timeline-desc',
		);

		$this->options['st_content_bg_hover'] = array(
			'type'      => 'background',
			'title'     => esc_html__( 'Background Color', 'profecient-essential' ),
			'segment'   => 'style_content',
			'selectors' => '.profecient-timeline .timeline-item:hover .timeline-content, {{WRAPPER}} .profecient-timeline .timeline-item:hover .timeline-content:after',
			'options'   => array(
				'classic',
				'gradient',
			),
		);

		$this->options['st_content_enable_boxshadow_hover'] = array(
			'type'    => 'checkbox',
			'title'   => esc_html__( 'Enable Box Shadow', 'profecient-essential' ),
			'segment' => 'style_content',
			'default' => false,
		);

		$this->options['st_content_boxshadow_hover'] = array(
			'type'       => 'boxshadow',
			'title'      => esc_html__( 'Box Shadow', 'profecient-essential' ),
			'segment'    => 'style_content',
			'selectors'  => '.profecient-timeline .timeline-content:hover',
			'dependency' => array(
				array(
					'field'    => 'st_content_enable_boxshadow_hover',
					'operator' => '==',
					'value'    => true,
				),
			),
		);

		$this->options['st_content_hover_tab_end'] = array(
			'type'    => 'control_tab_end',
			'segment' => 'style_content',
		);

		$this->options['st_content_tabs_end'] = array(
			'type'    => 'control_tabs_end',
			'segment' => 'style_content',
		);

		// Icon tab
		$this->options['st_icon_size'] = array(
			'type'      => 'slider',
			'title'     => esc_html__( 'Icon Size', 'profecient-essential' ),
			'segment'   => 'style_badge',
			'options'   => array(
				'min'  => 0,
				'max'  => 50,
				'step' => 1,
			),
			'selectors' => '.profecient-timeline .timeline-badge',
			'attribute' => 'font-size',
		);

		$this->options['st_icon_margin'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Margin', 'jeg-elementor-kit' ),
			'segment'   => 'style_badge',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.profecient-timeline .timeline-badge',
			'attribute' => 'margin',
		);

		$this->options['st_icon_padding'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Padding', 'jeg-elementor-kit' ),
			'segment'   => 'style_badge',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.profecient-timeline .timeline-badge',
			'attribute' => 'padding',
		);

		$this->options['st_icon_border'] = array(
			'type'      => 'border',
			'title'     => esc_html__( 'Border Type', 'profecient-essential' ),
			'segment'   => 'style_badge',
			'selectors' => '.profecient-timeline .timeline-badge',
		);

		$this->options['st_icon_border_radius'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Border Radius', 'profecient-essential' ),
			'segment'   => 'style_badge',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.profecient-timeline .timeline-badge',
			'attribute' => 'border-radius',
		);

		$this->options['st_icon_tabs_start'] = array(
			'type'    => 'control_tabs_start',
			'segment' => 'style_badge',
		);

		// normal option
		$this->options['st_icon_normal_tab_start'] = array(
			'type'    => 'control_tab_start',
			'title'   => esc_html__( 'Normal', 'profecient-essential' ),
			'segment' => 'style_badge',
		);

		$this->options['st_icon_color_normal'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Icon Color', 'profecient-essential' ),
			'segment'   => 'style_badge',
			'selectors' => '.profecient-timeline .timeline-badge',
		);

		$this->options['st_icon_bg_normal'] = array(
			'type'      => 'background',
			'title'     => esc_html__( 'Background Color', 'profecient-essential' ),
			'segment'   => 'style_badge',
			'selectors' => '.profecient-timeline .timeline-badge',
			'options'   => array(
				'classic',
				'gradient',
			),
		);

		$this->options['st_icon_bs_normal'] = array(
			'type'      => 'boxshadow',
			'title'     => esc_html__( 'Box Shadow', 'profecient-essential' ),
			'segment'   => 'style_badge',
			'selectors' => '.profecient-timeline .timeline-badge',
		);

		$this->options['st_icon_normal_tab_end'] = array(
			'type'    => 'control_tab_end',
			'segment' => 'style_badge',
		);

		// hover option
		$this->options['st_icon_hover_tab_start'] = array(
			'type'    => 'control_tab_start',
			'title'   => esc_html__( 'Hover', 'profecient-essential' ),
			'segment' => 'style_badge',
		);

		$this->options['st_icon_color_hover'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Icon Color', 'profecient-essential' ),
			'segment'   => 'style_badge',
			'selectors' => '.profecient-timeline .timeline-item:hover .timeline-badge',
		);

		$this->options['st_icon_bg_hover'] = array(
			'type'      => 'background',
			'title'     => esc_html__( 'Background Color', 'profecient-essential' ),
			'segment'   => 'style_badge',
			'selectors' => '.profecient-timeline .timeline-item:hover .timeline-badge',
			'options'   => array(
				'classic',
				'gradient',
			),
		);

		$this->options['st_icon_bs_hover'] = array(
			'type'      => 'boxshadow',
			'title'     => esc_html__( 'Box Shadow', 'profecient-essential' ),
			'segment'   => 'style_badge',
			'selectors' => '.profecient-timeline .timeline-item:hover .timeline-badge',
		);

		$this->options['st_icon_hover_tab_end'] = array(
			'type'    => 'control_tab_end',
			'segment' => 'style_badge',
		);

		$this->options['st_icon_tabs_end'] = array(
			'type'    => 'control_tabs_end',
			'segment' => 'style_badge',
		);

		// Watermark tab
		$this->options['st_watermark'] = array(
			'type'    => 'checkbox',
			'title'   => esc_html__( 'Icon Watermark', 'profecient-essential' ),
			'default' => false,
			'segment' => 'style_watermark',
		);

		$this->options['st_watermark_size'] = array(
			'type'       => 'slider',
			'title'      => esc_html__( 'Watermark Size', 'profecient-essential' ),
			'segment'    => 'style_watermark',
			'options'    => array(
				'min'  => 0,
				'max'  => 500,
				'step' => 1,
			),
			'default'    => 60,
			'selectors'  => '.profecient-timeline .timeline-watermark',
			'attribute'  => 'font-size',
			'dependency' => array(
				array(
					'field'    => 'st_watermark',
					'operator' => '==',
					'value'    => true,
				),
			),
		);

		$this->options['st_watermark_vertical_offset'] = array(
			'type'       => 'slider',
			'title'      => esc_html__( 'Vertical Offset', 'profecient-essential' ),
			'segment'    => 'style_watermark',
			'responsive' => true,
			'units'      => array( 'px', '%', 'em' ),
			'options'    => array(
				'min'  => -50,
				'max'  => 100,
				'step' => 1,
			),
			'default'    => 8,
			'selectors'  => array(
				'custom' => array(
					'{{WRAPPER}} .profecient-timeline .timeline-watermark' => 'bottom: {{SIZE}}{{UNIT}};',
				),
			),
			'dependency' => array(
				array(
					'field'    => 'st_watermark',
					'operator' => '==',
					'value'    => true,
				),
			),
		);

		$this->options['st_watermark_horizontal_offset'] = array(
			'type'       => 'slider',
			'title'      => esc_html__( 'Horizontal Offset', 'profecient-essential' ),
			'segment'    => 'style_watermark',
			'responsive' => true,
			'units'      => array( 'px', '%', 'em' ),
			'options'    => array(
				'min'  => -50,
				'max'  => 300,
				'step' => 1,
			),
			'default'    => 8,
			'selectors'  => array(
				'custom' => array(
					'{{WRAPPER}} .profecient-timeline .timeline-items .timeline-watermark' => 'left: {{SIZE}}{{UNIT}};',
					'{{WRAPPER}} .profecient-timeline .timeline-items.start-left .timeline-item:nth-child(even) .timeline-watermark' => 'right: {{SIZE}}{{UNIT}}; left: unset;',
					'{{WRAPPER}} .profecient-timeline .timeline-items.start-right .timeline-item:nth-child(odd) .timeline-watermark' => 'right: {{SIZE}}{{UNIT}}; left: unset;',
					'{{WRAPPER}} .profecient-timeline .timeline-items.start-contentright .timeline-watermark' => 'right: {{SIZE}}{{UNIT}}; left: unset;',
				),
			),
			'dependency' => array(
				array(
					'field'    => 'st_watermark',
					'operator' => '==',
					'value'    => true,
				),
			),
		);

		$this->options['st_watermark_tabs_start'] = array(
			'type'    => 'control_tabs_start',
			'segment' => 'style_watermark',
		);

		// normal option
		$this->options['st_watermark_normal_tab_start'] = array(
			'type'       => 'control_tab_start',
			'title'      => esc_html__( 'Normal', 'profecient-essential' ),
			'segment'    => 'style_watermark',
			'dependency' => array(
				array(
					'field'    => 'st_watermark',
					'operator' => '==',
					'value'    => true,
				),
			),
		);

		$this->options['st_watermark_color'] = array(
			'type'       => 'color',
			'title'      => esc_html__( 'Icon Color', 'profecient-essential' ),
			'segment'    => 'style_watermark',
			'selectors'  => '.profecient-timeline .timeline-watermark',
			'attribute'  => 'color',
			'dependency' => array(
				array(
					'field'    => 'st_watermark',
					'operator' => '==',
					'value'    => true,
				),
			),
		);

		$this->options['st_watermark_normal_tab_end'] = array(
			'type'    => 'control_tab_end',
			'segment' => 'style_watermark',
		);

		// hover option
		$this->options['st_watermark_hover_tab_start'] = array(
			'type'       => 'control_tab_start',
			'title'      => esc_html__( 'Hover', 'profecient-essential' ),
			'segment'    => 'style_watermark',
			'dependency' => array(
				array(
					'field'    => 'st_watermark',
					'operator' => '==',
					'value'    => true,
				),
			),
		);

		$this->options['st_watermark_color_hover'] = array(
			'type'       => 'color',
			'title'      => esc_html__( 'Icon Color', 'profecient-essential' ),
			'segment'    => 'style_watermark',
			'selectors'  => '.profecient-timeline .timeline-content:hover .timeline-watermark',
			'attribute'  => 'color',
			'dependency' => array(
				array(
					'field'    => 'st_watermark',
					'operator' => '==',
					'value'    => true,
				),
			),
		);

		$this->options['st_watermark_hover_tab_end'] = array(
			'type'    => 'control_tab_end',
			'segment' => 'style_watermark',
		);

		$this->options['st_watermark_tabs_end'] = array(
			'type'    => 'control_tabs_end',
			'segment' => 'style_watermark',
		);

		// Timeline tab
		$this->options['st_timeline_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Line Color', 'profecient-essential' ),
			'segment'   => 'style_timeline',
			'selectors' => '.profecient-timeline .timeline-progress span',
			'attribute' => 'background-color',
		);

		$this->options['st_timeline_bg_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Line Background Color', 'profecient-essential' ),
			'segment'   => 'style_timeline',
			'selectors' => '.profecient-timeline .timeline-progress',
			'attribute' => 'background-color',
		);

		$this->options['st_point_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Point Color', 'profecient-essential' ),
			'segment'   => 'style_timeline',
			'selectors' => '.profecient-timeline .timeline-icon',
			'attribute' => 'background-color',
		);

		$this->options['st_point_size'] = array(
			'type'      => 'slider',
			'title'     => esc_html__( 'Point Size', 'profecient-essential' ),
			'segment'   => 'style_timeline',
			'options'   => array(
				'min'  => 1,
				'max'  => 100,
				'step' => 1,
			),
			'default'   => 14,
			'selectors' => array(
				'custom' => array(
					'{{WRAPPER}} .profecient-timeline .timeline-icon' => 'height: {{SIZE}}px; line-height: {{SIZE}}px; width: {{SIZE}}px;',
				),
			),
		);

		$this->options['st_point_border_size'] = array(
			'type'           => 'border',
			'title'          => esc_html__( 'Border', 'profecient-essential' ),
			'segment'        => 'style_timeline',
			'selectors'      => '.profecient-timeline .timeline-icon',
			'fields_options' => array(
				'border' => array(
					'default' => 'solid',
				),
				'width'  => array(
					'default' => array(
						'top'      => '2',
						'right'    => '2',
						'bottom'   => '2',
						'left'     => '2',
						'isLinked' => true,
					),
				),
				'color'  => array(
					'default' => '#5AA794',
				),
			),
		);

		$this->options['st_point_border_radius'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Border Radius', 'profecient-essential' ),
			'segment'   => 'style_timeline',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.profecient-timeline .timeline-icon',
			'attribute' => 'border-radius',
		);

		$this->options['st_point_icon_enable'] = array(
			'type'    => 'checkbox',
			'title'   => esc_html__( 'Enable Icon', 'profecient-essential' ),
			'segment' => 'style_timeline',
			'default' => false,
		);

		$this->options['st_point_icon'] = array(
			'type'       => 'iconpicker',
			'title'      => esc_html__( 'Icon', 'profecient-essential' ),
			'segment'    => 'style_timeline',
			'dependency' => array(
				array(
					'field'    => 'st_point_icon_enable',
					'operator' => '==',
					'value'    => true,
				),
			),
		);

		$this->options['st_point_icon_color'] = array(
			'type'       => 'color',
			'title'      => esc_html__( 'Icon Color', 'profecient-essential' ),
			'segment'    => 'style_timeline',
			'selectors'  => '.profecient-timeline .timeline-icon',
			'attribute'  => 'color',
			'dependency' => array(
				array(
					'field'    => 'st_point_icon_enable',
					'operator' => '==',
					'value'    => true,
				),
			),
		);

		$this->options['st_point_icon_size'] = array(
			'type'       => 'slider',
			'title'      => esc_html__( 'Icon Size', 'profecient-essential' ),
			'segment'    => 'style_timeline',
			'options'    => array(
				'min'  => 0,
				'max'  => 50,
				'step' => 1,
			),
			'default'    => 18,
			'selectors'  => '.profecient-timeline .timeline-icon',
			'attribute'  => 'font-size',
			'dependency' => array(
				array(
					'field'    => 'st_point_icon_enable',
					'operator' => '==',
					'value'    => true,
				),
			),
		);

		$this->options['st_point_icon_bs'] = array(
			'type'       => 'boxshadow',
			'title'      => esc_html__( 'Box Shadow', 'profecient-essential' ),
			'segment'    => 'style_timeline',
			'selectors'  => '.profecient-timeline .timeline-icon',
			'dependency' => array(
				array(
					'field'    => 'st_point_icon_enable',
					'operator' => '==',
					'value'    => true,
				),
			),
		);
	}
}
