<?php
/**
 * Woocommerce Account Page Option Class
 *
 * @package profecient-essential
 * @author jegtheme
 * @since 1.0.0
 */

namespace Profecient\Essential\JKit\Elements\Options;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

use Jeg\Elementor_Kit\Elements\Options\Option_Abstract;

/**
 * Class Woocommerce_Account_Page_Option
 */
class Woocommerce_Account_Page_Option extends Option_Abstract {
	/**
	 * Show color scheme flag for element.
	 *
	 * @return bool
	 */
	public function show_color_scheme() {
		return false;
	}

	/**
	 * Compatibility column
	 *
	 * @return array
	 */
	public function compatible_column() {
		return array();
	}

	/**
	 * Override function to remove compatible column alert
	 */
	public function set_compatible_column_option() {}

	/**
	 * Element name
	 *
	 * @return string
	 */
	public function get_element_name() {
		return esc_html__( 'Account Page', 'profecient-essential' );
	}

	/**
	 * Element category
	 *
	 * @return string
	 */
	public function get_category() {
		return esc_html__( 'Profecient - Woocommerce', 'profecient-essential' );
	}

	/**
	 * Element options
	 */
	public function set_options() {
		$this->set_style_option();

		parent::set_options();
	}

	/**
	 * Option segments
	 */
	public function set_segments() {
		$this->set_style_segment();
	}

	/**
	 * Style segments
	 */
	public function set_style_segment() {
		$this->segments['layout'] = array(
			'name'      => esc_html__( 'Layout', 'profecient-essential' ),
			'priority'  => 11,
			'kit_style' => true,
		);

		$this->segments['woocommerce_message'] = array(
			'name'      => esc_html__( 'Woocommerce Message', 'profecient-essential' ),
			'priority'  => 11,
			'kit_style' => true,
		);

		$this->segments['browse_product_button'] = array(
			'name'      => esc_html__( 'Browse Button', 'profecient-essential' ),
			'priority'  => 11,
			'kit_style' => true,
		);

		$this->segments['navigation'] = array(
			'name'      => esc_html__( 'Navigation', 'profecient-essential' ),
			'priority'  => 11,
			'kit_style' => true,
		);

		$this->segments['content_wrapper'] = array(
			'name'      => esc_html__( 'Content Wrapper', 'profecient-essential' ),
			'priority'  => 11,
			'kit_style' => true,
		);

		$this->segments['addresses'] = array(
			'name'      => esc_html__( 'Adresses', 'profecient-essential' ),
			'priority'  => 11,
			'kit_style' => true,
		);

		$this->segments['orders_table'] = array(
			'name'      => esc_html__( 'Orders', 'profecient-essential' ),
			'priority'  => 11,
			'kit_style' => true,
		);

		$this->segments['orders_action_button'] = array(
			'name'      => esc_html__( 'Order Action Button', 'profecient-essential' ),
			'priority'  => 11,
			'kit_style' => true,
		);

		$this->segments['downloads_table'] = array(
			'name'      => esc_html__( 'Downloads', 'profecient-essential' ),
			'priority'  => 11,
			'kit_style' => true,
		);

		$this->segments['download_button'] = array(
			'name'      => esc_html__( 'Download Button', 'profecient-essential' ),
			'priority'  => 11,
			'kit_style' => true,
		);

		$this->segments['account_details'] = array(
			'name'      => esc_html__( 'Account Details', 'profecient-essential' ),
			'priority'  => 11,
			'kit_style' => true,
		);

		parent::set_style_segment();
	}

	public function style_option() {

		$global_button_background = parent::get_global_style_option( 'button_background_color' );
		$global_button_text_color = parent::get_global_style_option( 'button_text_color' );

		$this->options['layout_type'] = array(
			'type'    => 'select',
			'title'   => esc_html__( 'Layout Type', 'profecient-essential' ),
			'default' => 'layout-1',
			'segment' => 'layout',
			'options' => array(
				'layout-1' => 'Layout 1',
				'layout-2' => 'Layout 2',
			),
		);

		/* ----- NO Data ----- */
		$this->options['woocommerce_message_box_shadow'] = array(
			'type'       => 'boxshadow',
			'title'      => esc_html__( 'Wrapper Box Shadow', 'profecient-essential' ),
			'segment'    => 'woocommerce_message',
			'selectors'  => '.woocommerce-info',
			'dependency' => array(
				array(
					'field'    => 'layout_type',
					'operator' => '==',
					'value'    => 'layout-1',
				),
			),
		);

		$this->options['woocommerce_message_border'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Border', 'profecient-essential' ),
			'segment'   => 'woocommerce_message',
			'selectors' => array(
				'custom' => array(
					'{{WRAPPER}} .woocommerce-Message' => 'border-top-color: {{VALUE}};',
				),
			),
		);

		$this->options['woocommerce_message_background'] = array(
			'type'      => 'background',
			'title'     => esc_html__( 'Background Color', 'profecient-essential' ),
			'segment'   => 'woocommerce_message',
			'selectors' => '.woocommerce-info',
			'options'   => array(
				'classic',
				'gradient',
			),
			'exclude'   => array( 'image' ),
		);

		$this->options['woocommerce_message_padding'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Padding', 'profecient-essential' ),
			'segment'   => 'woocommerce_message',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.woocommerce-info',
			'attribute' => 'padding',
		);

		$this->options['woocommerce_message_margin'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Margin', 'profecient-essential' ),
			'segment'   => 'woocommerce_message',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.woocommerce-info',
			'attribute' => 'margin',
		);
		/* ----- No Data ----- */

		/* ----- Browse Product Button Segment ----- */
		$this->options['browse_product_button_typography'] = array(
			'type'      => 'typography',
			'title'     => esc_html__( 'Button Typograhpy', 'profecient-essential' ),
			'segment'   => 'browse_product_button',
			'selectors' => '.woocommerce-MyAccount-content .woocommerce-Button.button',
		);

		$this->options['browse_product_button_tabs_start'] = array(
			'type'    => 'control_tabs_start',
			'segment' => 'browse_product_button',
		);

		$this->options['browse_product_button_normal_tab_start'] = array(
			'type'    => 'control_tab_start',
			'title'   => esc_html__( 'Normal', 'profecient-essential' ),
			'segment' => 'browse_product_button',
		);

		$this->options['browse_product_button_normal_box_shadow'] = array(
			'type'      => 'boxshadow',
			'title'     => esc_html__( 'Box Shadow', 'profecient-essential' ),
			'segment'   => 'browse_product_button',
			'selectors' => '.woocommerce-MyAccount-content .woocommerce-Button.button',
		);

		$this->options['browse_product_button_normal_border'] = array(
			'type'      => 'border',
			'title'     => esc_html__( 'Border button', 'profecient-essential' ),
			'segment'   => 'browse_product_button',
			'selectors' => '.woocommerce-MyAccount-content .woocommerce-Button.button',
		);

		$this->options['browse_product_button_normal_border_radius'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Border Radius', 'profecient-essential' ),
			'segment'   => 'browse_product_button',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.woocommerce-MyAccount-content .woocommerce-Button.button',
			'attribute' => 'border-radius',
		);

		$this->options['browse_product_button_normal_margin'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Button Margin', 'profecient-essential' ),
			'segment'   => 'browse_product_button',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.woocommerce-MyAccount-content .woocommerce-Button.button',
			'attribute' => 'margin',
		);

		$this->options['browse_product_button_normal_padding'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Button Padding', 'profecient-essential' ),
			'segment'   => 'browse_product_button',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.woocommerce-MyAccount-content .woocommerce-Button.button',
			'attribute' => 'padding',
		);

		$this->options['browse_product_button_background'] = array(
			'type'           => 'background',
			'title'          => esc_html__( 'Button Background', 'profecient-essential' ),
			'segment'        => 'browse_product_button',
			'selectors'      => '.woocommerce-MyAccount-content .woocommerce-Button.button',
			'fields_options' => array(
				'background' => array(
					'default' => 'classic',
				),
				'color'      => array(
					'global' => array(
						'default' => $global_button_background,
					),
				),
			),
			'options'        => array(
				'classic',
				'gradient',
			),
			'exclude'        => array( 'image' ),
		);

		$this->options['browse_product_button_normal_text_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Text Color', 'profecient-essential' ),
			'segment'   => 'browse_product_button',
			'global'    => array(
				'default' => $global_button_text_color,
			),
			'selectors' => '.woocommerce-MyAccount-content .woocommerce-Button.button',
		);

		$this->options['browse_product_button_normal_tab_end'] = array(
			'type'    => 'control_tab_end',
			'segment' => 'browse_product_button',
		);

		$this->options['browse_product_button_hover_tab_start'] = array(
			'type'    => 'control_tab_start',
			'title'   => esc_html__( 'Hover', 'profecient-essential' ),
			'segment' => 'browse_product_button',
		);

		$this->options['browse_product_button_hover_box_shadow'] = array(
			'type'      => 'boxshadow',
			'title'     => esc_html__( 'Box Shadow', 'profecient-essential' ),
			'segment'   => 'browse_product_button',
			'selectors' => '.woocommerce-MyAccount-content .woocommerce-Button.button:hover',
		);

		$this->options['browse_product_button_hover_border'] = array(
			'type'      => 'border',
			'title'     => esc_html__( 'Border button', 'profecient-essential' ),
			'segment'   => 'browse_product_button',
			'selectors' => '.woocommerce-MyAccount-content .woocommerce-Button.button:hover',
		);

		$this->options['browse_product_button_normal_hover_radius'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Border Radius', 'profecient-essential' ),
			'segment'   => 'browse_product_button',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.woocommerce-MyAccount-content .woocommerce-Button.button:hover',
			'attribute' => 'border-radius',
		);

		$this->options['browse_product_button_hover_margin'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Button Margin', 'profecient-essential' ),
			'segment'   => 'browse_product_button',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.woocommerce-MyAccount-content .woocommerce-Button.button:hover',
			'attribute' => 'margin',
		);

		$this->options['browse_product_button_hover_padding'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Button Padding', 'profecient-essential' ),
			'segment'   => 'browse_product_button',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.woocommerce-MyAccount-content .woocommerce-Button.button:hover',
			'attribute' => 'padding',
		);

		$this->options['browse_product_button_hover_background'] = array(
			'type'           => 'background',
			'title'          => esc_html__( 'Button Background', 'profecient-essential' ),
			'segment'        => 'browse_product_button',
			'selectors'      => '.woocommerce-MyAccount-content .woocommerce-Button.button:hover',
			'fields_options' => array(
				'background' => array(
					'default' => 'classic',
				),
				'color'      => array(
					'global' => array(
						'default' => $global_button_background,
					),
				),
			),
			'options'        => array(
				'classic',
				'gradient',
			),
			'exclude'        => array( 'image' ),
		);

		$this->options['browse_product_button_hover_text_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Text Color', 'profecient-essential' ),
			'segment'   => 'browse_product_button',
			'global'    => array(
				'default' => $global_button_text_color,
			),
			'selectors' => '.woocommerce-MyAccount-content .woocommerce-Button.button:hover',
		);

		$this->options['browse_product_button_hover_tab_end'] = array(
			'type'    => 'control_tab_end',
			'segment' => 'browse_product_button',
		);

		$this->options['browse_product_button_tabs_end'] = array(
			'type'    => 'control_tabs_end',
			'segment' => 'browse_product_button',
		);
		/* ----- Browse Product Button Segment ----- */

		/* ----- Navigation ----- */
		$this->options['navigation_item_margin'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Margin', 'profecient-essential' ),
			'segment'   => 'navigation',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.woocommerce-MyAccount-navigation-link a',
			'attribute' => 'margin',
		);

		$this->options['navigation_item_padding'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Padding', 'profecient-essential' ),
			'segment'   => 'navigation',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.woocommerce-MyAccount-navigation-link a',
			'attribute' => 'padding',
		);

		$this->options['navigation_item_column_gap'] = array(
			'type'       => 'slider',
			'title'      => esc_html__( 'Column Gap', 'profecient-essential' ),
			'segment'    => 'navigation',
			'options'    => array(
				'min'  => 0,
				'max'  => 100,
				'step' => 1,
			),
			'units'      => array( 'px', '%', 'em' ),
			'responsive' => true,
			'selectors'  => array(
				'custom' => array(
					'{{WRAPPER}} .woocommerce-MyAccount-navigation ul' => 'column-gap: {{SIZE}}{{UNIT}};',
				),
			),
		);

		$this->options['navigation_item_row_gap'] = array(
			'type'       => 'slider',
			'title'      => esc_html__( 'Row Gap', 'profecient-essential' ),
			'segment'    => 'navigation',
			'options'    => array(
				'min'  => 0,
				'max'  => 100,
				'step' => 1,
			),
			'units'      => array( 'px', '%', 'em' ),
			'responsive' => true,
			'selectors'  => array(
				'custom' => array(
					'{{WRAPPER}} .woocommerce-MyAccount-navigation ul' => 'row-gap: {{SIZE}}{{UNIT}};',
				),
			),
		);

		$this->options['navigation_item_text_typography'] = array(
			'type'      => 'typography',
			'title'     => esc_html__( 'Text Typography', 'profecient-essential' ),
			'segment'   => 'navigation',
			'selectors' => '.woocommerce-MyAccount-navigation-link a',
		);

		$this->options['navigation_item_tabs_start'] = array(
			'type'    => 'control_tabs_start',
			'segment' => 'navigation',
		);

		$this->options['navgiation_item_normal_tab_start'] = array(
			'type'    => 'control_tab_start',
			'title'   => esc_html__( 'Normal', 'profecient-essential' ),
			'segment' => 'navigation',
		);

		$this->options['navigation_item_tabs_normal_box_shadow'] = array(
			'type'      => 'boxshadow',
			'title'     => esc_html__( 'Wrapper Box Shadow', 'profecient-essential' ),
			'segment'   => 'navigation',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.woocommerce-MyAccount-navigation-link a',
			'attribute' => 'border-radius',
		);

		$this->options['navigation_item_tabs_normal_border_radius'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Border Radius', 'profecient-essential' ),
			'segment'   => 'navigation',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.woocommerce-MyAccount-navigation-link a',
			'attribute' => 'border-radius',
		);

		$this->options['navigation_item_border'] = array(
			'type'      => 'border',
			'title'     => esc_html__( 'Border', 'profecient-essential' ),
			'segment'   => 'navigation',
			'selectors' => '.woocommerce-MyAccount-navigation-link a',
		);

		$this->options['navigation_item_background'] = array(
			'type'      => 'background',
			'title'     => esc_html__( 'Nav Item Background', 'profecient-essential' ),
			'segment'   => 'navigation',
			'selectors' => '.woocommerce-MyAccount-navigation-link a',
			'options'   => array(
				'classic',
				'gradient',
			),
			'exclude'   => array( 'image' ),
		);

		$this->options['navigation_item_normal_text_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Color', 'profecient-essential' ),
			'segment'   => 'navigation',
			'selectors' => '.woocommerce-MyAccount-navigation-link a',
		);

		$this->options['navigation_item_normal_tab_end'] = array(
			'type'    => 'control_tab_end',
			'segment' => 'navigation',
		);

		$this->options['navigation_item_active_tab_start'] = array(
			'type'    => 'control_tab_start',
			'title'   => esc_html__( 'Active', 'profecient-essential' ),
			'segment' => 'navigation',
		);

		$this->options['navigation_item_tabs_active_border_radius'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Border Radius', 'profecient-essential' ),
			'segment'   => 'navigation',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.woocommerce-MyAccount-navigation-link.is-active a',
			'attribute' => 'border-radius',
		);

		$this->options['navigation_item_border_active'] = array(
			'type'      => 'border',
			'title'     => esc_html__( 'Border', 'profecient-essential' ),
			'segment'   => 'navigation',
			'selectors' => '.woocommerce-MyAccount-navigation-link.is-active a',
		);

		$this->options['navigation_item_active_text_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Color', 'profecient-essential' ),
			'segment'   => 'navigation',
			'selectors' => '.woocommerce-MyAccount-navigation-link.is-active a',
		);

		$this->options['navigation_item_active_background'] = array(
			'type'      => 'background',
			'title'     => esc_html__( 'Nav Item Background', 'profecient-essential' ),
			'segment'   => 'navigation',
			'selectors' => '.woocommerce-MyAccount-navigation-link.is-active a',
			'options'   => array(
				'classic',
				'gradient',
			),
			'exclude'   => array( 'image' ),
		);

		$this->options['navigation_item_active_tab_end'] = array(
			'type'    => 'control_tab_end',
			'segment' => 'navigation',
		);

		$this->options['navigation_item_hover_tab_start'] = array(
			'type'    => 'control_tab_start',
			'title'   => esc_html__( 'Hover', 'profecient-essential' ),
			'segment' => 'navigation',
		);

		$this->options['navigation_item_tabs_hover_border_radius'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Border Radius', 'profecient-essential' ),
			'segment'   => 'navigation',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.woocommerce-MyAccount-navigation-link a:hover',
			'attribute' => 'border-radius',
		);

		$this->options['navigation_item_border_hover'] = array(
			'type'      => 'border',
			'title'     => esc_html__( 'Border', 'profecient-essential' ),
			'segment'   => 'navigation',
			'selectors' => '.woocommerce-MyAccount-navigation-link a:hover',
		);

		$this->options['navigation_item_hover_text_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Color', 'profecient-essential' ),
			'segment'   => 'navigation',
			'selectors' => '.woocommerce-MyAccount-navigation-link a:hover',
		);

		$this->options['navigation_item_hover_background'] = array(
			'type'      => 'background',
			'title'     => esc_html__( 'Nav Item Background', 'profecient-essential' ),
			'segment'   => 'navigation',
			'selectors' => '.woocommerce-MyAccount-navigation-link a:hover',
			'options'   => array(
				'classic',
				'gradient',
			),
			'exclude'   => array( 'image' ),
		);

		$this->options['navigation_item_hover_tab_end'] = array(
			'type'    => 'control_tab_end',
			'segment' => 'navigation',
		);

		$this->options['navigation_item_tabs_end'] = array(
			'type'    => 'control_tabs_end',
			'segment' => 'navigation',
		);
		/* ----- Navigation ----- */

		/* ----- Content Wrapper ----- */
		$this->options['content_wrapper_box_shadow'] = array(
			'type'       => 'boxshadow',
			'title'      => esc_html__( 'Wrapper Box Shadow', 'profecient-essential' ),
			'segment'    => 'content_wrapper',
			'selectors'  => '.woocommerce-MyAccount-content .woocommerce-MyAccount-content-wrapper, {{WRAPPER}} .woocommerce-MyAccount-content .woocommerce-MyAccount-content-wrapper-no-data',
			'dependency' => array(
				array(
					'field'    => 'layout_type',
					'operator' => '==',
					'value'    => 'layout-1',
				),
			),
		);

		$this->options['content_wrapper_border'] = array(
			'type'      => 'border',
			'title'     => esc_html__( 'Border', 'profecient-essential' ),
			'segment'   => 'content_wrapper',
			'selectors' => '.woocommerce-MyAccount-content .woocommerce-MyAccount-content-wrapper, {{WRAPPER}} .woocommerce-MyAccount-content .woocommerce-MyAccount-content-wrapper-no-data',
		);

		$this->options['content_wrapper_border_radius'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Border Radius', 'profecient-essential' ),
			'segment'   => 'content_wrapper',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.woocommerce-MyAccount-content .woocommerce-MyAccount-content-wrapper, {{WRAPPER}} .woocommerce-MyAccount-content .woocommerce-MyAccount-content-wrapper-no-data',
			'attribute' => 'border-radius',
		);

		$this->options['content_wrapper_background'] = array(
			'type'      => 'background',
			'title'     => esc_html__( 'Background Color', 'profecient-essential' ),
			'segment'   => 'content_wrapper',
			'selectors' => '.woocommerce-MyAccount-content .woocommerce-MyAccount-content-wrapper, {{WRAPPER}} .woocommerce-MyAccount-content .woocommerce-MyAccount-content-wrapper-no-data',
			'options'   => array(
				'classic',
				'gradient',
			),
			'exclude'   => array( 'image' ),
		);

		$this->options['content_wrapper_padding'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Padding', 'profecient-essential' ),
			'segment'   => 'content_wrapper',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.woocommerce-MyAccount-content .woocommerce-MyAccount-content-wrapper, {{WRAPPER}} .woocommerce-MyAccount-content .woocommerce-MyAccount-content-wrapper-no-data',
			'attribute' => 'padding',
		);

		$this->options['content_wrapper_margin'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Margin', 'profecient-essential' ),
			'segment'   => 'content_wrapper',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.woocommerce-MyAccount-content .woocommerce-MyAccount-content-wrapper, {{WRAPPER}} .woocommerce-MyAccount-content .woocommerce-MyAccount-content-wrapper-no-data',
			'attribute' => 'margin',
		);
		/* ----- Content Wrapper ----- */

		/* ----- Address ----- */
		$this->options['addresses_section_border'] = array(
			'type'      => 'border',
			'title'     => esc_html__( 'Section Border', 'profecient-essential' ),
			'segment'   => 'addresses',
			'selectors' => '.woocommerce-Address',
		);

		$this->options['addresses_section_border_radius'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Section Border Radius', 'profecient-essential' ),
			'segment'   => 'addresses',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.woocommerce-Address',
			'attribute' => 'border-radius',
		);

		$this->options['addresses_section_background'] = array(
			'type'      => 'background',
			'title'     => esc_html__( 'Section Background Color', 'profecient-essential' ),
			'segment'   => 'addresses',
			'selectors' => '.woocommerce-Address',
			'options'   => array(
				'classic',
				'gradient',
			),
			'exclude'   => array( 'image' ),
		);

		$this->options['addresses_section_padding'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Section Padding', 'profecient-essential' ),
			'segment'   => 'addresses',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.woocommerce-Address',
			'attribute' => 'padding',
		);

		$this->options['addresses_section_margin'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Section Margin', 'profecient-essential' ),
			'segment'   => 'addresses',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.woocommerce-Address',
			'attribute' => 'margin',
		);

		$this->options['addresses_heading_typography'] = array(
			'type'      => 'typography',
			'title'     => esc_html__( 'Heading Typography', 'profecient-essential' ),
			'segment'   => 'addresses',
			'selectors' => '.woocommerce-Addresses h3',
		);

		$this->options['addresses_heading_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Heading Color', 'profecient-essential' ),
			'segment'   => 'addresses',
			'selectors' => '.woocommerce-Addresses h3',
		);

		$this->options['addresses_text_typography'] = array(
			'type'      => 'typography',
			'title'     => esc_html__( 'Text Typography', 'profecient-essential' ),
			'segment'   => 'addresses',
			'selectors' => '.woocommerce-Addresses address, .woocommerce-Addresses p',
		);

		$this->options['addresses_text_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Text Color', 'profecient-essential' ),
			'segment'   => 'addresses',
			'selectors' => '.woocommerce-Addresses address, .woocommerce-Addresses p',
		);

		$this->options['addresses_link_tabs_start'] = array(
			'type'    => 'control_tabs_start',
			'segment' => 'addresses',
		);

		$this->options['addresses_link_normal_tab_start'] = array(
			'type'    => 'control_tab_start',
			'title'   => esc_html__( 'Normal', 'profecient-essential' ),
			'segment' => 'addresses',
		);

		$this->options['addresses_link_background'] = array(
			'type'      => 'background',
			'title'     => esc_html__( 'Link Background', 'profecient-essential' ),
			'segment'   => 'addresses',
			'selectors' => '.woocommerce-Address-title .edit',
			'options'   => array(
				'classic',
				'gradient',
			),
			'exclude'   => array( 'image' ),
		);

		$this->options['addresses_link_normal_text_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Link Text Color', 'profecient-essential' ),
			'segment'   => 'addresses',
			'selectors' => '.woocommerce-Address-title .edit',
		);

		$this->options['addresses_link_normal_tab_end'] = array(
			'type'    => 'control_tab_end',
			'segment' => 'addresses',
		);

		$this->options['addresses_link_hover_tab_start'] = array(
			'type'    => 'control_tab_start',
			'title'   => esc_html__( 'Hover', 'profecient-essential' ),
			'segment' => 'addresses',
		);

		$this->options['addresses_link_hover_text_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Link Hover Text Color', 'profecient-essential' ),
			'segment'   => 'addresses',
			'selectors' => '.woocommerce-Address-title .edit:hover',
		);

		$this->options['addresses_link_hover_background'] = array(
			'type'      => 'background',
			'title'     => esc_html__( 'Link Hover Text Background', 'profecient-essential' ),
			'segment'   => 'addresses',
			'selectors' => '.woocommerce-Address-title .edit:hover',
			'options'   => array(
				'classic',
				'gradient',
			),
			'exclude'   => array( 'image' ),
		);

		$this->options['addresses_link_hover_tab_end'] = array(
			'type'    => 'control_tab_end',
			'segment' => 'addresses',
		);

		$this->options['addresses_link_tabs_end'] = array(
			'type'    => 'control_tabs_end',
			'segment' => 'addresses',
		);

		$this->options['addresses_link_border'] = array(
			'type'      => 'border',
			'title'     => esc_html__( 'Border', 'profecient-essential' ),
			'segment'   => 'content_wrapper',
			'selectors' => '.woocommerce-Address-title .edit',
		);

		$this->options['addresses_link_border_radius'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Border Radius', 'profecient-essential' ),
			'segment'   => 'addresses',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.woocommerce-Address-title .edit',
			'attribute' => 'border-radius',
		);

		$this->options['addresses_link_padding'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Link Padding', 'profecient-essential' ),
			'segment'   => 'addresses',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.woocommerce-Address-title .edit',
			'attribute' => 'padding',
		);

		$this->options['addresses_link_margin'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Link Margin', 'profecient-essential' ),
			'segment'   => 'addresses',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.woocommerce-Address-title .edit',
			'attribute' => 'margin',
		);
		/* ----- Address ----- */

		/* ----- Orders ----- */
		$this->options['order_table_wrapper_box_shadow'] = array(
			'type'      => 'boxshadow',
			'title'     => esc_html__( 'Table Box Shadow', 'profecient-essential' ),
			'segment'   => 'orders_table',
			'selectors' => '.woocommerce-MyAccount-content .woocommerce-MyAccount-content-wrapper .woocommerce-orders-table',
		);

		$this->options['order_table_outer_border'] = array(
			'type'      => 'border',
			'title'     => esc_html__( 'Table Border', 'profecient-essential' ),
			'segment'   => 'orders_table',
			'selectors' => '.woocommerce-MyAccount-content .woocommerce-MyAccount-content-wrapper .woocommerce-orders-table, {{WRAPPER}} .woocommerce-MyAccount-content .woocommerce-MyAccount-content-wrapper .woocommerce-orders-table td, {{WRAPPER}} .woocommerce-MyAccount-content .woocommerce-MyAccount-content-wrapper .woocommerce-orders-table th',
		);

		$this->options['order_table_wrapper_background'] = array(
			'type'      => 'background',
			'title'     => esc_html__( 'Background Color', 'profecient-essential' ),
			'segment'   => 'orders_table',
			'selectors' => '.woocommerce-MyAccount-content .woocommerce-MyAccount-content-wrapper .woocommerce-orders-table',
			'options'   => array(
				'classic',
				'gradient',
			),
			'exclude'   => array( 'image' ),
		);

		$this->options['order_table_wrapper_padding'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Table Padding', 'profecient-essential' ),
			'segment'   => 'orders_table',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.woocommerce-MyAccount-content .woocommerce-MyAccount-content-wrapper .woocommerce-orders-table',
			'attribute' => 'padding',
		);

		$this->options['order_table_wrapper_margin'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Table Margin', 'profecient-essential' ),
			'segment'   => 'orders_table',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.woocommerce-MyAccount-content .woocommerce-MyAccount-content-wrapper .woocommerce-orders-table',
			'attribute' => 'margin',
		);

		$this->options['order_table_text_align'] = array(
			'type'      => 'radio',
			'title'     => esc_html__( 'Text Align', 'profecient-essential' ),
			'segment'   => 'orders_table',
			'selectors' => '.woocommerce-MyAccount-content .woocommerce-MyAccount-content-wrapper .woocommerce-orders-table th, {{WRAPPER}} .woocommerce-MyAccount-content .woocommerce-MyAccount-content-wrapper .woocommerce-orders-table td',
			'options'   => array(
				'left'   => array(
					'title' => esc_html__( 'Left', 'profecient-essential' ),
					'icon'  => 'fas fa-align-left',
				),
				'center' => array(
					'title' => esc_html__( 'Center', 'profecient-essential' ),
					'icon'  => 'fas fa-align-center',
				),
				'right'  => array(
					'title' => esc_html__( 'Right', 'profecient-essential' ),
					'icon'  => 'fas fa-align-right',
				),
			),
			'default'   => 'center',
			'attribute' => 'text-align',
		);

		$this->options['order_table_heading_txt'] = array(
			'type'      => 'typography',
			'title'     => esc_html__( 'Table Heading Text', 'profecient-essential' ),
			'segment'   => 'orders_table',
			'selectors' => '.woocommerce-MyAccount-content .woocommerce-MyAccount-content-wrapper .woocommerce-orders-table th.woocommerce-orders-table__header',
		);

		$this->options['order_table_heading_txt_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Table Heading Color', 'profecient-essential' ),
			'segment'   => 'orders_table',
			'selectors' => '.woocommerce-MyAccount-content .woocommerce-MyAccount-content-wrapper .woocommerce-orders-table th.woocommerce-orders-table__header',
		);

		$this->options['order_table_data_txt'] = array(
			'type'      => 'typography',
			'title'     => esc_html__( 'Table Body Data Text', 'profecient-essential' ),
			'segment'   => 'orders_table',
			'selectors' => '.woocommerce-MyAccount-content .woocommerce-MyAccount-content-wrapper .woocommerce-orders-table td',
		);

		$this->options['order_table_data_txt_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Body Data Text color', 'profecient-essential' ),
			'segment'   => 'orders_table',
			'selectors' => '.woocommerce-MyAccount-content .woocommerce-MyAccount-content-wrapper .woocommerce-orders-table td',
		);
		/* ----- Orders ----- */

		/* ----- Action Button ----- */
		$this->options['orders_action_button_typography'] = array(
			'type'      => 'typography',
			'title'     => esc_html__( 'Button Typograhpy', 'profecient-essential' ),
			'segment'   => 'orders_action_button',
			'selectors' => '.woocommerce-MyAccount-content .woocommerce-MyAccount-content-wrapper .woocommerce-orders-table .woocommerce-button.button.view',
		);

		$this->options['orders_action_button_tabs_start'] = array(
			'type'    => 'control_tabs_start',
			'segment' => 'orders_action_button',
		);

		$this->options['orders_action_button_normal_tab_start'] = array(
			'type'    => 'control_tab_start',
			'title'   => esc_html__( 'Normal', 'profecient-essential' ),
			'segment' => 'orders_action_button',
		);

		$this->options['orders_action_button_normal_border'] = array(
			'type'      => 'border',
			'title'     => esc_html__( 'Border button', 'profecient-essential' ),
			'segment'   => 'orders_action_button',
			'selectors' => '.woocommerce-MyAccount-content .woocommerce-MyAccount-content-wrapper .woocommerce-orders-table .woocommerce-button.button.view',
		);

		$this->options['orders_action_button_normal_border_radius'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Border Radius', 'profecient-essential' ),
			'segment'   => 'orders_action_button',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.woocommerce-MyAccount-content .woocommerce-MyAccount-content-wrapper .woocommerce-orders-table .woocommerce-button.button.view',
			'attribute' => 'border-radius',
		);

		$this->options['orders_action_button_normal_margin'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Button Margin', 'profecient-essential' ),
			'segment'   => 'orders_action_button',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.woocommerce-MyAccount-content .woocommerce-MyAccount-content-wrapper .woocommerce-orders-table .woocommerce-button.button.view',
			'attribute' => 'margin',
		);

		$this->options['orders_action_button_normal_padding'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Button Padding', 'profecient-essential' ),
			'segment'   => 'orders_action_button',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.woocommerce-MyAccount-content .woocommerce-MyAccount-content-wrapper .woocommerce-orders-table .woocommerce-button.button.view',
			'attribute' => 'padding',
		);

		$this->options['orders_action_button_background'] = array(
			'type'           => 'background',
			'title'          => esc_html__( 'Button Background', 'profecient-essential' ),
			'segment'        => 'orders_action_button',
			'selectors'      => '.woocommerce-MyAccount-content .woocommerce-MyAccount-content-wrapper .woocommerce-orders-table .woocommerce-button.button.view',
			'fields_options' => array(
				'background' => array(
					'default' => 'classic',
				),
				'color'      => array(
					'global' => array(
						'default' => $global_button_background,
					),
				),
			),
			'options'        => array(
				'classic',
				'gradient',
			),
			'exclude'        => array( 'image' ),
		);

		$this->options['orders_action_button_normal_text_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Text Color', 'profecient-essential' ),
			'segment'   => 'orders_action_button',
			'global'    => array(
				'default' => $global_button_text_color,
			),
			'selectors' => '.woocommerce-MyAccount-content .woocommerce-MyAccount-content-wrapper .woocommerce-orders-table .woocommerce-button.button.view',
		);

		$this->options['orders_action_button_normal_tab_end'] = array(
			'type'    => 'control_tab_end',
			'segment' => 'orders_action_button',
		);

		$this->options['orders_action_button_hover_tab_start'] = array(
			'type'    => 'control_tab_start',
			'title'   => esc_html__( 'Hover', 'profecient-essential' ),
			'segment' => 'orders_action_button',
		);

		$this->options['orders_action_button_hover_border'] = array(
			'type'      => 'border',
			'title'     => esc_html__( 'Border button', 'profecient-essential' ),
			'segment'   => 'orders_action_button',
			'selectors' => '.woocommerce-MyAccount-content .woocommerce-MyAccount-content-wrapper .woocommerce-orders-table .woocommerce-button.button.view:hover',
		);

		$this->options['orders_action_button_normal_hover_radius'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Border Radius', 'profecient-essential' ),
			'segment'   => 'orders_action_button',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.woocommerce-MyAccount-content .woocommerce-MyAccount-content-wrapper .woocommerce-orders-table .woocommerce-button.button.view:hover',
			'attribute' => 'border-radius',
		);

		$this->options['orders_action_button_hover_margin'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Button Margin', 'profecient-essential' ),
			'segment'   => 'orders_action_button',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.woocommerce-MyAccount-content .woocommerce-MyAccount-content-wrapper .woocommerce-orders-table .woocommerce-button.button.view:hover',
			'attribute' => 'margin',
		);

		$this->options['orders_action_button_hover_padding'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Button Padding', 'profecient-essential' ),
			'segment'   => 'orders_action_button',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.woocommerce-MyAccount-content .woocommerce-MyAccount-content-wrapper .woocommerce-orders-table .woocommerce-button.button.view:hover',
			'attribute' => 'padding',
		);

		$this->options['orders_action_button_hover_background'] = array(
			'type'           => 'background',
			'title'          => esc_html__( 'Button Background', 'profecient-essential' ),
			'segment'        => 'orders_action_button',
			'selectors'      => '.woocommerce-MyAccount-content .woocommerce-MyAccount-content-wrapper .woocommerce-orders-table .woocommerce-button.button.view:hover',
			'fields_options' => array(
				'background' => array(
					'default' => 'classic',
				),
				'color'      => array(
					'global' => array(
						'default' => $global_button_background,
					),
				),
			),
			'options'        => array(
				'classic',
				'gradient',
			),
			'exclude'        => array( 'image' ),
		);

		$this->options['orders_action_button_hover_text_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Text Color', 'profecient-essential' ),
			'segment'   => 'orders_action_button',
			'global'    => array(
				'default' => $global_button_text_color,
			),
			'selectors' => '.woocommerce-MyAccount-content .woocommerce-MyAccount-content-wrapper .woocommerce-orders-table .woocommerce-button.button.view:hover',
		);

		$this->options['orders_action_button_hover_tab_end'] = array(
			'type'    => 'control_tab_end',
			'segment' => 'orders_action_button',
		);

		$this->options['orders_action_button_tabs_end'] = array(
			'type'    => 'control_tabs_end',
			'segment' => 'orders_action_button',
		);
		/* ----- Action Button ----- */

		/* ----- Downlaods ----- */
		$this->options['downloads_table_wrapper_box_shadow'] = array(
			'type'      => 'boxshadow',
			'title'     => esc_html__( 'Table Box Shadow', 'profecient-essential' ),
			'segment'   => 'downloads_table',
			'selectors' => '.woocommerce-MyAccount-content .woocommerce-MyAccount-content-wrapper .woocommerce-table--order-downloads',
		);

		$this->options['downloads_table_outer_border'] = array(
			'type'      => 'border',
			'title'     => esc_html__( 'Table Border', 'profecient-essential' ),
			'segment'   => 'downloads_table',
			'selectors' => '.woocommerce-MyAccount-content .woocommerce-MyAccount-content-wrapper table.woocommerce-table--order-download, {{WRAPPER}} .woocommerce-MyAccount-content .woocommerce-MyAccount-content-wrapper .woocommerce-table--order-downloads td, {{WRAPPER}} .woocommerce-MyAccount-content .woocommerce-MyAccount-content-wrapper .woocommerce-table--order-downloads th',
		);

		$this->options['downloads_table_wrapper_background'] = array(
			'type'      => 'background',
			'title'     => esc_html__( 'Background Color', 'profecient-essential' ),
			'segment'   => 'downloads_table',
			'selectors' => '.woocommerce-MyAccount-content .woocommerce-MyAccount-content-wrapper .woocommerce-table--order-downloads',
			'options'   => array(
				'classic',
				'gradient',
			),
			'exclude'   => array( 'image' ),
		);

		$this->options['downloads_table_wrapper_padding'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Table Padding', 'profecient-essential' ),
			'segment'   => 'downloads_table',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.woocommerce-MyAccount-content .woocommerce-MyAccount-content-wrapper .woocommerce-table--order-downloads',
			'attribute' => 'padding',
		);

		$this->options['downloads_table_wrapper_margin'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Table Margin', 'profecient-essential' ),
			'segment'   => 'downloads_table',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.woocommerce-MyAccount-content .woocommerce-MyAccount-content-wrapper .woocommerce-table--order-downloads',
			'attribute' => 'margin',
		);

		$this->options['downloads_table_text_align'] = array(
			'type'      => 'radio',
			'title'     => esc_html__( 'Text Align', 'profecient-essential' ),
			'segment'   => 'downloads_table',
			'selectors' => '.woocommerce-MyAccount-content .woocommerce-MyAccount-content-wrapper .woocommerce-table--order-downloads th, {{WRAPPER}} .woocommerce-MyAccount-content .woocommerce-MyAccount-content-wrapper .woocommerce-table--order-downloads td',
			'options'   => array(
				'left'   => array(
					'title' => esc_html__( 'Left', 'profecient-essential' ),
					'icon'  => 'fas fa-align-left',
				),
				'center' => array(
					'title' => esc_html__( 'Center', 'profecient-essential' ),
					'icon'  => 'fas fa-align-center',
				),
				'right'  => array(
					'title' => esc_html__( 'Right', 'profecient-essential' ),
					'icon'  => 'fas fa-align-right',
				),
			),
			'default'   => 'center',
			'attribute' => 'text-align',
		);

		$this->options['downloads_table_heading_txt'] = array(
			'type'      => 'typography',
			'title'     => esc_html__( 'Table Heading Text', 'profecient-essential' ),
			'segment'   => 'downloads_table',
			'selectors' => '.woocommerce-MyAccount-content .woocommerce-MyAccount-content-wrapper .woocommerce-table--order-downloads th',
		);

		$this->options['downloads_table_heading_txt_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Table Heading Color', 'profecient-essential' ),
			'segment'   => 'downloads_table',
			'selectors' => '.woocommerce-MyAccount-content .woocommerce-MyAccount-content-wrapper .woocommerce-table--order-downloads th',
		);

		$this->options['downloads_table_data_txt'] = array(
			'type'      => 'typography',
			'title'     => esc_html__( 'Table Body Data Text', 'profecient-essential' ),
			'segment'   => 'downloads_table',
			'selectors' => '.woocommerce-MyAccount-content .woocommerce-MyAccount-content-wrapper .woocommerce-table--order-downloads td',
		);

		$this->options['downloads_table_data_txt_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Body Data Text color', 'profecient-essential' ),
			'segment'   => 'downloads_table',
			'selectors' => '.woocommerce-MyAccount-content .woocommerce-MyAccount-content-wrapper .woocommerce-table--order-downloads td',
		);
		/* ----- Downloads ----- */

		/* ----- Download Button ----- */
		$this->options['download_button_typography'] = array(
			'type'      => 'typography',
			'title'     => esc_html__( 'Button Typograhpy', 'profecient-essential' ),
			'segment'   => 'download_button',
			'selectors' => '.woocommerce-MyAccount-content .woocommerce-MyAccount-content-wrapper .woocommerce-table--order-downloads .woocommerce-MyAccount-downloads-file.button',
		);

		$this->options['download_button_tabs_start'] = array(
			'type'    => 'control_tabs_start',
			'segment' => 'download_button',
		);

		$this->options['download_button_normal_tab_start'] = array(
			'type'    => 'control_tab_start',
			'title'   => esc_html__( 'Normal', 'profecient-essential' ),
			'segment' => 'download_button',
		);

		$this->options['download_button_normal_border'] = array(
			'type'      => 'border',
			'title'     => esc_html__( 'Border button', 'profecient-essential' ),
			'segment'   => 'download_button',
			'selectors' => '.woocommerce-MyAccount-content .woocommerce-MyAccount-content-wrapper .woocommerce-table--order-downloads .woocommerce-MyAccount-downloads-file.button',
		);

		$this->options['download_button_normal_border_radius'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Border Radius', 'profecient-essential' ),
			'segment'   => 'download_button',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.woocommerce-MyAccount-content .woocommerce-MyAccount-content-wrapper .woocommerce-table--order-downloads .woocommerce-MyAccount-downloads-file.button',
			'attribute' => 'border-radius',
		);

		$this->options['download_button_normal_margin'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Button Margin', 'profecient-essential' ),
			'segment'   => 'download_button',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.woocommerce-MyAccount-content .woocommerce-MyAccount-content-wrapper .woocommerce-table--order-downloads .woocommerce-MyAccount-downloads-file.button',
			'attribute' => 'margin',
		);

		$this->options['download_button_normal_padding'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Button Padding', 'profecient-essential' ),
			'segment'   => 'download_button',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.woocommerce-MyAccount-content .woocommerce-MyAccount-content-wrapper .woocommerce-table--order-downloads .woocommerce-MyAccount-downloads-file.button',
			'attribute' => 'padding',
		);

		$this->options['download_button_background'] = array(
			'type'           => 'background',
			'title'          => esc_html__( 'Button Background', 'profecient-essential' ),
			'segment'        => 'download_button',
			'selectors'      => '.woocommerce-MyAccount-content .woocommerce-MyAccount-content-wrapper .woocommerce-table--order-downloads .woocommerce-MyAccount-downloads-file.button',
			'fields_options' => array(
				'background' => array(
					'default' => 'classic',
				),
				'color'      => array(
					'global' => array(
						'default' => $global_button_background,
					),
				),
			),
			'options'        => array(
				'classic',
				'gradient',
			),
			'exclude'        => array( 'image' ),
		);

		$this->options['download_button_normal_text_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Text Color', 'profecient-essential' ),
			'segment'   => 'download_button',
			'global'    => array(
				'default' => $global_button_text_color,
			),
			'selectors' => '.woocommerce-MyAccount-content .woocommerce-MyAccount-content-wrapper .woocommerce-table--order-downloads .woocommerce-MyAccount-downloads-file.button',
		);

		$this->options['download_button_normal_tab_end'] = array(
			'type'    => 'control_tab_end',
			'segment' => 'download_button',
		);

		$this->options['download_button_hover_tab_start'] = array(
			'type'    => 'control_tab_start',
			'title'   => esc_html__( 'Hover', 'profecient-essential' ),
			'segment' => 'download_button',
		);

		$this->options['download_button_hover_border'] = array(
			'type'      => 'border',
			'title'     => esc_html__( 'Border button', 'profecient-essential' ),
			'segment'   => 'download_button',
			'selectors' => '.woocommerce-MyAccount-content .woocommerce-MyAccount-content-wrapper .woocommerce-table--order-downloads .woocommerce-MyAccount-downloads-file.button:hover',
		);

		$this->options['download_button_normal_hover_radius'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Border Radius', 'profecient-essential' ),
			'segment'   => 'download_button',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.woocommerce-MyAccount-content .woocommerce-MyAccount-content-wrapper .woocommerce-table--order-downloads .woocommerce-MyAccount-downloads-file.button:hover',
			'attribute' => 'border-radius',
		);

		$this->options['download_button_hover_margin'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Button Margin', 'profecient-essential' ),
			'segment'   => 'download_button',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.woocommerce-MyAccount-content .woocommerce-MyAccount-content-wrapper .woocommerce-table--order-downloads .woocommerce-MyAccount-downloads-file.button:hover',
			'attribute' => 'margin',
		);

		$this->options['download_button_hover_padding'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Button Padding', 'profecient-essential' ),
			'segment'   => 'download_button',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.woocommerce-MyAccount-content .woocommerce-MyAccount-content-wrapper .woocommerce-table--order-downloads .woocommerce-MyAccount-downloads-file.button:hover',
			'attribute' => 'padding',
		);

		$this->options['download_button_hover_background'] = array(
			'type'           => 'background',
			'title'          => esc_html__( 'Button Background', 'profecient-essential' ),
			'segment'        => 'download_button',
			'selectors'      => '.woocommerce-MyAccount-content .woocommerce-MyAccount-content-wrapper .woocommerce-table--order-downloads .woocommerce-MyAccount-downloads-file.button:hover',
			'fields_options' => array(
				'background' => array(
					'default' => 'classic',
				),
				'color'      => array(
					'global' => array(
						'default' => $global_button_background,
					),
				),
			),
			'options'        => array(
				'classic',
				'gradient',
			),
			'exclude'        => array( 'image' ),
		);

		$this->options['download_button_hover_text_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Text Color', 'profecient-essential' ),
			'segment'   => 'download_button',
			'global'    => array(
				'default' => $global_button_text_color,
			),
			'selectors' => '.woocommerce-MyAccount-content .woocommerce-MyAccount-content-wrapper .woocommerce-table--order-downloads .woocommerce-MyAccount-downloads-file.button:hover',
		);

		$this->options['download_button_hover_tab_end'] = array(
			'type'    => 'control_tab_end',
			'segment' => 'download_button',
		);

		$this->options['download_button_tabs_end'] = array(
			'type'    => 'control_tabs_end',
			'segment' => 'download_button',
		);
		/* ----- Download Button ----- */

		/* ----- Account Details ----- */
		$this->options['account_details_column_gap'] = array(
			'type'      => 'slider',
			'title'     => esc_html__( 'Form Column Gap', 'profecient-essential' ),
			'segment'   => 'account_details',
			'options'   => array(
				'min'  => 0,
				'max'  => 100,
				'step' => 1,
			),
			'selectors' => array(
				'custom' => array(
					'{{WRAPPER}} .woocommerce-EditAccountForm > *, {{WRAPPER}} .woocommerce-EditAccountForm fieldset p' => 'margin-bottom: {{SIZE}}{{UNIT}};',
				),
			),
		);

		$this->options['account_details_required_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Required Color', 'profecient-essential' ),
			'segment'   => 'account_details',
			'selectors' => '.woocommerce-EditAccountForm span.required',
		);

		$this->options['account_details_form_label'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Form Label Color', 'profecient-essential' ),
			'segment'   => 'account_details',
			'selectors' => '.woocommerce-EditAccountForm label',
		);

		$this->options['account_details_label_typography'] = array(
			'type'      => 'typography',
			'title'     => esc_html__( 'Form Label', 'profecient-essential' ),
			'segment'   => 'account_details',
			'selectors' => '.woocommerce-EditAccountForm label',
		);

		$this->options['account_details_input_box_shadow'] = array(
			'type'      => 'boxshadow',
			'title'     => esc_html__( 'Input Box Shadow', 'profecient-essential' ),
			'segment'   => 'account_details',
			'selectors' => 'input.woocommerce-Input',
		);

		$this->options['account_details_input_border'] = array(
			'type'      => 'border',
			'title'     => esc_html__( 'Input border', 'profecient-essential' ),
			'segment'   => 'account_details',
			'selectors' => 'input.woocommerce-Input',
		);

		$this->options['account_details_input_box_shadow'] = array(
			'type'      => 'boxshadow',
			'title'     => esc_html__( 'Input Box Shadow', 'profecient-essential' ),
			'segment'   => 'account_details',
			'selectors' => 'input.woocommerce-Input',
		);

		$this->options['account_details_input_border_radius'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Input Border Radius', 'profecient-essential' ),
			'segment'   => 'account_details',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => 'input.woocommerce-Input',
			'attribute' => 'border-radius',
		);

		$this->options['account_details_input_margin'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Input Margin', 'profecient-essential' ),
			'segment'   => 'account_details',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => 'input.woocommerce-Input',
			'attribute' => 'margin',
		);

		$this->options['account_details_input_padding'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Input Padding', 'profecient-essential' ),
			'segment'   => 'account_details',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => 'input.woocommerce-Input',
			'attribute' => 'padding',
		);

		$this->options['account_details_input_background'] = array(
			'type'      => 'background',
			'title'     => esc_html__( 'Input Background', 'profecient-essential' ),
			'segment'   => 'account_details',
			'selectors' => 'input.woocommerce-Input',
			'options'   => array(
				'classic',
				'gradient',
			),
			'exclude'   => array( 'image' ),
		);

		$this->options['account_details_input_text'] = array(
			'type'      => 'typography',
			'title'     => esc_html__( 'Input Text', 'profecient-essential' ),
			'segment'   => 'account_details',
			'selectors' => 'input.woocommerce-Input',
		);

		$this->options['account_details_input_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Input Text Color', 'profecient-essential' ),
			'segment'   => 'account_details',
			'selectors' => 'input.woocommerce-Input',
		);

		$this->options['account_details_button_typography'] = array(
			'type'      => 'typography',
			'title'     => esc_html__( 'Button Typograhpy', 'profecient-essential' ),
			'segment'   => 'account_details',
			'selectors' => '.woocommerce-EditAccountForm button.woocommerce-Button.button',
		);

		$this->options['form_button_tabs_start'] = array(
			'type'    => 'control_tabs_start',
			'segment' => 'account_details',
		);

		$this->options['account_details_button_button_normal_tab_start'] = array(
			'type'    => 'control_tab_start',
			'title'   => esc_html__( 'Normal', 'profecient-essential' ),
			'segment' => 'account_details',
		);

		$this->options['account_details_button_normal_box_shadow'] = array(
			'type'      => 'boxshadow',
			'title'     => esc_html__( 'Box Shadow', 'profecient-essential' ),
			'segment'   => 'account_details',
			'selectors' => '.woocommerce-EditAccountForm button.woocommerce-Button.button',
		);

		$this->options['account_details_button_normal_border'] = array(
			'type'      => 'border',
			'title'     => esc_html__( 'Border', 'profecient-essential' ),
			'segment'   => 'account_details',
			'selectors' => '.woocommerce-EditAccountForm button.woocommerce-Button.button',
		);

		$this->options['account_details_button_normal_border_radius'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Border Radius', 'profecient-essential' ),
			'segment'   => 'account_details',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.woocommerce-EditAccountForm button.woocommerce-Button.button',
			'attribute' => 'border-radius',
		);

		$this->options['account_details_button_normal_margin'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Button Margin', 'profecient-essential' ),
			'segment'   => 'account_details',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.woocommerce-EditAccountForm button.woocommerce-Button.button',
			'attribute' => 'margin',
		);

		$this->options['account_details_button_normal_padding'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Button Padding', 'profecient-essential' ),
			'segment'   => 'account_details',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.woocommerce-EditAccountForm button.woocommerce-Button.button',
			'attribute' => 'padding',
		);

		$this->options['account_details_button_normal_background'] = array(
			'type'           => 'background',
			'title'          => esc_html__( 'Button Background', 'profecient-essential' ),
			'segment'        => 'account_details',
			'selectors'      => '.woocommerce-EditAccountForm button.woocommerce-Button.button',
			'fields_options' => array(
				'background' => array(
					'default' => 'classic',
				),
				'color'      => array(
					'global' => array(
						'default' => $global_button_background,
					),
				),
			),
			'options'        => array(
				'classic',
				'gradient',
			),
			'exclude'        => array( 'image' ),
		);

		$this->options['account_details_button_normal_text_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Text Color', 'profecient-essential' ),
			'segment'   => 'account_details',
			'global'    => array(
				'default' => $global_button_text_color,
			),
			'selectors' => '.woocommerce-EditAccountForm button.woocommerce-Button.button',
		);

		$this->options['account_details_button_normal_tab_end'] = array(
			'type'    => 'control_tab_end',
			'segment' => 'account_details',
		);

		$this->options['account_details_button_hover_tab_start'] = array(
			'type'    => 'control_tab_start',
			'title'   => esc_html__( 'Hover', 'profecient-essential' ),
			'segment' => 'account_details',
		);

		$this->options['account_details_button_hover_box_shadow'] = array(
			'type'      => 'boxshadow',
			'title'     => esc_html__( 'Box Shadow', 'profecient-essential' ),
			'segment'   => 'account_details',
			'selectors' => '.woocommerce-EditAccountForm button.woocommerce-Button.button:hover',
		);

		$this->options['account_details_button_hover_border'] = array(
			'type'      => 'border',
			'title'     => esc_html__( 'Border', 'profecient-essential' ),
			'segment'   => 'account_details',
			'selectors' => '.woocommerce-EditAccountForm button.woocommerce-Button.button:hover',
		);

		$this->options['account_details_button_hover_border_radius'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Border Radius', 'profecient-essential' ),
			'segment'   => 'account_details',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.woocommerce-EditAccountForm button.woocommerce-Button.button:hover',
			'attribute' => 'border-radius',
		);

		$this->options['account_details_button_hover_margin'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Button Margin', 'profecient-essential' ),
			'segment'   => 'account_details',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.woocommerce-EditAccountForm button.woocommerce-Button.button:hover',
			'attribute' => 'margin',
		);

		$this->options['account_details_button_hover_padding'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Button Padding', 'profecient-essential' ),
			'segment'   => 'account_details',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.woocommerce-EditAccountForm button.woocommerce-Button.button:hover',
			'attribute' => 'padding',
		);

		$this->options['account_details_button_hover_background'] = array(
			'type'           => 'background',
			'title'          => esc_html__( 'Button Background', 'profecient-essential' ),
			'segment'        => 'account_details',
			'selectors'      => '.woocommerce-EditAccountForm button.woocommerce-Button.button:hover',
			'fields_options' => array(
				'background' => array(
					'default' => 'classic',
				),
				'color'      => array(
					'global' => array(
						'default' => $global_button_background,
					),
				),
			),
			'options'        => array(
				'classic',
				'gradient',
			),
			'exclude'        => array( 'image' ),
		);

		$this->options['account_details_button_hover_text_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Text Color', 'profecient-essential' ),
			'segment'   => 'account_details',
			'global'    => array(
				'default' => $global_button_text_color,
			),
			'selectors' => '.woocommerce-EditAccountForm button.woocommerce-Button.button:hover',
		);

		$this->options['account_details_button_hover_tab_end'] = array(
			'type'    => 'control_tab_end',
			'segment' => 'account_details',
		);

		$this->options['account_details_button_tabs_end'] = array(
			'type'    => 'control_tabs_end',
			'segment' => 'account_details',
		);
		/* ----- Account Details ----- */
	}

	/**
	 * Add Additional Style.
	 */
	public function additional_style() {
		$this->style_option();

		parent::additional_style();
	}
}
