<?php
/**
 * Woocommerce Cart Page Option Class
 *
 * @package profecient-essential
 * @author jegtheme
 * @since 1.0.0
 */

namespace Profecient\Essential\JKit\Elements\Options;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

use Jeg\Elementor_Kit\Elements\Options\Option_Abstract;

/**
 * Class Woocommerce_Cart_Page_Option
 */
class Woocommerce_Cart_Page_Option extends Option_Abstract {
	/**
	 * Show color scheme flag for element.
	 *
	 * @return bool
	 */
	public function show_color_scheme() {
		return false;
	}

	/**
	 * Compatibility column
	 *
	 * @return array
	 */
	public function compatible_column() {
		return array();
	}

	/**
	 * Override function to remove compatible column alert
	 */
	public function set_compatible_column_option() {}

	/**
	 * Element name
	 *
	 * @return string
	 */
	public function get_element_name() {
		return esc_html__( 'Cart Page', 'profecient-essential' );
	}

	/**
	 * Element category
	 *
	 * @return string
	 */
	public function get_category() {
		return esc_html__( 'Profecient - Woocommerce', 'profecient-essential' );
	}

	/**
	 * Element options
	 */
	public function set_options() {
		$this->set_style_option();

		parent::set_options();
	}

	/**
	 * Option segments
	 */
	public function set_segments() {
		$this->set_style_segment();
	}

	/**
	 * Style segments
	 */
	public function set_style_segment() {
		$this->segments['layout'] = array(
			'name'      => esc_html__( 'Layout', 'profecient-essential' ),
			'priority'  => 11,
			'kit_style' => true,
		);

		$this->segments['cart_table'] = array(
			'name'      => esc_html__( 'Cart Table', 'profecient-essential' ),
			'priority'  => 11,
			'kit_style' => true,
		);

		$this->segments['total_table'] = array(
			'name'      => esc_html__( 'Total Table', 'profecient-essential' ),
			'priority'  => 11,
			'kit_style' => true,
		);

		$this->segments['coupon_code_section'] = array(
			'name'      => esc_html__( 'Coupon Code Section', 'profecient-essential' ),
			'priority'  => 11,
			'kit_style' => true,
		);

		$this->segments['button_style'] = array(
			'name'      => esc_html__( 'Button', 'profecient-essential' ),
			'priority'  => 11,
			'kit_style' => true,
		);

		$this->segments['update_cart_style_button'] = array(
			'name'      => esc_html__( 'Update Cart Button', 'profecient-essential' ),
			'priority'  => 11,
			'kit_style' => true,
		);

		$this->segments['apply_coupon_style_button'] = array(
			'name'      => esc_html__( 'Apply Coupon Button', 'profecient-essential' ),
			'priority'  => 11,
			'kit_style' => true,
		);

		$this->segments['proceed_style_button'] = array(
			'name'      => esc_html__( 'Proceed Checkout Button', 'profecient-essential' ),
			'priority'  => 11,
			'kit_style' => true,
		);

		parent::set_style_segment();
	}

	public function style_option() {
		$global_button_typography       = parent::get_global_style_option( 'button_typography_typography' );
		$global_button_background       = parent::get_global_style_option( 'button_background_color' );
		$global_button_text             = parent::get_global_style_option( 'button_text_color' );
		$global_button_hover_background = parent::get_global_style_option( 'button_hover_background_color' );

		$this->options['layout_type'] = array(
			'type'    => 'select',
			'title'   => esc_html__( 'Layout Type', 'profecient-essential' ),
			'default' => 'layout-1',
			'segment' => 'layout',
			'options' => array(
				'layout-1' => 'Layout 1',
				'layout-2' => 'Layout 2',
			),
		);

		// cart product page style option
		/* ----- Checkout Cart Table Segment ----- */
		$this->options['cart_table_wrapper_box_shadow'] = array(
			'type'      => 'boxshadow',
			'title'     => esc_html__( 'Wrapper Box Shadow', 'profecient-essential' ),
			'segment'   => 'cart_table',
			'selectors' => '.woocommerce-cart-form .profecient-woocommerce-cart-wrapper',
		);

		$this->options['cart_table_outer_border'] = array(
			'type'       => 'border',
			'title'      => esc_html__( 'Table  Border', 'profecient-essential' ),
			'segment'    => 'cart_table',
			'selectors'  => '.woocommerce-cart-form .profecient-woocommerce-cart-wrapper',
			'dependency' => array(
				array(
					'field'    => 'layout_type',
					'operator' => '==',
					'value'    => 'layout-1',
				),
			),
		);

		$this->options['cart_table_wrapper_border_radius'] = array(
			'type'       => 'dimension',
			'title'      => esc_html__( 'Wrapper Border Radius', 'profecient-essential' ),
			'segment'    => 'cart_table',
			'units'      => array( 'px', '%', 'em' ),
			'selectors'  => '.woocommerce-cart-form .profecient-woocommerce-cart-wrapper',
			'attribute'  => 'border-radius',
			'dependency' => array(
				array(
					'field'    => 'layout_type',
					'operator' => '==',
					'value'    => 'layout-1',
				),
			),
		);

		$this->options['cart_table_wrapper_background'] = array(
			'type'      => 'background',
			'title'     => esc_html__( 'Background Color', 'profecient-essential' ),
			'segment'   => 'cart_table',
			'selectors' => '.woocommerce-cart-form .profecient-woocommerce-cart-wrapper',
			'options'   => array(
				'classic',
				'gradient',
			),
			'exclude'   => array( 'image' ),
		);

		$this->options['cart_table_wrapper_padding'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Wrapper Padding', 'profecient-essential' ),
			'segment'   => 'cart_table',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.woocommerce-cart-form .profecient-woocommerce-cart-wrapper',
			'attribute' => 'padding',
		);

		$this->options['cart_table_wrapper_margin'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Wrapper Margin', 'profecient-essential' ),
			'segment'   => 'cart_table',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.woocommerce-cart-form .profecient-woocommerce-cart-wrapper',
			'attribute' => 'margin',
		);

		$this->options['cart_table_head_border'] = array(
			'type'      => 'border',
			'title'     => esc_html__( 'Table Head Border', 'profecient-essential' ),
			'segment'   => 'cart_table',
			'selectors' => '.woocommerce-cart-form table.shop_table th, {{WRAPPER}} .woocommerce-cart-form .profecient-woocommerce-cart-wrapper table.shop_table_responsive tr td:before',
			'separator' => 'before',
		);

		$this->options['cart_table_text_align'] = array(
			'type'      => 'radio',
			'title'     => esc_html__( 'Text Align', 'profecient-essential' ),
			'segment'   => 'cart_table',
			'selectors' => '.woocommerce .profecient-woocommerce-cart-wrapper table.shop_table, {{WRAPPER}} .woocommerce-cart-form .profecient-woocommerce-cart-wrapper table.shop_table_responsive tr td:before',
			'options'   => array(
				'left'   => array(
					'title' => esc_html__( 'Left', 'profecient-essential' ),
					'icon'  => 'fas fa-align-left',
				),
				'center' => array(
					'title' => esc_html__( 'Center', 'profecient-essential' ),
					'icon'  => 'fas fa-align-center',
				),
				'right'  => array(
					'title' => esc_html__( 'Right', 'profecient-essential' ),
					'icon'  => 'fas fa-align-right',
				),
			),
			'default'   => 'center',
			'attribute' => 'text-align',
		);

		$this->options['cart_table_heading_txt'] = array(
			'type'      => 'typography',
			'title'     => esc_html__( 'Table Heading Text', 'profecient-essential' ),
			'segment'   => 'cart_table',
			'selectors' => '.woocommerce-cart-form .profecient-woocommerce-cart-wrapper table.shop_table th, {{WRAPPER}} .woocommerce-cart-form .profecient-woocommerce-cart-wrapper table.shop_table_responsive tr td:before',
		);

		$this->options['cart_table_heading_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Table Heading Color', 'profecient-essential' ),
			'segment'   => 'cart_table',
			'selectors' => '.woocommerce-cart-form table.shop_table th, {{WRAPPER}} .woocommerce-cart-form .profecient-woocommerce-cart-wrapper table.shop_table_responsive tr td:before',
		);

		$this->options['cart_table_data_border'] = array(
			'type'      => 'border',
			'title'     => esc_html__( 'Table Row Border', 'profecient-essential' ),
			'segment'   => 'cart_table',
			'selectors' => '.woocommerce-cart-form table tr.woocommerce-cart-form__cart-item.cart_item td',
		);

		$this->options['cart_table_row_border'] = array(
			'type'      => 'border',
			'title'     => esc_html__( 'Table Data Border', 'profecient-essential' ),
			'segment'   => 'cart_table',
			'selectors' => '.woocommerce-cart-form .profecient-woocommerce-cart-wrapper table tr.cart_item',
		);

		$this->options['cart_table_data_txt'] = array(
			'type'      => 'typography',
			'title'     => esc_html__( 'Table Data Text', 'profecient-essential' ),
			'segment'   => 'cart_table',
			'selectors' => '.woocommerce-cart-form table.shop_table .cart_item',
		);

		$this->options['cart_table_product_name_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Product Name Color', 'profecient-essential' ),
			'segment'   => 'cart_table',
			'selectors' => '.woocommerce-cart-form table.shop_table .cart_item .product-name a',
		);

		$this->options['cart_table_data_txt_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Table Data Text Color', 'profecient-essential' ),
			'segment'   => 'cart_table',
			'selectors' => '.woocommerce-cart-form table.shop_table td',
		);

		$this->options['cart_table_remove_icon_tabs_start'] = array(
			'type'    => 'control_tabs_start',
			'segment' => 'cart_table',
		);

		$this->options['cart_table_remove_icon_normal_tab_start'] = array(
			'type'    => 'control_tab_start',
			'title'   => esc_html__( 'Normal', 'profecient-essential' ),
			'segment' => 'cart_table',
		);

		$this->options['cart_table_remove_icon_normal_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Remove Icon Color', 'profecient-essential' ),
			'segment'   => 'cart_table',
			'selectors' => array(
				'custom' => array(
					'{{WRAPPER}}  .woocommerce-cart-form .profecient-woocommerce-cart-wrapper table a.remove'    => 'color: {{VALUE}} !important;',
				),
			),
		);

		$this->options['cart_table_remove_icon_normal_background'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Remove Icon Background', 'profecient-essential' ),
			'segment'   => 'cart_table',
			'selectors' => array(
				'custom' => array(
					'{{WRAPPER}}  .woocommerce-cart-form .profecient-woocommerce-cart-wrapper table a.remove'    => 'background: {{VALUE}} !important;',
				),
			),
		);

		$this->options['cart_table_remove_icon_normal_tab_end'] = array(
			'type'    => 'control_tab_end',
			'segment' => 'cart_table',
		);

		$this->options['cart_table_remove_icon_hover_tab_start'] = array(
			'type'    => 'control_tab_start',
			'title'   => esc_html__( 'Hover', 'profecient-essential' ),
			'segment' => 'cart_table',
		);

		$this->options['cart_table_remove_icon_hover_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Remove Icon Color', 'profecient-essential' ),
			'segment'   => 'cart_table',
			'selectors' => array(
				'custom' => array(
					'{{WRAPPER}}  .woocommerce-cart-form .profecient-woocommerce-cart-wrapper table a.remove:hover'  => 'color: {{VALUE}} !important;',
				),
			),
		);

		$this->options['cart_table_remove_icon_normal_hover_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Remove Icon Background', 'profecient-essential' ),
			'segment'   => 'cart_table',
			'selectors' => array(
				'custom' => array(
					'{{WRAPPER}}  .woocommerce-cart-form .profecient-woocommerce-cart-wrapper table a.remove:hover'  => 'background: {{VALUE}} !important;',
				),
			),
		);

		$this->options['cart_table_remove_icon_hover_tab_end'] = array(
			'type'    => 'control_tab_end',
			'segment' => 'cart_table',
		);

		$this->options['cart_table_remove_icon_tabs_end'] = array(
			'type'    => 'control_tabs_end',
			'segment' => 'cart_table',
		);

		$this->options['cart_table_image_width'] = array(
			'type'       => 'slider',
			'title'      => esc_html__( 'Image Width', 'profecient-essential' ),
			'segment'    => 'cart_table',
			'responsive' => true,
			'units'      => array( 'px', '%', 'em' ),
			'options'    => array(
				'min'  => 0,
				'max'  => 300,
				'step' => 1,
			),
			'selectors'  => '.woocommerce-cart-form table.shop_table .cart_item img',
			'attribute'  => 'width',
		);

		/** IM HERE */

		$this->options['cart_table_form_input_heading'] = array(
			'type'      => 'heading',
			'title'     => esc_html__( 'Input', 'profecient-essential' ),
			'segment'   => 'cart_table',
			'separator' => 'before',
		);

		$this->options['cart_table_form_input_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Form Input Color', 'profecient-essential' ),
			'segment'   => 'cart_table',
			'selectors' => '.woocommerce-cart-form .profecient-woocommerce-cart-wrapper table .cart_item td .quantity .qty',
		);

		$this->options['cart_table_form_input_background'] = array(
			'type'      => 'background',
			'title'     => esc_html__( 'Background', 'profecient-essential' ),
			'segment'   => 'cart_table',
			'selectors' => '.woocommerce-cart-form .profecient-woocommerce-cart-wrapper table .cart_item td .quantity .qty',
			'options'   => array(
				'classic',
				'gradient',
			),
			'exclude'   => array( 'image' ),
		);

		$this->options['cart_table_form_input_width'] = array(
			'type'       => 'slider',
			'title'      => esc_html__( 'Width', 'profecient-essential' ),
			'segment'    => 'cart_table',
			'responsive' => true,
			'units'      => array( 'px', '%', 'em' ),
			'options'    => array(
				'min'  => 0,
				'max'  => 300,
				'step' => 1,
			),
			'selectors'  => '.woocommerce-cart-form .profecient-woocommerce-cart-wrapper table .cart_item td .quantity .qty',
			'attribute'  => 'width',
		);

		$this->options['cart_table_form_input_border'] = array(
			'type'      => 'border',
			'title'     => esc_html__( 'Input Border', 'profecient-essential' ),
			'segment'   => 'cart_table',
			'selectors' => '.woocommerce-cart-form .profecient-woocommerce-cart-wrapper table .cart_item td .quantity .qty',
		);

		$this->options['cart_table_form_input_border_radius'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Input Border Radius', 'profecient-essential' ),
			'segment'   => 'cart_table',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.woocommerce-cart-form .profecient-woocommerce-cart-wrapper table .cart_item td .quantity .qty',
			'attribute' => 'border-radius',
		);

		$this->options['cart_table_form_input_padding'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Input Padding', 'profecient-essential' ),
			'segment'   => 'cart_table',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.woocommerce-cart-form .profecient-woocommerce-cart-wrapper table .cart_item td .quantity .qty',
			'attribute' => 'padding',
		);
		/* ----- Checkout Cart Table Segment ----- */

		/* ----- Coupon Code Section Segment ----- */
		$this->options['coupon_code_section_wrapper_box_shadow'] = array(
			'type'      => 'boxshadow',
			'title'     => esc_html__( 'Wrapper Box Shadow', 'profecient-essential' ),
			'segment'   => 'coupon_code_section',
			'selectors' => '.woocommerce-cart-form .coupon-col',
		);

		$this->options['coupon_code_section_border'] = array(
			'type'      => 'border',
			'title'     => esc_html__( 'Table Wrapper Border', 'profecient-essential' ),
			'segment'   => 'coupon_code_section',
			'selectors' => '.woocommerce-cart-form .coupon-col',
		);

		$this->options['coupon_code_section_border_radius'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Wrapper Border Radius', 'profecient-essential' ),
			'segment'   => 'coupon_code_section',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.woocommerce-cart-form .coupon-col',
			'attribute' => 'border-radius',
		);

		$this->options['coupon_code_section_background'] = array(
			'type'      => 'background',
			'title'     => esc_html__( 'Background Color', 'profecient-essential' ),
			'segment'   => 'coupon_code_section',
			'selectors' => '.woocommerce-cart-form .coupon-col',
			'options'   => array(
				'classic',
				'gradient',
			),
			'exclude'   => array( 'image' ),
		);

		$this->options['coupon_code_section_padding'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Wrapper Padding', 'profecient-essential' ),
			'segment'   => 'coupon_code_section',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.woocommerce-cart-form .coupon-col',
			'attribute' => 'padding',
		);

		$this->options['coupon_code_section_margin'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Wrapper Margin', 'profecient-essential' ),
			'segment'   => 'coupon_code_section',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.woocommerce-cart-form .coupon-col',
			'attribute' => 'margin',
		);

		$this->options['coupon_code_section_input_typography'] = array(
			'type'      => 'typography',
			'title'     => esc_html__( 'Form Input Typography', 'profecient-essential' ),
			'segment'   => 'coupon_code_section',
			'selectors' => '.woocommerce-cart-form .coupon-col input',
		);

		$this->options['coupon_code_section_input_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Form Input Color', 'profecient-essential' ),
			'segment'   => 'coupon_code_section',
			'selectors' => '.woocommerce-cart-form .coupon-col input',
		);

		$this->options['coupon_code_section_input_background'] = array(
			'type'      => 'background',
			'title'     => esc_html__( 'Background', 'profecient-essential' ),
			'segment'   => 'coupon_code_section',
			'selectors' => '.woocommerce-cart-form .coupon-col input',
			'options'   => array(
				'classic',
				'gradient',
			),
			'exclude'   => array( 'image' ),
		);

		$this->options['coupon_code_section_input_border'] = array(
			'type'      => 'border',
			'title'     => esc_html__( 'Input Border', 'profecient-essential' ),
			'segment'   => 'coupon_code_section',
			'selectors' => '.woocommerce-cart-form .coupon-col input',
		);

		$this->options['coupon_code_section_input_border_radius'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Input Border Radius', 'profecient-essential' ),
			'segment'   => 'coupon_code_section',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.woocommerce-cart-form .coupon-col input',
			'attribute' => 'border-radius',
		);

		$this->options['coupon_code_section_input_padding'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Input Padding', 'profecient-essential' ),
			'segment'   => 'coupon_code_section',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.woocommerce-cart-form .coupon-col input',
			'attribute' => 'padding',
		);
		/* ----- Coupon Code Section Segment ----- */

		/* ----- Checkout Total Table Segment ----- */
		$this->options['total_table_wrapper_box_shadow'] = array(
			'type'      => 'boxshadow',
			'title'     => esc_html__( 'Wrapper Box Shadow', 'profecient-essential' ),
			'segment'   => 'total_table',
			'selectors' => '.cart-collaterals .cart_totals',
		);

		$this->options['total_table_wrapper_border'] = array(
			'type'      => 'border',
			'title'     => esc_html__( 'Table Outer Border', 'profecient-essential' ),
			'segment'   => 'total_table',
			'selectors' => '.cart-collaterals .cart_totals',
		);

		$this->options['total_table_wrapper_border_radius'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Wrapper Border Radius', 'profecient-essential' ),
			'segment'   => 'total_table',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.cart-collaterals .cart_totals',
			'attribute' => 'border-radius',
		);

		$this->options['total_table_wrapper_background'] = array(
			'type'      => 'background',
			'title'     => esc_html__( 'Background Color', 'profecient-essential' ),
			'segment'   => 'total_table',
			'selectors' => '.cart-collaterals .cart_totals',
			'options'   => array(
				'classic',
				'gradient',
			),
			'exclude'   => array( 'image' ),
		);

		$this->options['total_table_wrapper_padding'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Wrapper Padding', 'profecient-essential' ),
			'segment'   => 'total_table',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.cart-collaterals .cart_totals',
			'attribute' => 'padding',
		);

		$this->options['total_table_wrapper_margin'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Wrapper Margin', 'profecient-essential' ),
			'segment'   => 'total_table',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.cart-collaterals .cart_totals',
			'attribute' => 'margin',
		);

		$this->options['total_table_float'] = array(
			'type'       => 'radio',
			'title'      => esc_html__( 'Table Float', 'profecient-essential' ),
			'segment'    => 'total_table',
			'selectors'  => '.cart_totals',
			'dependency' => array(
				array(
					'field'    => 'layout_type',
					'operator' => '==',
					'value'    => 'layout-2',
				),
			),
			'options'    => array(
				'left'  => array(
					'title' => esc_html__( 'Left', 'profecient-essential' ),
					'icon'  => 'fas fa-align-left',
				),
				'right' => array(
					'title' => esc_html__( 'Right', 'profecient-essential' ),
					'icon'  => 'fas fa-align-right',
				),
			),
			'default'    => 'right',
			'attribute'  => 'float',
		);

		$this->options['total_table_width'] = array(
			'type'         => 'slider',
			'title'        => esc_html__( 'Table Width', 'profecient-essential' ),
			'segment'      => 'total_table',
			'default_unit' => '%',
			'default'      => 100,
			'units'        => array( '%' ),
			'options'      => array(
				'min'  => 0,
				'max'  => 100,
				'step' => 1,
			),
			'selectors'    => '.cart_totals',
			'attribute'    => 'width',
			'responsive'   => true,
		);

		$this->options['total_table_heading_typography'] = array(
			'type'      => 'typography',
			'title'     => esc_html__( 'Table Heading', 'profecient-essential' ),
			'segment'   => 'total_table',
			'selectors' => '.woocommerce div.cart-collaterals div.cart_totals h2',
		);

		$this->options['total_table_heading_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Table Heading', 'profecient-essential' ),
			'segment'   => 'total_table',
			'global'    => array(
				'default' => parent::get_global_style_option( 'h2_color' ),
			),
			'selectors' => '.cart_totals h2',
		);

		$this->options['total_table_heading_align'] = array(
			'type'      => 'radio',
			'title'     => esc_html__( 'Heading Alignment', 'profecient-essential' ),
			'segment'   => 'total_table',
			'options'   => array(
				'left'   => array(
					'title' => esc_html__( 'Left', 'profecient-essential' ),
					'icon'  => 'fas fa-align-left',
				),
				'center' => array(
					'title' => esc_html__( 'Center', 'profecient-essential' ),
					'icon'  => 'fas fa-align-center',
				),
				'right'  => array(
					'title' => esc_html__( 'Right', 'profecient-essential' ),
					'icon'  => 'fas fa-align-right',
				),
			),
			'default'   => 'left',
			'selectors' => '.cart-collaterals .cart_totals h2',
			'attribute' => 'text-align',
		);

		$this->options['total_table_outer_border'] = array(
			'type'      => 'border',
			'title'     => esc_html__( 'Table Outer Border', 'profecient-essential' ),
			'segment'   => 'total_table',
			'selectors' => '.cart_totals table.shop_table',
		);

		$this->options['total_table_head_border'] = array(
			'type'      => 'border',
			'title'     => esc_html__( 'Total Table Head Border', 'profecient-essential' ),
			'segment'   => 'total_table',
			'selectors' => '.cart_totals table.shop_table th, {{WRAPPER}} .cart_totals table.shop_table tr td:before',
		);

		$this->options['total_table_heading_txt'] = array(
			'type'      => 'typography',
			'title'     => esc_html__( 'Table Head Text', 'profecient-essential' ),
			'segment'   => 'total_table',
			'selectors' => '.cart_totals table.shop_table th, {{WRAPPER}} .cart_totals table.shop_table tr td:before',
		);

		$this->options['total_table_head_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Head Text color', 'profecient-essential' ),
			'segment'   => 'total_table',
			'selectors' => '.cart_totals table.shop_table th, {{WRAPPER}} .cart_totals table.shop_table tr td:before',
		);

		$this->options['total_table_data_border'] = array(
			'type'      => 'border',
			'title'     => esc_html__( 'Table Data Border', 'profecient-essential' ),
			'segment'   => 'total_table',
			'selectors' => '.cart_totals table.shop_table td',
		);

		$this->options['total_table_data_typography'] = array(
			'type'      => 'typography',
			'title'     => esc_html__( 'Table Data Text', 'profecient-essential' ),
			'segment'   => 'total_table',
			'selectors' => '.cart_totals table.shop_table td',
		);

		$this->options['total_table_data_txt_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Data Text Color', 'profecient-essential' ),
			'segment'   => 'total_table',
			'selectors' => '.cart_totals table.shop_table td',
		);
		/* ----- Checkout Total Table Segment ----- */

		/* ----- Button Segment ----- */
		$this->options['button_normal_typography'] = array(
			'type'      => 'typography',
			'title'     => esc_html__( 'Button Typograhpy', 'profecient-essential' ),
			'segment'   => 'button_style',
			'global'    => array(
				'default' => $global_button_typography,
			),
			'selectors' => 'button[name="update_cart"], {{WRAPPER}} .coupon button, {{WRAPPER}} .wc-proceed-to-checkout a.button.alt',
		);
		/* ----- Button Segment ----- */

		/* ----- Update Cart Button Segment ----- */
		$this->options['update_cart_button_tabs_start'] = array(
			'type'    => 'control_tabs_start',
			'segment' => 'update_cart_style_button',
		);

		$this->options['update_cart_button_normal_tab_start'] = array(
			'type'    => 'control_tab_start',
			'title'   => esc_html__( 'Normal', 'profecient-essential' ),
			'segment' => 'update_cart_style_button',
		);

		$this->options['update_cart_button_normal_box_shadow'] = array(
			'type'      => 'boxshadow',
			'title'     => esc_html__( 'Box Shadow', 'profecient-essential' ),
			'segment'   => 'update_cart_style_button',
			'selectors' => 'td.actions button.button',
		);

		$this->options['update_cart_button_normal_border'] = array(
			'type'      => 'border',
			'title'     => esc_html__( 'Border', 'profecient-essential' ),
			'segment'   => 'update_cart_style_button',
			'selectors' => 'td.actions button.button',
		);

		$this->options['update_cart_button_normal_border_radius'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Border Radius', 'profecient-essential' ),
			'segment'   => 'update_cart_style_button',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => 'td.actions button.button',
			'attribute' => 'border-radius',
		);

		$this->options['update_cart_button_normal_margin'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Button Margin', 'profecient-essential' ),
			'segment'   => 'update_cart_style_button',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => 'button[name="update_cart"]',
			'attribute' => 'margin',
		);

		$this->options['update_cart_normal_padding'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Button Padding', 'profecient-essential' ),
			'segment'   => 'update_cart_style_button',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => 'button[name="update_cart"]',
			'attribute' => 'padding',
		);

		$this->options['update_cart_button_normal_background'] = array(
			'type'           => 'background',
			'title'          => esc_html__( 'Button Background', 'profecient-essential' ),
			'segment'        => 'update_cart_style_button',
			'selectors'      => '.woocommerce .woocommerce-cart-form td.actions button.button',
			'fields_options' => array(
				'background' => array(
					'default' => 'classic',
				),
				'color'      => array(
					'global' => array(
						'default' => $global_button_background,
					),
				),
			),
			'options'        => array(
				'classic',
				'gradient',
			),
			'exclude'        => array( 'image' ),
		);

		$this->options['update_cart_button_normal_text_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Text Color', 'profecient-essential' ),
			'segment'   => 'update_cart_style_button',
			'global'    => array(
				'default' => $global_button_text,
			),
			'selectors' => '.woocommerce .woocommerce-cart-form td.actions button.button',
		);

		$this->options['update_cart_button_normal_tab_end'] = array(
			'type'    => 'control_tab_end',
			'segment' => 'update_cart_style_button',
		);

		$this->options['update_cart_button_hover_tab_start'] = array(
			'type'    => 'control_tab_start',
			'title'   => esc_html__( 'Hover', 'profecient-essential' ),
			'segment' => 'update_cart_style_button',
		);

		$this->options['update_cart_button_hover_box_shadow'] = array(
			'type'      => 'boxshadow',
			'title'     => esc_html__( 'Box Shadow', 'profecient-essential' ),
			'segment'   => 'update_cart_style_button',
			'selectors' => '.woocommerce .woocommerce-cart-form td.actions button.button:hover',
		);

		$this->options['update_cart_button_hover_border'] = array(
			'type'      => 'border',
			'title'     => esc_html__( 'Border', 'profecient-essential' ),
			'segment'   => 'update_cart_style_button',
			'selectors' => '.woocommerce .woocommerce-cart-form td.actions button.button:hover',
		);

		$this->options['update_cart_button_hover_border_radius'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Border Radius', 'profecient-essential' ),
			'segment'   => 'update_cart_style_button',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.woocommerce .woocommerce-cart-form td.actions button.button:hover',
			'attribute' => 'border-radius',
		);

		$this->options['update_cart_button_hover_margin'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Button Margin', 'profecient-essential' ),
			'segment'   => 'update_cart_style_button',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.woocommerce .woocommerce-cart-form td.actions button.button:hover',
			'attribute' => 'margin',
		);

		$this->options['update_cart_hover_padding'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Button Padding', 'profecient-essential' ),
			'segment'   => 'update_cart_style_button',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.woocommerce .woocommerce-cart-form td.actions button.button:hover',
			'attribute' => 'padding',
		);

		$this->options['update_cart_button_hover_background'] = array(
			'type'           => 'background',
			'title'          => esc_html__( 'Background', 'profecient-essential' ),
			'segment'        => 'update_cart_style_button',
			'selectors'      => '.woocommerce .woocommerce-cart-form td.actions button.button:hover',
			'fields_options' => array(
				'background' => array(
					'default' => 'classic',
				),
				'color'      => array(
					'global' => array(
						'default' => $global_button_hover_background,
					),
				),
			),
			'options'        => array(
				'classic',
				'gradient',
			),
			'exclude'        => array( 'image' ),
		);

		$this->options['update_cart_button_hover_text_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Text Color', 'profecient-essential' ),
			'segment'   => 'update_cart_style_button',
			'selectors' => '.woocommerce .woocommerce-cart-form td.actions button.button:hover',
			'global'    => array(
				'default' => $global_button_text,
			),
		);

		$this->options['update_cart_button_hover_tab_end'] = array(
			'type'    => 'control_tab_end',
			'segment' => 'update_cart_style_button',
		);

		$this->options['update_cart_button_disabled_tab_start'] = array(
			'type'    => 'control_tab_start',
			'title'   => esc_html__( 'Disabled', 'profecient-essential' ),
			'segment' => 'update_cart_style_button',
		);

		$this->options['update_cart_button_disabled_background'] = array(
			'type'           => 'background',
			'title'          => esc_html__( 'Background', 'profecient-essential' ),
			'segment'        => 'update_cart_style_button',
			'selectors'      => '.woocommerce .woocommerce-cart-form td.actions button.button:disabled[disabled]',
			'fields_options' => array(
				'background' => array(
					'default' => 'classic',
				),
				'color'      => array(
					'global' => array(
						'default' => $global_button_background,
					),
				),
			),
			'options'        => array(
				'classic',
				'gradient',
			),
			'exclude'        => array( 'image' ),
		);

		$this->options['update_cart_button_disabled_text_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Text Color', 'profecient-essential' ),
			'segment'   => 'update_cart_style_button',
			'selectors' => '.woocommerce .woocommerce-cart-form td.actions button.button:disabled[disabled]',
			'global'    => array(
				'default' => $global_button_text,
			),
		);

		$this->options['update_cart_button_disabled_tab_end'] = array(
			'type'    => 'control_tab_end',
			'segment' => 'update_cart_style_button',
		);

		$this->options['update_cart_button_tabs_end'] = array(
			'type'    => 'control_tabs_end',
			'segment' => 'update_cart_style_button',
		);
		/* ----- Update Cart Button Segment ----- */

		/* ----- Apply Coupon Button Segment ----- */
		$this->options['apply_coupon_button_tabs_start'] = array(
			'type'    => 'control_tabs_start',
			'segment' => 'apply_coupon_style_button',
		);

		$this->options['apply_coupon_button_normal_tab_start'] = array(
			'type'    => 'control_tab_start',
			'title'   => esc_html__( 'Normal', 'profecient-essential' ),
			'segment' => 'apply_coupon_style_button',
		);

		$this->options['apply_coupon_button_normal_box_shadow'] = array(
			'type'      => 'boxshadow',
			'title'     => esc_html__( 'Box Shadow', 'profecient-essential' ),
			'segment'   => 'apply_coupon_style_button',
			'selectors' => '.coupon button.button',
		);

		$this->options['apply_coupon_button_normal_border'] = array(
			'type'      => 'border',
			'title'     => esc_html__( 'Border', 'profecient-essential' ),
			'segment'   => 'apply_coupon_style_button',
			'selectors' => '.coupon button.button',
		);

		$this->options['apply_coupon_button_normal_border_radius'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Border Radius', 'profecient-essential' ),
			'segment'   => 'apply_coupon_style_button',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.coupon button.button',
			'attribute' => 'border-radius',
		);

		$this->options['apply_coupon_button_normal_margin'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Button Margin', 'profecient-essential' ),
			'segment'   => 'apply_coupon_style_button',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.coupon button',
			'attribute' => 'margin',
		);

		$this->options['apply_coupon_button_normal_padding'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Button Padding', 'profecient-essential' ),
			'segment'   => 'apply_coupon_style_button',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.coupon button',
			'attribute' => 'padding',
		);

		$this->options['apply_coupon_button_normal_background'] = array(
			'type'           => 'background',
			'title'          => esc_html__( 'Button Background', 'profecient-essential' ),
			'segment'        => 'apply_coupon_style_button',
			'selectors'      => '.woocommerce .coupon .coupon-col .coupon-col-end button.button',
			'fields_options' => array(
				'background' => array(
					'default' => 'classic',
				),
				'color'      => array(
					'global' => array(
						'default' => $global_button_background,
					),
				),
			),
			'options'        => array(
				'classic',
				'gradient',
			),
			'exclude'        => array( 'image' ),
		);

		$this->options['apply_coupon_button_normal_text_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Text Color', 'profecient-essential' ),
			'segment'   => 'apply_coupon_style_button',
			'selectors' => '.woocommerce .coupon .coupon-col .coupon-col-end button.button',
			'global'    => array(
				'default' => $global_button_text,
			),
		);

		$this->options['apply_coupon_button_normal_tab_end'] = array(
			'type'    => 'control_tab_end',
			'segment' => 'apply_coupon_style_button',
		);

		$this->options['apply_coupon_button_hover_tab_start'] = array(
			'type'    => 'control_tab_start',
			'title'   => esc_html__( 'Hover', 'profecient-essential' ),
			'segment' => 'apply_coupon_style_button',
		);

		$this->options['apply_coupon_button_hover_box_shadow'] = array(
			'type'      => 'boxshadow',
			'title'     => esc_html__( 'Box Shadow', 'profecient-essential' ),
			'segment'   => 'apply_coupon_style_button',
			'selectors' => '.woocommerce .coupon .coupon-col .coupon-col-end button.button:hover',
		);

		$this->options['apply_coupon_button_hover_border'] = array(
			'type'      => 'border',
			'title'     => esc_html__( 'Border', 'profecient-essential' ),
			'segment'   => 'apply_coupon_style_button',
			'selectors' => '.woocommerce .coupon .coupon-col .coupon-col-end button.button:hover',
		);

		$this->options['apply_coupon_button_hover_border_radius'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Border Radius', 'profecient-essential' ),
			'segment'   => 'apply_coupon_style_button',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.woocommerce .coupon .coupon-col .coupon-col-end button.button:hover',
			'attribute' => 'border-radius',
		);

		$this->options['apply_coupon_button_hover_margin'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Button Margin', 'profecient-essential' ),
			'segment'   => 'apply_coupon_style_button',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.woocommerce .coupon .coupon-col .coupon-col-end button.button:hover',
			'attribute' => 'margin',
		);

		$this->options['apply_coupon_button_hover_padding'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Button Padding', 'profecient-essential' ),
			'segment'   => 'apply_coupon_style_button',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.woocommerce .coupon .coupon-col .coupon-col-end button.button:hover',
			'attribute' => 'padding',
		);

		$this->options['apply_coupon_button_hover_background'] = array(
			'type'           => 'background',
			'title'          => esc_html__( 'Background', 'profecient-essential' ),
			'segment'        => 'apply_coupon_style_button',
			'selectors'      => '.woocommerce .coupon .coupon-col .coupon-col-end button.button:hover',
			'options'        => array(
				'classic',
				'gradient',
			),
			'fields_options' => array(
				'background' => array(
					'default' => 'classic',
				),
				'color'      => array(
					'global' => array(
						'default' => $global_button_hover_background,
					),
				),
			),
			'exclude'        => array( 'image' ),
		);

		$this->options['apply_coupon_button_hover_text_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Text Color', 'profecient-essential' ),
			'segment'   => 'apply_coupon_style_button',
			'selectors' => '.woocommerce .coupon .coupon-col .coupon-col-end button.button:hover',
			'global'    => array(
				'default' => $global_button_text,
			),
		);

		$this->options['apply_coupon_button_hover_tab_end'] = array(
			'type'    => 'control_tab_end',
			'segment' => 'apply_coupon_style_button',
		);

		$this->options['apply_coupon_button_tabs_end'] = array(
			'type'    => 'control_tabs_end',
			'segment' => 'apply_coupon_style_button',
		);
		/* ----- Apply Coupon Button Segment ----- */

		/* ----- Proceed to checkout Button Segment ----- */
		$this->options['proceed_checkout_button_tabs_start'] = array(
			'type'    => 'control_tabs_start',
			'segment' => 'proceed_style_button',
		);

		$this->options['proceed_checkout_button_normal_tab_start'] = array(
			'type'    => 'control_tab_start',
			'title'   => esc_html__( 'Normal', 'profecient-essential' ),
			'segment' => 'proceed_style_button',
		);

		$this->options['proceed_checkout_button_normal_box_shadow'] = array(
			'type'      => 'boxshadow',
			'title'     => esc_html__( 'Box Shadow', 'profecient-essential' ),
			'segment'   => 'proceed_style_button',
			'selectors' => '.wc-proceed-to-checkout a.button.alt',
		);

		$this->options['proceed_checkout_button_normal_border'] = array(
			'type'      => 'border',
			'title'     => esc_html__( 'Border', 'profecient-essential' ),
			'segment'   => 'proceed_style_button',
			'selectors' => '.wc-proceed-to-checkout a.button.alt',
		);

		$this->options['proceed_checkout_button_normal_border_radius'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Border Radius', 'profecient-essential' ),
			'segment'   => 'proceed_style_button',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.wc-proceed-to-checkout a.button.alt',
			'attribute' => 'border-radius',
		);

		$this->options['proceed_checkout_button_normal_margin'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Button Margin', 'profecient-essential' ),
			'segment'   => 'proceed_style_button',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.wc-proceed-to-checkout a.button.alt',
			'attribute' => 'margin',
		);

		$this->options['proceed_checkout_button_normal_padding'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Button Padding', 'profecient-essential' ),
			'segment'   => 'proceed_style_button',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.wc-proceed-to-checkout a.button.alt',
			'attribute' => 'padding',
		);

		$this->options['proceed_checkout_button_background'] = array(
			'type'           => 'background',
			'title'          => esc_html__( 'Button Background', 'profecient-essential' ),
			'segment'        => 'proceed_style_button',
			'selectors'      => '.woocommerce .cart-collaterals .cart_totals .wc-proceed-to-checkout  a.button.alt',
			'fields_options' => array(
				'background' => array(
					'default' => 'classic',
				),
				'color'      => array(
					'global' => array(
						'default' => $global_button_background,
					),
				),
			),
			'options'        => array(
				'classic',
				'gradient',
			),
			'exclude'        => array( 'image' ),
		);

		$this->options['proceed_checkout_button_normal_text_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Text Color', 'profecient-essential' ),
			'segment'   => 'proceed_style_button',
			'selectors' => '.woocommerce .cart-collaterals .cart_totals .wc-proceed-to-checkout  a.button.alt',
			'global'    => array(
				'default' => $global_button_text,
			),
		);

		$this->options['proceed_checkout_button_normal_tab_end'] = array(
			'type'    => 'control_tab_end',
			'segment' => 'proceed_style_button',
		);

		$this->options['proceed_checkout_button_hover_tab_start'] = array(
			'type'    => 'control_tab_start',
			'title'   => esc_html__( 'Hover', 'profecient-essential' ),
			'segment' => 'proceed_style_button',
		);

		$this->options['proceed_checkout_button_hover_box_shadow'] = array(
			'type'      => 'boxshadow',
			'title'     => esc_html__( 'Box Shadow', 'profecient-essential' ),
			'segment'   => 'proceed_style_button',
			'selectors' => '.woocommerce .cart-collaterals .cart_totals .wc-proceed-to-checkout  a.button.alt:hover',
		);

		$this->options['proceed_checkout_button_hover_border'] = array(
			'type'      => 'border',
			'title'     => esc_html__( 'Border', 'profecient-essential' ),
			'segment'   => 'proceed_style_button',
			'selectors' => '.woocommerce .cart-collaterals .cart_totals .wc-proceed-to-checkout  a.button.alt:hover',
		);

		$this->options['proceed_checkout_button_hover_border_radius'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Border Radius', 'profecient-essential' ),
			'segment'   => 'proceed_style_button',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.woocommerce .cart-collaterals .cart_totals .wc-proceed-to-checkout  a.button.alt:hover',
			'attribute' => 'border-radius',
		);

		$this->options['proceed_checkout_button_hover_margin'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Button Margin', 'profecient-essential' ),
			'segment'   => 'proceed_style_button',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.woocommerce .cart-collaterals .cart_totals .wc-proceed-to-checkout  a.button.alt:hover',
			'attribute' => 'margin',
		);

		$this->options['proceed_checkout_button_hover_padding'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Button Padding', 'profecient-essential' ),
			'segment'   => 'proceed_style_button',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.woocommerce .cart-collaterals .cart_totals .wc-proceed-to-checkout  a.button.alt:hover',
			'attribute' => 'padding',
		);

		$this->options['proceed_checkout_button_hover_background'] = array(
			'type'           => 'background',
			'title'          => esc_html__( 'Background', 'profecient-essential' ),
			'segment'        => 'proceed_style_button',
			'selectors'      => '.woocommerce .cart-collaterals .cart_totals .wc-proceed-to-checkout  a.button.alt:hover',
			'fields_options' => array(
				'background' => array(
					'default' => 'classic',
				),
				'color'      => array(
					'global' => array(
						'default' => $global_button_hover_background,
					),
				),
			),
			'options'        => array(
				'classic',
				'gradient',
			),
			'exclude'        => array( 'image' ),
		);

		$this->options['proceed_checkout_button_hover_text_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Text Color', 'profecient-essential' ),
			'segment'   => 'proceed_style_button',
			'selectors' => '.woocommerce .cart-collaterals .cart_totals .wc-proceed-to-checkout  a.button.alt:hover',
			'global'    => array(
				'default' => $global_button_text,
			),
		);

		$this->options['proceed_checkout_button_hover_tab_end'] = array(
			'type'    => 'control_tab_end',
			'segment' => 'proceed_style_button',
		);

		$this->options['proceed_checkout_button_disabled_tab_start'] = array(
			'type'    => 'control_tab_start',
			'title'   => esc_html__( 'Disabled', 'profecient-essential' ),
			'segment' => 'proceed_style_button',
		);

		$this->options['proceed_checkout_button_disabled_box_shadow'] = array(
			'type'      => 'boxshadow',
			'title'     => esc_html__( 'Box Shadow', 'profecient-essential' ),
			'segment'   => 'proceed_style_button',
			'selectors' => '.wc-proceed-to-checkout a.button.alt.disabled',
		);

		$this->options['proceed_checkout_button_disabled_border'] = array(
			'type'      => 'border',
			'title'     => esc_html__( 'Border', 'profecient-essential' ),
			'segment'   => 'proceed_style_button',
			'selectors' => '.wc-proceed-to-checkout a.button.alt.disabled',
		);

		$this->options['proceed_checkout_button_disabled_border_radius'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Border Radius', 'profecient-essential' ),
			'segment'   => 'proceed_style_button',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.wc-proceed-to-checkout a.button.alt.disabled',
			'attribute' => 'border-radius',
		);

		$this->options['proceed_checkout_button_disabled_margin'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Button Margin', 'profecient-essential' ),
			'segment'   => 'proceed_style_button',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.wc-proceed-to-checkout a.button.alt.disabled',
			'attribute' => 'margin',
		);

		$this->options['proceed_checkout_button_disabled_padding'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Button Padding', 'profecient-essential' ),
			'segment'   => 'proceed_style_button',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.wc-proceed-to-checkout a.button.alt.disabled',
			'attribute' => 'padding',
		);

		$this->options['proceed_checkout_button_disabled_text_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Text Color', 'profecient-essential' ),
			'segment'   => 'proceed_style_button',
			'selectors' => '.wc-proceed-to-checkout a.button.alt.disabled',
		);

		$this->options['proceed_checkout_button_disabled_background'] = array(
			'type'      => 'background',
			'title'     => esc_html__( 'Background', 'profecient-essential' ),
			'segment'   => 'proceed_style_button',
			'selectors' => '.wc-proceed-to-checkout a.button.alt.disabled',
			'options'   => array(
				'classic',
				'gradient',
			),
			'exclude'   => array( 'image' ),
		);

		$this->options['proceed_checkout_button_disabled_tab_end'] = array(
			'type'    => 'control_tab_end',
			'segment' => 'proceed_style_button',
		);

		$this->options['proceed_checkout_button_tabs_end'] = array(
			'type'    => 'control_tabs_end',
			'segment' => 'proceed_style_button',
		);
		/* ----- Proceed to checkout Button Segment ----- */
	}

	/**
	 * Add Additional Style.
	 */
	public function additional_style() {
		$this->style_option();

		parent::additional_style();
	}
}
