<?php
/**
 * Woocommerce Checkout Page Option Class
 *
 * @package profecient-essential
 * @author jegtheme
 * @since 1.0.0
 */

namespace Profecient\Essential\JKit\Elements\Options;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

use Jeg\Elementor_Kit\Elements\Options\Option_Abstract;

/**
 * Class Woocommerce_Checkout_Page_Option
 */
class Woocommerce_Checkout_Page_Option extends Option_Abstract {
	/**
	 * Show color scheme flag for element.
	 *
	 * @return bool
	 */
	public function show_color_scheme() {
		return false;
	}

	/**
	 * Compatibility column
	 *
	 * @return array
	 */
	public function compatible_column() {
		return array();
	}

	/**
	 * Override function to remove compatible column alert
	 */
	public function set_compatible_column_option() {}

	/**
	 * Element name
	 *
	 * @return string
	 */
	public function get_element_name() {
		return esc_html__( 'Checkout Page', 'profecient-essential' );
	}

	/**
	 * Element category
	 *
	 * @return string
	 */
	public function get_category() {
		return esc_html__( 'Profecient - Woocommerce', 'profecient-essential' );
	}

	/**
	 * Element options
	 */
	public function set_options() {
		$this->set_style_option();

		parent::set_options();
	}

	/**
	 * Option segments
	 */
	public function set_segments() {
		$this->set_style_segment();
	}

	/**
	 * Style segments
	 */
	public function set_style_segment() {
		$this->segments['layout'] = array(
			'name'      => esc_html__( 'Layout', 'profecient-essential' ),
			'priority'  => 11,
			'kit_style' => true,
		);

		$this->segments['form_coupon'] = array(
			'name'      => esc_html__( 'Form Coupon', 'profecient-essential' ),
			'priority'  => 11,
			'kit_style' => true,
		);

		$this->segments['form_coupon_button'] = array(
			'name'      => esc_html__( 'Apply Button', 'profecient-essential' ),
			'priority'  => 11,
			'kit_style' => true,
		);

		$this->segments['checkout_form'] = array(
			'name'      => esc_html__( 'Checkout Form', 'profecient-essential' ),
			'priority'  => 11,
			'kit_style' => true,
		);

		$this->segments['order_table'] = array(
			'name'      => esc_html__( 'Order Table', 'profecient-essential' ),
			'priority'  => 11,
			'kit_style' => true,
		);

		$this->segments['payment_method'] = array(
			'name'      => esc_html__( 'Payment Method', 'profecient-essential' ),
			'priority'  => 11,
			'kit_style' => true,
		);

		$this->segments['place_order'] = array(
			'name'      => esc_html__( 'Place Order', 'profecient-essential' ),
			'priority'  => 11,
			'kit_style' => true,
		);

		$this->segments['place_order_button'] = array(
			'name'      => esc_html__( 'Place Order Button', 'profecient-essential' ),
			'priority'  => 11,
			'kit_style' => true,
		);

		$this->segments['additional_information'] = array(
			'name'      => esc_html__( 'Additional Information', 'profecient-essential' ),
			'priority'  => 11,
			'kit_style' => true,
		);

		parent::set_style_segment();
	}

	public function style_option() {
		// cart product page style option
		$global_h3_color              = parent::get_global_style_option( 'h3_color' );
		$global_form_field_background = parent::get_global_style_option( 'form_field_background_color' );
		$global_button_background     = parent::get_global_style_option( 'button_background_color' );
		$global_button_text_color     = parent::get_global_style_option( 'button_text_color' );

		$this->options['layout_type'] = array(
			'type'    => 'select',
			'title'   => esc_html__( 'Layout Type', 'profecient-essential' ),
			'default' => 'layout-1',
			'segment' => 'layout',
			'options' => array(
				'layout-1' => 'Layout 1',
				'layout-2' => 'Layout 2',
			),
		);

		/* ----- Apply Button Segment ----- */
		$this->options['form_coupon_button_typography'] = array(
			'type'      => 'typography',
			'title'     => esc_html__( 'Button Typograhpy', 'profecient-essential' ),
			'segment'   => 'form_coupon_button',
			'selectors' => '.woocommerce-form-coupon-toggle .profecient-coupon-anchor .coupon-container-grid .woocommerce-button',
		);

		$this->options['form_coupon_button_tabs_start'] = array(
			'type'    => 'control_tabs_start',
			'segment' => 'form_coupon_button',
		);

		$this->options['form_coupon_button_normal_tab_start'] = array(
			'type'    => 'control_tab_start',
			'title'   => esc_html__( 'Normal', 'profecient-essential' ),
			'segment' => 'form_coupon_button',
		);

		$this->options['form_coupon_button_normal_box_shadow'] = array(
			'type'      => 'boxshadow',
			'title'     => esc_html__( 'Button Box Shadow', 'profecient-essential' ),
			'segment'   => 'form_coupon_button',
			'selectors' => '.woocommerce-form-coupon-toggle .profecient-coupon-anchor .coupon-container-grid .woocommerce-button',
		);

		$this->options['form_coupon_button_normal_border'] = array(
			'type'      => 'border',
			'title'     => esc_html__( 'Border button', 'profecient-essential' ),
			'segment'   => 'form_coupon_button',
			'selectors' => '.woocommerce-form-coupon-toggle .profecient-coupon-anchor .coupon-container-grid .woocommerce-button',
		);

		$this->options['form_coupon_button_normal_border_radius'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Border Radius', 'profecient-essential' ),
			'segment'   => 'form_coupon_button',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.woocommerce-form-coupon-toggle .profecient-coupon-anchor .coupon-container-grid .woocommerce-button',
			'attribute' => 'border-radius',
		);

		$this->options['form_coupon_button_normal_margin'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Button Margin', 'profecient-essential' ),
			'segment'   => 'form_coupon_button',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.woocommerce-form-coupon-toggle .profecient-coupon-anchor .coupon-container-grid .coupon-col-2',
			'attribute' => 'margin',
		);

		$this->options['form_coupon_button_normal_padding'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Button Padding', 'profecient-essential' ),
			'segment'   => 'form_coupon_button',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.woocommerce-form-coupon-toggle .profecient-coupon-anchor .coupon-container-grid .woocommerce-button',
			'attribute' => 'padding',
		);

		$this->options['form_coupon_button_normal_background'] = array(
			'type'           => 'background',
			'title'          => esc_html__( 'Button Background', 'profecient-essential' ),
			'segment'        => 'form_coupon_button',
			'selectors'      => '.woocommerce-form-coupon-toggle .profecient-coupon-anchor .coupon-container-grid .woocommerce-button',
			'fields_options' => array(
				'background' => array(
					'default' => 'classic',
				),
				'color'      => array(
					'global' => array(
						'default' => $global_button_background,
					),
				),
			),
			'options'        => array(
				'classic',
				'gradient',
			),
			'exclude'        => array( 'image' ),
		);

		$this->options['form_coupon_button_normal_text_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Text Color', 'profecient-essential' ),
			'segment'   => 'form_coupon_button',
			'global'    => array(
				'default' => $global_button_text_color,
			),
			'selectors' => '.profecient-sticky-right-column .woocommerce-form-coupon-toggle .profecient-coupon-anchor .coupon-container-grid .coupon-col-2 button.woocommerce-button',
		);

		$this->options['form_coupon_button_normal_tab_end'] = array(
			'type'    => 'control_tab_end',
			'segment' => 'form_coupon_button',
		);

		$this->options['form_coupon_button_hover_tab_start'] = array(
			'type'    => 'control_tab_start',
			'title'   => esc_html__( 'Hover', 'profecient-essential' ),
			'segment' => 'form_coupon_button',
		);

		$this->options['form_coupon_button_hover_box_shadow'] = array(
			'type'      => 'boxshadow',
			'title'     => esc_html__( 'Button Box Shadow', 'profecient-essential' ),
			'segment'   => 'form_coupon_button',
			'selectors' => '.woocommerce-form-coupon-toggle .profecient-coupon-anchor .coupon-container-grid .woocommerce-button:hover',
		);

		$this->options['form_coupon_button_hover_border'] = array(
			'type'      => 'border',
			'title'     => esc_html__( 'Border button', 'profecient-essential' ),
			'segment'   => 'form_coupon_button',
			'selectors' => '.woocommerce-form-coupon-toggle .profecient-coupon-anchor .coupon-container-grid .woocommerce-button:hover',
		);

		$this->options['form_coupon_button_hover_border_radius'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Border Radius', 'profecient-essential' ),
			'segment'   => 'form_coupon_button',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.woocommerce-form-coupon-toggle .profecient-coupon-anchor .coupon-container-grid .woocommerce-button:hover',
			'attribute' => 'border-radius',
		);

		$this->options['form_coupon_button_hover_margin'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Button Margin', 'profecient-essential' ),
			'segment'   => 'form_coupon_button',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.woocommerce-form-coupon-toggle .profecient-coupon-anchor .coupon-container-grid .coupon-col-2:hover',
			'attribute' => 'margin',
		);

		$this->options['form_coupon_button_hover_padding'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Button Padding', 'profecient-essential' ),
			'segment'   => 'form_coupon_button',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.woocommerce-form-coupon-toggle .profecient-coupon-anchor .coupon-container-grid .woocommerce-button:hover',
			'attribute' => 'padding',
		);

		$this->options['form_coupon_button_hover_background'] = array(
			'type'           => 'background',
			'title'          => esc_html__( 'Button Background', 'profecient-essential' ),
			'segment'        => 'form_coupon_button',
			'selectors'      => '.woocommerce-form-coupon-toggle .profecient-coupon-anchor .coupon-container-grid .woocommerce-button:hover',
			'fields_options' => array(
				'background' => array(
					'default' => 'classic',
				),
				'color'      => array(
					'global' => array(
						'default' => $global_button_background,
					),
				),
			),
			'options'        => array(
				'classic',
				'gradient',
			),
			'exclude'        => array( 'image' ),
		);

		$this->options['form_coupon_button_hover_text_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Text Color', 'profecient-essential' ),
			'segment'   => 'form_coupon_button',
			'global'    => array(
				'default' => $global_button_text_color,
			),
			'selectors' => '.profecient-sticky-right-column .woocommerce-form-coupon-toggle .profecient-coupon-anchor .coupon-container-grid .coupon-col-2 button.woocommerce-button:hover',
		);

		$this->options['form_coupon_button_hover_tab_end'] = array(
			'type'    => 'control_tab_end',
			'segment' => 'form_coupon_button',
		);

		$this->options['form_coupon_button_tabs_end'] = array(
			'type'    => 'control_tabs_end',
			'segment' => 'form_coupon_button',
		);

		/* ----- Apply Button Segment ----- */

		/* ----- Form Coupon Segment ----- */
		$this->options['form_coupon_wrapper_box_shadow'] = array(
			'type'       => 'boxshadow',
			'title'      => esc_html__( 'Wrapper Box Shadow', 'profecient-essential' ),
			'segment'    => 'form_coupon',
			'selectors'  => '.profecient-checkout-column-end .woocommerce-form-coupon-toggle',
			'dependency' => array(
				array(
					'field'    => 'layout_type',
					'operator' => '==',
					'value'    => 'layout-1',
				),
			),
		);

		$this->options['form_coupon_wrapper_border'] = array(
			'type'       => 'border',
			'title'      => esc_html__( 'Wrapper Border', 'profecient-essential' ),
			'segment'    => 'form_coupon',
			'selectors'  => '.profecient-checkout-column-end .woocommerce-form-coupon-toggle',
			'dependency' => array(
				array(
					'field'    => 'layout_type',
					'operator' => '==',
					'value'    => 'layout-1',
				),
			),
		);

		$this->options['form_coupon_wrapper_border_radius'] = array(
			'type'       => 'dimension',
			'title'      => esc_html__( 'Wrapper Border Radius', 'profecient-essential' ),
			'segment'    => 'form_coupon',
			'units'      => array( 'px', '%', 'em' ),
			'selectors'  => '.profecient-checkout-column-end .woocommerce-form-coupon-toggle',
			'attribute'  => 'border-radius',
			'dependency' => array(
				array(
					'field'    => 'layout_type',
					'operator' => '==',
					'value'    => 'layout-1',
				),
			),
		);

		$this->options['form_coupon_wrapper_background'] = array(
			'type'       => 'background',
			'title'      => esc_html__( 'Background Color', 'profecient-essential' ),
			'segment'    => 'form_coupon',
			'selectors'  => '.profecient-checkout-column-end .woocommerce-form-coupon-toggle',
			'dependency' => array(
				array(
					'field'    => 'layout_type',
					'operator' => '==',
					'value'    => 'layout-1',
				),
			),
			'options'    => array(
				'classic',
				'gradient',
			),
			'exclude'    => array( 'image' ),
		);

		$this->options['form_coupon_wrapper_padding'] = array(
			'type'       => 'dimension',
			'title'      => esc_html__( 'Wrapper Padding', 'profecient-essential' ),
			'segment'    => 'form_coupon',
			'units'      => array( 'px', '%', 'em' ),
			'selectors'  => '.profecient-checkout-column-end .woocommerce-form-coupon-toggle',
			'dependency' => array(
				array(
					'field'    => 'layout_type',
					'operator' => '==',
					'value'    => 'layout-1',
				),
			),
			'attribute'  => 'padding',
		);

		$this->options['form_coupon_wrapper_margin'] = array(
			'type'       => 'dimension',
			'title'      => esc_html__( 'Wrapper Margin', 'profecient-essential' ),
			'segment'    => 'form_coupon',
			'units'      => array( 'px', '%', 'em' ),
			'dependency' => array(
				array(
					'field'    => 'layout_type',
					'operator' => '==',
					'value'    => 'layout-1',
				),
			),
			'selectors'  => '.profecient-checkout-column-end .woocommerce-form-coupon-toggle',
			'attribute'  => 'margin',
		);

		$this->options['form_coupon_notice_icon'] = array(
			'type'       => 'iconpicker',
			'title'      => esc_html__( 'Icon', 'profecient-essential' ),
			'segment'    => 'form_coupon',
			'default'    => array(
				'value'   => 'fas fa-info-circle',
				'library' => 'fa-solid',
			),
			'dependency' => array(
				array(
					'field'    => 'layout_type',
					'operator' => '==',
					'value'    => 'layout-2',
				),
			),
		);

		$this->options['form_coupon_notice_icon_color'] = array(
			'type'       => 'color',
			'title'      => esc_html__( 'Icon Color', 'profecient-essential' ),
			'segment'    => 'form_coupon',
			'default'    => '#1e85be',
			'selectors'  => '.woocommerce-form-coupon-toggle .woocommerce-info i',
			'dependency' => array(
				array(
					'field'    => 'layout_type',
					'operator' => '==',
					'value'    => 'layout-2',
				),
			),
		);

		$this->options['form_coupon_background'] = array(
			'type'       => 'background',
			'title'      => esc_html__( 'Form Coupon Background', 'profecient-essential' ),
			'segment'    => 'form_coupon',
			'selectors'  => '.woocommerce-form-coupon-toggle .woocommerce-info',
			'options'    => array(
				'classic',
				'gradient',
			),
			'dependency' => array(
				array(
					'field'    => 'layout_type',
					'operator' => '==',
					'value'    => 'layout-2',
				),
			),
			'exclude'    => array( 'image' ),
		);

		$this->options['form_coupon_border'] = array(
			'type'       => 'border',
			'title'      => esc_html__( 'Form Coupon Border', 'profecient-essential' ),
			'segment'    => 'form_coupon',
			'selectors'  => '.woocommerce-form-coupon-toggle .woocommerce-info',
			'dependency' => array(
				array(
					'field'    => 'layout_type',
					'operator' => '==',
					'value'    => 'layout-2',
				),
			),
		);

		$this->options['form_coupon_link_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Link Color', 'profecient-essential' ),
			'segment'   => 'form_coupon',
			'selectors' => '.woocommerce-form-coupon-toggle .woocommerce-info .showcoupon, {{WRAPPER}} .woocommerce-form-coupon-toggle .profecient-checkout-secondary-title .showcoupon',
			'separator' => 'before',
		);

		$this->options['form_coupon_link_color_hover'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Link Color Hover', 'profecient-essential' ),
			'segment'   => 'form_coupon',
			'selectors' => '.woocommerce-form-coupon-toggle .woocommerce-info .showcoupon, {{WRAPPER}} .woocommerce-form-coupon-toggle .profecient-checkout-secondary-title .showcoupon:hover',
		);

		$this->options['form_coupon_typography'] = array(
			'type'      => 'typography',
			'title'     => esc_html__( 'Typograhpy', 'profecient-essential' ),
			'segment'   => 'form_coupon',
			'selectors' => '.woocommerce-form-coupon-toggle .woocommerce-info, {{WRAPPER}} .woocommerce-form-coupon-toggle .profecient-checkout-secondary-title, {{WRAPPER}} .profecient-coupon-anchor .profecient-coupon-anchor-description',
		);

		$this->options['form_coupon_text_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Text Color', 'profecient-essential' ),
			'segment'   => 'form_coupon',
			'selectors' => '.woocommerce-form-coupon-toggle .woocommerce-info, {{WRAPPER}} .woocommerce-form-coupon-toggle .profecient-checkout-secondary-title, {{WRAPPER}} .profecient-coupon-anchor .profecient-coupon-anchor-description',
		);

		$this->options['form_coupon_input_typography'] = array(
			'type'      => 'typography',
			'title'     => esc_html__( 'Coupon Input Typography', 'profecient-essential' ),
			'segment'   => 'form_coupon',
			'selectors' => '.coupon-container-grid .coupon-col-1 input.input-text',
		);

		$this->options['form_coupon_input_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Coupon Input Color', 'profecient-essential' ),
			'segment'   => 'form_coupon',
			'selectors' => '.coupon-container-grid .coupon-col-1 input.input-text',
		);

		$this->options['form_coupon_input_background'] = array(
			'type'           => 'background',
			'title'          => esc_html__( 'Coupon Input Background', 'profecient-essential' ),
			'segment'        => 'form_coupon',
			'selectors'      => '.coupon-container-grid .coupon-col-1 input.input-text',
			'fields_options' => array(
				'background' => array(
					'default' => 'classic',
				),
				'color'      => array(
					'global' => array(
						'default' => $global_form_field_background,
					),
				),
			),
			'options'        => array(
				'classic',
				'gradient',
			),
			'exclude'        => array( 'image' ),
		);

		$this->options['form_coupon_input_border'] = array(
			'type'      => 'border',
			'title'     => esc_html__( 'Coupon Input Border', 'profecient-essential' ),
			'segment'   => 'form_coupon',
			'selectors' => '.coupon-container-grid .coupon-col-1 input.input-text',
		);

		$this->options['form_coupon_input_border_radius'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Coupon Input Border Radius', 'profecient-essential' ),
			'segment'   => 'form_coupon',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.coupon-container-grid .coupon-col-1 input.input-text',
			'attribute' => 'border-radius',
		);

		/* ----- Form Coupon Segment ----- */

		/* ----- Checkout Form Segment ----- */
		$this->options['checkout_form_wrapper_box_shadow'] = array(
			'type'       => 'boxshadow',
			'title'      => esc_html__( 'Wrapper Box Shadow', 'profecient-essential' ),
			'segment'    => 'checkout_form',
			'selectors'  => '.profecient-checkout-container .profecient-checkout-column-start .col2-set .col-1',
			'dependency' => array(
				array(
					'field'    => 'layout_type',
					'operator' => '==',
					'value'    => 'layout-1',
				),
			),
		);

		$this->options['checkout_form_wrapper_border'] = array(
			'type'       => 'border',
			'title'      => esc_html__( 'Wrapper Border', 'profecient-essential' ),
			'segment'    => 'checkout_form',
			'dependency' => array(
				array(
					'field'    => 'layout_type',
					'operator' => '==',
					'value'    => 'layout-1',
				),
			),
			'selectors'  => '.profecient-checkout-container .profecient-checkout-column-start .col2-set .col-1',
		);

		$this->options['checkout_form_wrapper_border_radius'] = array(
			'type'       => 'dimension',
			'title'      => esc_html__( 'Border Radius', 'profecient-essential' ),
			'segment'    => 'checkout_form',
			'units'      => array( 'px', '%', 'em' ),
			'dependency' => array(
				array(
					'field'    => 'layout_type',
					'operator' => '==',
					'value'    => 'layout-1',
				),
			),
			'selectors'  => '.profecient-checkout-container .profecient-checkout-column-start .col2-set .col-1',
			'attribute'  => 'border-radius',
		);

		$this->options['checkout_form_wrapper_background'] = array(
			'type'       => 'background',
			'title'      => esc_html__( 'Background Color', 'profecient-essential' ),
			'segment'    => 'checkout_form',
			'selectors'  => '.profecient-checkout-container .profecient-checkout-column-start col2-set .col-1',
			'options'    => array(
				'classic',
				'gradient',
			),
			'dependency' => array(
				array(
					'field'    => 'layout_type',
					'operator' => '==',
					'value'    => 'layout-1',
				),
			),
			'exclude'    => array( 'image' ),
		);

		$this->options['checkout_form_wrapper_padding'] = array(
			'type'       => 'dimension',
			'title'      => esc_html__( 'Wrapper Padding', 'profecient-essential' ),
			'segment'    => 'checkout_form',
			'units'      => array( 'px', '%', 'em' ),
			'selectors'  => '.profecient-checkout-container .profecient-checkout-column-start .col2-set .col-1',
			'attribute'  => 'padding',
			'dependency' => array(
				array(
					'field'    => 'layout_type',
					'operator' => '==',
					'value'    => 'layout-1',
				),
			),
		);

		$this->options['checkout_form_wrapper_margin'] = array(
			'type'       => 'dimension',
			'title'      => esc_html__( 'Wrapper Margin', 'profecient-essential' ),
			'segment'    => 'checkout_form',
			'units'      => array( 'px', '%', 'em' ),
			'selectors'  => '.profecient-checkout-container .profecient-checkout-column-start .col2-set .col-1',
			'attribute'  => 'margin',
			'dependency' => array(
				array(
					'field'    => 'layout_type',
					'operator' => '==',
					'value'    => 'layout-1',
				),
			),
		);

		$this->options['checkout_form_heading_typography'] = array(
			'type'       => 'typography',
			'title'      => esc_html__( 'Form Heading Typography', 'profecient-essential' ),
			'segment'    => 'checkout_form',
			'selectors'  => ' .woocommerce-checkout .woocommerce-billing-fields h3',
			'dependency' => array(
				array(
					'field'    => 'layout_type',
					'operator' => '==',
					'value'    => 'layout-1',
				),
			),
			'separator'  => 'before',
		);

		$this->options['checkout_form_heading_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Form Heading Color', 'profecient-essential' ),
			'segment'   => 'checkout_form',
			'selectors' => '.woocommerce-checkout .woocommerce-billing-fields h3',
			'global'    => array(
				'default' => $global_h3_color,
			),
		);

		$this->options['checkout_form_label_typography'] = array(
			'type'      => 'typography',
			'title'     => esc_html__( 'Form Label', 'profecient-essential' ),
			'segment'   => 'checkout_form',
			'selectors' => '.woocommerce-checkout .woocommerce-billing-fields label',
		);

		$this->options['checkout_form_label_typography_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Form Label Color', 'profecient-essential' ),
			'segment'   => 'checkout_form',
			'selectors' => '.woocommerce-checkout .woocommerce-billing-fields label',
		);

		$this->options['checkout_form_required_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Required color', 'profecient-essential' ),
			'segment'   => 'checkout_form',
			'selectors' => '.woocommerce-checkout .woocommerce-billing-fields .required',
		);

		$this->options['checkout_form_input_typography'] = array(
			'type'      => 'typography',
			'title'     => esc_html__( 'Form Input Typography', 'profecient-essential' ),
			'segment'   => 'checkout_form',
			'selectors' => '.woocommerce-input-wrapper input, {{WRAPPER}} .woocommerce-input-wrapper select, {{WRAPPER}} .select2 .select2-selection__rendered, .select2-container .select2-dropdown',
		);

		$this->options['checkout_form_input_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Form Input Color', 'profecient-essential' ),
			'segment'   => 'checkout_form',
			'selectors' => '.woocommerce-input-wrapper input, {{WRAPPER}} .woocommerce-input-wrapper select, {{WRAPPER}} .select2 .select2-selection__rendered, .select2-container .select2-dropdown',
		);

		$this->options['checkout_form_input_background'] = array(
			'type'           => 'background',
			'title'          => esc_html__( 'Background', 'profecient-essential' ),
			'segment'        => 'checkout_form',
			'selectors'      => '.woocommerce-billing-fields .woocommerce-input-wrapper input, {{WRAPPER}} .woocommerce-billing-fields span.woocommerce-input-wrapper select, {{WRAPPER}} .select2 .select2-selection__rendered, .select2-container .select2-dropdown',
			'fields_options' => array(
				'background' => array(
					'default' => 'classic',
				),
				'color'      => array(
					'global' => array(
						'default' => $global_form_field_background,
					),
				),
			),
			'options'        => array(
				'classic',
				'gradient',
			),
			'exclude'        => array( 'image' ),
		);

		$this->options['checkout_form_input_padding'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Input Padding', 'profecient-essential' ),
			'segment'   => 'checkout_form',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.woocommerce-input-wrapper input, {{WRAPPER}} .woocommerce-input-wrapper select, {{WRAPPER}} .select2 .select2-selection__rendered, .select2-container .select2-dropdown',
			'attribute' => 'padding',
		);

		$this->options['checkout_form_input_border'] = array(
			'type'      => 'border',
			'title'     => esc_html__( 'Input Border', 'profecient-essential' ),
			'segment'   => 'checkout_form',
			'selectors' => '.woocommerce-input-wrapper input, {{WRAPPER}} .woocommerce-input-wrapper select, {{WRAPPER}} .select2 .select2-selection__rendered, .select2-container .select2-dropdown',
		);

		$this->options['checkout_form_input_border_radius'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Input Border Radius', 'profecient-essential' ),
			'segment'   => 'checkout_form',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.woocommerce-input-wrapper input, {{WRAPPER}} .woocommerce-input-wrapper select, {{WRAPPER}} .select2 .select2-selection__rendered, .select2-container .select2-dropdown',
			'attribute' => 'border-radius',
		);

		$this->options['checkout_form_input_select_heading'] = array(
			'type'      => 'heading',
			'title'     => esc_html__( 'Select Input', 'profecient-essential' ),
			'segment'   => 'checkout_form',
			'separator' => 'before',
		);

		$this->options['checkout_form_input_border_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Select Search Border Color', 'profecient-essential' ),
			'segment'   => 'checkout_form',
			'selectors' => array(
				'custom' => array(
					'span.select2-container .select2-search--dropdown .select2-search__field' => 'border-color: {{VALUE}}',
				),
			),
		);

		$this->options['checkout_form_input_selected_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Form Input Selected Color', 'profecient-essential' ),
			'segment'   => 'checkout_form',
			'selectors' => array(
				'custom' => array(
					'span.select2-container .select2-results__option[data-selected=true]' => 'background-color: {{VALUE}}',
				),
			),
		);

		$this->options['checkout_form_input_highlighted_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Form Input Highlighted Color', 'profecient-essential' ),
			'segment'   => 'checkout_form',
			'selectors' => array(
				'custom' => array(
					'span.select2-container .select2-results__option.select2-results__option--highlighted' => 'background-color: {{VALUE}}',
				),
			),
		);

		$this->options['additional_information_select_arrow_size'] = array(
			'type'         => 'slider',
			'title'        => esc_html__( 'Select\'s Arrow Size', 'profecient-essential' ),
			'segment'      => 'checkout_form',
			'responsive'   => true,
			'units'        => array( 'px' ),
			'default_unit' => 'px',
			'options'      => array(
				'min'  => 0,
				'max'  => 30,
				'step' => 1,
			),
			'selectors'    => array(
				'custom' => array(
					'{{WRAPPER}} .woocommerce-input-wrapper select' => 'background-size: {{SIZE}}{{UNIT}};',
				),
			),
		);

		$this->options['additional_information_select_arrow_position_x'] = array(
			'type'         => 'slider',
			'title'        => esc_html__( 'Select\'s Arrow Position X', 'profecient-essential' ),
			'segment'      => 'checkout_form',
			'responsive'   => true,
			'units'        => array( '%' ),
			'default_unit' => '%',
			'options'      => array(
				'min'  => 0,
				'max'  => 100,
				'step' => 1,
			),
			'selectors'    => array(
				'custom' => array(
					'{{WRAPPER}} .woocommerce-input-wrapper select' => '--profecient-arrow-position-x: {{SIZE}}{{UNIT}};',
				),
			),
		);

		$this->options['additional_information_select_arrow_position_y'] = array(
			'type'         => 'slider',
			'title'        => esc_html__( 'Select\'s Arrow Position Y', 'profecient-essential' ),
			'segment'      => 'checkout_form',
			'responsive'   => true,
			'units'        => array( '%' ),
			'default_unit' => '%',
			'options'      => array(
				'min'  => 0,
				'max'  => 100,
				'step' => 1,
			),
			'selectors'    => array(
				'custom' => array(
					'{{WRAPPER}} .woocommerce-input-wrapper select' => '--profecient-arrow-position-y: {{SIZE}}{{UNIT}};',
				),
			),
		);

		/* ----- Checkout Form Segment ----- */

		/* ----- Checkout Form Segment ----- */
		$this->options['payment_method_background'] = array(
			'type'       => 'background',
			'title'      => esc_html__( 'Background', 'profecient-essential' ),
			'segment'    => 'payment_method',
			'selectors'  => 'ul.payment_methods',
			'options'    => array(
				'classic',
				'gradient',
			),
			'dependency' => array(
				array(
					'field'    => 'layout_type',
					'operator' => '==',
					'value'    => 'layout-2',
				),
			),
			'exclude'    => array( 'image' ),
		);

		$this->options['payment_method_notice_background'] = array(
			'type'       => 'background',
			'title'      => esc_html__( 'Notice Background', 'profecient-essential' ),
			'segment'    => 'payment_method',
			'selectors'  => 'ul.payment_methods .woocommerce-notice',
			'options'    => array(
				'classic',
				'gradient',
			),
			'dependency' => array(
				array(
					'field'    => 'layout_type',
					'operator' => '==',
					'value'    => 'layout-2',
				),
			),
			'exclude'    => array( 'image' ),
		);

		$this->options['payment_method_notice_typography'] = array(
			'type'      => 'typography',
			'title'     => esc_html__( 'Notice Typograhpy', 'profecient-essential' ),
			'segment'   => 'payment_method',
			'selectors' => 'ul.payment_methods .woocommerce-info',
		);

		$this->options['payment_method_notice_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Notice text color', 'profecient-essential' ),
			'segment'   => 'payment_method',
			'selectors' => 'ul.payment_methods .woocommerce-info',
		);

		$this->options['payment_method_notice_border_color'] = array(
			'type'       => 'color',
			'title'      => esc_html__( 'Notice Border Color', 'profecient-essential' ),
			'segment'    => 'payment_method',
			'selectors'  => array(
				'custom' => array(
					'{{WRAPPER}}  ul.payment_methods .woocommerce-info' => 'border-top-color: {{VALUE}};',
				),
			),
			'dependency' => array(
				array(
					'field'    => 'layout_type',
					'operator' => '==',
					'value'    => 'layout-2',
				),
			),
		);

		$this->options['payment_method_notice_icon'] = array(
			'type'       => 'iconpicker',
			'title'      => esc_html__( 'Icon', 'profecient-essential' ),
			'segment'    => 'payment_method',
			'dependency' => array(
				array(
					'field'    => 'layout_type',
					'operator' => '==',
					'value'    => 'layout-2',
				),
			),
			'default'    => array(
				'value'   => 'fas fa-info-circle',
				'library' => 'fa-solid',
			),
		);

		$this->options['payment_method_notice_icon_color'] = array(
			'type'       => 'color',
			'title'      => esc_html__( 'Icon Color', 'profecient-essential' ),
			'segment'    => 'payment_method',
			'selectors'  => 'ul.payment_methods .woocommerce-notice i',
			'default'    => '#1e85be',
			'dependency' => array(
				array(
					'field'    => 'layout_type',
					'operator' => '==',
					'value'    => 'layout-2',
				),
			),
		);

		/* ----- Checkout Form Segment ----- */

		/* ----- Checkout Form Place Order Segment ----- */
		$this->options['place_order_wrapper_box_shadow'] = array(
			'type'       => 'boxshadow',
			'title'      => esc_html__( 'Wrapper Box Shadow', 'profecient-essential' ),
			'segment'    => 'place_order',
			'selectors'  => '.profecient-checkout-column-end .profecient-checkout-order-review-2',
			'dependency' => array(
				array(
					'field'    => 'layout_type',
					'operator' => '==',
					'value'    => 'layout-1',
				),
			),
		);

		$this->options['place_order_wrapper_border'] = array(
			'type'       => 'border',
			'title'      => esc_html__( 'Wrapper Border', 'profecient-essential' ),
			'segment'    => 'place_order',
			'selectors'  => '.profecient-checkout-column-end .profecient-checkout-order-review-2',
			'dependency' => array(
				array(
					'field'    => 'layout_type',
					'operator' => '==',
					'value'    => 'layout-1',
				),
			),
		);

		$this->options['place_order_wrapper_border_radius'] = array(
			'type'       => 'dimension',
			'title'      => esc_html__( 'Wrapper Border Radius', 'profecient-essential' ),
			'segment'    => 'place_order',
			'units'      => array( 'px', '%', 'em' ),
			'selectors'  => '.profecient-checkout-column-end .profecient-checkout-order-review-2',
			'attribute'  => 'border-radius',
			'dependency' => array(
				array(
					'field'    => 'layout_type',
					'operator' => '==',
					'value'    => 'layout-1',
				),
			),
		);

		$this->options['place_order_wrapper_background'] = array(
			'type'       => 'background',
			'title'      => esc_html__( 'Background Color', 'profecient-essential' ),
			'segment'    => 'place_order',
			'selectors'  => '.profecient-checkout-column-end .profecient-checkout-order-review-2',
			'options'    => array(
				'classic',
				'gradient',
			),
			'exclude'    => array( 'image' ),
			'dependency' => array(
				array(
					'field'    => 'layout_type',
					'operator' => '==',
					'value'    => 'layout-1',
				),
			),
		);

		$this->options['place_order_wrapper_padding'] = array(
			'type'       => 'dimension',
			'title'      => esc_html__( 'Wrapper Padding', 'profecient-essential' ),
			'segment'    => 'place_order',
			'units'      => array( 'px', '%', 'em' ),
			'selectors'  => '.profecient-checkout-column-end .profecient-checkout-order-review-2',
			'attribute'  => 'padding',
			'dependency' => array(
				array(
					'field'    => 'layout_type',
					'operator' => '==',
					'value'    => 'layout-1',
				),
			),
		);

		$this->options['place_order_wrapper_margin'] = array(
			'type'       => 'dimension',
			'title'      => esc_html__( 'Wrapper Margin', 'profecient-essential' ),
			'segment'    => 'place_order',
			'units'      => array( 'px', '%', 'em' ),
			'selectors'  => '.profecient-checkout-column-end .profecient-checkout-order-review-2',
			'attribute'  => 'margin',
			'dependency' => array(
				array(
					'field'    => 'layout_type',
					'operator' => '==',
					'value'    => 'layout-1',
				),
			),
		);

		$this->options['place_order_background'] = array(
			'type'       => 'background',
			'title'      => esc_html__( 'Background', 'profecient-essential' ),
			'segment'    => 'place_order',
			'selectors'  => '.form-row.place-order',
			'options'    => array(
				'classic',
				'gradient',
			),
			'dependency' => array(
				array(
					'field'    => 'layout_type',
					'operator' => '==',
					'value'    => 'layout-2',
				),
			),
			'exclude'    => array( 'image' ),
		);

		$this->options['place_order_text_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'text color', 'profecient-essential' ),
			'segment'   => 'place_order',
			'selectors' => '.form-row.place-order p',
		);

		$this->options['place_order_typography'] = array(
			'type'      => 'typography',
			'title'     => esc_html__( 'Typograhpy', 'profecient-essential' ),
			'segment'   => 'place_order',
			'selectors' => '.form-row.place-order p',
		);

		$this->options['place_order_link_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Link Color', 'profecient-essential' ),
			'segment'   => 'place_order',
			'selectors' => '.form-row.place-order p a',
		);

		/* ----- Checkout Form Place Order Segment ----- */

		/* ----- Checkout Place Order Button Segment ----- */
		$this->options['place_order_button_typography'] = array(
			'type'      => 'typography',
			'title'     => esc_html__( 'Button Typograhpy', 'profecient-essential' ),
			'segment'   => 'place_order_button',
			'selectors' => '.profecient-wooocommerce-checkout-wrapper .woocommerce-checkout-payment .form-row.place-order button#place_order',
		);

		$this->options['place_order_button_tabs_start'] = array(
			'type'    => 'control_tabs_start',
			'segment' => 'place_order_button',
		);

		$this->options['place_order_button_normal_tab_start'] = array(
			'type'    => 'control_tab_start',
			'title'   => esc_html__( 'Normal', 'profecient-essential' ),
			'segment' => 'place_order_button',
		);

		$this->options['place_order_button_normal_box_shadow'] = array(
			'type'      => 'boxshadow',
			'title'     => esc_html__( 'Box Shadow', 'profecient-essential' ),
			'segment'   => 'place_order_button',
			'selectors' => '.profecient-wooocommerce-checkout-wrapper .woocommerce-checkout-payment .form-row.place-order button#place_order',
		);

		$this->options['place_order_button_normal_border'] = array(
			'type'      => 'border',
			'title'     => esc_html__( 'Border button', 'profecient-essential' ),
			'segment'   => 'place_order_button',
			'selectors' => '.profecient-wooocommerce-checkout-wrapper .woocommerce-checkout-payment .form-row.place-order button#place_order',
		);

		$this->options['place_order_button_normal_border_radius'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Border Radius', 'profecient-essential' ),
			'segment'   => 'place_order_button',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.profecient-wooocommerce-checkout-wrapper .woocommerce-checkout-payment .form-row.place-order button#place_order',
			'attribute' => 'border-radius',
		);

		$this->options['place_order_button_normal_margin'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Button Margin', 'profecient-essential' ),
			'segment'   => 'place_order_button',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.profecient-wooocommerce-checkout-wrapper .woocommerce-checkout-payment .form-row.place-order button#place_order',
			'attribute' => 'margin',
		);

		$this->options['place_order_button_normal_padding'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Button Padding', 'profecient-essential' ),
			'segment'   => 'place_order_button',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.profecient-wooocommerce-checkout-wrapper .woocommerce-checkout-payment .form-row.place-order button#place_order',
			'attribute' => 'padding',
		);

		$this->options['place_order_button_normal_background'] = array(
			'type'           => 'background',
			'title'          => esc_html__( 'Button Background', 'profecient-essential' ),
			'segment'        => 'place_order_button',
			'selectors'      => '.profecient-wooocommerce-checkout-wrapper .woocommerce-checkout-payment .form-row.place-order button#place_order',
			'fields_options' => array(
				'background' => array(
					'default' => 'classic',
				),
				'color'      => array(
					'global' => array(
						'default' => $global_button_background,
					),
				),
			),
			'options'        => array(
				'classic',
				'gradient',
			),
			'exclude'        => array( 'image' ),
		);

		$this->options['place_order_button_normal_text_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Text Color', 'profecient-essential' ),
			'segment'   => 'place_order_button',
			'global'    => array(
				'default' => $global_button_text_color,
			),
			'selectors' => '.profecient-wooocommerce-checkout-wrapper .woocommerce-checkout-payment .form-row.place-order button#place_order',
		);

		$this->options['place_order_button_normal_tab_end'] = array(
			'type'    => 'control_tab_end',
			'segment' => 'place_order_button',
		);

		$this->options['place_order_button_hover_tab_start'] = array(
			'type'    => 'control_tab_start',
			'title'   => esc_html__( 'Hover', 'profecient-essential' ),
			'segment' => 'place_order_button',
		);

		$this->options['place_order_button_hover_box_shadow'] = array(
			'type'      => 'boxshadow',
			'title'     => esc_html__( 'Box Shadow', 'profecient-essential' ),
			'segment'   => 'place_order_button',
			'selectors' => '.profecient-wooocommerce-checkout-wrapper .woocommerce-checkout-payment .form-row.place-order button#place_order:hover',
		);

		$this->options['place_order_button_hover_border'] = array(
			'type'      => 'border',
			'title'     => esc_html__( 'Border button', 'profecient-essential' ),
			'segment'   => 'place_order_button',
			'selectors' => '.profecient-wooocommerce-checkout-wrapper .woocommerce-checkout-payment .form-row.place-order button#place_order:hover',
		);

		$this->options['place_order_button_normal_hover_radius'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Border Radius', 'profecient-essential' ),
			'segment'   => 'place_order_button',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.profecient-wooocommerce-checkout-wrapper .woocommerce-checkout-payment .form-row.place-order button#place_order:hover',
			'attribute' => 'border-radius',
		);

		$this->options['place_order_button_hover_margin'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Button Margin', 'profecient-essential' ),
			'segment'   => 'place_order_button',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.profecient-wooocommerce-checkout-wrapper .woocommerce-checkout-payment .form-row.place-order button#place_order:hover',
			'attribute' => 'margin',
		);

		$this->options['place_order_button_hover_padding'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Button Padding', 'profecient-essential' ),
			'segment'   => 'place_order_button',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.profecient-wooocommerce-checkout-wrapper .woocommerce-checkout-payment .form-row.place-order button#place_order:hover',
			'attribute' => 'padding',
		);

		$this->options['place_order_button_hover_background'] = array(
			'type'           => 'background',
			'title'          => esc_html__( 'Button Background', 'profecient-essential' ),
			'segment'        => 'place_order_button',
			'selectors'      => '.profecient-wooocommerce-checkout-wrapper .woocommerce-checkout-payment .form-row.place-order button#place_order:hover',
			'fields_options' => array(
				'background' => array(
					'default' => 'classic',
				),
				'color'      => array(
					'global' => array(
						'default' => $global_button_background,
					),
				),
			),
			'options'        => array(
				'classic',
				'gradient',
			),
			'exclude'        => array( 'image' ),
		);

		$this->options['place_order_button_hover_text_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Text Color', 'profecient-essential' ),
			'segment'   => 'place_order_button',
			'global'    => array(
				'default' => $global_button_text_color,
			),
			'selectors' => '.profecient-wooocommerce-checkout-wrapper .woocommerce-checkout-payment .form-row.place-order button#place_order:hover',
		);

		$this->options['place_order_button_hover_tab_end'] = array(
			'type'    => 'control_tab_end',
			'segment' => 'place_order_button',
		);

		$this->options['place_order_button_tabs_end'] = array(
			'type'    => 'control_tabs_end',
			'segment' => 'place_order_button',
		);

		/* ----- Checkout Place Order Button Segment ----- */

		/* ----- Order Table Segment ----- */
		$this->options['order_table_wrapper_box_shadow'] = array(
			'type'       => 'boxshadow',
			'title'      => esc_html__( 'Wrapper Box Shadow', 'profecient-essential' ),
			'segment'    => 'order_table',
			'selectors'  => '.profecient-checkout-container .profecient-checkout-column-end .profecient-checkout-order-review',
			'dependency' => array(
				array(
					'field'    => 'layout_type',
					'operator' => '==',
					'value'    => 'layout-1',
				),
			),
		);

		$this->options['order_table_wrapper_border'] = array(
			'type'       => 'border',
			'title'      => esc_html__( 'Wrapper Border', 'profecient-essential' ),
			'segment'    => 'order_table',
			'selectors'  => '.profecient-checkout-container .profecient-checkout-column-end .profecient-checkout-order-review',
			'dependency' => array(
				array(
					'field'    => 'layout_type',
					'operator' => '==',
					'value'    => 'layout-1',
				),
			),
		);

		$this->options['order_table_wrapper_border_radius'] = array(
			'type'       => 'dimension',
			'title'      => esc_html__( 'Wrapper Border Radius', 'profecient-essential' ),
			'segment'    => 'order_table',
			'units'      => array( 'px', '%', 'em' ),
			'selectors'  => '.profecient-checkout-container .profecient-checkout-column-end .profecient-checkout-order-review',
			'attribute'  => 'border-radius',
			'dependency' => array(
				array(
					'field'    => 'layout_type',
					'operator' => '==',
					'value'    => 'layout-1',
				),
			),
		);

		$this->options['order_table_wrapper_background'] = array(
			'type'       => 'background',
			'title'      => esc_html__( 'Background Color', 'profecient-essential' ),
			'segment'    => 'order_table',
			'selectors'  => '.profecient-checkout-container .profecient-checkout-column-end .profecient-checkout-order-review',
			'options'    => array(
				'classic',
				'gradient',
			),
			'exclude'    => array( 'image' ),
			'dependency' => array(
				array(
					'field'    => 'layout_type',
					'operator' => '==',
					'value'    => 'layout-1',
				),
			),
		);

		$this->options['order_table_wrapper_padding'] = array(
			'type'       => 'dimension',
			'title'      => esc_html__( 'Wrapper Padding', 'profecient-essential' ),
			'segment'    => 'order_table',
			'units'      => array( 'px', '%', 'em' ),
			'selectors'  => '.profecient-checkout-container .profecient-checkout-column-end .profecient-checkout-order-review',
			'attribute'  => 'padding',
			'dependency' => array(
				array(
					'field'    => 'layout_type',
					'operator' => '==',
					'value'    => 'layout-1',
				),
			),
		);

		$this->options['order_table_wrapper_margin'] = array(
			'type'       => 'dimension',
			'title'      => esc_html__( 'Wrapper Margin', 'profecient-essential' ),
			'segment'    => 'order_table',
			'units'      => array( 'px', '%', 'em' ),
			'selectors'  => '.profecient-checkout-container .profecient-checkout-column-end .profecient-checkout-order-review',
			'attribute'  => 'margin',
			'dependency' => array(
				array(
					'field'    => 'layout_type',
					'operator' => '==',
					'value'    => 'layout-1',
				),
			),
		);

		$this->options['order_table_heading_typography'] = array(
			'type'      => 'typography',
			'title'     => esc_html__( 'Table Heading typography', 'profecient-essential' ),
			'segment'   => 'order_table',
			'selectors' => '#order_review_heading',
		);

		$this->options['order_table_heading_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Table Heading Color', 'profecient-essential' ),
			'segment'   => 'order_table',
			'selectors' => '#order_review_heading',
			'global'    => array(
				'default' => $global_h3_color,
			),
		);

		$this->options['order_table_outer_border'] = array(
			'type'       => 'border',
			'title'      => esc_html__( 'Table Outer Border', 'profecient-essential' ),
			'segment'    => 'order_table',
			'selectors'  => '.woocommerce-checkout-review-order-table',
			'dependency' => array(
				array(
					'field'    => 'layout_type',
					'operator' => '==',
					'value'    => 'layout-2',
				),
			),
		);

		$this->options['order_table_head_border'] = array(
			'type'       => 'border',
			'title'      => esc_html__( 'Table Head Border', 'profecient-essential' ),
			'segment'    => 'order_table',
			'selectors'  => '.woocommerce-checkout-review-order-table thead th',
			'dependency' => array(
				array(
					'field'    => 'layout_type',
					'operator' => '==',
					'value'    => 'layout-2',
				),
			),
		);

		$this->options['order_table_heading_txt'] = array(
			'type'      => 'typography',
			'title'     => esc_html__( 'Table Heading Text', 'profecient-essential' ),
			'segment'   => 'order_table',
			'selectors' => '.woocommerce-checkout-review-order-table thead th',
		);

		$this->options['order_table_heading_txt_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Table Heading Color', 'profecient-essential' ),
			'segment'   => 'order_table',
			'selectors' => '.woocommerce-checkout-review-order-table thead th',
		);

		$this->options['order_table_data_border'] = array(
			'type'       => 'border',
			'title'      => esc_html__( 'Table Body Data Border', 'profecient-essential' ),
			'segment'    => 'order_table',
			'selectors'  => '.woocommerce-checkout-review-order-table tbody td',
			'dependency' => array(
				array(
					'field'    => 'layout_type',
					'operator' => '==',
					'value'    => 'layout-2',
				),
			),
		);

		$this->options['order_table_data_txt'] = array(
			'type'      => 'typography',
			'title'     => esc_html__( 'Table Body Data Text', 'profecient-essential' ),
			'segment'   => 'order_table',
			'selectors' => '.woocommerce-checkout-review-order-table tbody td',
		);

		$this->options['order_table_data_txt_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Body Data Text color', 'profecient-essential' ),
			'segment'   => 'order_table',
			'selectors' => '.woocommerce-checkout-review-order-table tbody td',
		);

		$this->options['order_table_footer_head_border'] = array(
			'type'       => 'border',
			'title'      => esc_html__( 'Table Footer Head Border', 'profecient-essential' ),
			'segment'    => 'order_table',
			'selectors'  => '.woocommerce-checkout-review-order-table tfoot th',
			'dependency' => array(
				array(
					'field'    => 'layout_type',
					'operator' => '==',
					'value'    => 'layout-2',
				),
			),
		);

		$this->options['order_table_footer_head_txt'] = array(
			'type'      => 'typography',
			'title'     => esc_html__( 'Table Footer Head Text', 'profecient-essential' ),
			'segment'   => 'order_table',
			'selectors' => '.woocommerce-checkout-review-order-table tfoot th',
		);

		$this->options['order_table_footer_head_txt_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Footer Head Text Color', 'profecient-essential' ),
			'segment'   => 'order_table',
			'selectors' => '.woocommerce-checkout-review-order-table tfoot th',
		);

		$this->options['order_table_footer_body_border'] = array(
			'type'       => 'border',
			'title'      => esc_html__( 'Table Footer Body Border', 'profecient-essential' ),
			'segment'    => 'order_table',
			'selectors'  => '.woocommerce-checkout-review-order-table tfoot td',
			'dependency' => array(
				array(
					'field'    => 'layout_type',
					'operator' => '==',
					'value'    => 'layout-2',
				),
			),
		);

		$this->options['order_table_footer_body_txt'] = array(
			'type'      => 'typography',
			'title'     => esc_html__( 'Table Footer Body Text', 'profecient-essential' ),
			'segment'   => 'order_table',
			'selectors' => '.woocommerce-checkout-review-order-table tfoot td',
		);

		$this->options['order_table_footer_body_txt_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Footer Body Text Color', 'profecient-essential' ),
			'segment'   => 'order_table',
			'selectors' => '.woocommerce-checkout-review-order-table tfoot td',
		);

		/* ----- Order Table Segment ----- */

		/* ----- Additional Information */
		$this->options['additional_information_wrapper_box_shadow'] = array(
			'type'       => 'boxshadow',
			'title'      => esc_html__( 'Wrapper Box Shadow', 'profecient-essential' ),
			'segment'    => 'additional_information',
			'selectors'  => '.profecient-checkout-container .profecient-checkout-column-start .col2-set .col-2',
			'dependency' => array(
				array(
					'field'    => 'layout_type',
					'operator' => '==',
					'value'    => 'layout-1',
				),
			),
		);

		$this->options['additional_information_wrapper_border'] = array(
			'type'       => 'border',
			'title'      => esc_html__( 'Wrapper Border', 'profecient-essential' ),
			'segment'    => 'additional_information',
			'selectors'  => '.profecient-checkout-container .profecient-checkout-column-start .col2-set .col-2',
			'dependency' => array(
				array(
					'field'    => 'layout_type',
					'operator' => '==',
					'value'    => 'layout-1',
				),
			),
		);

		$this->options['additional_information_wrapper_border_radius'] = array(
			'type'       => 'dimension',
			'title'      => esc_html__( 'Wrapper Border Radius', 'profecient-essential' ),
			'segment'    => 'additional_information',
			'units'      => array( 'px', '%', 'em' ),
			'selectors'  => '.profecient-checkout-container .profecient-checkout-column-start .col2-set .col-2',
			'attribute'  => 'border-radius',
			'dependency' => array(
				array(
					'field'    => 'layout_type',
					'operator' => '==',
					'value'    => 'layout-1',
				),
			),
		);

		$this->options['additional_information_wrapper_background'] = array(
			'type'       => 'background',
			'title'      => esc_html__( 'Background Color', 'profecient-essential' ),
			'segment'    => 'additional_information',
			'selectors'  => '.profecient-checkout-container .profecient-checkout-column-start .col2-set .col-2',
			'options'    => array(
				'classic',
				'gradient',
			),
			'exclude'    => array( 'image' ),
			'dependency' => array(
				array(
					'field'    => 'layout_type',
					'operator' => '==',
					'value'    => 'layout-1',
				),
			),
		);

		$this->options['additional_information_wrapper_padding'] = array(
			'type'       => 'dimension',
			'title'      => esc_html__( 'Wrapper Padding', 'profecient-essential' ),
			'segment'    => 'additional_information',
			'units'      => array( 'px', '%', 'em' ),
			'selectors'  => '.profecient-checkout-container .profecient-checkout-column-start .col2-set .col-2',
			'attribute'  => 'padding',
			'dependency' => array(
				array(
					'field'    => 'layout_type',
					'operator' => '==',
					'value'    => 'layout-1',
				),
			),
		);

		$this->options['additional_information_wrapper_margin'] = array(
			'type'       => 'dimension',
			'title'      => esc_html__( 'Wrapper Margin', 'profecient-essential' ),
			'segment'    => 'additional_information',
			'units'      => array( 'px', '%', 'em' ),
			'selectors'  => '.profecient-checkout-container .profecient-checkout-column-start .col2-set .col-2',
			'attribute'  => 'margin',
			'dependency' => array(
				array(
					'field'    => 'layout_type',
					'operator' => '==',
					'value'    => 'layout-1',
				),
			),
		);

		$this->options['additional_information_heading_typography'] = array(
			'type'      => 'typography',
			'title'     => esc_html__( 'Form Heading Typography', 'profecient-essential' ),
			'segment'   => 'additional_information',
			'selectors' => '.woocommerce-additional-fields h3',
		);

		$this->options['additional_information_heading_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Form Heading Color', 'profecient-essential' ),
			'segment'   => 'additional_information',
			'selectors' => '.woocommerce-additional-fields h3',
			'global'    => array(
				'default' => $global_h3_color,
			),
		);

		$this->options['additional_information_label_typography'] = array(
			'type'      => 'typography',
			'title'     => esc_html__( 'Form Label', 'profecient-essential' ),
			'segment'   => 'additional_information',
			'selectors' => '.woocommerce-additional-fields label',
		);

		$this->options['additional_information_label_typography_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Form Label Color', 'profecient-essential' ),
			'segment'   => 'additional_information',
			'selectors' => '.woocommerce-additional-fields label',
		);

		$this->options['additional_information_input_typography'] = array(
			'type'      => 'typography',
			'title'     => esc_html__( 'Form Input Typography', 'profecient-essential' ),
			'segment'   => 'additional_information',
			'selectors' => '.woocommerce-additional-fields .woocommerce-input-wrapper textarea',
		);

		$this->options['additional_information_input_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Form Input Color', 'profecient-essential' ),
			'segment'   => 'additional_information',
			'selectors' => '.woocommerce-additional-fields .woocommerce-input-wrapper textarea',
		);

		$this->options['additional_information_input_background'] = array(
			'type'           => 'background',
			'title'          => esc_html__( 'Input Background', 'profecient-essential' ),
			'segment'        => 'additional_information',
			'selectors'      => '.woocommerce-additional-fields .woocommerce-input-wrapper textarea',
			'fields_options' => array(
				'background' => array(
					'default' => 'classic',
				),
				'color'      => array(
					'global' => array(
						'default' => $global_form_field_background,
					),
				),
			),
			'options'        => array(
				'classic',
				'gradient',
			),
			'exclude'        => array( 'image' ),
		);

		$this->options['additional_information_input_border'] = array(
			'type'      => 'border',
			'title'     => esc_html__( 'Input Border', 'profecient-essential' ),
			'segment'   => 'additional_information',
			'selectors' => '.woocommerce-additional-fields .woocommerce-input-wrapper textarea',
		);

		$this->options['additional_information_input_border_radius'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Input Border Radius', 'profecient-essential' ),
			'segment'   => 'additional_information',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.woocommerce-additional-fields .woocommerce-input-wrapper textarea',
			'attribute' => 'border-radius',
		);

		/* ----- Additional Information ----- */
	}

	/**
	 * Add Additional Style.
	 */
	public function additional_style() {
		$this->style_option();

		parent::additional_style();
	}
}
