<?php
/**
 * Woocommerce Menu Cart Option Class
 *
 * @package profecient-essential
 * @author jegtheme
 * @since 1.0.0
 */

namespace Profecient\Essential\JKit\Elements\Options;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

use Jeg\Elementor_Kit\Elements\Options\Option_Abstract;

/**
 * Class Woocommerce_Menu_Cart_Option
 */
class Woocommerce_Menu_Cart_Option extends Option_Abstract {
	/**
	 * Show color scheme flag for element.
	 *
	 * @return bool
	 */
	public function show_color_scheme() {
		return false;
	}

	/**
	 * Compatibility column
	 *
	 * @return array
	 */
	public function compatible_column() {
		return array();
	}

	/**
	 * Override function to remove compatible column alert
	 */
	public function set_compatible_column_option() {}

	/**
	 * Element name
	 *
	 * @return string
	 */
	public function get_element_name() {
		return esc_html__( 'Menu Cart', 'profecient-essential' );
	}

	/**
	 * Element category
	 *
	 * @return string
	 */
	public function get_category() {
		return esc_html__( 'Profecient - Woocommerce', 'profecient-essential' );
	}

	/**
	 * Element options
	 */
	public function set_options() {
		$this->set_element_options();
		$this->set_style_option();

		parent::set_options();
	}

	/**
	 * Option segments
	 */
	public function set_segments() {
		$this->segments['segment_button_toggle'] = array(
			'name'     => esc_html__( 'Button Toggle', 'profecient-essential' ),
			'priority' => 10,
		);

		$this->segments['segment_offcanvas'] = array(
			'name'     => esc_html__( 'Offcanvas', 'profecient-essential' ),
			'priority' => 11,
		);

		$this->set_style_segment();
	}

	/**
	 * Style segments
	 */
	public function set_style_segment() {
		$this->segments['style_toggle_button'] = array(
			'name'      => esc_html__( 'Toggle Button', 'profecient-essential' ),
			'priority'  => 11,
			'kit_style' => true,
		);

		$this->segments['style_panel'] = array(
			'name'      => esc_html__( 'Panel', 'profecient-essential' ),
			'priority'  => 12,
			'kit_style' => true,
		);

		$this->segments['style_close_button'] = array(
			'name'      => esc_html__( 'Close Button', 'profecient-essential' ),
			'priority'  => 13,
			'kit_style' => true,
		);

		$this->segments['style_close_button'] = array(
			'name'      => esc_html__( 'Close Button', 'profecient-essential' ),
			'priority'  => 13,
			'kit_style' => true,
		);

		$this->segments['style_cart_item'] = array(
			'name'      => esc_html__( 'Cart Item', 'profecient-essential' ),
			'priority'  => 14,
			'kit_style' => true,
		);

		$this->segments['style_total_price'] = array(
			'name'      => esc_html__( 'Total Price', 'profecient-essential' ),
			'priority'  => 15,
			'kit_style' => true,
		);

		$this->segments['style_cart_button'] = array(
			'name'      => esc_html__( 'Button', 'profecient-essential' ),
			'priority'  => 16,
			'kit_style' => true,
		);

		$this->segments['style_cart_empty'] = array(
			'name'      => esc_html__( 'Cart Empty', 'profecient-essential' ),
			'priority'  => 17,
			'kit_style' => true,
		);

		parent::set_style_segment();
	}

	/**
	 * Set element option
	 */
	public function set_element_options() {
		$this->options['sg_button_toggle_icon'] = array(
			'type'    => 'iconpicker',
			'title'   => esc_html__( 'Icon', 'profecient-essential' ),
			'segment' => 'segment_button_toggle',
			'default' => array(
				'value'   => 'jki jki-cart11-light',
				'library' => 'jkiticon',
			),
		);

		$this->options['sg_button_toggle_total_item_show'] = array(
			'type'    => 'checkbox',
			'title'   => esc_html__( 'Total Item', 'profecient-essential' ),
			'segment' => 'segment_button_toggle',
			'default' => 'yes',
		);

		$this->options['sg_button_toggle_total_item_type'] = array(
			'type'       => 'select',
			'title'      => esc_html__( 'Total Item Type', 'profecient-essential' ),
			'segment'    => 'segment_button_toggle',
			'options'    => array(
				'initial'  => esc_html__( 'Initial', 'profecient-essential' ),
				'absolute' => esc_html__( 'Absolute', 'profecient-essential' ),
			),
			'default'    => 'absolute',
			'dependency' => array(
				array(
					'field'    => 'sg_button_toggle_total_item_show',
					'operator' => '==',
					'value'    => 'yes',
				),
			),
		);

		$this->options['sg_button_toggle_subtotal_show'] = array(
			'type'    => 'checkbox',
			'title'   => esc_html__( 'Subtotal', 'profecient-essential' ),
			'segment' => 'segment_button_toggle',
			'default' => 'yes',
		);

		$this->options['sg_offcanvas_position'] = array(
			'type'    => 'radio',
			'title'   => esc_html__( 'Offcanvas position', 'profecient-essential' ),
			'default' => 'right',
			'segment' => 'segment_offcanvas',
			'options' => array(
				'left'  => array(
					'title' => esc_html__( 'Left', 'profecient-essential' ),
					'icon'  => 'fas fa-align-left',
				),
				'right' => array(
					'title' => esc_html__( 'Right', 'profecient-essential' ),
					'icon'  => 'fas fa-align-right',
				),
			),
		);
	}

	public function set_style_option() {
		$this->options['st_button_toggle_margin'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Margin', 'profecient-essential' ),
			'segment'   => 'style_toggle_button',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.profecient-menu-cart .cart-button-wrapper .cart-button-toggle',
			'attribute' => 'margin',
		);

		$this->options['st_button_toggle_padding'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Padding', 'profecient-essential' ),
			'segment'   => 'style_toggle_button',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.profecient-menu-cart .cart-button-wrapper .cart-button-toggle',
			'attribute' => 'padding',
		);

		$this->options['st_button_toggle_align'] = array(
			'type'       => 'radio',
			'title'      => esc_html__( 'Wrapper Alignment', 'profecient-essential' ),
			'segment'    => 'style_toggle_button',
			'options'    => array(
				'left'   => array(
					'title' => esc_html__( 'Left', 'profecient-essential' ),
					'icon'  => 'fas fa-align-left',
				),
				'center' => array(
					'title' => esc_html__( 'Center', 'profecient-essential' ),
					'icon'  => 'fas fa-align-center',
				),
				'right'  => array(
					'title' => esc_html__( 'Right', 'profecient-essential' ),
					'icon'  => 'fas fa-align-right',
				),
			),
			'selectors'  => '.profecient-menu-cart .cart-button-wrapper',
			'attribute'  => 'text-align',
			'responsive' => true,
		);

		$this->options['st_button_toggle_icon_position'] = array(
			'type'       => 'radio',
			'title'      => esc_html__( 'Icon Position', 'profecient-essential' ),
			'segment'    => 'style_toggle_button',
			'default'    => 'row',
			'options'    => array(
				'row-reverse' => array(
					'title' => esc_html__( 'Left', 'profecient-essential' ),
					'icon'  => 'eicon-h-align-left',
				),
				'row'         => array(
					'title' => esc_html__( 'Right', 'profecient-essential' ),
					'icon'  => 'eicon-h-align-right',
				),
			),
			'selectors'  => '.profecient-menu-cart .cart-button-wrapper .cart-button-toggle',
			'attribute'  => 'flex-direction',
			'dependency' => array(
				array(
					'field'    => 'sg_button_toggle_subtotal_show',
					'operator' => '==',
					'value'    => 'yes',
				),
			),
		);

		$this->options['st_button_toggle_icon_gap'] = array(
			'type'       => 'slider',
			'title'      => esc_html__( 'Icon Gap', 'profecient-essential' ),
			'segment'    => 'style_toggle_button',
			'responsive' => true,
			'units'      => array( 'px', 'em' ),
			'options'    => array(
				'min'  => 0,
				'max'  => 100,
				'step' => 1,
			),
			'selectors'  => '.profecient-menu-cart .cart-button-wrapper .cart-button-toggle',
			'attribute'  => 'gap',
			'dependency' => array(
				array(
					'field'    => 'sg_button_toggle_total_item_show',
					'operator' => '==',
					'value'    => 'yes',
				),
			),
		);

		$this->options['st_button_toggle_typograhpy'] = array(
			'type'      => 'typography',
			'title'     => esc_html__( 'Typography', 'profecient-essential' ),
			'segment'   => 'style_toggle_button',
			'selectors' => '.profecient-menu-cart .cart-button-wrapper .cart-button-toggle',
		);

		$this->options['st_button_toggle_tabs_start'] = array(
			'type'    => 'control_tabs_start',
			'segment' => 'style_toggle_button',
		);

		$this->options['st_button_toggle_normal_tab_start'] = array(
			'type'    => 'control_tab_start',
			'title'   => esc_html__( 'Normal', 'profecient-essential' ),
			'segment' => 'style_toggle_button',
		);

		$this->options['st_button_toggle_normal_text_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Text Color', 'profecient-essential' ),
			'segment'   => 'style_toggle_button',
			'selectors' => '.profecient-menu-cart .cart-button-wrapper .cart-button-toggle',
		);

		$this->options['st_button_toggle_normal_background'] = array(
			'type'      => 'background',
			'title'     => esc_html__( 'Background', 'profecient-essential' ),
			'segment'   => 'style_toggle_button',
			'options'   => array(
				'classic',
				'gradient',
			),
			'selectors' => '.profecient-menu-cart .cart-button-wrapper .cart-button-toggle',
		);

		$this->options['st_button_toggle_normal_border'] = array(
			'type'      => 'border',
			'title'     => esc_html__( 'Border', 'profecient-essential' ),
			'segment'   => 'style_toggle_button',
			'selectors' => '.profecient-menu-cart .cart-button-wrapper .cart-button-toggle',
		);

		$this->options['st_button_toggle_normal_border_radius'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Border Radius', 'profecient-essential' ),
			'segment'   => 'style_toggle_button',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.profecient-menu-cart .cart-button-wrapper .cart-button-toggle',
			'attribute' => 'border-radius',
		);

		$this->options['st_button_toggle_normal_boxshadow'] = array(
			'type'      => 'boxshadow',
			'title'     => esc_html__( 'Box Shadow', 'profecient-essential' ),
			'segment'   => 'style_toggle_button',
			'selectors' => '.profecient-menu-cart .cart-button-wrapper .cart-button-toggle',
		);

		$this->options['st_button_toggle_normal_tab_end'] = array(
			'type'    => 'control_tab_end',
			'segment' => 'style_toggle_button',
		);

		$this->options['st_button_toggle_hover_tab_start'] = array(
			'type'    => 'control_tab_start',
			'title'   => esc_html__( 'Hover', 'profecient-essential' ),
			'segment' => 'style_toggle_button',
		);

		$this->options['st_button_toggle_hover_transition_duration'] = array(
			'type'      => 'slider',
			'title'     => esc_html__( 'Transition Duration', 'profecient-essential' ),
			'segment'   => 'style_toggle_button',
			'options'   => array(
				'min'  => 0,
				'max'  => 10,
				'step' => 0.1,
			),
			'selectors' => array(
				'custom' => array(
					'{{WRAPPER}} .profecient-menu-cart .cart-button-wrapper .cart-button-toggle' => 'transition-duration: {{SIZE}}s;',
				),
			),
		);

		$this->options['st_button_toggle_hover_text_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Text Color', 'profecient-essential' ),
			'segment'   => 'style_toggle_button',
			'selectors' => '.profecient-menu-cart .cart-button-wrapper .cart-button-toggle:hover',
		);

		$this->options['st_button_toggle_hover_background'] = array(
			'type'      => 'background',
			'title'     => esc_html__( 'Background', 'profecient-essential' ),
			'segment'   => 'style_toggle_button',
			'options'   => array(
				'classic',
				'gradient',
			),
			'selectors' => '.profecient-menu-cart .cart-button-wrapper .cart-button-toggle:hover',
		);

		$this->options['st_button_toggle_hover_border'] = array(
			'type'      => 'border',
			'title'     => esc_html__( 'Border', 'profecient-essential' ),
			'segment'   => 'style_toggle_button',
			'selectors' => '.profecient-menu-cart .cart-button-wrapper .cart-button-toggle:hover',
		);

		$this->options['st_button_toggle_hover_border_radius'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Border Radius', 'profecient-essential' ),
			'segment'   => 'style_toggle_button',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.profecient-menu-cart .cart-button-wrapper .cart-button-toggle:hover',
			'attribute' => 'border-radius',
		);

		$this->options['st_button_toggle_hover_boxshadow'] = array(
			'type'      => 'boxshadow',
			'title'     => esc_html__( 'Box Shadow', 'profecient-essential' ),
			'segment'   => 'style_toggle_button',
			'selectors' => '.profecient-menu-cart .cart-button-wrapper .cart-button-toggle:hover',
		);

		$this->options['st_button_toggle_hover_tab_end'] = array(
			'type'    => 'control_tab_end',
			'segment' => 'style_toggle_button',
		);

		$this->options['st_button_toggle_tabs_end'] = array(
			'type'    => 'control_tabs_end',
			'segment' => 'style_toggle_button',
		);

		$this->options['st_button_toggle_total_item_heading'] = array(
			'type'       => 'heading',
			'title'      => esc_html__( 'Total item', 'profecient-essential' ),
			'segment'    => 'style_toggle_button',
			'separator'  => 'before',
			'dependency' => array(
				array(
					'field'    => 'sg_button_toggle_total_item_show',
					'operator' => '==',
					'value'    => 'yes',
				),
			),
		);

		$this->options['st_button_toggle_total_item_position'] = array(
			'type'       => 'radio',
			'title'      => esc_html__( 'Total Item Position', 'profecient-essential' ),
			'segment'    => 'style_toggle_button',
			'default'    => 'row',
			'options'    => array(
				'row-reverse' => array(
					'title' => esc_html__( 'Left', 'profecient-essential' ),
					'icon'  => 'eicon-h-align-left',
				),
				'row'         => array(
					'title' => esc_html__( 'Right', 'profecient-essential' ),
					'icon'  => 'eicon-h-align-right',
				),
			),
			'selectors'  => '.profecient-menu-cart .cart-button-wrapper .cart-button-toggle .cart-button-icon',
			'attribute'  => 'flex-direction',
			'dependency' => array(
				array(
					'field'    => 'sg_button_toggle_subtotal_show',
					'operator' => '==',
					'value'    => 'yes',
				),
				array(
					'field'    => 'sg_button_toggle_total_item_type',
					'operator' => '==',
					'value'    => 'initial',
				),
			),
		);

		$this->options['st_button_toggle_total_item_gap'] = array(
			'type'       => 'slider',
			'title'      => esc_html__( 'Total Item Gap', 'profecient-essential' ),
			'segment'    => 'style_toggle_button',
			'responsive' => true,
			'units'      => array( 'px', 'em' ),
			'options'    => array(
				'min'  => 0,
				'max'  => 100,
				'step' => 1,
			),
			'selectors'  => '.profecient-menu-cart .cart-button-wrapper .cart-button-toggle .cart-button-icon',
			'attribute'  => 'gap',
			'dependency' => array(
				array(
					'field'    => 'sg_button_toggle_total_item_show',
					'operator' => '==',
					'value'    => 'yes',
				),
				array(
					'field'    => 'sg_button_toggle_total_item_type',
					'operator' => '==',
					'value'    => 'initial',
				),
			),
		);

		$this->options['st_button_toggle_total_item_horizontal_orientation'] = array(
			'type'       => 'radio',
			'title'      => esc_html__( 'Horizontal Orientation', 'profecient-essential' ),
			'segment'    => 'style_toggle_button',
			'options'    => array(
				'left'  => array(
					'title' => esc_html__( 'Left', 'profecient-essential' ),
					'icon'  => 'eicon-h-align-left',
				),
				'right' => array(
					'title' => esc_html__( 'Right', 'profecient-essential' ),
					'icon'  => 'eicon-h-align-right',
				),
			),
			'default'    => 'left',
			'toggle'     => false,
			'dependency' => array(
				array(
					'field'    => 'sg_button_toggle_total_item_show',
					'operator' => '==',
					'value'    => 'yes',
				),
				array(
					'field'    => 'sg_button_toggle_total_item_type',
					'operator' => '==',
					'value'    => 'absolute',
				),
			),
		);

		$this->options['st_button_toggle_total_item_horizontal_offset'] = array(
			'type'       => 'slider',
			'title'      => esc_html__( 'Offset', 'profecient-essential' ),
			'segment'    => 'style_toggle_button',
			'responsive' => true,
			'units'      => array( 'px', '%', 'em' ),
			'options'    => array(
				'min'  => 0,
				'max'  => 100,
				'step' => 1,
			),
			'default'    => 8,
			'selectors'  => array(
				'custom' => array( '{{WRAPPER}} .profecient-menu-cart .cart-button-wrapper .cart-button-toggle .total-item' => '{{st_button_toggle_total_item_horizontal_orientation.VALUE}}: {{SIZE}}{{UNIT}};' ),
			),
			'dependency' => array(
				array(
					'field'    => 'sg_button_toggle_total_item_show',
					'operator' => '==',
					'value'    => 'yes',
				),
				array(
					'field'    => 'sg_button_toggle_total_item_type',
					'operator' => '==',
					'value'    => 'absolute',
				),
			),
		);

		$this->options['st_button_toggle_total_item_vertical_orientation'] = array(
			'type'       => 'radio',
			'title'      => esc_html__( 'Vertical Orientation', 'profecient-essential' ),
			'segment'    => 'style_toggle_button',
			'options'    => array(
				'top'    => array(
					'title' => esc_html__( 'Top', 'profecient-essential' ),
					'icon'  => 'eicon-v-align-top',
				),
				'bottom' => array(
					'title' => esc_html__( 'Bottom', 'profecient-essential' ),
					'icon'  => 'eicon-v-align-bottom',
				),
			),
			'default'    => 'bottom',
			'toggle'     => false,
			'dependency' => array(
				array(
					'field'    => 'sg_button_toggle_total_item_show',
					'operator' => '==',
					'value'    => 'yes',
				),
				array(
					'field'    => 'sg_button_toggle_total_item_type',
					'operator' => '==',
					'value'    => 'absolute',
				),
			),
		);

		$this->options['st_button_toggle_total_item_vertical_offset'] = array(
			'type'       => 'slider',
			'title'      => esc_html__( 'Offset', 'profecient-essential' ),
			'segment'    => 'style_toggle_button',
			'responsive' => true,
			'units'      => array( 'px', '%', 'em' ),
			'options'    => array(
				'min'  => 0,
				'max'  => 100,
				'step' => 1,
			),
			'default'    => 3,
			'selectors'  => array(
				'custom' => array( '{{WRAPPER}} .profecient-menu-cart .cart-button-wrapper .cart-button-toggle .total-item' => '{{st_button_toggle_total_item_vertical_orientation.VALUE}}: {{SIZE}}{{UNIT}};' ),
			),
			'dependency' => array(
				array(
					'field'    => 'sg_button_toggle_total_item_show',
					'operator' => '==',
					'value'    => 'yes',
				),
				array(
					'field'    => 'sg_button_toggle_total_item_type',
					'operator' => '==',
					'value'    => 'absolute',
				),
			),
		);

		$this->options['st_button_toggle_total_item_margin'] = array(
			'type'       => 'dimension',
			'title'      => esc_html__( 'Margin', 'profecient-essential' ),
			'segment'    => 'style_toggle_button',
			'units'      => array( 'px', '%', 'em' ),
			'selectors'  => '.profecient-menu-cart .cart-button-wrapper .cart-button-toggle .total-item',
			'attribute'  => 'margin',
			'dependency' => array(
				array(
					'field'    => 'sg_button_toggle_total_item_show',
					'operator' => '==',
					'value'    => 'yes',
				),
				array(
					'field'    => 'sg_button_toggle_total_item_type',
					'operator' => '==',
					'value'    => 'absolute',
				),
			),
		);

		$this->options['st_button_toggle_total_item_padding'] = array(
			'type'       => 'dimension',
			'title'      => esc_html__( 'Padding', 'profecient-essential' ),
			'segment'    => 'style_toggle_button',
			'units'      => array( 'px', '%', 'em' ),
			'selectors'  => '.profecient-menu-cart .cart-button-wrapper .cart-button-toggle .total-item',
			'attribute'  => 'padding',
			'dependency' => array(
				array(
					'field'    => 'sg_button_toggle_total_item_show',
					'operator' => '==',
					'value'    => 'yes',
				),
				array(
					'field'    => 'sg_button_toggle_total_item_type',
					'operator' => '==',
					'value'    => 'absolute',
				),
			),
		);

		$this->options['st_button_toggle_total_item_typograhpy'] = array(
			'type'       => 'typography',
			'title'      => esc_html__( 'Typography', 'profecient-essential' ),
			'segment'    => 'style_toggle_button',
			'selectors'  => '.profecient-menu-cart .cart-button-wrapper .cart-button-toggle .total-item',
			'dependency' => array(
				array(
					'field'    => 'sg_button_toggle_total_item_show',
					'operator' => '==',
					'value'    => 'yes',
				),
				array(
					'field'    => 'sg_button_toggle_total_item_type',
					'operator' => '==',
					'value'    => 'absolute',
				),
			),
		);

		$this->options['st_button_toggle_total_item_tabs_start'] = array(
			'type'       => 'control_tabs_start',
			'segment'    => 'style_toggle_button',
			'dependency' => array(
				array(
					'field'    => 'sg_button_toggle_total_item_show',
					'operator' => '==',
					'value'    => 'yes',
				),
				array(
					'field'    => 'sg_button_toggle_total_item_type',
					'operator' => '==',
					'value'    => 'absolute',
				),
			),
		);

		$this->options['st_button_toggle_total_item_normal_tab_start'] = array(
			'type'       => 'control_tab_start',
			'title'      => esc_html__( 'Normal', 'profecient-essential' ),
			'segment'    => 'style_toggle_button',
			'dependency' => array(
				array(
					'field'    => 'sg_button_toggle_total_item_show',
					'operator' => '==',
					'value'    => 'yes',
				),
			),
		);

		$this->options['st_button_toggle_total_item_normal_text_color'] = array(
			'type'       => 'color',
			'title'      => esc_html__( 'Text Color', 'profecient-essential' ),
			'segment'    => 'style_toggle_button',
			'selectors'  => '.profecient-menu-cart .cart-button-wrapper .cart-button-toggle .total-item',
			'dependency' => array(
				array(
					'field'    => 'sg_button_toggle_total_item_show',
					'operator' => '==',
					'value'    => 'yes',
				),
			),
		);

		$this->options['st_button_toggle_total_item_normal_background'] = array(
			'type'       => 'background',
			'title'      => esc_html__( 'Background', 'profecient-essential' ),
			'segment'    => 'style_toggle_button',
			'options'    => array(
				'classic',
				'gradient',
			),
			'selectors'  => '.profecient-menu-cart .cart-button-wrapper .cart-button-toggle .total-item',
			'dependency' => array(
				array(
					'field'    => 'sg_button_toggle_total_item_show',
					'operator' => '==',
					'value'    => 'yes',
				),
			),
		);

		$this->options['st_button_toggle_total_item_normal_border'] = array(
			'type'       => 'border',
			'title'      => esc_html__( 'Border', 'profecient-essential' ),
			'segment'    => 'style_toggle_button',
			'selectors'  => '.profecient-menu-cart .cart-button-wrapper .cart-button-toggle .total-item',
			'dependency' => array(
				array(
					'field'    => 'sg_button_toggle_total_item_show',
					'operator' => '==',
					'value'    => 'yes',
				),
			),
		);

		$this->options['st_button_toggle_total_item_normal_border_radius'] = array(
			'type'       => 'dimension',
			'title'      => esc_html__( 'Border Radius', 'profecient-essential' ),
			'segment'    => 'style_toggle_button',
			'units'      => array( 'px', '%', 'em' ),
			'selectors'  => '.profecient-menu-cart .cart-button-wrapper .cart-button-toggle .total-item',
			'attribute'  => 'border-radius',
			'dependency' => array(
				array(
					'field'    => 'sg_button_toggle_total_item_show',
					'operator' => '==',
					'value'    => 'yes',
				),
			),
		);

		$this->options['st_button_toggle_total_item_normal_boxshadow'] = array(
			'type'       => 'boxshadow',
			'title'      => esc_html__( 'Box Shadow', 'profecient-essential' ),
			'segment'    => 'style_toggle_button',
			'selectors'  => '.profecient-menu-cart .cart-button-wrapper .cart-button-toggle .total-item',
			'dependency' => array(
				array(
					'field'    => 'sg_button_toggle_total_item_show',
					'operator' => '==',
					'value'    => 'yes',
				),
			),
		);

		$this->options['st_button_toggle_total_item_normal_tab_end'] = array(
			'type'       => 'control_tab_end',
			'segment'    => 'style_toggle_button',
			'dependency' => array(
				array(
					'field'    => 'sg_button_toggle_total_item_show',
					'operator' => '==',
					'value'    => 'yes',
				),
			),
		);

		$this->options['st_button_toggle_total_item_hover_tab_start'] = array(
			'type'       => 'control_tab_start',
			'title'      => esc_html__( 'Hover', 'profecient-essential' ),
			'segment'    => 'style_toggle_button',
			'dependency' => array(
				array(
					'field'    => 'sg_button_toggle_total_item_show',
					'operator' => '==',
					'value'    => 'yes',
				),
			),
		);

		$this->options['st_button_toggle_total_item_hover_transition_duration'] = array(
			'type'       => 'slider',
			'title'      => esc_html__( 'Transition Duration', 'profecient-essential' ),
			'segment'    => 'style_toggle_button',
			'options'    => array(
				'min'  => 0,
				'max'  => 10,
				'step' => 0.1,
			),
			'selectors'  => array(
				'custom' => array(
					'{{WRAPPER}} .profecient-menu-cart .cart-button-wrapper .cart-button-toggle .total-item' => 'transition-duration: {{SIZE}}s;',
				),
			),
			'dependency' => array(
				array(
					'field'    => 'sg_button_toggle_total_item_show',
					'operator' => '==',
					'value'    => 'yes',
				),
			),
		);

		$this->options['st_button_toggle_total_item_hover_text_color'] = array(
			'type'       => 'color',
			'title'      => esc_html__( 'Text Color', 'profecient-essential' ),
			'segment'    => 'style_toggle_button',
			'selectors'  => '.profecient-menu-cart .cart-button-wrapper .cart-button-toggle .total-item:hover',
			'dependency' => array(
				array(
					'field'    => 'sg_button_toggle_total_item_show',
					'operator' => '==',
					'value'    => 'yes',
				),
			),
		);

		$this->options['st_button_toggle_total_item_hover_background'] = array(
			'type'       => 'background',
			'title'      => esc_html__( 'Background', 'profecient-essential' ),
			'segment'    => 'style_toggle_button',
			'options'    => array(
				'classic',
				'gradient',
			),
			'selectors'  => '.profecient-menu-cart .cart-button-wrapper .cart-button-toggle .total-item:hover',
			'dependency' => array(
				array(
					'field'    => 'sg_button_toggle_total_item_show',
					'operator' => '==',
					'value'    => 'yes',
				),
			),
		);

		$this->options['st_button_toggle_total_item_hover_border'] = array(
			'type'       => 'border',
			'title'      => esc_html__( 'Border', 'profecient-essential' ),
			'segment'    => 'style_toggle_button',
			'selectors'  => '.profecient-menu-cart .cart-button-wrapper .cart-button-toggle .total-item:hover',
			'dependency' => array(
				array(
					'field'    => 'sg_button_toggle_total_item_show',
					'operator' => '==',
					'value'    => 'yes',
				),
			),
		);

		$this->options['st_button_toggle_total_item_hover_border_radius'] = array(
			'type'       => 'dimension',
			'title'      => esc_html__( 'Border Radius', 'profecient-essential' ),
			'segment'    => 'style_toggle_button',
			'units'      => array( 'px', '%', 'em' ),
			'selectors'  => '.profecient-menu-cart .cart-button-wrapper .cart-button-toggle .total-item:hover',
			'attribute'  => 'border-radius',
			'dependency' => array(
				array(
					'field'    => 'sg_button_toggle_total_item_show',
					'operator' => '==',
					'value'    => 'yes',
				),
			),
		);

		$this->options['st_button_toggle_total_item_hover_boxshadow'] = array(
			'type'       => 'boxshadow',
			'title'      => esc_html__( 'Box Shadow', 'profecient-essential' ),
			'segment'    => 'style_toggle_button',
			'selectors'  => '.profecient-menu-cart .cart-button-wrapper .cart-button-toggle .total-item:hover',
			'dependency' => array(
				array(
					'field'    => 'sg_button_toggle_total_item_show',
					'operator' => '==',
					'value'    => 'yes',
				),
			),
		);

		$this->options['st_button_toggle_total_item_hover_tab_end'] = array(
			'type'       => 'control_tab_end',
			'segment'    => 'style_toggle_button',
			'dependency' => array(
				array(
					'field'    => 'sg_button_toggle_total_item_show',
					'operator' => '==',
					'value'    => 'yes',
				),
			),
		);

		$this->options['st_button_toggle_total_item_tabs_end'] = array(
			'type'       => 'control_tabs_end',
			'segment'    => 'style_toggle_button',
			'dependency' => array(
				array(
					'field'    => 'sg_button_toggle_total_item_show',
					'operator' => '==',
					'value'    => 'yes',
				),
			),
		);

		$this->options['st_panel_margin'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Margin', 'profecient-essential' ),
			'segment'   => 'style_panel',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.profecient-menu-cart .cart-offcanvas .sidebar',
			'attribute' => 'margin',
		);

		$this->options['st_panel_padding'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Padding', 'profecient-essential' ),
			'segment'   => 'style_panel',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.profecient-menu-cart .cart-offcanvas .sidebar',
			'attribute' => 'padding',
		);

		$this->options['st_panel_width'] = array(
			'type'       => 'slider',
			'title'      => esc_html__( 'Width', 'profecient-essential' ),
			'segment'    => 'style_panel',
			'options'    => array(
				'min'  => 0,
				'max'  => 5000,
				'step' => 1,
			),
			'units'      => array( 'px', '%', 'em' ),
			'responsive' => true,
			'selectors'  => '.profecient-menu-cart .cart-offcanvas .sidebar',
			'attribute'  => 'width',
		);

		$this->options['st_panel_background'] = array(
			'type'      => 'background',
			'title'     => esc_html__( 'Background', 'profecient-essential' ),
			'segment'   => 'style_panel',
			'options'   => array(
				'classic',
				'gradient',
			),
			'selectors' => '.profecient-menu-cart .cart-offcanvas .sidebar',
		);

		$this->options['st_close_button_margin'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Margin', 'profecient-essential' ),
			'segment'   => 'style_close_button',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.profecient-menu-cart .cart-offcanvas .sidebar .offcanvas-close-button-wrapper .offcanvas-close-button',
			'attribute' => 'margin',
			'default'   => array(
				'top'      => '25',
				'right'    => '25',
				'bottom'   => '25',
				'left'     => '25',
				'unit'     => 'px',
				'isLinked' => true,
			),
		);

		$this->options['st_close_button_padding'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Padding', 'profecient-essential' ),
			'segment'   => 'style_close_button',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.profecient-menu-cart .cart-offcanvas .sidebar .offcanvas-close-button-wrapper .offcanvas-close-button',
			'attribute' => 'padding',
		);

		$this->options['st_close_button_alignment'] = array(
			'type'       => 'radio',
			'title'      => esc_html__( 'Alignment', 'profecient-essential' ),
			'segment'    => 'style_close_button',
			'options'    => array(
				'left'   => array(
					'title' => esc_html__( 'Left', 'profecient-essential' ),
					'icon'  => 'fas fa-align-left',
				),
				'center' => array(
					'title' => esc_html__( 'Center', 'profecient-essential' ),
					'icon'  => 'fas fa-align-center',
				),
				'right'  => array(
					'title' => esc_html__( 'Right', 'profecient-essential' ),
					'icon'  => 'fas fa-align-right',
				),
			),
			'responsive' => true,
			'selectors'  => '.profecient-menu-cart .cart-offcanvas .sidebar .offcanvas-close-button-wrapper',
			'attribute'  => 'text-align',
			'default'    => 'right',
		);

		$this->options['st_close_button_width'] = array(
			'type'       => 'slider',
			'title'      => esc_html__( 'Width', 'profecient-essential' ),
			'segment'    => 'style_close_button',
			'options'    => array(
				'min'  => 0,
				'max'  => 1000,
				'step' => 1,
			),
			'units'      => array( 'px', '%' ),
			'responsive' => true,
			'selectors'  => '.profecient-menu-cart .cart-offcanvas .sidebar .offcanvas-close-button-wrapper .offcanvas-close-button',
			'attribute'  => 'width',
		);

		$this->options['st_close_button_size'] = array(
			'type'       => 'slider',
			'title'      => esc_html__( 'Size', 'profecient-essential' ),
			'segment'    => 'style_close_button',
			'units'      => array( 'px' ),
			'default'    => 20,
			'options'    => array(
				'min'  => 0,
				'max'  => 100,
				'step' => 1,
			),
			'responsive' => true,
			'selectors'  => array(
				'custom' => array(
					'{{WRAPPER}} .profecient-menu-cart .cart-offcanvas .sidebar .offcanvas-close-button-wrapper .offcanvas-close-button'     => 'font-size: {{SIZE}}{{UNIT}};',
					'{{WRAPPER}} .profecient-menu-cart .cart-offcanvas .sidebar .offcanvas-close-button-wrapper .offcanvas-close-button svg' => 'width: {{SIZE}}{{UNIT}};',
				),
			),
		);

		$this->options['st_close_button_tabs_start'] = array(
			'type'    => 'control_tabs_start',
			'segment' => 'style_close_button',
		);

		$this->options['st_close_button_normal_tab_start'] = array(
			'type'    => 'control_tab_start',
			'title'   => esc_html__( 'Normal', 'profecient-essential' ),
			'segment' => 'style_close_button',
		);

		$this->options['st_close_button_normal_color'] = array(
			'type'       => 'color',
			'title'      => esc_html__( 'Color', 'profecient-essential' ),
			'responsive' => true,
			'segment'    => 'style_close_button',
			'selectors'  => array(
				'custom' => array(
					'{{WRAPPER}} .profecient-menu-cart .cart-offcanvas .sidebar .offcanvas-close-button-wrapper .offcanvas-close-button'     => 'color: {{VALUE}};',
					'{{WRAPPER}} .profecient-menu-cart .cart-offcanvas .sidebar .offcanvas-close-button-wrapper .offcanvas-close-button svg' => 'fill: {{VALUE}};',
				),
			),
		);

		$this->options['st_close_button_normal_background'] = array(
			'type'      => 'background',
			'title'     => esc_html__( 'Background', 'profecient-essential' ),
			'segment'   => 'style_close_button',
			'selectors' => '.profecient-menu-cart .cart-offcanvas .sidebar .offcanvas-close-button-wrapper .offcanvas-close-button',
			'options'   => array(
				'classic',
				'gradient',
			),
		);

		$this->options['st_close_button_normal_border'] = array(
			'type'      => 'border',
			'title'     => esc_html__( 'Border', 'profecient-essential' ),
			'segment'   => 'style_close_button',
			'selectors' => '.profecient-menu-cart .cart-offcanvas .sidebar .offcanvas-close-button-wrapper .offcanvas-close-button',
		);

		$this->options['st_close_button_normal_border_radius'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Border Radius', 'profecient-essential' ),
			'segment'   => 'style_close_button',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.profecient-menu-cart .cart-offcanvas .sidebar .offcanvas-close-button-wrapper .offcanvas-close-button',
			'attribute' => 'border-radius',
		);

		$this->options['st_close_button_normal_boxshadow'] = array(
			'type'      => 'boxshadow',
			'title'     => esc_html__( 'Box Shadow', 'profecient-essential' ),
			'segment'   => 'style_close_button',
			'selectors' => '.profecient-menu-cart .cart-offcanvas .sidebar .offcanvas-close-button-wrapper .offcanvas-close-button',
		);

		$this->options['st_close_button_normal_tab_end'] = array(
			'type'    => 'control_tab_end',
			'segment' => 'style_close_button',
		);

		$this->options['st_close_button_hover_tab_start'] = array(
			'type'    => 'control_tab_start',
			'title'   => esc_html__( 'Hover', 'profecient-essential' ),
			'segment' => 'style_close_button',
		);

		$this->options['st_close_button_hover_transition_duration'] = array(
			'type'      => 'slider',
			'title'     => esc_html__( 'Transition Duration', 'profecient-essential' ),
			'segment'   => 'style_close_button',
			'options'   => array(
				'min'  => 0,
				'max'  => 10,
				'step' => 0.1,
			),
			'selectors' => array(
				'custom' => array(
					'{{WRAPPER}} .profecient-menu-cart .cart-offcanvas .sidebar .offcanvas-close-button-wrapper .offcanvas-close-button' => 'transition-duration: {{SIZE}}s;',
				),
			),
		);

		$this->options['st_close_button_hover_color'] = array(
			'type'       => 'color',
			'title'      => esc_html__( 'Color', 'profecient-essential' ),
			'responsive' => true,
			'segment'    => 'style_close_button',
			'selectors'  => array(
				'custom' => array(
					'{{WRAPPER}} .profecient-menu-cart .cart-offcanvas .sidebar .offcanvas-close-button-wrapper .offcanvas-close-button:hover'     => 'color: {{VALUE}};',
					'{{WRAPPER}} .profecient-menu-cart .cart-offcanvas .sidebar .offcanvas-close-button-wrapper .offcanvas-close-button:hover svg' => 'fill: {{VALUE}};',
				),
			),
		);

		$this->options['st_close_button_hover_background'] = array(
			'type'      => 'background',
			'title'     => esc_html__( 'Background', 'profecient-essential' ),
			'segment'   => 'style_close_button',
			'selectors' => '.profecient-menu-cart .cart-offcanvas .sidebar .offcanvas-close-button-wrapper .offcanvas-close-button:hover',
			'options'   => array(
				'classic',
				'gradient',
			),
		);

		$this->options['st_close_button_hover_border'] = array(
			'type'      => 'border',
			'title'     => esc_html__( 'Border', 'profecient-essential' ),
			'segment'   => 'style_close_button',
			'selectors' => '.profecient-menu-cart .cart-offcanvas .sidebar .offcanvas-close-button-wrapper .offcanvas-close-button:hover',
		);

		$this->options['st_close_button_hover_border_radius'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Border Radius', 'profecient-essential' ),
			'segment'   => 'style_close_button',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.profecient-menu-cart .cart-offcanvas .sidebar .offcanvas-close-button-wrapper .offcanvas-close-button:hover',
			'attribute' => 'border-radius',
		);

		$this->options['st_close_button_hover_boxshadow'] = array(
			'type'      => 'boxshadow',
			'title'     => esc_html__( 'Box Shadow', 'profecient-essential' ),
			'segment'   => 'style_close_button',
			'selectors' => '.profecient-menu-cart .cart-offcanvas .sidebar .offcanvas-close-button-wrapper .offcanvas-close-button:hover',
		);

		$this->options['st_close_button_hover_tab_end'] = array(
			'type'    => 'control_tab_end',
			'segment' => 'style_close_button',
		);

		$this->options['st_close_button_tabs_end'] = array(
			'type'    => 'control_tabs_end',
			'segment' => 'style_close_button',
		);

		$this->options['st_cart_item_margin'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Margin', 'profecient-essential' ),
			'segment'   => 'style_cart_item',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.profecient-menu-cart .cart-offcanvas .sidebar .cart_list .mini_cart_item',
			'attribute' => 'margin',
		);

		$this->options['st_cart_item_padding'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Padding', 'profecient-essential' ),
			'segment'   => 'style_cart_item',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.profecient-menu-cart .cart-offcanvas .sidebar .cart_list .mini_cart_item',
			'attribute' => 'padding',
		);

		$this->options['st_cart_item_tabs_start'] = array(
			'type'    => 'control_tabs_start',
			'segment' => 'style_cart_item',
		);

		$this->options['st_cart_item_normal_tab_start'] = array(
			'type'    => 'control_tab_start',
			'title'   => esc_html__( 'Normal', 'profecient-essential' ),
			'segment' => 'style_cart_item',
		);

		$this->options['st_cart_item_normal_background'] = array(
			'type'      => 'background',
			'title'     => esc_html__( 'Background', 'profecient-essential' ),
			'segment'   => 'style_cart_item',
			'options'   => array(
				'classic',
				'gradient',
			),
			'selectors' => '.profecient-menu-cart .cart-offcanvas .sidebar .cart_list .mini_cart_item',
		);

		$this->options['st_cart_item_normal_border'] = array(
			'type'      => 'border',
			'title'     => esc_html__( 'Border', 'profecient-essential' ),
			'segment'   => 'style_cart_item',
			'selectors' => '.profecient-menu-cart .cart-offcanvas .sidebar .cart_list .mini_cart_item',
		);

		$this->options['st_cart_item_normal_border_radius'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Border Radius', 'profecient-essential' ),
			'segment'   => 'style_cart_item',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.profecient-menu-cart .cart-offcanvas .sidebar .cart_list .mini_cart_item',
			'attribute' => 'border-radius',
		);

		$this->options['st_cart_item_normal_boxshadow'] = array(
			'type'      => 'boxshadow',
			'title'     => esc_html__( 'Box Shadow', 'profecient-essential' ),
			'segment'   => 'style_cart_item',
			'selectors' => '.profecient-menu-cart .cart-offcanvas .sidebar .cart_list .mini_cart_item',
		);

		$this->options['st_cart_item_normal_tab_end'] = array(
			'type'    => 'control_tab_end',
			'segment' => 'style_cart_item',
		);

		$this->options['st_cart_item_hover_tab_start'] = array(
			'type'    => 'control_tab_start',
			'title'   => esc_html__( 'Hover', 'profecient-essential' ),
			'segment' => 'style_cart_item',
		);

		$this->options['st_cart_item_hover_transition_duration'] = array(
			'type'      => 'slider',
			'title'     => esc_html__( 'Transition Duration', 'profecient-essential' ),
			'segment'   => 'style_cart_item',
			'options'   => array(
				'min'  => 0,
				'max'  => 10,
				'step' => 0.1,
			),
			'selectors' => array(
				'custom' => array(
					'{{WRAPPER}} .profecient-menu-cart .cart-offcanvas .sidebar .cart_list .mini_cart_item' => 'transition-duration: {{SIZE}}s;',
				),
			),
		);

		$this->options['st_cart_item_hover_background'] = array(
			'type'      => 'background',
			'title'     => esc_html__( 'Background', 'profecient-essential' ),
			'segment'   => 'style_cart_item',
			'options'   => array(
				'classic',
				'gradient',
			),
			'selectors' => '.profecient-menu-cart .cart-offcanvas .sidebar .cart_list .mini_cart_item:hover',
		);

		$this->options['st_cart_item_hover_border'] = array(
			'type'      => 'border',
			'title'     => esc_html__( 'Border', 'profecient-essential' ),
			'segment'   => 'style_cart_item',
			'selectors' => '.profecient-menu-cart .cart-offcanvas .sidebar .cart_list .mini_cart_item:hover',
		);

		$this->options['st_cart_item_hover_border_radius'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Border Radius', 'profecient-essential' ),
			'segment'   => 'style_cart_item',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.profecient-menu-cart .cart-offcanvas .sidebar .cart_list .mini_cart_item:hover',
			'attribute' => 'border-radius',
		);

		$this->options['st_cart_item_hover_boxshadow'] = array(
			'type'      => 'boxshadow',
			'title'     => esc_html__( 'Box Shadow', 'profecient-essential' ),
			'segment'   => 'style_cart_item',
			'selectors' => '.profecient-menu-cart .cart-offcanvas .sidebar .cart_list .mini_cart_item:hover',
		);

		$this->options['st_cart_item_hover_tab_end'] = array(
			'type'    => 'control_tab_end',
			'segment' => 'style_cart_item',
		);

		$this->options['st_cart_item_tabs_end'] = array(
			'type'    => 'control_tabs_end',
			'segment' => 'style_cart_item',
		);

		/** Button Remove Style Section */
		$this->options['st_cart_item_button_remove_heading'] = array(
			'type'      => 'heading',
			'title'     => esc_html__( 'Button Remove', 'profecient-essential' ),
			'segment'   => 'style_cart_item',
			'separator' => 'before',
		);

		$this->options['st_cart_item_button_remove_margin'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Margin', 'profecient-essential' ),
			'segment'   => 'style_cart_item',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.profecient-menu-cart .cart-offcanvas .sidebar .cart_list .mini_cart_item .remove',
			'attribute' => 'margin',
		);

		$this->options['st_cart_item_button_remove_padding'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Padding', 'profecient-essential' ),
			'segment'   => 'style_cart_item',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.profecient-menu-cart .cart-offcanvas .sidebar .cart_list .mini_cart_item .remove',
			'attribute' => 'padding',
		);

		$this->options['st_cart_item_button_remove_typograhpy'] = array(
			'type'      => 'typography',
			'title'     => esc_html__( 'Typography', 'profecient-essential' ),
			'segment'   => 'style_cart_item',
			'selectors' => '.profecient-menu-cart .cart-offcanvas .sidebar .cart_list .mini_cart_item .remove',
		);

		$this->options['st_cart_item_button_remove_tabs_start'] = array(
			'type'    => 'control_tabs_start',
			'segment' => 'style_cart_item',
		);

		$this->options['st_cart_item_button_remove_normal_tab_start'] = array(
			'type'    => 'control_tab_start',
			'title'   => esc_html__( 'Normal', 'profecient-essential' ),
			'segment' => 'style_cart_item',
		);

		$this->options['st_cart_item_button_remove_normal_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Color', 'profecient-essential' ),
			'segment'   => 'style_cart_item',
			'selectors' => array(
				'custom' => array(
					'{{WRAPPER}} .profecient-menu-cart .cart-offcanvas .sidebar .cart_list .mini_cart_item .remove' => 'color: {{VALUE}}!important;',
				),
			),
		);

		$this->options['st_cart_item_button_remove_normal_background'] = array(
			'type'      => 'background',
			'title'     => esc_html__( 'Background', 'profecient-essential' ),
			'segment'   => 'style_cart_item',
			'options'   => array(
				'classic',
				'gradient',
			),
			'selectors' => '.profecient-menu-cart .cart-offcanvas .sidebar .cart_list .mini_cart_item .remove',
		);

		$this->options['st_cart_item_button_remove_normal_border'] = array(
			'type'      => 'border',
			'title'     => esc_html__( 'Border', 'profecient-essential' ),
			'segment'   => 'style_cart_item',
			'selectors' => '.profecient-menu-cart .cart-offcanvas .sidebar .cart_list .mini_cart_item .remove',
		);

		$this->options['st_cart_item_button_remove_normal_border_radius'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Border Radius', 'profecient-essential' ),
			'segment'   => 'style_cart_item',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.profecient-menu-cart .cart-offcanvas .sidebar .cart_list .mini_cart_item .remove',
			'attribute' => 'border-radius',
		);

		$this->options['st_cart_item_button_remove_normal_boxshadow'] = array(
			'type'      => 'boxshadow',
			'title'     => esc_html__( 'Box Shadow', 'profecient-essential' ),
			'segment'   => 'style_cart_item',
			'selectors' => '.profecient-menu-cart .cart-offcanvas .sidebar .cart_list .mini_cart_item .remove',
		);

		$this->options['st_cart_item_button_remove_normal_tab_end'] = array(
			'type'    => 'control_tab_end',
			'segment' => 'style_cart_item',
		);

		$this->options['st_cart_item_button_remove_hover_tab_start'] = array(
			'type'    => 'control_tab_start',
			'title'   => esc_html__( 'Hover', 'profecient-essential' ),
			'segment' => 'style_cart_item',
		);

		$this->options['st_cart_item_button_remove_hover_transition_duration'] = array(
			'type'      => 'slider',
			'title'     => esc_html__( 'Transition Duration', 'profecient-essential' ),
			'segment'   => 'style_cart_item',
			'options'   => array(
				'min'  => 0,
				'max'  => 10,
				'step' => 0.1,
			),
			'selectors' => array(
				'custom' => array(
					'{{WRAPPER}} .profecient-menu-cart .cart-offcanvas .sidebar .cart_list .mini_cart_item .remove' => 'transition-duration: {{SIZE}}s;',
				),
			),
		);

		$this->options['st_cart_item_button_remove_hover_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Color', 'profecient-essential' ),
			'segment'   => 'style_cart_item',
			'selectors' => array(
				'custom' => array(
					'{{WRAPPER}} .profecient-menu-cart .cart-offcanvas .sidebar .cart_list .mini_cart_item .remove:hover' => 'color: {{VALUE}}!important;',
				),
			),
		);

		$this->options['st_cart_item_button_remove_hover_background'] = array(
			'type'      => 'background',
			'title'     => esc_html__( 'Background', 'profecient-essential' ),
			'segment'   => 'style_cart_item',
			'options'   => array(
				'classic',
				'gradient',
			),
			'selectors' => '.profecient-menu-cart .cart-offcanvas .sidebar .cart_list .mini_cart_item .remove:hover',
		);

		$this->options['st_cart_item_button_remove_hover_border'] = array(
			'type'      => 'border',
			'title'     => esc_html__( 'Border', 'profecient-essential' ),
			'segment'   => 'style_cart_item',
			'selectors' => '.profecient-menu-cart .cart-offcanvas .sidebar .cart_list .mini_cart_item .remove:hover',
		);

		$this->options['st_cart_item_button_remove_hover_border_radius'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Border Radius', 'profecient-essential' ),
			'segment'   => 'style_cart_item',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.profecient-menu-cart .cart-offcanvas .sidebar .cart_list .mini_cart_item .remove:hover',
			'attribute' => 'border-radius',
		);

		$this->options['st_cart_item_button_remove_hover_boxshadow'] = array(
			'type'      => 'boxshadow',
			'title'     => esc_html__( 'Box Shadow', 'profecient-essential' ),
			'segment'   => 'style_cart_item',
			'selectors' => '.profecient-menu-cart .cart-offcanvas .sidebar .cart_list .mini_cart_item .remove:hover',
		);

		$this->options['st_cart_item_button_remove_hover_tab_end'] = array(
			'type'    => 'control_tab_end',
			'segment' => 'style_cart_item',
		);

		$this->options['st_cart_item_button_remove_tabs_end'] = array(
			'type'    => 'control_tabs_end',
			'segment' => 'style_cart_item',
		);

		/** Thumbnail Style Section */
		$this->options['st_cart_item_thumbnail_heading'] = array(
			'type'      => 'heading',
			'title'     => esc_html__( 'Thumbnail', 'profecient-essential' ),
			'segment'   => 'style_cart_item',
			'separator' => 'before',
		);

		$this->options['st_cart_item_thumbnail_margin'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Margin', 'profecient-essential' ),
			'segment'   => 'style_cart_item',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.profecient-menu-cart .cart-offcanvas .sidebar .cart_list .mini_cart_item img',
			'attribute' => 'margin',
		);

		$this->options['st_cart_item_thumbnail_padding'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Padding', 'profecient-essential' ),
			'segment'   => 'style_cart_item',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.profecient-menu-cart .cart-offcanvas .sidebar .cart_list .mini_cart_item img',
			'attribute' => 'padding',
		);

		$this->options['st_cart_item_thumbnail_tabs_start'] = array(
			'type'    => 'control_tabs_start',
			'segment' => 'style_cart_item',
		);

		$this->options['st_cart_item_thumbnail_normal_tab_start'] = array(
			'type'    => 'control_tab_start',
			'title'   => esc_html__( 'Normal', 'profecient-essential' ),
			'segment' => 'style_cart_item',
		);

		$this->options['st_cart_item_thumbnail_normal_background'] = array(
			'type'      => 'background',
			'title'     => esc_html__( 'Background', 'profecient-essential' ),
			'segment'   => 'style_cart_item',
			'options'   => array(
				'classic',
				'gradient',
			),
			'selectors' => '.profecient-menu-cart .cart-offcanvas .sidebar .cart_list .mini_cart_item img',
		);

		$this->options['st_cart_item_thumbnail_normal_border'] = array(
			'type'      => 'border',
			'title'     => esc_html__( 'Border', 'profecient-essential' ),
			'segment'   => 'style_cart_item',
			'selectors' => '.profecient-menu-cart .cart-offcanvas .sidebar .cart_list .mini_cart_item img',
		);

		$this->options['st_cart_item_thumbnail_normal_border_radius'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Border Radius', 'profecient-essential' ),
			'segment'   => 'style_cart_item',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.profecient-menu-cart .cart-offcanvas .sidebar .cart_list .mini_cart_item img',
			'attribute' => 'border-radius',
		);

		$this->options['st_cart_item_thumbnail_normal_boxshadow'] = array(
			'type'      => 'boxshadow',
			'title'     => esc_html__( 'Box Shadow', 'profecient-essential' ),
			'segment'   => 'style_cart_item',
			'selectors' => '.profecient-menu-cart .cart-offcanvas .sidebar .cart_list .mini_cart_item img',
		);

		$this->options['st_cart_item_thumbnail_normal_tab_end'] = array(
			'type'    => 'control_tab_end',
			'segment' => 'style_cart_item',
		);

		$this->options['st_cart_item_thumbnail_hover_tab_start'] = array(
			'type'    => 'control_tab_start',
			'title'   => esc_html__( 'Hover', 'profecient-essential' ),
			'segment' => 'style_cart_item',
		);

		$this->options['st_cart_item_thumbnail_hover_transition_duration'] = array(
			'type'      => 'slider',
			'title'     => esc_html__( 'Transition Duration', 'profecient-essential' ),
			'segment'   => 'style_cart_item',
			'options'   => array(
				'min'  => 0,
				'max'  => 10,
				'step' => 0.1,
			),
			'selectors' => array(
				'custom' => array(
					'{{WRAPPER}} .profecient-menu-cart .cart-offcanvas .sidebar .cart_list .mini_cart_item img' => 'transition-duration: {{SIZE}}s;',
				),
			),
		);

		$this->options['st_cart_item_thumbnail_hover_background'] = array(
			'type'      => 'background',
			'title'     => esc_html__( 'Background', 'profecient-essential' ),
			'segment'   => 'style_cart_item',
			'options'   => array(
				'classic',
				'gradient',
			),
			'selectors' => '.profecient-menu-cart .cart-offcanvas .sidebar .cart_list .mini_cart_item img:hover',
		);

		$this->options['st_cart_item_thumbnail_hover_border'] = array(
			'type'      => 'border',
			'title'     => esc_html__( 'Border', 'profecient-essential' ),
			'segment'   => 'style_cart_item',
			'selectors' => '.profecient-menu-cart .cart-offcanvas .sidebar .cart_list .mini_cart_item img:hover',
		);

		$this->options['st_cart_item_thumbnail_hover_border_radius'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Border Radius', 'profecient-essential' ),
			'segment'   => 'style_cart_item',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.profecient-menu-cart .cart-offcanvas .sidebar .cart_list .mini_cart_item img:hover',
			'attribute' => 'border-radius',
		);

		$this->options['st_cart_item_thumbnail_hover_boxshadow'] = array(
			'type'      => 'boxshadow',
			'title'     => esc_html__( 'Box Shadow', 'profecient-essential' ),
			'segment'   => 'style_cart_item',
			'selectors' => '.profecient-menu-cart .cart-offcanvas .sidebar .cart_list .mini_cart_item img:hover',
		);

		$this->options['st_cart_item_thumbnail_hover_tab_end'] = array(
			'type'    => 'control_tab_end',
			'segment' => 'style_cart_item',
		);

		$this->options['st_cart_item_thumbnail_tabs_end'] = array(
			'type'    => 'control_tabs_end',
			'segment' => 'style_cart_item',
		);

		/** Item Title Style Section */
		$this->options['st_cart_item_title_heading'] = array(
			'type'      => 'heading',
			'title'     => esc_html__( 'Title', 'profecient-essential' ),
			'segment'   => 'style_cart_item',
			'separator' => 'before',
		);

		$this->options['st_cart_item_title_margin'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Margin', 'profecient-essential' ),
			'segment'   => 'style_cart_item',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.profecient-menu-cart .cart-offcanvas .sidebar .cart_list .mini_cart_item .product-tittle',
			'attribute' => 'margin',
		);

		$this->options['st_cart_item_title_padding'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Padding', 'profecient-essential' ),
			'segment'   => 'style_cart_item',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.profecient-menu-cart .cart-offcanvas .sidebar .cart_list .mini_cart_item .product-tittle',
			'attribute' => 'padding',
		);

		$this->options['st_cart_item_title_typograhpy'] = array(
			'type'      => 'typography',
			'title'     => esc_html__( 'Typography', 'profecient-essential' ),
			'segment'   => 'style_cart_item',
			'selectors' => '.profecient-menu-cart .cart-offcanvas .sidebar .cart_list .mini_cart_item .product-tittle',
		);

		$this->options['st_cart_item_title_tabs_start'] = array(
			'type'    => 'control_tabs_start',
			'segment' => 'style_cart_item',
		);

		$this->options['st_cart_item_title_normal_tab_start'] = array(
			'type'    => 'control_tab_start',
			'title'   => esc_html__( 'Normal', 'profecient-essential' ),
			'segment' => 'style_cart_item',
		);

		$this->options['st_cart_item_title_normal_text_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Text Color', 'profecient-essential' ),
			'segment'   => 'style_cart_item',
			'selectors' => '.profecient-menu-cart .cart-offcanvas .sidebar .cart_list .mini_cart_item .product-tittle',
		);

		$this->options['st_cart_item_title_normal_background'] = array(
			'type'      => 'background',
			'title'     => esc_html__( 'Background', 'profecient-essential' ),
			'segment'   => 'style_cart_item',
			'options'   => array(
				'classic',
				'gradient',
			),
			'selectors' => '.profecient-menu-cart .cart-offcanvas .sidebar .cart_list .mini_cart_item .product-tittle',
		);

		$this->options['st_cart_item_title_normal_border'] = array(
			'type'      => 'border',
			'title'     => esc_html__( 'Border', 'profecient-essential' ),
			'segment'   => 'style_cart_item',
			'selectors' => '.profecient-menu-cart .cart-offcanvas .sidebar .cart_list .mini_cart_item .product-tittle',
		);

		$this->options['st_cart_item_title_normal_border_radius'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Border Radius', 'profecient-essential' ),
			'segment'   => 'style_cart_item',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.profecient-menu-cart .cart-offcanvas .sidebar .cart_list .mini_cart_item .product-tittle',
			'attribute' => 'border-radius',
		);

		$this->options['st_cart_item_title_normal_boxshadow'] = array(
			'type'      => 'boxshadow',
			'title'     => esc_html__( 'Box Shadow', 'profecient-essential' ),
			'segment'   => 'style_cart_item',
			'selectors' => '.profecient-menu-cart .cart-offcanvas .sidebar .cart_list .mini_cart_item .product-tittle',
		);

		$this->options['st_cart_item_title_normal_tab_end'] = array(
			'type'    => 'control_tab_end',
			'segment' => 'style_cart_item',
		);

		$this->options['st_cart_item_title_hover_tab_start'] = array(
			'type'    => 'control_tab_start',
			'title'   => esc_html__( 'Hover', 'profecient-essential' ),
			'segment' => 'style_cart_item',
		);

		$this->options['st_cart_item_title_hover_transition_duration'] = array(
			'type'      => 'slider',
			'title'     => esc_html__( 'Transition Duration', 'profecient-essential' ),
			'segment'   => 'style_cart_item',
			'options'   => array(
				'min'  => 0,
				'max'  => 10,
				'step' => 0.1,
			),
			'selectors' => array(
				'custom' => array(
					'{{WRAPPER}} .profecient-menu-cart .cart-offcanvas .sidebar .cart_list .mini_cart_item .product-tittle' => 'transition-duration: {{SIZE}}s;',
				),
			),
		);

		$this->options['st_cart_item_title_hover_text_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Text Color', 'profecient-essential' ),
			'segment'   => 'style_cart_item',
			'selectors' => '.profecient-menu-cart .cart-offcanvas .sidebar .cart_list .mini_cart_item .product-tittle:hover',
		);

		$this->options['st_cart_item_title_hover_background'] = array(
			'type'      => 'background',
			'title'     => esc_html__( 'Background', 'profecient-essential' ),
			'segment'   => 'style_cart_item',
			'options'   => array(
				'classic',
				'gradient',
			),
			'selectors' => '.profecient-menu-cart .cart-offcanvas .sidebar .cart_list .mini_cart_item .product-tittle:hover',
		);

		$this->options['st_cart_item_title_hover_border'] = array(
			'type'      => 'border',
			'title'     => esc_html__( 'Border', 'profecient-essential' ),
			'segment'   => 'style_cart_item',
			'selectors' => '.profecient-menu-cart .cart-offcanvas .sidebar .cart_list .mini_cart_item .product-tittle:hover',
		);

		$this->options['st_cart_item_title_hover_border_radius'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Border Radius', 'profecient-essential' ),
			'segment'   => 'style_cart_item',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.profecient-menu-cart .cart-offcanvas .sidebar .cart_list .mini_cart_item .product-tittle:hover',
			'attribute' => 'border-radius',
		);

		$this->options['st_cart_item_title_hover_boxshadow'] = array(
			'type'      => 'boxshadow',
			'title'     => esc_html__( 'Box Shadow', 'profecient-essential' ),
			'segment'   => 'style_cart_item',
			'selectors' => '.profecient-menu-cart .cart-offcanvas .sidebar .cart_list .mini_cart_item .product-tittle:hover',
		);

		$this->options['st_cart_item_title_hover_tab_end'] = array(
			'type'    => 'control_tab_end',
			'segment' => 'style_cart_item',
		);

		$this->options['st_cart_item_title_tabs_end'] = array(
			'type'    => 'control_tabs_end',
			'segment' => 'style_cart_item',
		);

		/** Item Price Style Section */
		$this->options['st_cart_item_price_heading'] = array(
			'type'      => 'heading',
			'title'     => esc_html__( 'Price', 'profecient-essential' ),
			'segment'   => 'style_cart_item',
			'separator' => 'before',
		);

		$this->options['st_cart_item_price_margin'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Margin', 'profecient-essential' ),
			'segment'   => 'style_cart_item',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.profecient-menu-cart .cart-offcanvas .sidebar .cart_list .mini_cart_item .quantity',
			'attribute' => 'margin',
		);

		$this->options['st_cart_item_price_padding'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Padding', 'profecient-essential' ),
			'segment'   => 'style_cart_item',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.profecient-menu-cart .cart-offcanvas .sidebar .cart_list .mini_cart_item .quantity',
			'attribute' => 'padding',
		);

		$this->options['st_cart_item_price_typograhpy'] = array(
			'type'      => 'typography',
			'title'     => esc_html__( 'Typography', 'profecient-essential' ),
			'segment'   => 'style_cart_item',
			'selectors' => '.profecient-menu-cart .cart-offcanvas .sidebar .cart_list .mini_cart_item .quantity',
		);

		$this->options['st_cart_item_price_tabs_start'] = array(
			'type'    => 'control_tabs_start',
			'segment' => 'style_cart_item',
		);

		$this->options['st_cart_item_price_normal_tab_start'] = array(
			'type'    => 'control_tab_start',
			'title'   => esc_html__( 'Normal', 'profecient-essential' ),
			'segment' => 'style_cart_item',
		);

		$this->options['st_cart_item_price_normal_text_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Text Color', 'profecient-essential' ),
			'segment'   => 'style_cart_item',
			'selectors' => '.profecient-menu-cart .cart-offcanvas .sidebar .cart_list .mini_cart_item .quantity',
		);

		$this->options['st_cart_item_price_normal_background'] = array(
			'type'      => 'background',
			'title'     => esc_html__( 'Background', 'profecient-essential' ),
			'segment'   => 'style_cart_item',
			'options'   => array(
				'classic',
				'gradient',
			),
			'selectors' => '.profecient-menu-cart .cart-offcanvas .sidebar .cart_list .mini_cart_item .quantity',
		);

		$this->options['st_cart_item_price_normal_border'] = array(
			'type'      => 'border',
			'title'     => esc_html__( 'Border', 'profecient-essential' ),
			'segment'   => 'style_cart_item',
			'selectors' => '.profecient-menu-cart .cart-offcanvas .sidebar .cart_list .mini_cart_item .quantity',
		);

		$this->options['st_cart_item_price_normal_border_radius'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Border Radius', 'profecient-essential' ),
			'segment'   => 'style_cart_item',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.profecient-menu-cart .cart-offcanvas .sidebar .cart_list .mini_cart_item .quantity',
			'attribute' => 'border-radius',
		);

		$this->options['st_cart_item_price_normal_boxshadow'] = array(
			'type'      => 'boxshadow',
			'title'     => esc_html__( 'Box Shadow', 'profecient-essential' ),
			'segment'   => 'style_cart_item',
			'selectors' => '.profecient-menu-cart .cart-offcanvas .sidebar .cart_list .mini_cart_item .quantity',
		);

		$this->options['st_cart_item_price_normal_tab_end'] = array(
			'type'    => 'control_tab_end',
			'segment' => 'style_cart_item',
		);

		$this->options['st_cart_item_price_hover_tab_start'] = array(
			'type'    => 'control_tab_start',
			'title'   => esc_html__( 'Hover', 'profecient-essential' ),
			'segment' => 'style_cart_item',
		);

		$this->options['st_cart_item_price_hover_transition_duration'] = array(
			'type'      => 'slider',
			'title'     => esc_html__( 'Transition Duration', 'profecient-essential' ),
			'segment'   => 'style_cart_item',
			'options'   => array(
				'min'  => 0,
				'max'  => 10,
				'step' => 0.1,
			),
			'selectors' => array(
				'custom' => array(
					'{{WRAPPER}} .profecient-menu-cart .cart-offcanvas .sidebar .cart_list .mini_cart_item .quantity' => 'transition-duration: {{SIZE}}s;',
				),
			),
		);

		$this->options['st_cart_item_price_hover_text_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Text Color', 'profecient-essential' ),
			'segment'   => 'style_cart_item',
			'selectors' => '.profecient-menu-cart .cart-offcanvas .sidebar .cart_list .mini_cart_item .quantity:hover',
		);

		$this->options['st_cart_item_price_hover_background'] = array(
			'type'      => 'background',
			'title'     => esc_html__( 'Background', 'profecient-essential' ),
			'segment'   => 'style_cart_item',
			'options'   => array(
				'classic',
				'gradient',
			),
			'selectors' => '.profecient-menu-cart .cart-offcanvas .sidebar .cart_list .mini_cart_item .quantity:hover',
		);

		$this->options['st_cart_item_price_hover_border'] = array(
			'type'      => 'border',
			'title'     => esc_html__( 'Border', 'profecient-essential' ),
			'segment'   => 'style_cart_item',
			'selectors' => '.profecient-menu-cart .cart-offcanvas .sidebar .cart_list .mini_cart_item .quantity:hover',
		);

		$this->options['st_cart_item_price_hover_border_radius'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Border Radius', 'profecient-essential' ),
			'segment'   => 'style_cart_item',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.profecient-menu-cart .cart-offcanvas .sidebar .cart_list .mini_cart_item .quantity:hover',
			'attribute' => 'border-radius',
		);

		$this->options['st_cart_item_price_hover_boxshadow'] = array(
			'type'      => 'boxshadow',
			'title'     => esc_html__( 'Box Shadow', 'profecient-essential' ),
			'segment'   => 'style_cart_item',
			'selectors' => '.profecient-menu-cart .cart-offcanvas .sidebar .cart_list .mini_cart_item .quantity:hover',
		);

		$this->options['st_cart_item_price_hover_tab_end'] = array(
			'type'    => 'control_tab_end',
			'segment' => 'style_cart_item',
		);

		$this->options['st_cart_item_price_tabs_end'] = array(
			'type'    => 'control_tabs_end',
			'segment' => 'style_cart_item',
		);

		$this->options['st_total_price_margin'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Margin', 'profecient-essential' ),
			'segment'   => 'style_total_price',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.profecient-menu-cart .cart-offcanvas .sidebar .total',
			'attribute' => 'margin',
		);

		$this->options['st_total_price_padding'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Padding', 'profecient-essential' ),
			'segment'   => 'style_total_price',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.profecient-menu-cart .cart-offcanvas .sidebar .total',
			'attribute' => 'padding',
		);

		$this->options['st_total_price_typograhpy'] = array(
			'type'      => 'typography',
			'title'     => esc_html__( 'Typography', 'profecient-essential' ),
			'segment'   => 'style_total_price',
			'selectors' => '.profecient-menu-cart .cart-offcanvas .sidebar .total',
		);

		$this->options['st_total_price_tabs_start'] = array(
			'type'    => 'control_tabs_start',
			'segment' => 'style_total_price',
		);

		$this->options['st_total_price_normal_tab_start'] = array(
			'type'    => 'control_tab_start',
			'title'   => esc_html__( 'Normal', 'profecient-essential' ),
			'segment' => 'style_total_price',
		);

		$this->options['st_total_price_normal_text_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Text Color', 'profecient-essential' ),
			'segment'   => 'style_total_price',
			'selectors' => '.profecient-menu-cart .cart-offcanvas .sidebar .total',
		);

		$this->options['st_total_price_normal_background'] = array(
			'type'      => 'background',
			'title'     => esc_html__( 'Background', 'profecient-essential' ),
			'segment'   => 'style_total_price',
			'options'   => array(
				'classic',
				'gradient',
			),
			'selectors' => '.profecient-menu-cart .cart-offcanvas .sidebar .total',
		);

		$this->options['st_total_price_normal_border'] = array(
			'type'      => 'border',
			'title'     => esc_html__( 'Border', 'profecient-essential' ),
			'segment'   => 'style_total_price',
			'selectors' => '.profecient-menu-cart .cart-offcanvas .sidebar .total',
		);

		$this->options['st_total_price_normal_border_radius'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Border Radius', 'profecient-essential' ),
			'segment'   => 'style_total_price',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.profecient-menu-cart .cart-offcanvas .sidebar .total',
			'attribute' => 'border-radius',
		);

		$this->options['st_total_price_normal_boxshadow'] = array(
			'type'      => 'boxshadow',
			'title'     => esc_html__( 'Box Shadow', 'profecient-essential' ),
			'segment'   => 'style_total_price',
			'selectors' => '.profecient-menu-cart .cart-offcanvas .sidebar .total',
		);

		$this->options['st_total_price_normal_tab_end'] = array(
			'type'    => 'control_tab_end',
			'segment' => 'style_total_price',
		);

		$this->options['st_total_price_hover_tab_start'] = array(
			'type'    => 'control_tab_start',
			'title'   => esc_html__( 'Hover', 'profecient-essential' ),
			'segment' => 'style_total_price',
		);

		$this->options['st_total_price_hover_transition_duration'] = array(
			'type'      => 'slider',
			'title'     => esc_html__( 'Transition Duration', 'profecient-essential' ),
			'segment'   => 'style_total_price',
			'options'   => array(
				'min'  => 0,
				'max'  => 10,
				'step' => 0.1,
			),
			'selectors' => array(
				'custom' => array(
					'{{WRAPPER}} .profecient-menu-cart .cart-offcanvas .sidebar .total' => 'transition-duration: {{SIZE}}s;',
				),
			),
		);

		$this->options['st_total_price_hover_text_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Text Color', 'profecient-essential' ),
			'segment'   => 'style_total_price',
			'selectors' => '.profecient-menu-cart .cart-offcanvas .sidebar .total:hover',
		);

		$this->options['st_total_price_hover_background'] = array(
			'type'      => 'background',
			'title'     => esc_html__( 'Background', 'profecient-essential' ),
			'segment'   => 'style_total_price',
			'options'   => array(
				'classic',
				'gradient',
			),
			'selectors' => '.profecient-menu-cart .cart-offcanvas .sidebar .total:hover',
		);

		$this->options['st_total_price_hover_border'] = array(
			'type'      => 'border',
			'title'     => esc_html__( 'Border', 'profecient-essential' ),
			'segment'   => 'style_total_price',
			'selectors' => '.profecient-menu-cart .cart-offcanvas .sidebar .total:hover',
		);

		$this->options['st_total_price_hover_border_radius'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Border Radius', 'profecient-essential' ),
			'segment'   => 'style_total_price',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.profecient-menu-cart .cart-offcanvas .sidebar .total:hover',
			'attribute' => 'border-radius',
		);

		$this->options['st_total_price_hover_boxshadow'] = array(
			'type'      => 'boxshadow',
			'title'     => esc_html__( 'Box Shadow', 'profecient-essential' ),
			'segment'   => 'style_total_price',
			'selectors' => '.profecient-menu-cart .cart-offcanvas .sidebar .total:hover',
		);

		$this->options['st_total_price_hover_tab_end'] = array(
			'type'    => 'control_tab_end',
			'segment' => 'style_total_price',
		);

		$this->options['st_total_price_tabs_end'] = array(
			'type'    => 'control_tabs_end',
			'segment' => 'style_total_price',
		);

		$this->options['st_cart_button_margin'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Margin', 'profecient-essential' ),
			'segment'   => 'style_cart_button',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.profecient-menu-cart .cart-offcanvas .sidebar .buttons a',
			'attribute' => 'margin',
		);

		$this->options['st_cart_button_padding'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Padding', 'profecient-essential' ),
			'segment'   => 'style_cart_button',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.profecient-menu-cart .cart-offcanvas .sidebar .buttons a',
			'attribute' => 'padding',
		);

		$this->options['st_cart_button_typograhpy'] = array(
			'type'      => 'typography',
			'title'     => esc_html__( 'Typography', 'profecient-essential' ),
			'segment'   => 'style_cart_button',
			'selectors' => '.profecient-menu-cart .cart-offcanvas .sidebar .buttons a',
		);

		$this->options['st_cart_button_tabs_start'] = array(
			'type'    => 'control_tabs_start',
			'segment' => 'style_cart_button',
		);

		$this->options['st_cart_button_normal_tab_start'] = array(
			'type'    => 'control_tab_start',
			'title'   => esc_html__( 'Normal', 'profecient-essential' ),
			'segment' => 'style_cart_button',
		);

		$this->options['st_cart_button_normal_text_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Text Color', 'profecient-essential' ),
			'segment'   => 'style_cart_button',
			'selectors' => '.profecient-menu-cart .cart-offcanvas .sidebar .buttons a',
		);

		$this->options['st_cart_button_normal_background'] = array(
			'type'      => 'background',
			'title'     => esc_html__( 'Background', 'profecient-essential' ),
			'segment'   => 'style_cart_button',
			'options'   => array(
				'classic',
				'gradient',
			),
			'selectors' => '.profecient-menu-cart .cart-offcanvas .sidebar .buttons a',
		);

		$this->options['st_cart_button_normal_border'] = array(
			'type'      => 'border',
			'title'     => esc_html__( 'Border', 'profecient-essential' ),
			'segment'   => 'style_cart_button',
			'selectors' => '.profecient-menu-cart .cart-offcanvas .sidebar .buttons a',
		);

		$this->options['st_cart_button_normal_border_radius'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Border Radius', 'profecient-essential' ),
			'segment'   => 'style_cart_button',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.profecient-menu-cart .cart-offcanvas .sidebar .buttons a',
			'attribute' => 'border-radius',
		);

		$this->options['st_cart_button_normal_boxshadow'] = array(
			'type'      => 'boxshadow',
			'title'     => esc_html__( 'Box Shadow', 'profecient-essential' ),
			'segment'   => 'style_cart_button',
			'selectors' => '.profecient-menu-cart .cart-offcanvas .sidebar .buttons a',
		);

		$this->options['st_cart_button_normal_tab_end'] = array(
			'type'    => 'control_tab_end',
			'segment' => 'style_cart_button',
		);

		$this->options['st_cart_button_hover_tab_start'] = array(
			'type'    => 'control_tab_start',
			'title'   => esc_html__( 'Hover', 'profecient-essential' ),
			'segment' => 'style_cart_button',
		);

		$this->options['st_cart_button_hover_transition_duration'] = array(
			'type'      => 'slider',
			'title'     => esc_html__( 'Transition Duration', 'profecient-essential' ),
			'segment'   => 'style_cart_button',
			'options'   => array(
				'min'  => 0,
				'max'  => 10,
				'step' => 0.1,
			),
			'selectors' => array(
				'custom' => array(
					'{{WRAPPER}} .profecient-menu-cart .cart-offcanvas .sidebar .buttons a' => 'transition-duration: {{SIZE}}s;',
				),
			),
		);

		$this->options['st_cart_button_hover_text_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Text Color', 'profecient-essential' ),
			'segment'   => 'style_cart_button',
			'selectors' => '.profecient-menu-cart .cart-offcanvas .sidebar .buttons a:hover, {{WRAPPER}} .profecient-menu-cart .cart-offcanvas .sidebar .buttons a:first-child:hover, {{WRAPPER}} .profecient-menu-cart .cart-offcanvas .sidebar .buttons a:last-child:hover',
		);

		$this->options['st_cart_button_hover_background'] = array(
			'type'      => 'background',
			'title'     => esc_html__( 'Background', 'profecient-essential' ),
			'segment'   => 'style_cart_button',
			'options'   => array(
				'classic',
				'gradient',
			),
			'selectors' => '.profecient-menu-cart .cart-offcanvas .sidebar .buttons a:hover, {{WRAPPER}} .profecient-menu-cart .cart-offcanvas .sidebar .buttons a:first-child:hover, {{WRAPPER}} .profecient-menu-cart .cart-offcanvas .sidebar .buttons a:last-child:hover',
		);

		$this->options['st_cart_button_hover_border'] = array(
			'type'      => 'border',
			'title'     => esc_html__( 'Border', 'profecient-essential' ),
			'segment'   => 'style_cart_button',
			'selectors' => '.profecient-menu-cart .cart-offcanvas .sidebar .buttons a:hover, {{WRAPPER}} .profecient-menu-cart .cart-offcanvas .sidebar .buttons a:first-child:hover, {{WRAPPER}} .profecient-menu-cart .cart-offcanvas .sidebar .buttons a:last-child:hover',
		);

		$this->options['st_cart_button_hover_border_radius'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Border Radius', 'profecient-essential' ),
			'segment'   => 'style_cart_button',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.profecient-menu-cart .cart-offcanvas .sidebar .buttons a:hover, {{WRAPPER}} .profecient-menu-cart .cart-offcanvas .sidebar .buttons a:first-child:hover, {{WRAPPER}} .profecient-menu-cart .cart-offcanvas .sidebar .buttons a:last-child:hover',
			'attribute' => 'border-radius',
		);

		$this->options['st_cart_button_hover_boxshadow'] = array(
			'type'      => 'boxshadow',
			'title'     => esc_html__( 'Box Shadow', 'profecient-essential' ),
			'segment'   => 'style_cart_button',
			'selectors' => '.profecient-menu-cart .cart-offcanvas .sidebar .buttons a:hover, {{WRAPPER}} .profecient-menu-cart .cart-offcanvas .sidebar .buttons a:first-child:hover, {{WRAPPER}} .profecient-menu-cart .cart-offcanvas .sidebar .buttons a:last-child:hover',
		);

		$this->options['st_cart_button_hover_tab_end'] = array(
			'type'    => 'control_tab_end',
			'segment' => 'style_cart_button',
		);

		$this->options['st_cart_button_tabs_end'] = array(
			'type'    => 'control_tabs_end',
			'segment' => 'style_cart_button',
		);

		/** View Cart Button */
		$this->options['st_view_cart_button_remove_heading'] = array(
			'type'      => 'heading',
			'title'     => esc_html__( 'View Cart Button', 'profecient-essential' ),
			'segment'   => 'style_cart_button',
			'separator' => 'before',
		);

		$this->options['st_view_cart_button_margin'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Margin', 'profecient-essential' ),
			'segment'   => 'style_cart_button',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.profecient-menu-cart .cart-offcanvas .sidebar .buttons a:first-child',
			'attribute' => 'margin',
		);

		$this->options['st_view_cart_button_padding'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Padding', 'profecient-essential' ),
			'segment'   => 'style_cart_button',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.profecient-menu-cart .cart-offcanvas .sidebar .buttons a:first-child',
			'attribute' => 'padding',
		);

		$this->options['st_view_cart_button_typograhpy'] = array(
			'type'      => 'typography',
			'title'     => esc_html__( 'Typography', 'profecient-essential' ),
			'segment'   => 'style_cart_button',
			'selectors' => '.profecient-menu-cart .cart-offcanvas .sidebar .buttons a:first-child',
		);

		$this->options['st_view_cart_button_tabs_start'] = array(
			'type'    => 'control_tabs_start',
			'segment' => 'style_cart_button',
		);

		$this->options['st_view_cart_button_normal_tab_start'] = array(
			'type'    => 'control_tab_start',
			'title'   => esc_html__( 'Normal', 'profecient-essential' ),
			'segment' => 'style_cart_button',
		);

		$this->options['st_view_cart_button_normal_text_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Text Color', 'profecient-essential' ),
			'segment'   => 'style_cart_button',
			'selectors' => '.profecient-menu-cart .cart-offcanvas .sidebar .buttons a:first-child',
		);

		$this->options['st_view_cart_button_normal_background'] = array(
			'type'      => 'background',
			'title'     => esc_html__( 'Background', 'profecient-essential' ),
			'segment'   => 'style_cart_button',
			'options'   => array(
				'classic',
				'gradient',
			),
			'selectors' => '.profecient-menu-cart .cart-offcanvas .sidebar .buttons a:first-child',
		);

		$this->options['st_view_cart_button_normal_border'] = array(
			'type'      => 'border',
			'title'     => esc_html__( 'Border', 'profecient-essential' ),
			'segment'   => 'style_cart_button',
			'selectors' => '.profecient-menu-cart .cart-offcanvas .sidebar .buttons a:first-child',
		);

		$this->options['st_view_cart_button_normal_border_radius'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Border Radius', 'profecient-essential' ),
			'segment'   => 'style_cart_button',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.profecient-menu-cart .cart-offcanvas .sidebar .buttons a:first-child',
			'attribute' => 'border-radius',
		);

		$this->options['st_view_cart_button_normal_boxshadow'] = array(
			'type'      => 'boxshadow',
			'title'     => esc_html__( 'Box Shadow', 'profecient-essential' ),
			'segment'   => 'style_cart_button',
			'selectors' => '.profecient-menu-cart .cart-offcanvas .sidebar .buttons a:first-child',
		);

		$this->options['st_view_cart_button_normal_tab_end'] = array(
			'type'    => 'control_tab_end',
			'segment' => 'style_cart_button',
		);

		$this->options['st_view_cart_button_hover_tab_start'] = array(
			'type'    => 'control_tab_start',
			'title'   => esc_html__( 'Hover', 'profecient-essential' ),
			'segment' => 'style_cart_button',
		);

		$this->options['st_view_cart_button_hover_transition_duration'] = array(
			'type'      => 'slider',
			'title'     => esc_html__( 'Transition Duration', 'profecient-essential' ),
			'segment'   => 'style_cart_button',
			'options'   => array(
				'min'  => 0,
				'max'  => 10,
				'step' => 0.1,
			),
			'selectors' => array(
				'custom' => array(
					'{{WRAPPER}} .profecient-menu-cart .cart-offcanvas .sidebar .buttons a:first-child' => 'transition-duration: {{SIZE}}s;',
				),
			),
		);

		$this->options['st_view_cart_button_hover_text_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Text Color', 'profecient-essential' ),
			'segment'   => 'style_cart_button',
			'selectors' => '.profecient-menu-cart .cart-offcanvas .sidebar .buttons a:first-child:hover',
		);

		$this->options['st_view_cart_button_hover_background'] = array(
			'type'      => 'background',
			'title'     => esc_html__( 'Background', 'profecient-essential' ),
			'segment'   => 'style_cart_button',
			'options'   => array(
				'classic',
				'gradient',
			),
			'selectors' => '.profecient-menu-cart .cart-offcanvas .sidebar .buttons a:first-child:hover',
		);

		$this->options['st_view_cart_button_hover_border'] = array(
			'type'      => 'border',
			'title'     => esc_html__( 'Border', 'profecient-essential' ),
			'segment'   => 'style_cart_button',
			'selectors' => '.profecient-menu-cart .cart-offcanvas .sidebar .buttons a:first-child:hover',
		);

		$this->options['st_view_cart_button_hover_border_radius'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Border Radius', 'profecient-essential' ),
			'segment'   => 'style_cart_button',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.profecient-menu-cart .cart-offcanvas .sidebar .buttons a:first-child:hover',
			'attribute' => 'border-radius',
		);

		$this->options['st_view_cart_button_hover_boxshadow'] = array(
			'type'      => 'boxshadow',
			'title'     => esc_html__( 'Box Shadow', 'profecient-essential' ),
			'segment'   => 'style_cart_button',
			'selectors' => '.profecient-menu-cart .cart-offcanvas .sidebar .buttons a:first-child:hover',
		);

		$this->options['st_view_cart_button_hover_tab_end'] = array(
			'type'    => 'control_tab_end',
			'segment' => 'style_cart_button',
		);

		$this->options['st_view_cart_button_tabs_end'] = array(
			'type'    => 'control_tabs_end',
			'segment' => 'style_cart_button',
		);

		/** Checkout Button */
		$this->options['st_checkout_cart_button_remove_heading'] = array(
			'type'      => 'heading',
			'title'     => esc_html__( 'Checkout Cart Button', 'profecient-essential' ),
			'segment'   => 'style_cart_button',
			'separator' => 'before',
		);

		$this->options['st_checkout_cart_button_margin'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Margin', 'profecient-essential' ),
			'segment'   => 'style_cart_button',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.profecient-menu-cart .cart-offcanvas .sidebar .buttons a:last-child',
			'attribute' => 'margin',
		);

		$this->options['st_checkout_cart_button_padding'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Padding', 'profecient-essential' ),
			'segment'   => 'style_cart_button',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.profecient-menu-cart .cart-offcanvas .sidebar .buttons a:last-child',
			'attribute' => 'padding',
		);

		$this->options['st_checkout_cart_button_typograhpy'] = array(
			'type'      => 'typography',
			'title'     => esc_html__( 'Typography', 'profecient-essential' ),
			'segment'   => 'style_cart_button',
			'selectors' => '.profecient-menu-cart .cart-offcanvas .sidebar .buttons a:last-child',
		);

		$this->options['st_checkout_cart_button_tabs_start'] = array(
			'type'    => 'control_tabs_start',
			'segment' => 'style_cart_button',
		);

		$this->options['st_checkout_cart_button_normal_tab_start'] = array(
			'type'    => 'control_tab_start',
			'title'   => esc_html__( 'Normal', 'profecient-essential' ),
			'segment' => 'style_cart_button',
		);

		$this->options['st_checkout_cart_button_normal_text_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Text Color', 'profecient-essential' ),
			'segment'   => 'style_cart_button',
			'selectors' => '.profecient-menu-cart .cart-offcanvas .sidebar .buttons a:last-child',
		);

		$this->options['st_checkout_cart_button_normal_background'] = array(
			'type'      => 'background',
			'title'     => esc_html__( 'Background', 'profecient-essential' ),
			'segment'   => 'style_cart_button',
			'options'   => array(
				'classic',
				'gradient',
			),
			'selectors' => '.profecient-menu-cart .cart-offcanvas .sidebar .buttons a:last-child',
		);

		$this->options['st_checkout_cart_button_normal_border'] = array(
			'type'      => 'border',
			'title'     => esc_html__( 'Border', 'profecient-essential' ),
			'segment'   => 'style_cart_button',
			'selectors' => '.profecient-menu-cart .cart-offcanvas .sidebar .buttons a:last-child',
		);

		$this->options['st_checkout_cart_button_normal_border_radius'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Border Radius', 'profecient-essential' ),
			'segment'   => 'style_cart_button',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.profecient-menu-cart .cart-offcanvas .sidebar .buttons a:last-child',
			'attribute' => 'border-radius',
		);

		$this->options['st_checkout_cart_button_normal_boxshadow'] = array(
			'type'      => 'boxshadow',
			'title'     => esc_html__( 'Box Shadow', 'profecient-essential' ),
			'segment'   => 'style_cart_button',
			'selectors' => '.profecient-menu-cart .cart-offcanvas .sidebar .buttons a:last-child',
		);

		$this->options['st_checkout_cart_button_normal_tab_end'] = array(
			'type'    => 'control_tab_end',
			'segment' => 'style_cart_button',
		);

		$this->options['st_checkout_cart_button_hover_tab_start'] = array(
			'type'    => 'control_tab_start',
			'title'   => esc_html__( 'Hover', 'profecient-essential' ),
			'segment' => 'style_cart_button',
		);

		$this->options['st_checkout_cart_button_hover_transition_duration'] = array(
			'type'      => 'slider',
			'title'     => esc_html__( 'Transition Duration', 'profecient-essential' ),
			'segment'   => 'style_cart_button',
			'options'   => array(
				'min'  => 0,
				'max'  => 10,
				'step' => 0.1,
			),
			'selectors' => array(
				'custom' => array(
					'{{WRAPPER}} .profecient-menu-cart .cart-offcanvas .sidebar .buttons a:last-child' => 'transition-duration: {{SIZE}}s;',
				),
			),
		);

		$this->options['st_checkout_cart_button_hover_text_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Text Color', 'profecient-essential' ),
			'segment'   => 'style_cart_button',
			'selectors' => '.profecient-menu-cart .cart-offcanvas .sidebar .buttons a:last-child:hover',
		);

		$this->options['st_checkout_cart_button_hover_background'] = array(
			'type'      => 'background',
			'title'     => esc_html__( 'Background', 'profecient-essential' ),
			'segment'   => 'style_cart_button',
			'options'   => array(
				'classic',
				'gradient',
			),
			'selectors' => '.profecient-menu-cart .cart-offcanvas .sidebar .buttons a:last-child:hover',
		);

		$this->options['st_checkout_cart_button_hover_border'] = array(
			'type'      => 'border',
			'title'     => esc_html__( 'Border', 'profecient-essential' ),
			'segment'   => 'style_cart_button',
			'selectors' => '.profecient-menu-cart .cart-offcanvas .sidebar .buttons a:last-child:hover',
		);

		$this->options['st_checkout_cart_button_hover_border_radius'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Border Radius', 'profecient-essential' ),
			'segment'   => 'style_cart_button',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.profecient-menu-cart .cart-offcanvas .sidebar .buttons a:last-child:hover',
			'attribute' => 'border-radius',
		);

		$this->options['st_checkout_cart_button_hover_boxshadow'] = array(
			'type'      => 'boxshadow',
			'title'     => esc_html__( 'Box Shadow', 'profecient-essential' ),
			'segment'   => 'style_cart_button',
			'selectors' => '.profecient-menu-cart .cart-offcanvas .sidebar .buttons a:last-child:hover',
		);

		$this->options['st_checkout_cart_button_hover_tab_end'] = array(
			'type'    => 'control_tab_end',
			'segment' => 'style_cart_button',
		);

		$this->options['st_checkout_cart_button_tabs_end'] = array(
			'type'    => 'control_tabs_end',
			'segment' => 'style_cart_button',
		);

		/** Empty Cart Section */
		$this->options['st_cart_empty_heading'] = array(
			'type'      => 'heading',
			'title'     => esc_html__( 'Empty Cart', 'profecient-essential' ),
			'segment'   => 'style_cart_empty',
			'separator' => 'before',
		);

		$this->options['st_cart_empty_margin'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Margin', 'profecient-essential' ),
			'segment'   => 'style_cart_empty',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.profecient-menu-cart .cart-offcanvas .sidebar .woocommerce-mini-cart__empty-message',
			'attribute' => 'margin',
		);

		$this->options['st_cart_empty_padding'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Padding', 'profecient-essential' ),
			'segment'   => 'style_cart_empty',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.profecient-menu-cart .cart-offcanvas .sidebar .woocommerce-mini-cart__empty-message',
			'attribute' => 'padding',
		);

		$this->options['st_cart_empty_typograhpy'] = array(
			'type'      => 'typography',
			'title'     => esc_html__( 'Typography', 'profecient-essential' ),
			'segment'   => 'style_cart_empty',
			'selectors' => '.profecient-menu-cart .cart-offcanvas .sidebar .woocommerce-mini-cart__empty-message',
		);

		$this->options['st_cart_empty_tabs_start'] = array(
			'type'    => 'control_tabs_start',
			'segment' => 'style_cart_empty',
		);

		$this->options['st_cart_empty_normal_tab_start'] = array(
			'type'    => 'control_tab_start',
			'title'   => esc_html__( 'Normal', 'profecient-essential' ),
			'segment' => 'style_cart_empty',
		);

		$this->options['st_cart_empty_normal_text_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Text Color', 'profecient-essential' ),
			'segment'   => 'style_cart_empty',
			'selectors' => '.profecient-menu-cart .cart-offcanvas .sidebar .woocommerce-mini-cart__empty-message',
		);

		$this->options['st_cart_empty_normal_background'] = array(
			'type'      => 'background',
			'title'     => esc_html__( 'Background', 'profecient-essential' ),
			'segment'   => 'style_cart_empty',
			'options'   => array(
				'classic',
				'gradient',
			),
			'selectors' => '.profecient-menu-cart .cart-offcanvas .sidebar .woocommerce-mini-cart__empty-message',
		);

		$this->options['st_cart_empty_normal_border'] = array(
			'type'      => 'border',
			'title'     => esc_html__( 'Border', 'profecient-essential' ),
			'segment'   => 'style_cart_empty',
			'selectors' => '.profecient-menu-cart .cart-offcanvas .sidebar .woocommerce-mini-cart__empty-message',
		);

		$this->options['st_cart_empty_normal_border_radius'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Border Radius', 'profecient-essential' ),
			'segment'   => 'style_cart_empty',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.profecient-menu-cart .cart-offcanvas .sidebar .woocommerce-mini-cart__empty-message',
			'attribute' => 'border-radius',
		);

		$this->options['st_cart_empty_normal_boxshadow'] = array(
			'type'      => 'boxshadow',
			'title'     => esc_html__( 'Box Shadow', 'profecient-essential' ),
			'segment'   => 'style_cart_empty',
			'selectors' => '.profecient-menu-cart .cart-offcanvas .sidebar .woocommerce-mini-cart__empty-message',
		);

		$this->options['st_cart_empty_normal_tab_end'] = array(
			'type'    => 'control_tab_end',
			'segment' => 'style_cart_empty',
		);

		$this->options['st_cart_empty_hover_tab_start'] = array(
			'type'    => 'control_tab_start',
			'title'   => esc_html__( 'Hover', 'profecient-essential' ),
			'segment' => 'style_cart_empty',
		);

		$this->options['st_cart_empty_hover_transition_duration'] = array(
			'type'      => 'slider',
			'title'     => esc_html__( 'Transition Duration', 'profecient-essential' ),
			'segment'   => 'style_cart_empty',
			'options'   => array(
				'min'  => 0,
				'max'  => 10,
				'step' => 0.1,
			),
			'selectors' => array(
				'custom' => array(
					'{{WRAPPER}} .profecient-menu-cart .cart-offcanvas .sidebar .woocommerce-mini-cart__empty-message' => 'transition-duration: {{SIZE}}s;',
				),
			),
		);

		$this->options['st_cart_empty_hover_text_color'] = array(
			'type'      => 'color',
			'title'     => esc_html__( 'Text Color', 'profecient-essential' ),
			'segment'   => 'style_cart_empty',
			'selectors' => '.profecient-menu-cart .cart-offcanvas .sidebar .woocommerce-mini-cart__empty-message:hover',
		);

		$this->options['st_cart_empty_hover_background'] = array(
			'type'      => 'background',
			'title'     => esc_html__( 'Background', 'profecient-essential' ),
			'segment'   => 'style_cart_empty',
			'options'   => array(
				'classic',
				'gradient',
			),
			'selectors' => '.profecient-menu-cart .cart-offcanvas .sidebar .woocommerce-mini-cart__empty-message:hover',
		);

		$this->options['st_cart_empty_hover_border'] = array(
			'type'      => 'border',
			'title'     => esc_html__( 'Border', 'profecient-essential' ),
			'segment'   => 'style_cart_empty',
			'selectors' => '.profecient-menu-cart .cart-offcanvas .sidebar .woocommerce-mini-cart__empty-message:hover',
		);

		$this->options['st_cart_empty_hover_border_radius'] = array(
			'type'      => 'dimension',
			'title'     => esc_html__( 'Border Radius', 'profecient-essential' ),
			'segment'   => 'style_cart_empty',
			'units'     => array( 'px', '%', 'em' ),
			'selectors' => '.profecient-menu-cart .cart-offcanvas .sidebar .woocommerce-mini-cart__empty-message:hover',
			'attribute' => 'border-radius',
		);

		$this->options['st_cart_empty_hover_boxshadow'] = array(
			'type'      => 'boxshadow',
			'title'     => esc_html__( 'Box Shadow', 'profecient-essential' ),
			'segment'   => 'style_cart_empty',
			'selectors' => '.profecient-menu-cart .cart-offcanvas .sidebar .woocommerce-mini-cart__empty-message:hover',
		);

		$this->options['st_cart_empty_hover_tab_end'] = array(
			'type'    => 'control_tab_end',
			'segment' => 'style_cart_empty',
		);

		$this->options['st_cart_empty_tabs_end'] = array(
			'type'    => 'control_tabs_end',
			'segment' => 'style_cart_empty',
		);

		parent::additional_style();
	}
}
