<?php
/**
 * Archive Title View Class
 *
 * @package profecient-essential
 * @author jegtheme
 * @since 1.0.0
 */

namespace Profecient\Essential\JKit\Elements\Views;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

use \Jeg\Elementor_Kit\Elements\Views\View_Abstract;

/**
 * Class Archive_Title_View
 */
class Archive_Title_View extends View_Abstract {
	/**
	 * Build content for frontend editor
	 *
	 * @param string $name
	 *
	 * @return string
	 */
	public function build_content_frontend( $name ) {
		$content = '';
		$title   = $this->get_archive_title();

		if ( '' !== $title ) {
			$link_to   = $this->attribute['sg_title_link_to'];
			$html_tag  = esc_attr( $this->attribute['sg_title_html_tag'] );
			$animation = ! empty( $this->attribute['st_title_hover_animation'] ) ? 'elementor-animation-' . esc_attr( $this->attribute['st_title_hover_animation'] ) : '';

			switch ( $link_to ) {
				case 'home':
					$content = sprintf( '<a href="%1$s">%2$s</a>', esc_url( get_home_url() ), $title );
					break;
				case 'custom':
					$content = $this->render_url_element( $this->attribute['sg_title_link_to_custom'], null, null, $title );
					break;
				default:
					$content = $title;
					break;
			}

			$content = sprintf( '<%1$s class="archive-title %2$s %3$s">%4$s</%1$s>', $html_tag, '', $animation, $content );
		}

		return '<div class="' . $name . ' ' . $this->unique_id . '">' . $content . '</div>';
	}

	/**
	 * Build content for backend editor
	 *
	 * @param string $name
	 *
	 * @return string
	 */
	public function build_content_backend( $name ) {
		$title     = esc_html__( 'Archive Title', 'profecient-essential' );
		$link_to   = $this->attribute['sg_title_link_to'];
		$html_tag  = esc_attr( $this->attribute['sg_title_html_tag'] );
		$animation = ! empty( $this->attribute['st_title_hover_animation'] ) ? 'elementor-animation-' . esc_attr( $this->attribute['st_title_hover_animation'] ) : '';

		switch ( $link_to ) {
			case 'home':
				$content = sprintf( '<a href="%1$s">%2$s</a>', '#', $title );
				break;
			case 'custom':
				$content = $this->render_url_element( $this->attribute['sg_title_link_to_custom'], null, null, $title );
				break;
			default:
				$content = $title;
				break;
		}

		$content = sprintf( '<%1$s class="archive-title %2$s %3$s">%4$s</%1$s>', $html_tag, '', $animation, $content );

		return '<div class="' . $name . ' ' . $this->unique_id . '">' . $content . '</div>';
	}

	/**
	 * Get Archive Title
	 */
	public function get_archive_title() {
		$title = '';

		if ( is_search() ) {
			/* translators: %s: Search query. */
			$title = sprintf( __( 'Search Results for &#8220;%s&#8221;' ), get_search_query() );
		} elseif ( is_post_type_archive() ) {
			$title = post_type_archive_title( '', false );
		} elseif ( is_tax() ) {
			$title = single_term_title( '', false );
		} elseif ( is_category() || is_tag() ) {
			$title = single_term_title( '', false );
		} elseif ( is_author() && get_queried_object() ) {
			$author = get_queried_object();
			$title  = $author->display_name;
		} elseif ( is_year() ) {
			$title = get_the_date( _x( 'Y', 'yearly archives date format' ) );
		} elseif ( is_month() ) {
			$title = get_the_date( _x( 'F Y', 'monthly archives date format' ) );
		} elseif ( is_day() ) {
			$title = get_the_date();
		}

		return $title;
	}

	/**
	 * Build block content
	 */
	public function build_content() {
		return $this->build_content_separately( 'profecient-archive-title' );
	}
}
