<?php
/**
 * Breadcrumb View Class
 *
 * @package profecient-essential
 * @author jegtheme
 * @since 1.0.0
 */

namespace Profecient\Essential\JKit\Elements\Views;

use Jeg\Elementor_Kit\Elements\Views\View_Abstract;
use Profecient\Essential\Helpers\Breadcrumb;

/**
 * Class Breadcrumb_View
 *
 * @package Jeg\Elementor_Kit\Elements\Views
 */
class Breadcrumb_View extends View_Abstract {
	/**
	 * The Crumbs
	 *
	 * @var array $crumbs
	 */
	private $crumbs = array();

	/**
	 * Build block content
	 *
	 * @return html
	 */
	public function build_content() {
		$content = $this->render_breadcrumb();

		if ( isset( $this->attribute['sg_settings_enable_breadcrumb_schema'] ) && (bool) $this->attribute['sg_settings_enable_breadcrumb_schema'] ) {
			$content .= $this->render_breadcrumb_schema();
		}

		return '<div class="profecient-breadcrumb ' . $this->unique_id . '">' . $content . '</div>';
	}

	/**
	 * Render Breadcrumb Schema for SEO
	 */
	private function render_breadcrumb_schema() {
		$json = array(
			'@context'        => 'https://schema.org',
			'@type'           => 'BreadcrumbList',
			'itemListElement' => array(),
		);

		foreach ( $this->crumbs as $key => $val ) {
			$json['itemListElement'][ $key ] = array(
				'@type'    => 'ListItem',
				'position' => $key + 1,
				'name'     => $val['name'],
				'item'     => $val['url'],
			);

			if ( empty( $val['url'] ) ) {
				unset( $json['itemListElement'][ $key ]['item'] );
			}
		}

		return '<script type="application/ld+json">' . wp_json_encode( $json ) . '</script>';
	}

	/**
	 * Render Breadcrumb
	 */
	private function render_breadcrumb() {
		$breadcrumb   = new Breadcrumb();
		$this->crumbs = $breadcrumb->generate_crumbs();
		$html         = $this->breadcrumb_html( $this->crumbs );
		$separator    = $this->separator_html();

		return implode( $separator, $html );
	}

	/**
	 * HTML of Breadcrumb
	 *
	 * @param array $breadcrumb Crumb Lists.
	 *
	 * @return array
	 */
	private function breadcrumb_html( $breadcrumb ) {
		$html      = array();
		$last_item = end( $breadcrumb );

		foreach ( $breadcrumb as $crumb ) {
			$item = $crumb['name'];

			if ( 'link' && $crumb !== $last_item ) {
				$item = '<a href="' . $crumb['url'] . '">' . $crumb['name'] . '</a>';
			}

			$item = '<span class="crumb">' . $item . '</span>';

			array_push( $html, $item );
		}

		return $html;
	}

	/**
	 * HTML of separator
	 *
	 * @return string
	 */
	private function separator_html() {
		$separator = $this->render_icon_element( $this->attribute['st_separator_icon'] );

		$html = '<span class="separator">' . $separator . '</span>';

		return $html;
	}
}
