<?php
/**
 * Charts View Class
 *
 * @package profecient-essential
 * @author jegtheme
 * @since 1.0.0
 */

namespace Profecient\Essential\JKit\Elements\Views;

/**
 * Class Charts_View
 *
 * @package Jeg\Elementor_Kit\Elements\Views
 */
class Charts_View extends View_Abstract {
	/**
	 * Build block content
	 */
	public function build_content() {
		$label      = $this->attribute['sg_chart_label'];
		$data       = $this->attribute['sg_chart_data'];
		$type       = $this->attribute['sg_chart_type'];
		$labels     = array();
		$datas      = array();
		$colors     = array();
		$typography = array();

		if ( $this->attribute['st_chart_typography_content_typography_font_family'] ) {
			$typography['family'] = $this->attribute['st_chart_typography_content_typography_font_family'];
		}

		if ( $this->attribute['st_chart_typography_content_typography_font_size']['size'] ) {
			$typography['size'] = $this->attribute['st_chart_typography_content_typography_font_size']['size'];
		}

		if ( $this->attribute['st_chart_typography_content_typography_font_style'] ) {
			$typography['style'] = $this->attribute['st_chart_typography_content_typography_font_style'];
		}

		if ( $this->attribute['st_chart_typography_content_typography_font_weight'] ) {
			$typography['weight'] = $this->attribute['st_chart_typography_content_typography_font_weight'];
		}

		if ( $this->attribute['st_chart_typography_content_typography_line_height']['size'] ) {
			$typography['lineHeight'] = $this->attribute['st_chart_typography_content_typography_line_height']['size'];
		}

		if ( $this->attribute['st_chart_typography_color'] ) {
			$typography['color'] = $this->attribute['st_chart_typography_color'];
		}

		foreach ( $label as $key => $lab ) {
			$labels[] = $lab['sg_chart_label_title'];
			$colors[] = $lab['st_background_color'];
		}

		foreach ( $data as $key => $dat ) {
			$numbersonly = preg_replace( '/[^-0-9,.]/', '', $dat['sg_chart_data_segmen'] );
			$numberarray = explode( ',', $numbersonly );
			$numberarray = array_map( 'floatval', $numberarray );

			$datas[] = array(
				'label' => $dat['sg_chart_data_title'],
				'data'  => $numberarray,
			);
			if ( $dat['st_background_clr'] || ( $this->color_check( $colors ) && ( 'pie' === $type || 'doughnut' === $type ) ) ) {
				$datas[ count( $datas ) - 1 ]['backgroundColor'] = ( 'pie' === $type || 'doughnut' === $type ) ? $colors : $dat['st_background_clr'];
			}
			if ( $dat['st_border_clr'] ) {
				$datas[ count( $datas ) - 1 ]['borderColor'] = $dat['st_border_clr'];
			}
			if ( $dat['st_border_width']['size'] ) {
				$datas[ count( $datas ) - 1 ]['borderWidth'] = $dat['st_border_width']['size'];
			}
			if ( $dat['st_border_radius']['size'] ) {
				$datas[ count( $datas ) - 1 ]['borderRadius'] = $dat['st_border_radius']['size'];
			}
		}
		return $this->render_wrapper(
			'charts',
			'<div class="profecient-essential profecient-charts"><canvas class="canvas-profecient-charts"></canvas></div>',
			array(),
			array(
				'labels'  => esc_html( wp_json_encode( $labels ) ),
				'segmens' => esc_html( wp_json_encode( $datas ) ),
				'typo'    => esc_html( wp_json_encode( $typography ) ),
				'type'    => esc_html( $type ),
			)
		);
	}

	/**
	 * Build block content
	 */
	public function color_check( $colors ) {
		foreach ( $colors as $value ) {
			if ( ! empty( $value ) ) {
				return true;
			}
		}
		return false;
	}
}
