<?php
/**
 * Horizontal Accordion View Class
 *
 * @package profecient-essential
 * @author jegtheme
 * @since 1.0.0
 */

namespace Profecient\Essential\JKit\Elements\Views;

/**
 * Class Horizontal_Accordion_View
 *
 * @package Jeg\Elementor_Kit\Elements\Views
 */
class Horizontal_Accordion_View extends View_Abstract {
	/**
	 * Build block content
	 */
	public function build_content() {
		return $this->render_wrapper( 'horizontal-accordion', $this->render_accordion(), array( 'style-' . $this->attribute['sg_accordion_style'] ) );
	}

	/**
	 * Render Accordion Responsive
	 */
	private function render_accordion_responsive() {
		$accordions = '';
		$list       = $this->attribute['sg_accordion_list'];
		$header     = '';
		$count      = count( $list );

		foreach ( $list as $key => $accordion ) {
			$expand_id     = 'expand-' . esc_attr( $accordion['_id'] );
			$title         = esc_attr( $accordion['sg_accordion_list_title'] );
			$content_title = 'yes' === $accordion['sg_accordion_include_title'] ? '<div class="card-title">' . $title . '</div>' : '';
			$img           = $accordion['sg_accordion_image']['url'] ? $accordion['sg_accordion_image'] : array( 'url' => \Elementor\Utils::get_placeholder_image_src() );
			$icon          = '';
			$swap_icon     = 'yes' === $accordion['sg_accordion_button_icon_postion'] ? 'swap' : '';
			if ( isset( $accordion['sg_accordion_button_icon']['value'] ) && ! empty( $accordion['sg_accordion_button_icon']['value'] ) ) {
				$icon = $this->render_icon_element( $accordion['sg_accordion_button_icon'] );
			}
			$button       = 'yes' === $accordion['sg_accordion_include_button'] ? '<a href="' . esc_attr( $accordion['sg_accordion_button_url'] ) . '" class="card-button ' . $swap_icon . '"><span>' . esc_attr( $accordion['sg_accordion_button_text'] ) . '</span>' . $icon . '</a>' : '';
			$image        = 'yes' === $accordion['sg_accordion_include_image'] ? '<img src="' . $img['url'] . '" class="wp-post-image" alt="" loading="lazy" data-caption="" data-src="' . $img['url'] . '" data-large_image="' . $img['url'] . '" srcset="' . $img['url'] . ' 600w, ' . $img['url'] . ' 300w, ' . $img['url'] . ' 100w, ' . $img['url'] . ' 150w, ' . $img['url'] . ' 768w, ' . $img['url'] . ' 800w" sizes="(max-width: 600px) 100vw, 600px" />' : '';
			$image_swap   = $image && 'yes' === $accordion['sg_accordion_image_swap'] ? 'swap' : '';
			$image_class  = $image ? 'image' : '';
			$content_swap = 'yes' === $accordion['sg_accordion_swap_content'] ? 'swap' : '';
			$content      = wp_kses_post( $accordion['sg_accordion_list_content'] );
			$expand       = 0 === $key ? 'expand' : '';
			$first        = 0 === $key ? 'first' : '';
			$pos          = $key + 1;
			$last         = $count === $pos ? 'last' : '';
			$body         = 'yes' === $accordion['sg_accordion_include_content'] ? '<div class="card-body">' . $content . '</div>' : '';

			$header = $header .
			'<div class="card-header ' . $expand . ' ' . $first . ' ' . $last . '" data-index="' . $key . '">
				<a href="#' . $expand_id . '" class="wp-block-button card-header-button" aria-expanded="false" data-target="#' . $expand_id . '" aria-controls="' . $expand_id . '">
					' . '<span class="title">' . $title . '</span>
				</a>
			</div>';

			$accordions = $accordions .
			'<div class="card-wrapper ' . $image_swap . ' ' . $expand . ' ' . $image_class . '" data-index="' . $key . '">
					<div class="card-expand ' . $content_swap . '" id="' . $expand_id . '">
					' . $content_title . '
					' . $body . '
							' . $button . '
					</div>
					' . $image . '
            </div>';
		}

		return '<div class="accordion-items-wrapper-responsive"><div class="card-header-responsive">' . $header . '</div><div class="card-wrapper-responsive">' . $accordions . '</div></div>';
	}

	/**
	 * Render Accordion
	 */
	private function render_accordion() {
		$accordions = '';
		$list       = $this->attribute['sg_accordion_list'];
		$count      = count( $list );
		$width      = $count * 80;

		foreach ( $list as $key => $accordion ) {
			$expand_id     = 'expand-' . esc_attr( $accordion['_id'] );
			$title         = esc_attr( $accordion['sg_accordion_list_title'] );
			$content_title = 'yes' === $accordion['sg_accordion_include_title'] ? '<div class="card-title">' . $title . '</div>' : '';
			$img           = $accordion['sg_accordion_image']['url'] ? $accordion['sg_accordion_image'] : array( 'url' => \Elementor\Utils::get_placeholder_image_src() );
			$swap_icon     = 'yes' === $accordion['sg_accordion_button_icon_postion'] ? 'swap' : '';
			$icon          = '';
			if ( isset( $accordion['sg_accordion_button_icon']['value'] ) && ! empty( $accordion['sg_accordion_button_icon']['value'] ) ) {
				$icon = $this->render_icon_element( $accordion['sg_accordion_button_icon'] );
			}
			$button       = 'yes' === $accordion['sg_accordion_include_button'] ? '<a href="' . esc_attr( $accordion['sg_accordion_button_url'] ) . '" class="card-button ' . $swap_icon . '"><span>' . esc_attr( $accordion['sg_accordion_button_text'] ) . '</span>' . $icon . '</a>' : '';
			$image        = 'yes' === $accordion['sg_accordion_include_image'] ? '<img src="' . $img['url'] . '" class="wp-post-image" alt="" loading="lazy" data-caption="" data-src="' . $img['url'] . '" data-large_image="' . $img['url'] . '" srcset="' . $img['url'] . ' 600w, ' . $img['url'] . ' 300w, ' . $img['url'] . ' 100w, ' . $img['url'] . ' 150w, ' . $img['url'] . ' 768w, ' . $img['url'] . ' 800w" sizes="(max-width: 600px) 100vw, 600px" />' : '';
			$image_swap   = $image && 'yes' === $accordion['sg_accordion_image_swap'] ? 'swap' : '';
			$image_class  = $image ? 'image' : '';
			$content_swap = 'yes' === $accordion['sg_accordion_swap_content'] ? 'swap' : '';
			$content      = wp_kses_post( $accordion['sg_accordion_list_content'] );
			$expand       = 0 === $key ? 'expand' : '';
			$sort         = $key + 1;
			$left         = $sort * 80;
			$first        = 0 === $key ? 'first' : '';
			$pos          = $key + 1;
			$last         = $count === $pos ? 'last' : '';
			$body         = 'yes' === $accordion['sg_accordion_include_content'] ? '<div class="card-body">' . $content . '</div>' : '';

			$accordions = $accordions .
			'<div class="card-wrapper ' . $image_swap . ' ' . $expand . ' ' . $image_class . ' ' . $first . ' ' . $last . '" style="width: calc(100% - ' . $width . 'px); ' . $this->attribute['sg_accordion_style'] . ': ' . $left . 'px;" data-index="' . $key . '">
                <div class="card-header">
                    <a href="#' . $expand_id . '" class="wp-block-button card-header-button" aria-expanded="false" data-target="#' . $expand_id . '" aria-controls="' . $expand_id . '">
                        ' . '<span class="title">' . $title . '</span>
                    </a>
                </div>
					<div class="card-content">
					<div class="card-expand ' . $content_swap . '" id="' . $expand_id . '">
					' . $content_title . '
					' . $body . '
							' . $button . '
					</div>
					' . $image . '
					</div>
            </div>';
		}

		return '<div class="profecient-essential profecient-horizontal-accordion accordion-items-wrapper">' . $accordions . $this->render_accordion_responsive() . '</div>';
	}
}
