<?php
/**
 * Hotspot View Class
 *
 * @package profecient-essential
 * @author jegtheme
 * @since 1.0.0
 */

namespace Profecient\Essential\JKit\Elements\Views;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Class Hotspot_View
 */
class Hotspot_View extends View_Abstract {
	/**
	 * Build block content
	 *
	 * @return html
	 */
	public function build_content() {
		$data = $this->data_position( $this->attribute );

		return $this->render_wrapper( 'hotspot', $this->render_template(), array(), $data );
	}

	/**
	 * Build Data Position
	 *
	 * @param object|array $data The Data Position.
	 * @param boolean      $custom Custom Position.
	 *
	 * @return array
	 */
	public function data_position( $attribute, $custom = false ) {
		$prefix = isset( $attribute['sg_hotspot_custom_tooltip_properties'] ) && $attribute['sg_hotspot_custom_tooltip_properties'] === 'yes' && $custom ? 'sg_hotspot_custom_tooltip_' : 'sg_tooltips_';
		$data   = array();

		if ( isset( $attribute[ $prefix . 'position_responsive' ] ) ) {
			$data['position-desktop'] = $attribute[ $prefix . 'position_responsive' ];
		}

		foreach ( jkit_get_responsive_breakpoints() as $responsive ) {
			if ( isset( $attribute[ $prefix . 'position_responsive_' . $responsive['key'] ] ) ) {
				$data[ 'position-' . $responsive['key'] ] = $attribute[ $prefix . 'position_responsive_' . $responsive['key'] ];
			}
		}

		return $data;
	}

	/**
	 * Render Template
	 *
	 * @return html
	 */
	public function render_template() {
		$image_attachment = $this->attribute['sg_background_choose'];
		$image_size       = $this->attribute['sg_background_image_size_imagesize_size'];
		$image            = $this->render_image_element( $image_attachment, $image_size );
		$hotspots         = $this->build_hotspot();
		$container        = '<div class="profecient-hotspot-container">' . $image . $hotspots . '</div>';
		$wrapper          = '<div class="profecient-hotspot-wrapper">' . $container . '</div>';
		return $wrapper;
	}

	/**
	 * Build Hotspot
	 *
	 * @return html
	 */
	public function build_hotspot() {
		$hotspot = '';
		foreach ( $this->attribute['sg_hotspot_item'] as $hotspot_item ) {
			$hotspot_class = sprintf(
				'profecient-hotspot-item profecient-hotspot-%s elementor-repeater-item-%s profecient-hotspot-position-%s profecient-hotspot-position-%s',
				$hotspot_item['_id'],
				$hotspot_item['_id'],
				$hotspot_item['sg_hotspot_horizontal_orientation'],
				$hotspot_item['sg_hotspot_vertical_orientation']
			);
			if ( ! empty( $hotspot_item['sg_hotspot_link'] ) ) {
				$hotspot .= '<div class="' . $hotspot_class . '">' . $this->render_url_element( $hotspot_item['sg_hotspot_link'], null, 'profecient-hotspot-link', $this->build_button( $hotspot_item ) ) . $this->build_tooltip( $hotspot_item ) . '</div>';
			} else {
				$hotspot .= '<div class="' . $hotspot_class . '">' . $this->build_button( $hotspot_item ) . $this->build_tooltip( $hotspot_item ) . '</div>';
			}
		}

		return $hotspot;
	}

	/**
	 * Build Button
	 *
	 * @return html
	 */
	public function build_button( $hotspot_item ) {
		ob_start();
		?>
		<div class="profecient-hotspot-button profecient-hotspot-icon-position-<?php echo esc_attr( $hotspot_item['sg_hotspot_icon_position'] ); ?>">
			<?php if ( 'icon' === $hotspot_item['sg_hotspot_icon'] ) : ?>
				<div class="profecient-hotspot-icon"><?php echo $this->render_icon_element( $hotspot_item['sg_hotspot_icon_choose'] ); ?></div>
			<?php endif; ?>
			<?php if ( ! empty( $hotspot_item['sg_hotspot_label'] ) ) : ?>
				<div class="profecient-hotpsot-label"><?php echo esc_attr( $hotspot_item['sg_hotspot_label'] ); ?></div>
			<?php endif; ?>
		</div>
		<?php

		return ob_get_clean();
	}

	/**
	 * Build Tooltip
	 *
	 * @return html
	 */
	public function build_tooltip( $hotspot_item ) {
		$data = $this->data_position( $hotspot_item, true );

		ob_start();
		if ( ! empty( $hotspot_item['sg_hotspot_tooltip_content'] ) ) :
			?>
			<div class="profecient-hotspot-tooltip" <?php echo $this->build_data_attributes( $data ); ?>>
				<div class="profecient-hotspot-tooltip-content">
					<?php echo wp_kses( $hotspot_item['sg_hotspot_tooltip_content'], wp_kses_allowed_html() ); ?>
				</div>
				<?php if ( $this->attribute['sg_tooltips_arrow'] === 'yes' ) : ?>
					<div class="profecient-hotspot-arrow"></div>
				<?php endif; ?>
			</div>
			<?php
		endif;

		return ob_get_clean();
	}
}
