<?php
/**
 * Product Single Add To Cart View Class
 *
 * @package profecient-essential
 * @author jegtheme
 * @since 1.0.0
 */

namespace Profecient\Essential\JKit\Elements\Views;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

use Jeg\Elementor_Kit\Elements\Views\View_Abstract;

/**
 * Class Product_Single_Add_To_Cart_View
 */
class Product_Single_Add_To_Cart_View extends View_Abstract {
	/**
	 * Build content for frontend editor
	 *
	 * @param string $name
	 *
	 * @return string
	 */
	public function build_content_frontend( $name ) {
		global $product;
		if ( null === $product || empty( $product ) ) {
			return $this->build_content_backend( $name );
		}
		ob_start();

		switch ( $product->get_type() ) {
			case 'simple':
				$this->custom_add_to_cart_text( $this->attribute['sg_settings_custom_simple_single_add_to_cart_text'] );
				woocommerce_simple_add_to_cart(); /* Simple Add to Cart */
				break;
			case 'variable':
				$this->custom_add_to_cart_text( $this->attribute['sg_settings_custom_variable_single_add_to_cart_text'] );
				woocommerce_variable_add_to_cart(); /* Variable Add to Cart */
				break;
			case 'external':
				$this->custom_add_to_cart_text( $this->attribute['sg_settings_custom_external_single_add_to_cart_text'] );
				woocommerce_external_add_to_cart(); /* External Add to Cart */
				break;
			case 'grouped':
				$this->custom_add_to_cart_text( $this->attribute['sg_settings_custom_grouped_single_add_to_cart_text'] );
				woocommerce_grouped_add_to_cart(); /* Grouped Add to Cart */
				break;
		}

		$content = ob_get_clean();
		$content = apply_filters( 'single_product_add_to_cart', $content );

		return '<div class="' . $name . ' ' . $this->unique_id . '">' . $content . '</div>';
	}

	/**
	 * Build content for backend editor
	 *
	 * @param string $name
	 *
	 * @return string
	 */
	public function build_content_backend( $name ) {
		ob_start();

		switch ( $this->attribute['sg_settings_product_type_preview'] ) {
			case 'simple':
				$this->render_dummy_simple_add_to_cart( $this->attribute['sg_settings_custom_simple_single_add_to_cart_text'] ); /* Simple Add to Cart */
				break;
			case 'variable':
				$this->render_dummy_variable_add_to_cart( $this->attribute['sg_settings_custom_variable_single_add_to_cart_text'] ); /* Variable Add to Cart */
				break;
			case 'external':
				$this->render_dummy_external_add_to_cart( $this->attribute['sg_settings_custom_external_single_add_to_cart_text'] ); /* External Add to Cart */
				break;
			case 'grouped':
				$this->render_dummy_grouped_add_to_cart( $this->attribute['sg_settings_custom_grouped_single_add_to_cart_text'] ); /* Grouped Add to Cart */
				break;
		}

		$content = ob_get_clean();
		$content = apply_filters( 'single_product_add_to_cart', $content );

		return '<div class="' . $name . ' ' . $this->unique_id . ' product">' . $content . '</div>';
	}

	/**
	 * Custom Add To Cart Text
	 *
	 * @param string $custom_add_to_cart_text
	 */
	public function custom_add_to_cart_text( $custom_add_to_cart_text ) {
		if ( ! empty( $custom_add_to_cart_text ) ) {
			add_filter(
				'woocommerce_product_single_add_to_cart_text',
				function () use ( $custom_add_to_cart_text ) {
					return $custom_add_to_cart_text;
				}
			);
		}
	}

	/**
	 * Render Cart Icon
	 *
	 * @param string $content String of HTML
	 *
	 * @return string $content
	 */
	public function render_cart_icon( $content ) {
		if ( isset( $this->attribute['sg_settings_button_icon']['value'] ) && ! empty( $this->attribute['sg_settings_button_icon']['value'] ) ) {
			$icon    = $this->render_icon_element( $this->attribute['sg_settings_button_icon'] );
			$content = preg_replace( '/(<button.*?>)(.*?)(<\/button>)/', '$1' . $icon . '$2$3', $content );
		}
		return $content;
	}

	/**
	 * Setup hook
	 */
	public function setup_hook() {
		add_filter( 'single_product_add_to_cart', array( $this, 'render_cart_icon' ) );
	}

	/**
	 * Remove hook
	 */
	public function remove_hook() {
		remove_filter( 'single_product_add_to_cart', array( $this, 'render_cart_icon' ) );
	}

	/**
	 * Build block content
	 */
	public function build_content() {
		$this->setup_hook();
		$content = $this->build_content_separately( 'profecient-add-to-cart' );
		$this->remove_hook();

		return $content;
	}

	/**
	 * Render Dummy Simple Add To Cart
	 */
	public function render_dummy_simple_add_to_cart( $button_text ) {
		?>

		<form class="cart" action="#" method="post" enctype='multipart/form-data'>
			<?php do_action( 'woocommerce_before_add_to_cart_button' ); ?>

			<?php
			do_action( 'woocommerce_before_add_to_cart_quantity' );

			$GLOBALS['product'] = null;
			woocommerce_quantity_input(
				array(
					'min_value'   => 0,
					'max_value'   => 20,
					'input_value' => '0',
				)
			);

			do_action( 'woocommerce_after_add_to_cart_quantity' );
			?>

			<button type="submit" name="add-to-cart" value="dummy_product" class="single_add_to_cart_button button alt"><?php echo ! empty( $button_text ) ? esc_attr( $button_text ) : esc_html__( 'Add to cart', 'profecient-essential' ); ?></button>

			<?php do_action( 'woocommerce_after_add_to_cart_button' ); ?>
		</form>

		<?php
		do_action( 'woocommerce_after_add_to_cart_form' );
	}

	/**
	 * Render Dummy Variable Add To Cart
	 */
	public function render_dummy_variable_add_to_cart( $button_text ) {
		$variable_attr = $this->dummy_product_attr();

		do_action( 'woocommerce_before_add_to_cart_form' );
		?>
		<style>
			label, select {
				text-transform: capitalize;
			}
			.woocommerce div.product form.cart .reset_variations {
				visibility: visible;
			}
		</style>
		<form class="variations_form cart" action="#" method="post" enctype="multipart/form-data" data-product_id="dummy" data-product_variations="[]" current-image="0">
			<?php do_action( 'woocommerce_before_variations_form' ); ?>
			
			<?php if ( isset( $this->attribute['sg_show_variations'] ) && $this->attribute['sg_show_variations'] ) : ?>
				<p class="stock out-of-stock"><?php echo esc_html( apply_filters( 'woocommerce_out_of_stock_message', esc_html__( 'This product is currently out of stock and unavailable.', 'profecient-essential' ) ) ); ?></p>
			<?php else : ?>
				<table class="variations" cellspacing="0">
					<tbody>
						<?php foreach ( $variable_attr['variable'] as $attribute_name => $options ) : ?>
							<tr>
								<th class="label"><label for="<?php echo esc_attr( sanitize_title( $attribute_name ) ); ?>"><?php echo esc_attr( wc_attribute_label( $attribute_name ) ); // WPCS: XSS ok. ?></label></th>
								<td class="value">
									<?php
										wc_dropdown_variation_attribute_options(
											array(
												'options'  => $options,
												'attribute' => $attribute_name,
												'selected' => '',
											)
										);
										echo end( array_keys( $variable_attr['variable'] ) ) === $attribute_name ? wp_kses_post( apply_filters( 'woocommerce_reset_variations_link', '<a class="reset_variations" href="#">' . esc_html__( 'Clear', 'profecient-essential' ) . '</a>' ) ) : '';
									?>
								</td>
							</tr>
						<?php endforeach; ?>
					</tbody>
				</table>
				<?php do_action( 'woocommerce_after_variations_table' ); ?>
				<div class="single_variation_wrap">
					<div class="woocommerce-variation single_variation">
						<div class="woocommerce-variation-description">
							<p>Lorem ipsum dolor sit amet, consectetur adipiscing elit. Vestibulum sagittis orci ac odio dictum tincidunt. Donec ut metus leo. Class aptent taciti sociosqu ad litora torquent per conubia nostra, per inceptos himenaeos. Sed luctus, dui eu sagittis sodales, nulla nibh sagittis augue, vel porttitor diam enim non metus. Vestibulum aliquam augue neque. Phasellus tincidunt odio eget ullamcorper efficitur. Cras placerat ut turpis pellentesque vulputate. Nam sed consequat tortor. Curabitur finibus sapien dolor. Ut eleifend tellus nec erat pulvinar dignissim. Nam non arcu purus. Vivamus et massa massa.</p>
						</div>
						<div class="woocommerce-variation-price">
							<span class="price">
								<?php echo wp_kses( wc_price( 45.00 ), wp_kses_allowed_html() ); ?>
							</span>
						</div>
						<div class="woocommerce-variation-availability"></div>
					</div>
					<div class="woocommerce-variation-add-to-cart variations_button woocommerce-variation-add-to-cart-enabled">
						<?php
						$GLOBALS['product'] = null;
						woocommerce_quantity_input(
							array(
								'max_value'    => -2,
								'min_value'    => 1,
								'product_name' => 'Dummy Product',
							)
						);
						?>
						<button type="submit" class="single_add_to_cart_button button alt"><?php echo ! empty( $button_text ) ? esc_html__( $button_text, 'profecient-essential' ) : esc_html__( 'Add to cart', 'profecient-essential' ); ?></button> <!-- Use `disabled` clasess for button disabled -->
						<input type="hidden" name="add-to-cart" value="dummy_product-bomber-jacket">
						<input type="hidden" name="product_id" value="dummy_product-bomber-jacket">
						<input type="hidden" name="variation_id" class="variation_id" value="dummy_product-bomber-jacket">
					</div>
				</div>
			<?php endif; ?>
		</form>
		<?php
		do_action( 'woocommerce_after_add_to_cart_form' );
	}

	/**
	 * Render Dummy External Add To Cart
	 */
	public function render_dummy_external_add_to_cart( $button_text ) {
		do_action( 'woocommerce_before_add_to_cart_form' );
		?>
		<form class="cart" action="#" method="get">
			<?php do_action( 'woocommerce_before_add_to_cart_button' ); ?>
			<button type="submit" class="single_add_to_cart_button button alt"><?php echo ! empty( $button_text ) ? esc_html( $button_text ) : esc_html__( 'Buy on the WordPress swag store!', 'profecient-essential' ); ?></button>
			<?php do_action( 'woocommerce_after_add_to_cart_button' ); ?>
		</form>
		<?php
		do_action( 'woocommerce_after_add_to_cart_form' );
	}

	/**
	 * Render Dummy Grouped Add To Cart
	 */
	public function render_dummy_grouped_add_to_cart( $button_text ) {
		$grouped_product_columns = apply_filters(
			'woocommerce_grouped_product_columns',
			array(
				'quantity',
				'label',
				'price',
			),
		);

		do_action( 'woocommerce_before_add_to_cart_form' );
		?>
		<form class="cart grouped_form" action="#" method="post" enctype='multipart/form-data'>
			<table cellspacing="0" class="woocommerce-grouped-product-list group_table">
				<tbody>
					<?php foreach ( dummy_products() as $product ) : ?>
						<tr id="product-<?php echo esc_attr( $product['id'] ); ?>" class="woocommerce-grouped-product-list-item">
							<?php
							foreach ( $grouped_product_columns as $column_id ) {
								do_action( 'woocommerce_grouped_product_list_before_' . $column_id, $product );
								switch ( $column_id ) {
									case 'quantity':
										ob_start();

										if ( isset( $product['is_purchasable'] ) && ! $product['is_purchasable'] ) {
											$defaults = array(
												'quantity' => 1,
												'class'    => 'button product_type_simple',
												'attributes' => array(
													'data-product_id' => $product['id'],
													'data-product_sku' => $product['id'],
													'aria-label' => 'Read more about “' . $product['name'] . '”',
													'rel' => 'nofollow',
												),
											);

											$args = apply_filters( 'woocommerce_loop_add_to_cart_args', $defaults, $product );

											echo wp_kses(
												apply_filters(
													'woocommerce_loop_add_to_cart_link', // WPCS: XSS ok.
													sprintf(
														'<a href="%s" data-quantity="%s" class="%s" %s>%s</a>',
														esc_url( '#' ),
														esc_attr( isset( $args['quantity'] ) ? $args['quantity'] : 1 ),
														esc_attr( isset( $args['class'] ) ? $args['class'] : 'button' ),
														isset( $args['attributes'] ) ? wc_implode_html_attributes( $args['attributes'] ) : '',
														esc_html__( 'Read More', 'profecient-essential' )
													),
													$product,
													$args
												),
												wp_kses_allowed_html()
											);
										} elseif ( isset( $product['sold_individually'] ) && $product['sold_individually'] ) {
											echo wp_kses( '<input type="checkbox" name="' . esc_attr( 'quantity[' . $product['id'] . ']' ) . '" value="1" class="wc-grouped-product-add-to-cart-checkbox" />', wp_kses_allowed_html() );
										} else {
											do_action( 'woocommerce_before_add_to_cart_quantity' );

											$GLOBALS['product'] = null;
											woocommerce_quantity_input(
												array(
													'input_name'  => 'quantity[' . $product['id'] . ']',
													'input_value' => '1',
													'min_value'   => apply_filters( 'woocommerce_quantity_input_min', $product['quantity']['min_value'], $product ),
													'max_value'   => apply_filters( 'woocommerce_quantity_input_max', $product['quantity']['max_value'], $product ),
													'placeholder' => '0',
												)
											);

											do_action( 'woocommerce_after_add_to_cart_quantity' );
										}

										$value = ob_get_clean();
										break;
									case 'label':
										$value  = '<label for="product-' . esc_attr( $product['id'] ) . '">';
										$value .= $product['visible'] ? '<a href="#">' . $product['name'] . '</a>' : $product['name'];
										$value .= '</label>';
										break;
									case 'price':
										if ( isset( $product['onsale'] ) ) {
											$value = wc_format_sale_price( $product['price'], $product['onsale'] );
										} else {
											$value = wc_price( $product['price'] );
										}
										break;
									default:
										$value = '';
										break;
								}

								echo wp_kses( '<td class="woocommerce-grouped-product-list-item__' . esc_attr( $column_id ) . '">' . apply_filters( 'woocommerce_grouped_product_list_column_' . $column_id, $value, $product ) . '</td>', wp_kses_allowed_html() );
							}
							?>
						</tr>
					<?php endforeach; ?>
				</tbody>
			</table>
			<input type="hidden" name="add-to-cart" value="<?php echo esc_attr( 'dummy-product-id' ); ?>" />
			<?php do_action( 'woocommerce_before_add_to_cart_button' ); ?>
			<button type="submit" class="single_add_to_cart_button button alt"><?php echo ! empty( $button_text ) ? esc_attr( $button_text ) : esc_html__( 'Add to cart', 'profecient-essential' ); ?></button>
			<?php do_action( 'woocommerce_after_add_to_cart_button' ); ?>
		</form>
		<?php
		do_action( 'woocommerce_after_add_to_cart_form' );
	}

	/**
	 * Dummy Products
	 */
	public function dummy_product_attr() {
		return array(
			'variable' => array(
				'pa_color' => array( 'black', 'maroon', 'purple', 'tosca' ),
				'logo'     => array( 'yes', 'no' ),
			),
		);
	}
}
