<?php
/**
 * Product Single Additonal Information View Class
 *
 * @package profecient-essential
 * @author jegtheme
 * @since 1.0.0
 */

namespace Profecient\Essential\JKit\Elements\Views;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

use Jeg\Elementor_Kit\Elements\Views\View_Abstract;

/**
 * Class Product_Single_Additional_Information_View
 */
class Product_Single_Additional_Information_View extends View_Abstract {
	/**
	 * Build content for frontend editor
	 *
	 * @param string $name
	 *
	 * @return string
	 */
	public function build_content_frontend( $name ) {
		ob_start();

		global $product;

		if ( null === $product || empty( $product ) ) {
			return $this->build_content_backend( $name );
		}

		wc_get_template( 'single-product/tabs/additional-information.php' );

		$content = ob_get_clean();

		return '<div class="' . $name . ' ' . $this->unique_id . '">' . $content . '</div>';
	}

	/**
	 * Build content for backend editor
	 *
	 * @param string $name
	 *
	 * @return string
	 */
	public function build_content_backend( $name ) {
		ob_start();

		$heading = apply_filters( 'woocommerce_product_additional_information_heading', __( 'Additional information', 'profecient-essential' ) );
		?>
		
		<?php if ( $heading ) : ?>
			<h2><?php echo esc_html( $heading ); ?></h2>
		<?php endif; ?>

		<?php
		$product_attributes = $this->dummy_product_attributes();

		wc_get_template(
			'single-product/product-attributes.php',
			array(
				'product_attributes' => $product_attributes,
			)
		);

		$content = ob_get_clean();

		return '<div class="' . $name . ' ' . $this->unique_id . ' product">' . $content . '</div>';
	}

	/**
	 * Build block content
	 */
	public function build_content() {
		return $this->build_content_separately( 'profecient-additional-information' );
	}

	public function dummy_product_attributes() {
		return array(
			'attribute_pa_color' => array(
				'label' => 'Color',
				'value' => 'Blue, Green, Red',
			),
			'attribute_pa_size'  => array(
				'label' => 'Size',
				'value' => 'Large, Medium, Small',
			),
		);
	}
}
