<?php
/**
 * Product Single Breadcrumb View Class
 *
 * @package profecient-essential
 * @author jegtheme
 * @since 1.0.0
 */

namespace Profecient\Essential\JKit\Elements\Views;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

use Jeg\Elementor_Kit\Elements\Views\View_Abstract;

/**
 * Class Product_Single_Breadcrumb_View
 *
 * @package Jeg\Elementor_Kit\Elements\Views
 */
class Product_Single_Breadcrumb_View extends View_Abstract {
	/**
	 * Build content for frontend editor
	 *
	 * @param string $name
	 *
	 * @return string
	 */
	public function build_content_frontend( $name ) {
		ob_start();
		woocommerce_breadcrumb(
			array(
				'wrap_before' => '<nav class="woocommerce-breadcrumb">',
				'wrap_after'  => '</nav>',
				'before'      => '<span>',
				'after'       => '</span>',
				'delimiter'   => $this->get_delimiter(),
			)
		);

		$content = ob_get_clean();

		return '<div class="' . $name . ' ' . $this->unique_id . '">' . $content . '</div>';
	}

	/**
	 * Build content for backend editor
	 *
	 * @param string $name
	 *
	 * @return string
	 */
	public function build_content_backend( $name ) {
		$delimiter = $this->get_delimiter();
		$items     = array(
			'<span><a href="#" target="_self">' . esc_html__( 'Home', 'profecient-essential' ) . '</a></span>',
			'<span><a href="#" target="_self">' . esc_html__( 'Category', 'profecient-essential' ) . '</a></span>',
			'<span><a href="#" target="_self">' . esc_html__( 'Child Category', 'profecient-essential' ) . '</a></span>',
			'<span>' . esc_html__( 'Single Product', 'profecient-essential' ) . '</span>',
		);

		$content = '<nav class="woocommerce-breadcrumb">' . implode( $delimiter, $items ) . '</nav>';

		return '<div class="' . $name . ' ' . $this->unique_id . '">' . $content . '</div>';
	}

	/**
	 * Get Delimited Icon
	 *
	 * @return string HTML
	 */
	private function get_delimiter() {
		$delimiter = '<i>&nbsp;&#47;&nbsp;</i>';

		if ( isset( $this->attribute['st_breadcrumb_delimiter_icon'] ) ) {
			$delimiter = $this->render_icon_element( $this->attribute['st_breadcrumb_delimiter_icon'] );
		}

		return $delimiter;
	}

	/**
	 * Build block content
	 */
	public function build_content() {
		return $this->build_content_separately( 'profecient-product-breadcrumb' );
	}
}
