<?php
/**
 * Product Single Data Tabs View Class
 *
 * @package profecient-essential
 * @author jegtheme
 * @since 1.0.0
 */

namespace Profecient\Essential\JKit\Elements\Views;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

use Jeg\Elementor_Kit\Elements\Views\View_Abstract;

/**
 * Class Product_Single_Data_Tabs_View
 */
class Product_Single_Data_Tabs_View extends View_Abstract {
	/**
	 * Build content for frontend editor
	 *
	 * @param string $name
	 *
	 * @return string
	 */
	public function build_content_frontend( $name ) {
		global $product;
		if ( null === $product || empty( $product ) ) {
			return $this->build_content_backend( $name );
		}

		ob_start();

		woocommerce_output_product_data_tabs();

		$content = ob_get_clean();

		return '<div class="' . $name . ' ' . $this->unique_id . '">' . $content . '</div>';
	}

	/**
	 * Build content for backend editor
	 *
	 * @param string $name
	 *
	 * @return string
	 */
	public function build_content_backend( $name ) {
		ob_start();

		$product_tabs = $this->dummy_data();
		?>
		<div class="woocommerce-tabs wc-tabs-wrapper">
			<ul class="tabs wc-tabs" role="tablist">
				<?php foreach ( $product_tabs as $key => $product_tab ) : ?>
					<li class="<?php echo esc_attr( $key ); ?>_tab" id="tab-title-<?php echo esc_attr( $key ); ?>" role="tab" aria-controls="tab-<?php echo esc_attr( $key ); ?>">
						<a href="#tab-<?php echo esc_attr( $key ); ?>">
							<?php echo wp_kses_post( apply_filters( 'woocommerce_product_' . $key . '_tab_title', $product_tab['title'], $key ) ); ?>
						</a>
					</li>
				<?php endforeach; ?>
			</ul>
			<?php foreach ( $product_tabs as $key => $product_tab ) : ?>
				<div class="woocommerce-Tabs-panel woocommerce-Tabs-panel--<?php echo esc_attr( $key ); ?> panel entry-content wc-tab" id="tab-<?php echo esc_attr( $key ); ?>" role="tabpanel" aria-labelledby="tab-title-<?php echo esc_attr( $key ); ?>">
					<?php
					if ( isset( $product_tab['callback'] ) ) {
						call_user_func( array( $this, $product_tab['callback'] ) );
					}
					?>
				</div>
			<?php endforeach; ?>

			<?php do_action( 'woocommerce_product_after_tabs' ); ?>
		</div>
		<script>
			jQuery( '.wc-tabs-wrapper, .woocommerce-tabs, #rating' ).trigger( 'init' );
		</script>
		<?php

		$content = ob_get_clean();

		return '<div class="' . $name . ' ' . $this->unique_id . ' product">' . $content . '</div>';
	}

	/**
	 * Build block content
	 */
	public function build_content() {
		return $this->build_content_separately( 'profecient-data-tabs' );
	}

	/**
	 * Render Dummy Single Product Description
	 */
	private function render_dummy_single_product_description() {
		$heading     = apply_filters( 'woocommerce_product_description_heading', __( 'Description', 'profecient-essential' ) );
		$description = apply_filters( 'woocommerce_short_description', esc_html__( 'This is an example of the product short description.', 'profecient-essential' ) );

		?>
		<h2><?php echo esc_html( $heading ); ?></h2>
		<?php
		echo wp_kses( $description, wp_kses_allowed_html() );
	}

	/**
	 * Render Dummy Single Product Description
	 */
	private function render_dummy_single_product_additional_information() {
		$heading = apply_filters( 'woocommerce_product_additional_information_heading', __( 'Additional information', 'profecient-essential' ) );
		?>
		
		<?php if ( $heading ) : ?>
			<h2><?php echo esc_html( $heading ); ?></h2>
		<?php endif; ?>
		
		<?php
		$product_attributes = array(
			'attribute_pa_color' => array(
				'label' => 'Color',
				'value' => 'Blue, Green, Red',
			),
			'attribute_pa_size'  => array(
				'label' => 'Size',
				'value' => 'Large, Medium, Small',
			),
		);

		wc_get_template(
			'single-product/product-attributes.php',
			array(
				'product_attributes' => $product_attributes,
			)
		);
	}

	/**
	 * Render Dummy Single Product Reviews
	 */
	private function render_dummy_single_product_reviews() {
		$user           = wp_get_current_user()->data;
		$dummy_comments = array(
			array(
				'rating'      => 4,
				'verified'    => true,
				'date'        => '2022-04-12 04:22:49',
				'description' => 'mantap sekali gan!',
			),
			array(
				'rating'      => 3,
				'verified'    => false,
				'date'        => '2022-04-12 04:23:01',
				'description' => 'boleh lah gan!',
			),
			array(
				'rating'      => 2,
				'verified'    => false,
				'date'        => '2022-04-13 02:19:21',
				'description' => 'emm..',
			),
		);
		?>
		<div id="reviews" class="woocommerce-Reviews">
			<div id="comments">
				<h2 class="woocommerce-Reviews-title">
					<?php
					$count = 3;
					if ( $count && wc_review_ratings_enabled() ) {
						/* translators: 1: reviews count 2: product name */
						$reviews_title = sprintf( esc_html( _n( '%1$s review for %2$s', '%1$s reviews for %2$s', $count, 'profecient-essential' ) ), esc_html( $count ), '<span>Dummy Product</span>' );
						echo wp_kses( apply_filters( 'woocommerce_reviews_title', $reviews_title, $count, null ), wp_kses_allowed_html() ); // WPCS: XSS ok.
					}
					?>
				</h2>
				<ol class="commentlist">
				<?php foreach ( $dummy_comments as $key => $content ) : ?>
						<li class="review byuser comment-author-<?php echo esc_attr( $user->user_login ); ?> bypostauthor even thread-even depth-1" id="li-comment-<?php echo esc_attr( $key ); ?>">
							<div id="comment-<?php echo esc_attr( $key ); ?>" class="comment_container">
								<?php woocommerce_review_display_gravatar( $user->user_email ); ?>
								<div class="comment-text">
									<?php echo wc_get_rating_html( $content['rating'] ); ?>
									<p class="meta">
										<strong class="woocommerce-review__author"><?php echo esc_attr( $user->display_name ); ?></strong>
										<?php if ( isset( $content['verified'] ) && $content['verified'] ) : ?>
											<em class="woocommerce-review__verified verified"><?php echo esc_attr__( 'verified owner', 'profecient-essential' ); ?></em>
										<?php endif; ?>
										<span class="woocommerce-review__dash">–</span> <time class="woocommerce-review__published-date" datetime="<?php echo esc_attr( mysql2date( 'c', $content['date'] ) ); ?>"><?php echo esc_html( mysql2date( wc_date_format(), $content['date'] ) ); ?></time>
									</p>
									<div class="description">
										<p><?php echo esc_html( $content['description'] ); ?></p>
									</div>
								</div>
							</div>
						</li>
						<!-- #comment-## -->
				<?php endforeach; ?>
				</ol>
			</div>
			<div id="review_form_wrapper">
				<div id="review_form">
					<div id="respond" class="comment-respond">
						<span id="reply-title" class="comment-reply-title"><?php echo esc_html( 'Add a review ', 'profecient-essential' ); ?><small><a rel="nofollow" id="cancel-comment-reply-link" href="#respond" style="display:none;"><?php echo esc_html( 'Cancel reply', 'profecient-essential' ); ?></a></small></span>
						<form action="#" method="post" id="commentform" class="comment-form" novalidate="">
							<div class="comment-form-rating">
								<label for="rating"><?php echo esc_html( 'Your rating ', 'profecient-essential' ); ?><span class="required">*</span></label>
								<select name="rating" id="rating" required="" style="display: none;">
									<option value=""><?php echo esc_html( 'Rate…', 'profecient-essential' ); ?></option>
									<option value="5"><?php echo esc_html( 'Perfect', 'profecient-essential' ); ?></option>
									<option value="4"><?php echo esc_html( 'Good', 'profecient-essential' ); ?></option>
									<option value="3"><?php echo esc_html( 'Average', 'profecient-essential' ); ?></option>
									<option value="2"><?php echo esc_html( 'Not that bad', 'profecient-essential' ); ?></option>
									<option value="1"><?php echo esc_html( 'Very poor', 'profecient-essential' ); ?></option>
								</select>
							</div>
							<p class="comment-form-comment">
								<label for="comment"><?php echo esc_html( 'Your review ', 'profecient-essential' ); ?><span class="required">*</span></label>
								<textarea id="comment" name="comment" cols="45" rows="8" required=""></textarea>
							</p>
							<p class="form-submit">
								<input name="submit" type="submit" id="submit" class="submit" value="Submit">
								<input type="hidden" name="comment_post_ID" value="dummy_product" id="comment_post_ID">
								<input type="hidden" name="comment_parent" id="comment_parent" value="0">
							</p>
							<input type="hidden" id="_wp_unfiltered_html_comment_disabled" name="_wp_unfiltered_html_comment" value="8db16d0761">
						</form>
					</div>
					<!-- #respond -->
				</div>
			</div>
			<div class="clear"></div>
		</div>
		<?php
	}

	/**
	 * Dummy Product Data
	 */
	private function dummy_data() {
		return array(
			'description'            => array(
				'title'    => __( 'Description', 'profecient-essential' ),
				'priority' => 10,
				'callback' => 'render_dummy_single_product_description',
			),
			'additional_information' => array(
				'title'    => __( 'Additional information', 'profecient-essential' ),
				'priority' => 20,
				'callback' => 'render_dummy_single_product_additional_information',
			),
			'reviews'                => array(
				'title'    => __( 'Reviews (3)', 'profecient-essential' ),
				'priority' => 30,
				'callback' => 'render_dummy_single_product_reviews',
			),
		);
	}
}
