<?php
/**
 * Product Single Images View Class
 *
 * @package profecient-essential
 * @author jegtheme
 * @since 1.0.0
 */

namespace Profecient\Essential\JKit\Elements\Views;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

use \Jeg\Elementor_Kit\Elements\Views\View_WooCommerce_Abstract;

/**
 * Class Product_Single_Images_View
 */
class Product_Single_Images_View extends View_WooCommerce_Abstract {
	/**
	 * Product Class
	 */
	protected $product = null;

	/**
	 * Build content for frontend editor
	 *
	 * @param string $name
	 *
	 * @return string
	 */
	public function build_content_frontend( $name ) {
		$content       = '';
		$this->product = wc_get_product();

		if ( null === $this->product || empty( $this->product ) ) {
			return $this->build_content_backend( $name );
		}

		if ( $this->product->is_on_sale() ) {
			if ( ! $this->product->is_type( 'grouped' ) && $this->attribute['st_content_percentage'] ) {
				if ( $this->product->is_type( 'variable' ) ) {
					$prices           = $this->product->get_variation_prices();
					$regular_price    = $prices['regular_price'];
					$sale_price       = $prices['sale_price'];
					$price_percentage = array();

					foreach ( $prices['price'] as $key => $value ) {
						if ( ! empty( $regular_price[ $key ] ) ) {
							$percentage = round( 100 - ( $sale_price[ $key ] / $regular_price[ $key ] * 100 ) );

							if ( $percentage > 0 ) {
								$price_percentage[] = $percentage;
							}
						}
					}

					if ( ! empty( $price_percentage ) ) {
						asort( $price_percentage );
						$percentage = $price_percentage[0] . '%';

						if ( count( $price_percentage ) > 1 ) {
							$percentage .= '-' . end( $price_percentage ) . '%';
						}

						$content = '<span class="onsale percent">' . $percentage . '</span>';
					}
				} else {
					$regular_price = (float) $this->product->get_regular_price();
					$sale_price    = (float) $this->product->get_price();

					if ( ! empty( $regular_price ) ) {
						$percentage = round( 100 - ( $sale_price / $regular_price * 100 ) );

						if ( $percentage > 0 ) {
							$content = '<span class="onsale percent">' . $percentage . '%</span>';
						}
					}
				}
			}

			if ( $this->attribute['st_content_sale'] ) {
				$content .= '<span class="onsale text">' . esc_html__( 'Sale', 'profecient-essential' ) . '</span>';
			}
		}

		ob_start();

		echo wp_kses( $content, wp_kses_allowed_html() );
		wc_get_template( '/single-product/product-image.php' );

		return '<div class="' . $name . ' ' . $this->unique_id . ' product">' . ob_get_clean() . '</div>';
	}

	/**
	 * Build content for backend editor
	 *
	 * @param string $name
	 *
	 * @return string
	 */
	public function build_content_backend( $name ) {
		$content     = '';
		$dummy_image = apply_filters(
			'profecient_essential_dummy_product_image',
			array(
				'title' => esc_html__( 'Sweatshirt Hoodie Zipper', 'profecient-essential' ),
				'url'   => PROFECIENT_ESSENTIAL_URL . '/assets/img/products/sweatshirt-hoodie-with-zipper.jpg',
			)
		);

		if ( $this->attribute['st_content_percentage'] ) {
			$content .= '<span class="onsale percent">' . esc_html__( '10%', 'profecient-essential' ) . '</span>';
		}

		if ( $this->attribute['st_content_sale'] ) {
			$content .= '<span class="onsale text">' . esc_html__( 'Sale', 'profecient-essential' ) . '</span>';
		}

		$content .=
			'<div class="woocommerce-product-gallery woocommerce-product-gallery--with-images woocommerce-product-gallery--columns-4 images" data-columns="4" style="opacity: 0; transition: opacity .25s ease-in-out;">
				<a href="#" class="woocommerce-product-gallery__trigger">🔍</a>
				<figure class="woocommerce-product-gallery__wrapper">
					<div data-thumb="" data-thumb-alt="" class="woocommerce-product-gallery__image">
						<a href="#">
							<img width="600" height="599" src="' . $dummy_image['url'] . '" class="wp-post-image" alt="" loading="lazy" title="' . $dummy_image['title'] . '" data-caption="" data-src="' . $dummy_image['url'] . '" data-large_image="' . $dummy_image['url'] . '" data-large_image_width="800" data-large_image_height="799" srcset="' . $dummy_image['url'] . ' 600w, ' . $dummy_image['url'] . ' 300w, ' . $dummy_image['url'] . ' 100w, ' . $dummy_image['url'] . ' 150w, ' . $dummy_image['url'] . ' 768w, ' . $dummy_image['url'] . ' 800w" sizes="(max-width: 600px) 100vw, 600px" />
						</a>
					</div>
				</figure>
			</div>';

		return '<div class="' . $name . ' ' . $this->unique_id . ' product">' . $content . '</div>';
	}

	/**
	 * Build block content
	 */
	public function build_content() {
		return $this->build_content_separately( 'profecient-product-images' );
	}
}
