<?php
/**
 * Product Single Meta View Class
 *
 * @package profecient-essential
 * @author jegtheme
 * @since 1.0.0
 */

namespace Profecient\Essential\JKit\Elements\Views;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

use Jeg\Elementor_Kit\Elements\Views\View_Abstract;

/**
 * Class Product_Single_Meta_View
 */
class Product_Single_Meta_View extends View_Abstract {
	/**
	 * The String of Meta
	 *
	 * @var string
	 */
	private $sku_label;

	/**
	 * The String of Meta
	 *
	 * @var string
	 */
	private $sku_empty;

	/**
	 * The String of Meta
	 *
	 * @var string
	 */
	private $category_label_single;

	/**
	 * The String of Meta
	 *
	 * @var string
	 */
	private $category_label_plural;

	/**
	 * The String of Meta
	 *
	 * @var string
	 */
	private $tag_label_single;

	/**
	 * The String of Meta
	 *
	 * @var string
	 */
	private $tag_label_plural;

	/**
	 * Build content for frontend editor
	 *
	 * @param string $name
	 *
	 * @return string
	 */
	public function build_content_frontend( $name ) {
		global $product;

		$product = wc_get_product();

		if ( ! $product ) {
			return;
		}

		$sku          = $product->get_sku();
		$category_ids = $product->get_category_ids();
		$tag_ids      = $product->get_tag_ids();

		ob_start();

		?>
		<div class="product_meta">
			<?php do_action( 'woocommerce_product_meta_start' ); ?>

			<?php if ( wc_product_sku_enabled() && ( $sku || $product->is_type( 'variable' ) ) ) : ?>
				<span class="sku_wrapper">
					<span class="label">
						<?php echo esc_html( $this->sku_label ); ?>
					</span>
					<span class="sku">
						<?php
						if ( $sku ) {
							echo esc_html( $sku );
						} else {
							echo esc_html( $this->sku_empty );
						}
						?>
					</span>
				</span>
			<?php endif; ?>

			<?php if ( count( $category_ids ) ) : ?>
				<span class="posted_in">
					<span class="label">
						<?php echo esc_html( $this->is_plural_or_single( $this->category_label_single, $this->category_label_plural, count( $category_ids ) ) ); ?>
					</span>
					<span class="content">
						<?php echo wp_kses( get_the_term_list( $product->get_id(), 'product_cat', '', ', ' ), wp_kses_allowed_html() ); ?>
					</span>
				</span>
			<?php endif; ?>

			<?php if ( count( $tag_ids ) ) : ?>
				<span class="tagged_as">
					<span class="label">
						<?php echo esc_html( $this->is_plural_or_single( $this->tag_label_single, $this->tag_label_plural, count( $tag_ids ) ) ); ?>
					</span>
					<span class="content">
						<?php echo wp_kses( get_the_term_list( $product->get_id(), 'product_tag', '', ', ' ), wp_kses_allowed_html() ); ?>
					</span>
				</span>
			<?php endif; ?>

			<?php do_action( 'woocommerce_product_meta_end' ); ?>
		</div>
		<?php

		$content = ob_get_clean();

		return '<div class="' . $name . ' ' . $this->unique_id . '">' . $content . '</div>';
	}

	private function is_plural_or_single( $single, $plural, $count ) {
		return 1 === $count ? $single : $plural;
	}

	/**
	 * Build content for backend editor
	 *
	 * @param string $name
	 *
	 * @return string
	 */
	public function build_content_backend( $name ) {
		ob_start();
		?>
		<div class="product_meta">
			<?php do_action( 'woocommerce_product_meta_start' ); ?>

			<span class="sku_wrapper">
				<span class="label">
					<?php echo esc_html( $this->sku_label ); ?>
				</span>
				<span class="sku">
					<?php esc_html_e( 'sku-code', 'profecient-essential' ); ?>
				</span>
			</span>

			<span class="posted_in">
				<span class="label">
					<?php echo esc_html( $this->category_label_single ); ?>
				</span>
				<span class="content">
					<a href=""><?php esc_html_e( 'WooCommerce', 'profecient-essential' ); ?></a>
				</span>
			</span>

			<span class="tagged_as">
				<span class="label">
					<?php echo esc_html( $this->tag_label_single ); ?>
				</span>
				<span class="content">
					<a href=""><?php esc_html_e( 'WordPress', 'profecient-essential' ); ?></a>
				</span>
			</span>

			<?php do_action( 'woocommerce_product_meta_end' ); ?>
		</div>
		<?php

		$content = ob_get_clean();

		return '<div class="' . $name . ' ' . $this->unique_id . '">' . $content . '</div>';
	}

	/**
	 * Build block content
	 */
	public function build_content() {
		$this->sku_label             = esc_html__( 'SKU:', 'profecient-essential' );
		$this->sku_empty             = esc_html__( 'N/A', 'profecient-essential' );
		$this->category_label_single = esc_html__( 'Category:', 'profecient-essential' );
		$this->category_label_plural = esc_html__( 'Categories:', 'profecient-essential' );
		$this->tag_label_single      = esc_html__( 'Tag:', 'profecient-essential' );
		$this->tag_label_plural      = esc_html__( 'Tags:', 'profecient-essential' );

		return $this->build_content_separately( 'profecient-product-meta' );
	}
}
