<?php
/**
 * Product Single Rating View Class
 *
 * @package profecient-essential
 * @author jegtheme
 * @since 1.0.0
 */

namespace Profecient\Essential\JKit\Elements\Views;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

use \Jeg\Elementor_Kit\Elements\Views\View_Abstract;

/**
 * Class Product_Single_Rating_View
 */
class Product_Single_Rating_View extends View_Abstract {
	/**
	 * Build content for frontend editor
	 *
	 * @param string $name
	 *
	 * @return string
	 */
	public function build_content_frontend( $name ) {
		global $product;
		if ( null === $product || empty( $product ) ) {
			return $this->build_content_backend( $name );
		}
		ob_start();
		wc_get_template( '/single-product/rating.php' );

		return '<div class="' . $name . ' ' . $this->unique_id . '">' . ob_get_clean() . '</div>';
	}

	/**
	 * Build content for backend editor
	 *
	 * @param string $name
	 *
	 * @return string
	 */
	public function build_content_backend( $name ) {
		$review_avg   = 4.5;
		$review_count = 5;
		$content      = '<div class="woocommerce-product-rating">
						' . wc_get_rating_html( $review_avg, $review_count ) . '
						<a href="#reviews" class="woocommerce-review-link" rel="nofollow">
							(' . sprintf( _n( '%s customer review', '%s customer reviews', $review_count, 'profecient-essential' ), '<span class="count">' . esc_html( $review_count ) . '</span>' ) . ')
						</a>
					</div>';

		return '<div class="' . $name . ' ' . $this->unique_id . '">' . $content . '</div>';
	}

	/**
	 * Build block content
	 */
	public function build_content() {
		return $this->build_content_separately( 'profecient-product-rating' );
	}
}
