<?php
/**
 * Product Single Related View Class
 *
 * @package profecient-essential
 * @author jegtheme
 * @since 1.0.0
 */

namespace Profecient\Essential\JKit\Elements\Views;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

use Jeg\Elementor_Kit\Elements\Views\View_WooCommerce_Abstract;

/**
 * Class Product_Single_Related_View
 */
class Product_Single_Related_View extends View_WooCommerce_Abstract {
	/**
	 * Build content for frontend editor
	 *
	 * @param string $name
	 *
	 * @return string
	 */
	public function build_content_frontend( $name ) {
		global $product;

		$product = wc_get_product();

		if ( ! $product ) {
			return;
		}

		$args = array(
			'posts_per_page' => 4,
			'columns'        => 4,
			'orderby'        => isset( $this->attribute['orderby'] ) ? $this->attribute['orderby'] : '',
			'order'          => isset( $this->attribute['order'] ) ? $this->attribute['order'] : '',
		);

		if ( ! empty( $this->attribute['sg_filter_posts_per_page']['size'] ) ) {
			$args['posts_per_page'] = $this->attribute['sg_filter_posts_per_page']['size'];
		}

		if ( ! empty( $settings['columns'] ) ) {
			$args['columns'] = $this->attribute['columns'];
		}

		// Get visible related products then sort them at random.
		$args['related_products'] = array_filter( array_map( 'wc_get_product', wc_get_related_products( $product->get_id(), $args['posts_per_page'], $product->get_upsell_ids() ) ), 'wc_products_array_filter_visible' );

		// Handle orderby.
		$args['related_products'] = wc_products_array_orderby( $args['related_products'], $args['orderby'], $args['order'] );

		ob_start();

		wc_get_template( 'single-product/related.php', $args );

		$content = ob_get_clean();
		$content = apply_filters( 'single_product_related', $content );

		return '<div class="' . $name . ' ' . $this->unique_id . '">' . $content . '</div>';
	}

	/**
	 * Build content for backend editor
	 *
	 * @param string $name
	 *
	 * @return string
	 */
	public function build_content_backend( $name ) {
		ob_start();
		?>
		<section class="related products">

		<?php $heading = apply_filters( 'woocommerce_product_related_products_heading', __( 'Related products', 'profecient-essential' ) ); ?>

		<?php if ( $heading ) : ?>
			<h2><?php echo esc_html( $heading ); ?></h2>
		<?php endif; ?>

			<ul class="products columns-4">
				<?php foreach ( dummy_products() as $key => $product ) : ?>
					<?php
					if ( ! empty( $this->attribute['sg_filter_posts_per_page']['size'] ) && $key >= $this->attribute['sg_filter_posts_per_page']['size'] ) {
						break;
					}
					?>
					<li class="product type-product post-x status-publish first instock product_cat-jacket has-post-thumbnail shipping-taxable purchasable product-type-simple">
						<a href="#" class="woocommerce-LoopProduct-link woocommerce-loop-product__link">
							<?php if ( isset( $product['onsale'] ) ) : ?>
								<?php if ( $this->attribute['sg_content_percentage'] ) : ?>
									<span class="onsale percent"><?php echo esc_html( round( 100 - ( $product['onsale'] / $product['price'] * 100 ) ) ) . '%'; ?></span>
								<?php endif; ?>
								<?php if ( $this->attribute['sg_content_sale'] ) : ?>
									<span class="onsale text"><?php echo esc_html__( 'Sale!', 'profecient-essential' ); ?></span>
								<?php endif; ?>
							<?php endif; ?>
							<?php echo wp_kses( $product['image'], wp_kses_allowed_html() ); ?>
							<h2 class="woocommerce-loop-product__title"><?php echo esc_html( $product['name'] ); ?></h2>
							<div class="star-rating" role="img" aria-label="Rated <?php echo esc_html( $product['rating'] ); ?> out of 5"><span style="width:<?php echo esc_attr( ( $product['rating'] / 5 ) * 100 ); ?>%">
								Rated
								<strong class="rating"><?php echo esc_html( $product['rating'] ); ?></strong> out of 5</span>
							</div>
							<span class="price">
								<?php
								if ( isset( $product['onsale'] ) ) {
									echo wp_kses( wc_format_sale_price( $product['price'], $product['onsale'] ), wp_kses_allowed_html() );
								} else {
									echo wp_kses( wc_price( $product['price'] ), wp_kses_allowed_html() );
								}
								?>
							</span>
						</a>
						<a href="#" data-quantity="1" class="button product_type_simple add_to_cart_button ajax_add_to_cart" data-product_id="<?php echo esc_attr( $product['id'] ); ?>" data-product_sku="<?php echo esc_attr( $product['id'] ); ?>" aria-label="Add “<?php echo esc_attr( $product['name'] ); ?>” to your cart" rel="nofollow"><?php echo __( 'Add to cart', 'profecient-essential' ); ?></a>
					</li>
				<?php endforeach; ?>
			</ul>


		</section>
		<?php
		$content = ob_get_clean();
		$content = apply_filters( 'single_product_related', $content );

		return '<div class="' . $name . ' ' . $this->unique_id . '">' . $content . '</div>';
	}

	/**
	 * Render Cart Icon
	 */
	public function render_cart_icon( $content ) {
		if ( isset( $this->attribute['sg_button_icon']['value'] ) && ! empty( $this->attribute['sg_button_icon']['value'] ) ) {
			$icon    = $this->render_icon_element( $this->attribute['sg_button_icon'] );
			$content = preg_replace( '/(<a[^<]+class=[\"\'][^<]*\sadd_to_cart_button\s*[^<]*[\"\'][^<]+>)(.*?)(<\/a>)/', '$1' . $icon . '$2$3', $content );
		}
		return $content;
	}

	/**
	 * Render Custom On Sale Badge
	 */
	public function render_custom_onsale_badge( $content, $post, $product ) {
		$content = '';

		if ( $product->is_on_sale() ) {
			if ( ! $product->is_type( 'grouped' ) && $this->attribute['sg_content_percentage'] ) {
				if ( $product->is_type( 'variable' ) ) {
					$prices           = $product->get_variation_prices();
					$regular_price    = $prices['regular_price'];
					$sale_price       = $prices['sale_price'];
					$price_percentage = array();

					foreach ( $prices['price'] as $key => $value ) {
						if ( ! empty( $regular_price[ $key ] ) ) {
							$percentage = round( 100 - ( $sale_price[ $key ] / $regular_price[ $key ] * 100 ) );

							if ( $percentage > 0 ) {
								$price_percentage[] = $percentage;
							}
						}
					}

					if ( ! empty( $price_percentage ) ) {
						asort( $price_percentage );
						$percentage = $price_percentage[0] . '%';

						if ( count( $price_percentage ) > 1 ) {
							$percentage .= '-' . end( $price_percentage ) . '%';
						}

						$content .= '<span class="onsale percent">' . $percentage . '</span>';
					}
				} else {
					$regular_price = (float) $product->get_regular_price();
					$sale_price    = (float) $product->get_price();

					if ( ! empty( $regular_price ) ) {
						$percentage = round( 100 - ( $sale_price / $regular_price * 100 ) );

						if ( $percentage > 0 ) {
							$content = '<span class="onsale percent">' . $percentage . '%</span>';
						}
					}
				}
			}

			if ( $this->attribute['sg_content_sale'] ) {
				$content .= '<span class="onsale text">' . esc_html__( 'Sale', 'profecient-essential' ) . '</span>';
			}
		}

		return $content;
	}

	/**
	 * Set Thumbnail Size
	 *
	 * @param string $size Size of Thumbnail.
	 *
	 * @return string $size
	 */
	public function set_thumbnail_size( $size ) {
		if ( isset( $this->attribute['sg_content_image_size_imagesize_size'] ) && ! empty( $this->attribute['sg_content_image_size_imagesize_size'] ) ) {
			$size = $this->attribute['sg_content_image_size_imagesize_size'];
		}
		return $size;
	}

	/**
	 * Setup Hook
	 */
	public function setup_hook() {
		add_filter( 'single_product_related', array( $this, 'render_cart_icon' ) );
		add_filter( 'woocommerce_sale_flash', array( $this, 'render_custom_onsale_badge' ), 10, 3 );
		add_filter( 'single_product_archive_thumbnail_size', array( $this, 'set_thumbnail_size' ) );
	}

	/**
	 * Remove Hook
	 */
	public function remove_hook() {
		remove_filter( 'single_product_related', array( $this, 'render_cart_icon' ) );
		remove_filter( 'woocommerce_sale_flash', array( $this, 'render_custom_onsale_badge' ), 10, 3 );
		remove_filter( 'single_product_archive_thumbnail_size', array( $this, 'set_thumbnail_size' ) );
	}

	/**
	 * Build block content
	 */
	public function build_content() {
		$this->setup_hook();
		$content = $this->build_content_separately( 'profecient-product-related' );
		$this->remove_hook();

		return $content;
	}
}
