<?php
/**
 * Product Single Stock View Class
 *
 * @package profecient-essential
 * @author jegtheme
 * @since 1.0.0
 */

namespace Profecient\Essential\JKit\Elements\Views;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

use Jeg\Elementor_Kit\Elements\Views\View_Abstract;

/**
 * Class Product_Single_Stock_View
 */
class Product_Single_Stock_View extends View_Abstract {
	/**
	 * Build content for frontend editor
	 *
	 * @param string $name
	 *
	 * @return string
	 */
	public function build_content_frontend( $name ) {
		global $product;
		if ( null === $product || empty( $product ) ) {
			return $this->build_content_backend( $name );
		}
		$content = wc_get_stock_html( $product );

		return '<div class="' . $name . ' ' . $this->unique_id . '">' . $content . '</div>';
	}

	/**
	 * Build content for backend editor
	 *
	 * @param string $name
	 *
	 * @return string
	 */
	public function build_content_backend( $name ) {

		switch ( $this->attribute['sg_preview_product_stock'] ) {
			case 'in-stock':
				$content = '<p class="stock in-stock">' . esc_html__( '1 in stock', 'profecient-essential' ) . '</p>';
				break;
			case 'available-on-backorder':
				$content = '<p class="stock available-on-backorder">' . esc_html__( 'Available on backorder', 'profecient-essential' ) . '</p>';
				break;
			case 'out-of-stock':
				$content = '<p class="stock out-of-stock">' . esc_html__( 'Out of stock', 'profecient-essential' ) . '</p>';
				break;
		}

		return '<div class="' . $name . ' ' . $this->unique_id . '">' . $content . '</div>';
	}

	/**
	 * Build block content
	 */
	public function build_content() {
		return $this->build_content_separately( 'profecient-single-product-stock' );
	}
}
