<?php
/**
 * Product Single Title View Class
 *
 * @package profecient-essential
 * @author jegtheme
 * @since 1.0.0
 */

namespace Profecient\Essential\JKit\Elements\Views;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

use Jeg\Elementor_Kit\Elements\Views\View_Abstract;

/**
 * Class Product_Single_Title_View
 */
class Product_Single_Title_View extends View_Abstract {
	/**
	 * Build content for frontend editor
	 *
	 * @param string $name
	 *
	 * @return string
	 */
	public function build_content_frontend( $name ) {
		$content = '';
		$title   = get_the_title();

		if ( ! empty( $title ) ) {
			$link_to   = $this->attribute['sg_title_link_to'];
			$html_tag  = esc_attr( $this->attribute['sg_title_html_tag'] );
			$animation = ! empty( $this->attribute['st_title_hover_animation'] ) ? 'elementor-animation-' . esc_attr( $this->attribute['st_title_hover_animation'] ) : '';
			$style     = isset( $this->attribute['sg_title_color_style'] ) ? 'style-' . esc_attr( $this->attribute['sg_title_color_style'] ) : '';

			switch ( $link_to ) {
				case 'home':
					$content = sprintf( '<a href="%1$s">%2$s</a>', esc_url( get_home_url() ), $title );
					break;
				case 'product':
					$content = sprintf( '<a href="%1$s">%2$s</a>', esc_url( get_the_permalink() ), $title );
					break;
				case 'custom':
					$content = $this->render_url_element( $this->attribute['sg_title_link_to_custom'], null, null, $title );
					break;
				default:
					$content = $title;
					break;
			}

			$content = sprintf( '<%1$s class="product-title %2$s %3$s">%4$s</%1$s>', $html_tag, $style, $animation, $content );
		}

		return '<div class="' . $name . ' ' . $this->unique_id . '">' . $content . '</div>';
	}

	/**
	 * Build content for backend editor
	 *
	 * @param string $name
	 *
	 * @return string
	 */
	public function build_content_backend( $name ) {
		$title     = esc_html__( 'Single Product Title', 'profecient-essential' );
		$link_to   = $this->attribute['sg_title_link_to'];
		$html_tag  = esc_attr( $this->attribute['sg_title_html_tag'] );
		$animation = ! empty( $this->attribute['st_title_hover_animation'] ) ? 'elementor-animation-' . esc_attr( $this->attribute['st_title_hover_animation'] ) : '';
		$style     = isset( $this->attribute['sg_title_color_style'] ) ? 'style-' . esc_attr( $this->attribute['sg_title_color_style'] ) : '';

		switch ( $link_to ) {
			case 'home':
			case 'product':
				$content = sprintf( '<a href="%1$s">%2$s</a>', '#', $title );
				break;
			case 'custom':
				$content = $this->render_url_element( $this->attribute['sg_title_link_to_custom'], null, null, $title );
				break;
			default:
				$content = $title;
				break;
		}

		$content = sprintf( '<%1$s class="product-title %2$s %3$s">%4$s</%1$s>', $html_tag, $style, $animation, $content );

		return '<div class="' . $name . ' ' . $this->unique_id . '">' . $content . '</div>';
	}

	/**
	 * Build block content
	 */
	public function build_content() {
		return $this->build_content_separately( 'profecient-product-title' );
	}
}
