<?php
/**
 * View Abstract Class
 *
 * @package profecient-essential
 * @author jegtheme
 * @since 1.0.0
 */

namespace Profecient\Essential\JKit\Elements\Views;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

use Jeg\Elementor_Kit\Elements\Views\View_Abstract as JKit_View_Abstract;

/**
 * Class View_Abstract
 */
abstract class View_Abstract extends JKit_View_Abstract {
	/**
	 * Build element with wrapper
	 *
	 * @param string $element_name Element name.
	 * @param string $inner Inner element.
	 * @param array  $array_classes Classes.
	 * @param array  $array_data Data attribute.
	 * @param array  $id Element ID.
	 *
	 * @return string
	 */
	protected function render_wrapper( $element_name, $inner, $array_classes = array(), $array_data = array(), $id = null ) {
		$classes = $this->get_classnames( $array_classes );
		$data    = $this->build_data_attributes( $array_data );

		if ( $id ) {
			$id = 'id="' . $id . '"';
		}

		$classes = 'profecient profecient-' . $element_name . $classes . ' ' . $this->unique_id;

		return '<div ' . $id . ' class="' . $classes . '" ' . $data . '>' . $inner . '</div>';
	}

	/**
	 * Get classnames
	 *
	 * @param array $array_classes Classes.
	 *
	 * @return string
	 */
	protected function get_classnames( $array_classes ) {
		$classes = '';

		foreach ( $array_classes as $class ) {
			$classes = $classes . ' ' . $class;
		}

		return $classes;
	}

	/**
	 * Build data attributes
	 *
	 * @param array $array_data Data attribute.
	 *
	 * @return string
	 */
	protected function build_data_attributes( $array_data ) {
		$data = '';

		foreach ( $array_data as $key => $value ) {
			$data = $data . ' data-' . $key . '="' . $value . '"';
		}

		return $data;
	}
}
