<?php
/**
 * Woocommerce Cart Page View Class
 *
 * @package profecient-essential
 * @author jegtheme
 * @since 1.0.0
 */

namespace Profecient\Essential\JKit\Elements\Views;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

use Jeg\Elementor_Kit\Elements\Views\View_WooCommerce_Abstract;

/**
 * Class Woocommerce_Cart_Page_View
 */
class Woocommerce_Cart_Page_View extends View_WooCommerce_Abstract {
	/**
	 * Build content for frontend editor
	 *
	 * @param string $name
	 *
	 * @return string
	 */
	public function build_content_frontend( $name ) {
		$this->page_template();
	}

	/**
	 * Page Tempalte
	 */
	public function page_template() {
		add_action(
			'woocommerce_before_cart',
			function () {
				echo wp_kses( '<div class="profecient-woocommerce-cart-form-wrapper ' . $this->attribute['layout_type'] . '	">', wp_kses_allowed_html() );
			}
		);

		$is_layout1 = 'layout-1' === $this->attribute['layout_type'];

		add_action(
			'woocommerce_before_cart_table',
			function () {
				echo wp_kses( '<div class="profecient-woocommerce-cart-wrapper">', wp_kses_allowed_html() );
			}
		);
		add_action(
			'woocommerce_after_cart_table',
			function () {
				echo wp_kses( '</div>', wp_kses_allowed_html() );
			}
		);

		if ( $is_layout1 ) {
			add_action( 'woocommerce_after_cart_table', array( $this, 'woocommerce_after_cart_table' ) );
			add_action( 'woocommerce_cart_contents', array( $this, 'disable_cart_coupon' ) );
			add_action( 'woocommerce_after_cart_contents', array( $this, 'enable_cart_coupon' ) );
		}

		add_action(
			'woocommerce_after_cart',
			function () {
				echo wp_kses( '</div>', wp_kses_allowed_html() );
			}
		);

		$html = do_shortcode( '[woocommerce_cart]' );
		if ( '<div class="woocommerce"></div>' === $html ) {
			$html = '
			<div class="woocommerce">' . __( 'Your cart is currently empty.', 'profecient-essential' ) . '</div>';
		}

		echo wp_kses( $html, wp_kses_allowed_html() );
		if ( $is_layout1 ) {
			remove_filter( 'woocommerce_coupons_enabled', array( $this, 'hide_coupon_field_on_cart' ) );
			remove_action( 'woocommerce_cart_contents', array( $this, 'disable_cart_coupon' ) );
			remove_action( 'woocommerce_after_cart_contents', array( $this, 'enable_cart_coupon' ) );
		}
	}

	public function hide_coupon_field_on_cart( $enabled ) {
		return is_cart() ? false : $enabled;
	}

	public function disable_cart_coupon() {
		add_filter( 'woocommerce_coupons_enabled', array( $this, 'cart_coupon_return_false' ), 90 );
	}
	public function enable_cart_coupon() {
		remove_filter( 'woocommerce_coupons_enabled', array( $this, 'cart_coupon_return_false' ), 90 );
	}

	public function cart_coupon_return_false() {
		return false;
	}

	public function woocommerce_after_cart_table() {
		if ( function_exists( 'wc_coupons_enabled' ) && wc_coupons_enabled() ) {
			$this->render_woocommerce_cart_coupon_form();
		}
	}

	public function render_woocommerce_cart_coupon_form() {
		?>
		<div class="coupon profecient-cart-section shop_table">
			<div class="form-row coupon-col">
				<div class="coupon-col-start">
					<input type="text" name="coupon_code" class="input-text" id="coupon_code" value="" placeholder="<?php esc_attr_e( 'Coupon code', 'profecient-essential' ); ?>" />
				</div>
				<div class="coupon-col-end">
					<button name="apply_coupon" type="submit" class="button profecient-apply-coupon" value="<?php esc_attr_e( 'Apply coupon', 'profecient-essential' ); ?>"><?php esc_attr_e( 'Apply coupon', 'profecient-essential' ); ?></button>
				</div>
				<?php do_action( 'woocommerce_cart_coupon' ); ?>
			</div>
		</div>
		<?php
	}


	/**
	 * Build content for backend editor
	 *
	 * @param string $name
	 *
	 * @return string
	 */
	public function build_content_backend( $name ) {
		$this->page_template();
	}

	/**
	 * Build block content
	 */
	public function build_content() {
		return $this->build_content_separately( 'profecient-woocommerce-cart-page' );
	}
}
