<?php
/**
 * Woocommerce Checkout Page View Class
 *
 * @package profecient-essential
 * @author jegtheme
 */

namespace Profecient\Essential\JKit\Elements\Views;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

use Jeg\Elementor_Kit\Elements\Views\View_WooCommerce_Abstract;

/**
 * Class Woocommerce_Checkout_Page_View
 */
class Woocommerce_Checkout_Page_View extends View_WooCommerce_Abstract {

	/**
	 * Add Hooks
	 */
	public function add_hooks() {
		add_action(
			'woocommerce_before_checkout_form',
			function () {
				echo wp_kses( '<div class="profecient-wooocommerce-checkout-wrapper ' . $this->attribute['layout_type'] . '"><div class="woocommerce">', wp_kses_allowed_html() );
			}
		);
		add_action(
			'woocommerce_after_checkout_form',
			function () {
				echo wp_kses( '</div></div>', wp_kses_allowed_html() );
			}
		);
		if ( $this->is_layout1 ) {
			add_filter( 'woocommerce_get_terms_and_conditions_checkbox_text', array( $this, 'woocommerce_terms_and_conditions_checkbox_text' ), 10, 1 );

			add_action( 'woocommerce_checkout_before_customer_details', array( $this, 'woocommerce_checkout_before_customer_details' ), 5 );
			add_action( 'woocommerce_checkout_after_customer_details', array( $this, 'woocommerce_checkout_after_customer_details' ), 95 );
			add_action( 'woocommerce_checkout_before_order_review_heading', array( $this, 'woocommerce_checkout_before_order_review_heading_1' ), 5 );
			add_action( 'woocommerce_checkout_before_order_review_heading', array( $this, 'woocommerce_checkout_before_order_review_heading_2' ), 95 );
			add_action( 'woocommerce_checkout_order_review', array( $this, 'woocommerce_checkout_order_review' ), 15 );
			add_action( 'woocommerce_checkout_after_order_review', array( $this, 'woocommerce_checkout_after_order_review' ), 95 );

			// remove the default login & coupon form because we'll be adding our own forms
			remove_action( 'woocommerce_before_checkout_form', 'woocommerce_checkout_coupon_form' );
			remove_action( 'woocommerce_before_checkout_form', 'woocommerce_checkout_login_form' );
		} else {
			add_filter(
				'woocommerce_checkout_coupon_message',
				function () {
					return $this->render_icon_element( $this->attribute['form_coupon_notice_icon'] ) . esc_html__( 'Have a coupon?', 'woocommerce' ) . ' <a href="#" class="showcoupon">' . esc_html__( 'Click here to enter your code', 'woocommerce' ) . '</a>';
				}
			);
			add_filter(
				'woocommerce_no_available_payment_methods_message',
				function () {
					return $this->render_icon_element( $this->attribute['payment_method_notice_icon'] ) . '<span>' . esc_html__( 'Sorry, it seems that there are no available payment methods for your location. Please contact us if you require assistance or wish to make alternate arrangements.', 'woocommerce' ) . '</span>';
				}
			);
		}
	}


	/**
	 * Remove Render Hooks
	 *
	 * Remove actions & filters after displaying our widget.
	 */
	public function remove_render_hooks() {
		if ( $this->is_layout1 ) {
			remove_filter( 'woocommerce_get_terms_and_conditions_checkbox_text', array( $this, 'woocommerce_terms_and_conditions_checkbox_text' ), 10 );
			remove_action( 'woocommerce_checkout_before_customer_details', array( $this, 'woocommerce_checkout_before_customer_details' ), 5 );
			remove_action( 'woocommerce_checkout_after_customer_details', array( $this, 'woocommerce_checkout_after_customer_details' ), 95 );
			remove_action( 'woocommerce_checkout_before_order_review_heading', array( $this, 'woocommerce_checkout_before_order_review_heading_1' ), 5 );
			remove_action( 'woocommerce_checkout_before_order_review_heading', array( $this, 'woocommerce_checkout_before_order_review_heading_2' ), 95 );
			remove_action( 'woocommerce_checkout_order_review', array( $this, 'woocommerce_checkout_order_review' ), 15 );
			remove_action( 'woocommerce_checkout_after_order_review', array( $this, 'woocommerce_checkout_after_order_review' ), 95 );
		}
	}

	/**
	 * Build content for frontend editor
	 *
	 * @param string $name
	 *
	 * @return string
	 */
	public function build_content_frontend( $name ) {
		$this->page_template();
	}

	/**
	 * Build content for backend editor
	 *
	 * @param string $name
	 *
	 * @return string
	 */
	public function build_content_backend( $name ) {
		$this->page_template();
	}

	/**
	 * Page Template
	 */
	public function page_template() {
		// global $woocommerce;
		if ( is_null( WC()->cart ) ) {
			wc_load_cart();
		}

		if ( ! WC()->cart->is_empty() ) {
			$this->is_layout1 = 'layout-1' === $this->attribute['layout_type'];
			// Add actions & filters before displaying our Widget.
			$this->add_hooks();

			call_user_func( array( 'WC_Shortcode_Checkout', 'output' ), '' );

			// Remove actions & filters after displaying our Widget.
			$this->remove_render_hooks();
		} else {
			echo wp_kses(
				'<div class="profecient-checkout empty-cart">'
				. esc_html__( 'Please add item to cart to edit this element', 'profecient-essential' ) .
				'</div>',
				wp_kses_allowed_html()
			);
		}
	}

	/**
	 * WooCommerce Terms and Conditions Checkbox Text.
	 *
	 * WooCommerce filter is used to apply widget settings to Checkout Terms & Conditions text and link text.
	 *
	 * @param string $text
	 * @return string
	 */
	public function woocommerce_terms_and_conditions_checkbox_text( $text ) {
		$instance = $this->get_settings_for_display();

		if ( ! isset( $instance['terms_conditions_message_text'] ) || ! isset( $instance['terms_conditions_link_text'] ) ) {
			return $text;
		}

		$message = $instance['terms_conditions_message_text'];
		$link    = $instance['terms_conditions_link_text'];

		$terms_page_id = wc_terms_and_conditions_page_id();
		if ( $terms_page_id ) {
			$message .= ' <a href="' . esc_url( get_permalink( $terms_page_id ) ) . '" class="woocommerce-terms-and-conditions-link" target="_blank">' . $link . '</a>';
		}

		return $message;
	}

	/**
	 * WooCommerce Checkout Before Customer Details
	 *
	 * Callback function for the woocommerce_checkout_before_customer_details hook that outputs elements
	 *
	 * This eliminates the need for template overrides.
	 */
	public function woocommerce_checkout_before_customer_details() {
		?>
		<div class="profecient-checkout-container">
			<!--open container-->
			<div class="profecient-checkout-column-start">
				<!--open column-1-->
		<?php
	}

	/**
	 * WooCommerce After Before Customer Details
	 */
	public function woocommerce_checkout_after_customer_details() {
		?>
				<!--close column-1-->
			</div>
		<?php
	}

	/**
	 * WooCommerce checkout before order review heading 1
	 *
	 * Add custom class wrapper
	 */
	public function woocommerce_checkout_before_order_review_heading_1() {
		?>
			<div class="profecient-checkout-column-end">
				<!--open column-2-->
					<div class="profecient-sticky-right-column">
						<!--open column-inner-->
		<?php
	}

	/**
	 * WooCommerce checkoutt before oreder review heading 2
	 *
	 * Add custom class wrapper
	 */
	public function woocommerce_checkout_before_order_review_heading_2() {
		?>
			<div class="profecient-checkout-order-review">
				<!--open order_review-->
		<?php
	}

	/**
	 * WooCommerce checkout order review
	 */
	public function woocommerce_checkout_order_review() {
		?>
					<!--close wc_order_review-->
				</div>
				<!--close order_review-->
			</div>
		<?php
		if ( $this->should_render_coupon() ) {
			$this->render_woocommerce_checkout_coupon_form();
		}
		?>
			<div class="profecient-checkout-order-review-2">
			<!--reopen wc_order_review-2-->
		<?php
	}

	/**
	 * Render woocommerce checkout coupon form
	 */
	private function render_woocommerce_checkout_coupon_form() {
		?>
		<div class="woocommerce-form-coupon-toggle">
			<p class="profecient-woocommerce-coupon-nudge profecient-checkout-secondary-title"><?php esc_html_e( 'Have a coupon?', 'profecient-essential' ); ?> <a href="#" class="profecient-show-coupon-form showcoupon"><?php esc_html_e( 'Click here to enter your coupon code', 'profecient-essential' ); ?></a></p>
			<div class="profecient-coupon-anchor" style="display:none">
				<label class="profecient-coupon-anchor-description"><?php esc_html_e( 'If you have a coupon code, please apply it below.', 'profecient-essential' ); ?></label>
				<div class="form-row">
					<div class="coupon-container-grid">
						<div class="col coupon-col-1 ">
							<input type="text" name="coupon_code" class="input-text" placeholder="<?php esc_attr_e( 'Coupon code', 'profecient-essential' ); ?>" id="coupon_code" value="" />
						</div>
						<div class="col coupon-col-2">
							<button class="woocommerce-button button profecient-apply-coupon" name="apply_coupon" type="submit"><?php esc_html_e( 'Apply', 'profecient-essential' ); ?></button>
						</div>
					</div>
				</div>
				<div class="clear"></div>
			</div>
		</div>
		<?php
	}

	/**
	 * Should Render Coupon
	 */
	private function should_render_coupon() {
		return WC()->cart->needs_payment() || wc_coupons_enabled();
	}

	/**
	 * Woocommerce Checkout After Order Review
	 *
	 * Output containing elements. Callback function for the woocommerce_checkout_after_order_review hook.
	 *
	 * This eliminates the need for template overrides.
	 */
	public function woocommerce_checkout_after_order_review() {
		?>
						<!--close wc_order_review-2-->
						<!--close column-inner-->
					</div>
					<!--close column-2-->
				</div>
				<!--close container-->
			</div>
		<?php
	}

	/**
	 * Build block content
	 */
	public function build_content() {
		return $this->build_content_separately( 'profecient-woocommerce-checkout-page' );
	}
}
