<?php
/**
 * Woocommerce Menu Cart View Class
 *
 * @package profecient-essential
 * @author jegtheme
 * @since 1.0.0
 */

namespace Profecient\Essential\JKit\Elements\Views;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

use Jeg\Elementor_Kit\Elements\Views\View_WooCommerce_Abstract;

/**
 * Class Woocommerce_Menu_Cart_View
 */
class Woocommerce_Menu_Cart_View extends View_WooCommerce_Abstract {
	/**
	 * Build block content
	 */
	public function build_content() {
		$this->setup_hook();
		wc_load_cart();
		$content = '<div class="profecient-menu-cart ' . $this->unique_id . '">' . $this->render_template() . '</div>';
		$this->remove_hook();

		return $content;
	}

	/**
	 * Setup Hook
	 */
	public function setup_hook() {
		remove_all_filters( 'woocommerce_add_to_cart_fragments' );
		remove_all_filters( 'woocommerce_locate_template' );

		add_filter( 'woocommerce_mini_cart_item_class', array( $this, 'custom_mini_cart_item_class' ), 10, 3 );
		add_filter( 'woocommerce_cart_item_name', array( $this, 'custom_cart_item_name' ), 10, 3 );

		add_filter( 'woocommerce_add_to_cart_fragments', array( $this, 'custom_refreshed_fragments' ) );
	}

	/**
	 * Remove Hook
	 */
	public function remove_hook() {
		remove_filter( 'woocommerce_mini_cart_item_class', array( $this, 'custom_mini_cart_item_class' ), 10, 3 );
		remove_filter( 'woocommerce_cart_item_name', array( $this, 'custom_cart_item_name' ), 10, 3 );

		remove_filter( 'woocommerce_add_to_cart_fragments', array( $this, 'custom_refreshed_fragments' ) );
	}

	/**
	 * WooCommerce Ajax Request
	 */
	public function wc_ajax_request() {
		$this->setup_hook();
	}

	/**
	 * Custom Refreshed Fragments
	 */
	public function custom_refreshed_fragments( $fragments ) {
		$fragments['.profecient-menu-cart .cart-button-wrapper .cart-button-toggle .cart-button-text .amount']     = WC()->cart->get_cart_subtotal();
		$fragments['.profecient-menu-cart .cart-button-wrapper .cart-button-toggle .cart-button-icon .total-item'] = '<span class="total-item">' . WC()->cart->get_cart_contents_count() . '</span>';
		$fragments['.profecient-menu-cart .cart-offcanvas .mini-cart-wrapper']                                     = $this->build_mini_cart();

		return $fragments;
	}

	/**
	 * Add Custom Mini Cart Item Class
	 */
	public function custom_mini_cart_item_class( $class, $cart_item, $cart_item_key ) {
		if ( isset( $cart_item['data'] ) && ! $cart_item['data']->is_visible() ) {
			$class .= ' hidden';
		}
		return $class;
	}

	/**
	 * Add Custom Cart Item Name
	 */
	public function custom_cart_item_name( $html, $cart_item, $cart_item_key ) {
		$html = sprintf( '<span class="product-tittle">%s</span>', $cart_item['data']->get_name() );

		return $html;
	}

	/**
	 * Render template
	 */
	public function render_template() {
		ob_start();
		$this->build_cart_button();

		$before = $this->build_offcanvas();

		echo wp_kses( $this->build_cart_button(), wp_kses_allowed_html() );
		echo wp_kses( $this->build_offcanvas(), wp_kses_allowed_html() );
		return ob_get_clean();
	}

	/**
	 * Render Cart Button
	 */
	public function build_cart_button() {
		ob_start();
		?>
		<div class="cart-button-wrapper">
			<a class="cart-button-toggle">
				<?php echo wp_kses( $this->build_cart_text(), wp_kses_allowed_html() ); ?>
				<?php echo wp_kses( $this->build_cart_icon(), wp_kses_allowed_html() ); ?>
			</a>
		</div>
		<?php
		return ob_get_clean();
	}

	/**
	 * Render Cart Icon
	 */
	public function build_cart_icon() {
		ob_start();
		if ( ! empty( $this->attribute['sg_button_toggle_icon']['value'] ) ) :
			?>
			<span class="cart-button-icon <?php echo esc_attr( $this->attribute['sg_button_toggle_total_item_type'] ); ?>">
				<?php echo wp_kses( $this->render_icon_element( $this->attribute['sg_button_toggle_icon'] ), wp_kses_allowed_html() ); ?>
				<?php if ( 'yes' === $this->attribute['sg_button_toggle_total_item_show'] ) : ?>
					<span class="total-item"><?php echo esc_html( WC()->cart->get_cart_contents_count() ); ?></span>
				<?php endif; ?>
			</span>
			<?php
		endif;
		return ob_get_clean();
	}

	/**
	 * Render Cart Button
	 */
	public function build_cart_text() {
		ob_start();
		if ( 'yes' === $this->attribute['sg_button_toggle_subtotal_show'] ) :
			?>
			<span class="cart-button-text"><?php echo wp_kses( WC()->cart->get_cart_subtotal(), wp_kses_allowed_html() ); ?></span>
			<?php
		endif;
		return ob_get_clean();
	}

	/**
	 * Render Cart Button
	 */
	public function build_offcanvas() {
		$offcanvas_position = isset( $this->attribute['sg_offcanvas_position'] ) ? 'position-' . $this->attribute['sg_offcanvas_position'] : 'position-right';
		$close_icon         = array(
			'value'   => 'fas fa-times',
			'library' => 'fa-solid',
		);
		ob_start();

		$before = $this->build_mini_cart();
		?>
		<div class="cart-offcanvas">
			<div class="bg-overlay <?php echo esc_attr( $offcanvas_position ); ?>"></div>
			<div class="sidebar <?php echo esc_attr( $offcanvas_position ); ?>">
				<div class="offcanvas-close-button-wrapper">
					<a href="#" class="offcanvas-close-button">
						<?php echo wp_kses( $this->render_icon_element( $close_icon ), wp_kses_allowed_html() ); ?>
					</a>
				</div>
				<?php echo wp_kses( $before, wp_kses_allowed_html() ); ?>
			</div>
		</div>
		<?php
		return ob_get_clean();
	}

	/**
	 * Render Mini Cart
	 */
	public function build_mini_cart() {
		ob_start();
		?>
		<div class="mini-cart-wrapper">
			<?php woocommerce_mini_cart(); ?>
		</div>
		<?php
		return ob_get_clean();
	}
}
