<?php
/**
 * Jeg Elementor Kit class
 *
 * @package profecient-essential
 * @author jegtheme
 * @since 1.0.0
 */

namespace Profecient\Essential\JKit\Extra_Option;

use Profecient\Essential\JKit\Extra_Option\Options\Abstract_Option;

/**
 * Class Extra_Option
 */
class Extra_Option {

	/**
	 * Data
	 */
	private $data;

	/**
	 * Class instance
	 *
	 * @var Extra_Option
	 */
	private static $instance;

	/**
	 * Return class instance
	 *
	 * @return Extra_Option
	 */
	public static function instance() {
		if ( null === static::$instance ) {
			static::$instance = new static();
		}

		return static::$instance;
	}

	/**
	 * Extra_Option constructor.
	 */
	private function __construct() {
		$this->setup_hook();
	}

	/**
	 * Setup Hooks
	 */
	public function setup_hook() {
		add_action( 'elementor/init', array( $this, 'register_options' ) );
	}

	/**
	 * Render options
	 */
	public function register_options() {
		$class = $this;
		foreach ( $this->populate_options() as $id => $element ) {
			/**
			 * @var Abstract_Option $instance
			 */
			$instance = $class->get_extra_option( $id );
			if ( $instance instanceof Abstract_Option ) {
				$instance->add_action();
			}
		}
	}

	/**
	 * Options Instance.
	 *
	 * @param string $id ID of element option.
	 *
	 * @return Abstract_Option
	 */
	public function get_extra_option( $id ) {
		$options = $this->populate_options();
		$option  = $options[ $id ];
		$class   = $option['option'];

		return new $class( $id );
	}

	/**
	 * Populate options
	 *
	 * @return array
	 */
	public function populate_options() {
		return apply_filters( 'profecient_register_custom_options', array() );
	}
}
