<?php
namespace Profecient\Essential\JKit\Extra_Option\Options\Background_Motion_Effects;

use Profecient\Essential\JKit\Extra_Option\Options\Abstract_Option;

/**
 * Class Module
 */
class Module extends Abstract_Option {
	public function add_action( $register = true ) {
		$this->register();
		parent::add_action( false );
		add_action( 'elementor/frontend/section/after_render', array( $this, 'after_section_render' ), 10, 1 );
		add_action( 'elementor/frontend/column/after_render', array( $this, 'after_column_render' ), 10, 1 );
		add_action( 'elementor/frontend/container/after_render', array( $this, 'after_container_render' ), 10, 1 );
	}

	/**
	 * Register
	 */
	public function register() {
		if ( is_array( $this->controls['location'] ) ) {
			foreach ( $this->controls['location'] as $location ) {
				add_action( $location, array( $this, 'register_control' ), 9, 2 );
			}
		} else {
			add_action( $this->controls['location'], array( $this, 'register_control' ), 9, 3 );
		}
	}

	/**
	 * Register control
	 *
	 * @param $element \Elementor\Widget_Common|\Elementor\Element_Column|\Elementor\Element_Section Elementor element.
	 * @param $args array Arguments.
	 *
	 * @return void
	 */
	public function register_control( $element, $args ) {
		$current_class = get_class( $element );
		if ( isset( $this->controls['show_location'] ) ) {
			$show_location = $this->controls['show_location'];
			$current_class = str_replace( 'Elementor\\', '', $current_class );
			if ( ! in_array( $current_class, $show_location, true ) ) {
				return;
			}
		}
		foreach ( $this->controls['segment'] as $id => $segment ) {
			$element->start_injection(
				array(
					'type' => 'control',
					'at'   => 'after',
					'of'   => 'background_slideshow_ken_burns_zoom_direction',
				)
			);
			$this->parse_control_option( $element, $this->controls['options'], $id );
			$element->end_injection();
		}
	}

	/**
	 * Set Options
	 */
	public function set_options() {
		$location      = array(
			'elementor/element/container/section_layout/after_section_end',
			'elementor/element/section/section_advanced/after_section_end',
			'elementor/element/column/section_advanced/after_section_end',
		);
		$show_location = array(
			'Includes\Elements\Container',
			'Element_Section',
			'Element_Column',
		);
		$segment       = array(
			$this->get_option_name( 'segment' ) => array(
				'name'     => '<i class="profecient-option-additional"></i> ' . esc_html__( 'Background Motion Effects', 'profecient-essential' ),
				'priority' => 10,
			),
		);
		$options       = array(
			$this->get_option_name( 'toggle' )            => array(
				'title'              => esc_html__( 'Profecient Background Motion Effects', 'profecient-essential' ),
				'type'               => 'checkbox',
				'segment'            => $this->get_option_name( 'segment' ),
				'separator'          => 'before',
				'return_value'       => 'yes',
				'frontend_available' => true,
				'prefix_class'       => 'profecient-mouse-effects-',
			),
			$this->get_option_name( 'background_width' )  => array(
				'title'              => esc_html__( 'Background Width!', 'profecient-essential' ),
				'type'               => 'slider',
				'segment'            => $this->get_option_name( 'segment' ),
				'frontend_available' => true,
				'responsive'         => true,
				'default'            => 200,
				'options'            => array(
					'min'  => 100,
					'max'  => 200,
					'step' => 1,
				),
				'selectors'          => array(
					'custom' => array(
						'.elementor-element-{{ID}}.elementor-motion-effects-element-type-background > .profecient-background-motion-effect-container > .profecient-background-motion-effect-layer, .elementor-element-{{ID}} > .elementor-motion-effects-element-type-background > .profecient-background-motion-effect-container > .profecient-background-motion-effect-layer' => '--profecient-background-motion-effects-width: {{SIZE}}%',
					),
				),
				'dependency'         => array(
					array(
						'field'    => $this->get_option_name( 'toggle' ),
						'operator' => '==',
						'value'    => 'yes',
					),
				),
				'render_type'        => 'ui',
			),
			$this->get_option_name( 'background_height' ) => array(
				'title'              => esc_html__( 'Background Height', 'profecient-essential' ),
				'type'               => 'slider',
				'segment'            => $this->get_option_name( 'segment' ),
				'frontend_available' => true,
				'responsive'         => true,
				'default'            => 200,
				'options'            => array(
					'min'  => 100,
					'max'  => 200,
					'step' => 1,
				),
				'selectors'          => array(
					'custom' => array(
						'.elementor-element-{{ID}}.elementor-motion-effects-element-type-background > .profecient-background-motion-effect-container > .profecient-background-motion-effect-layer, .elementor-element-{{ID}} > .elementor-motion-effects-element-type-background > .profecient-background-motion-effect-container > .profecient-background-motion-effect-layer' => '--profecient-background-motion-effects-height: {{SIZE}}%',
					),
				),
				'dependency'         => array(
					array(
						'field'    => $this->get_option_name( 'toggle' ),
						'operator' => '==',
						'value'    => 'yes',
					),
				),
				'render_type'        => 'ui',
			),
			$this->get_option_name( 'position_left' )     => array(
				'title'              => esc_html__( 'Left', 'profecient-essential' ),
				'type'               => 'slider',
				'segment'            => $this->get_option_name( 'segment' ),
				'frontend_available' => true,
				'responsive'         => true,
				'default'            => -50,
				'options'            => array(
					'min'  => -100,
					'max'  => 100,
					'step' => 1,
				),
				'selectors'          => array(
					'custom' => array(
						'.elementor-element-{{ID}}.elementor-motion-effects-element-type-background > .profecient-background-motion-effect-container > .profecient-background-motion-effect-layer, .elementor-element-{{ID}} > .elementor-motion-effects-element-type-background > .profecient-background-motion-effect-container > .profecient-background-motion-effect-layer' => '--profecient-background-motion-effects-left: {{SIZE}}%',
					),
				),
				'dependency'         => array(
					array(
						'field'    => $this->get_option_name( 'toggle' ),
						'operator' => '==',
						'value'    => 'yes',
					),
				),
				'render_type'        => 'ui',
			),
			$this->get_option_name( 'position_top' )      => array(
				'title'              => esc_html__( 'Top', 'profecient-essential' ),
				'type'               => 'slider',
				'segment'            => $this->get_option_name( 'segment' ),
				'frontend_available' => true,
				'responsive'         => true,
				'default'            => -50,
				'options'            => array(
					'min'  => -100,
					'max'  => 100,
					'step' => 1,
				),
				'selectors'          => array(
					'custom' => array(
						'.elementor-element-{{ID}}.elementor-motion-effects-element-type-background > .profecient-background-motion-effect-container > .profecient-background-motion-effect-layer, .elementor-element-{{ID}} > .elementor-motion-effects-element-type-background > .profecient-background-motion-effect-container > .profecient-background-motion-effect-layer' => '--profecient-background-motion-effects-top: {{SIZE}}%',
					),
				),
				'dependency'         => array(
					array(
						'field'    => $this->get_option_name( 'toggle' ),
						'operator' => '==',
						'value'    => 'yes',
					),
				),
				'render_type'        => 'ui',
			),
		);

		/**
		 * Filters the location of the option.
		 *
		 * @param array $location Location of the option. Default is array( 'elementor/element/wp-page/document_settings/after_section_end' ).
		 * @param string $id ID of the option. Default is $this->id.
		 */
		$this->controls['location'] = apply_filters( $this->get_option_name( 'control_location' ), $location, $this->id );

		/**
		 * Filters the show location of the option.
		 *
		 * @param array $show_location Show location of the option. Default is array( 'Core\DocumentTypes\Page' ).
		 * @param string $id ID of the option. Default is $this->id.
		 */
		$this->controls['show_location'] = apply_filters( $this->get_option_name( 'control_show_location' ), $show_location, $this->id );

		/**
		 * Filters the segment of the option.
		 *
		 * @param array $segment Segment of the option. Default is array( $this->get_option_name( 'segment' ) => array( 'name' => '<i class="profecient-option-additional"></i> ' . esc_html__( 'Sample Option', 'profecient-essential' ), 'priority' => 10 ) ).
		 * @param string $id ID of the option. Default is $this->id.
		 */
		$this->controls['segment'] = apply_filters( $this->get_option_name( 'control_segment' ), $segment, $this->id );

		/**
		 * Filters the options of the option.
		 *
		 * @param array $options Options of the option. Default is array( $this->get_option_name( 'toggle' ) => array( 'title' => esc_html__( 'Enable Sample Option', 'profecient-essential' ), 'type' => 'checkbox', 'default' => false, 'segment' => $this->get_option_name( 'segment' ), 'return_value' => 'yes', 'prefix_class' => 'profecient-sample-option-' ) ).
		 * @param string $id ID of the option. Default is $this->id.
		 */
		$this->controls['options'] = apply_filters( $this->get_option_name( 'control_options' ), $options, $this->id );
	}

	/**
	 * Register styles
	 */
	public function register_styles() {
		wp_register_style( 'profecient-background-motion-effect', PROFECIENT_ESSENTIAL_URL . '/assets/css/extra/background-motion-effect.css', array(), PROFECIENT_ESSENTIAL_VERSION, 'all' );
	}

	/**
	 * Enqueue styles
	 */
	public function enqueue_styles() {
		wp_enqueue_style( 'profecient-background-motion-effect' );
	}

	/**
	 * Enqueue global styles
	 */
	public function enqueue_global_styles() {
	}

	/**
	 * Should style enqueue
	 */
	public function should_style_enqueue() {
	}

	/**
	 * Register scripts
	 */
	public function register_scripts() {
	}

	/**
	 * Enqueue scripts
	 */
	public function enqueue_scripts() {
	}

	/**
	 * Enqueue global scripts
	 */
	public function enqueue_global_scripts() {
	}

	/**
	 * Should script enqueue
	 */
	public function should_script_enqueue() {
	}

	/**
	 * After common render.
	 *
	 * @param $element \Elementor\Element_Base Element.
	 */
	public function after_common_render( $element ) {
		$this->after_render( $element );
	}

	/**
	 * After section render.
	 *
	 * @param $element \Elementor\Element_Base Element.
	 */
	public function after_section_render( $element ) {
		$this->after_render( $element );
	}

	/**
	 * After column render.
	 *
	 * @param $element \Elementor\Element_Base Element.
	 */
	public function after_column_render( $element ) {
		$this->after_render( $element );
	}

	/**
	 * After container render.
	 *
	 * @param $element \Elementor\Element_Base Element.
	 */
	public function after_container_render( $element ) {
		$this->after_render( $element );
	}

	/**
	 * After render.
	 *
	 * @param $element \Elementor\Element_Base Element.
	 */
	public function after_render( $element ) {
	}
}
