<?php
namespace Profecient\Essential\JKit\Extra_Option\Options\Background_Parallax;

use Profecient\Essential\JKit\Extra_Option\Options\Abstract_Option;

/**
 * Class Module
 */
class Module extends Abstract_Option {
	public function add_action( $register = true ) {
		$this->register();
		parent::add_action( false );
		add_action( 'elementor/frontend/section/after_render', array( $this, 'after_section_render' ), 10, 1 );
		add_action( 'elementor/frontend/column/after_render', array( $this, 'after_column_render' ), 10, 1 );
		add_action( 'elementor/frontend/container/after_render', array( $this, 'after_container_render' ), 10, 1 );
	}

	/**
	 * Register control
	 *
	 * @param $element \Elementor\Widget_Common|\Elementor\Element_Column|\Elementor\Element_Section Elementor element.
	 * @param $args array Arguments.
	 *
	 * @return void
	 */
	public function register_control( $element, $args ) {
		$current_class = get_class( $element );
		if ( isset( $this->controls['show_location'] ) ) {
			$show_location = $this->controls['show_location'];
			$current_class = str_replace( 'Elementor\\', '', $current_class );
			if ( ! in_array( $current_class, $show_location, true ) ) {
				return;
			}
		}
		foreach ( $this->controls['segment'] as $id => $segment ) {
			$element->start_injection(
				array(
					'type' => 'control',
					'at'   => 'after',
					'of'   => 'profecient_background_motion_effects_position_top_responsive_mobile',
				)
			);
			$this->parse_control_option( $element, $this->controls['options'], $id );
			$element->end_injection();
		}
	}

	/**
	 * Set Options
	 */
	public function set_options() {
		$location      = array(
			'elementor/element/container/section_layout/after_section_end',
			'elementor/element/section/section_advanced/after_section_end',
			'elementor/element/column/section_advanced/after_section_end',
		);
		$show_location = array(
			'Includes\Elements\Container',
			'Element_Section',
			'Element_Column',
		);
		$segment       = array(
			$this->get_option_name( 'segment' ) => array(
				'name'     => '<i class="profecient-option-additional"></i> ' . esc_html__( 'Parallax/Scrolling Effects', 'profecient-essential' ),
				'priority' => 10,
			),
		);
		$options       = array(
			$this->get_option_name( 'toggle' )             => array(
				'title'              => esc_html__( 'Enable Parallax/Scrolling Effects', 'profecient-essential' ),
				'description'        => esc_html__( 'Set parallax or scrolling background effects by enable this option.', 'profecient-essential' ),
				'type'               => 'checkbox',
				'segment'            => $this->get_option_name( 'segment' ),
				'separator'          => 'before',
				'return_value'       => 'yes',
				'frontend_available' => true,
				'prefix_class'       => 'profecient-parallax-',
				'dependency'         => array(
					array(
						'field'    => 'profecient_background_motion_effects_toggle',
						'operator' => '==',
						'value'    => 'yes',
					),
				),
				'selectors'          => array(
					'custom' => array(
						'{{WRAPPER}}.profecient-parallax-yes:not(.elementor-column), .elementor{{WRAPPER}}.elementor-section.profecient-parallax-yes:not(.elementor-column), .elementor{{WRAPPER}}.elementor-column.profecient-parallax-yes .elementor-widget-wrap' => 'overflow: hidden;',
					),
				),
			),
			// Horizontal Parallax(X)
			$this->get_option_name( 'x_popover_start' )    => array(
				'title'              => esc_html__( 'Horizontal Parallax(X)', 'profecient-essential' ),
				'type'               => 'control_popover_start',
				'segment'            => $this->get_option_name( 'segment' ),
				'return_value'       => 'yes',
				'frontend_available' => true,
				'dependency'         => array(
					array(
						'field'    => 'profecient_background_motion_effects_toggle',
						'operator' => '==',
						'value'    => 'yes',
					),
					array(
						'field'    => $this->get_option_name( 'toggle' ),
						'operator' => '==',
						'value'    => 'yes',
					),
				),
				'render_type'        => 'ui',
			),
			$this->get_option_name( 'x_start' )            => array(
				'title'              => esc_html__( 'Start', 'profecient-essential' ),
				'type'               => 'slider',
				'segment'            => $this->get_option_name( 'segment' ),
				'default'            => 0,
				'frontend_available' => true,
				'responsive'         => true,
				'options'            => array(
					'min'  => -1000,
					'max'  => 1000,
					'step' => 1,
				),
				'dependency'         => array(
					array(
						'field'    => 'profecient_background_motion_effects_toggle',
						'operator' => '==',
						'value'    => 'yes',
					),
					array(
						'field'    => $this->get_option_name( 'x_popover_start' ),
						'operator' => '==',
						'value'    => 'yes',
					),
				),
				'render_type'        => 'ui',
			),
			$this->get_option_name( 'x_end' )              => array(
				'title'              => esc_html__( 'End', 'profecient-essential' ),
				'type'               => 'slider',
				'segment'            => $this->get_option_name( 'segment' ),
				'default'            => 0,
				'frontend_available' => true,
				'responsive'         => true,
				'options'            => array(
					'min'  => -1000,
					'max'  => 1000,
					'step' => 1,
				),
				'dependency'         => array(
					array(
						'field'    => 'profecient_background_motion_effects_toggle',
						'operator' => '==',
						'value'    => 'yes',
					),
					array(
						'field'    => $this->get_option_name( 'x_popover_start' ),
						'operator' => '==',
						'value'    => 'yes',
					),
				),
				'render_type'        => 'ui',
			),
			$this->get_option_name( 'x_css_unit' )         => array(
				'title'              => esc_html__( 'CSS Unit', 'profecient-essential' ),
				'description'        => esc_html__( 'Enter a CSS Unit for Start and End positions.', 'profecient-essential' ),
				'type'               => 'text',
				'segment'            => $this->get_option_name( 'segment' ),
				'default'            => 'px',
				'frontend_available' => true,
				'dependency'         => array(
					array(
						'field'    => 'profecient_background_motion_effects_toggle',
						'operator' => '==',
						'value'    => 'yes',
					),
					array(
						'field'    => $this->get_option_name( 'x_popover_start' ),
						'operator' => '==',
						'value'    => 'yes',
					),
				),
				'render_type'        => 'ui',
			),
			$this->get_option_name( 'x_animation_viewport' ) => array(
				'title'              => esc_html__( 'Viewport', 'profecient-essential' ),
				'type'               => 'slider',
				'segment'            => $this->get_option_name( 'segment' ),
				'default_unit'       => '%',
				'default_sizes'      => array(
					'start' => 0,
					'end'   => 100,
				),
				'labels'             => array(
					__( 'Bottom', 'profecient-essential' ),
					__( 'Top', 'profecient-essential' ),
				),
				'scales'             => 1,
				'handles'            => 'range',
				'frontend_available' => true,
				'options'            => array(
					'min'  => 0,
					'max'  => 100,
					'step' => 1,
				),
				'dependency'         => array(
					array(
						'field'    => 'profecient_background_motion_effects_toggle',
						'operator' => '==',
						'value'    => 'yes',
					),
					array(
						'field'    => $this->get_option_name( 'toggle' ),
						'operator' => '==',
						'value'    => 'yes',
					),
				),
				'render_type'        => 'ui',
			),
			$this->get_option_name( 'x_popover_end' )      => array(
				'segment' => $this->get_option_name( 'segment' ),
				'type'    => 'control_popover_end',
			),
			// Horizontal Parallax(Y)
			$this->get_option_name( 'y_popover_start' )    => array(
				'title'              => esc_html__( 'Vertical Parallax(Y)', 'profecient-essential' ),
				'type'               => 'control_popover_start',
				'segment'            => $this->get_option_name( 'segment' ),
				'return_value'       => 'yes',
				'frontend_available' => true,
				'dependency'         => array(
					array(
						'field'    => 'profecient_background_motion_effects_toggle',
						'operator' => '==',
						'value'    => 'yes',
					),
					array(
						'field'    => $this->get_option_name( 'toggle' ),
						'operator' => '==',
						'value'    => 'yes',
					),
				),
				'render_type'        => 'ui',
			),
			$this->get_option_name( 'y_start' )            => array(
				'title'              => esc_html__( 'Start', 'profecient-essential' ),
				'type'               => 'slider',
				'segment'            => $this->get_option_name( 'segment' ),
				'default'            => 0,
				'frontend_available' => true,
				'responsive'         => true,
				'options'            => array(
					'min'  => -1000,
					'max'  => 1000,
					'step' => 1,
				),
				'dependency'         => array(
					array(
						'field'    => 'profecient_background_motion_effects_toggle',
						'operator' => '==',
						'value'    => 'yes',
					),
					array(
						'field'    => $this->get_option_name( 'y_popover_start' ),
						'operator' => '==',
						'value'    => 'yes',
					),
				),
				'render_type'        => 'ui',
			),
			$this->get_option_name( 'y_end' )              => array(
				'title'              => esc_html__( 'End', 'profecient-essential' ),
				'type'               => 'slider',
				'segment'            => $this->get_option_name( 'segment' ),
				'default'            => 0,
				'frontend_available' => true,
				'responsive'         => true,
				'options'            => array(
					'min'  => -1000,
					'max'  => 1000,
					'step' => 1,
				),
				'dependency'         => array(
					array(
						'field'    => 'profecient_background_motion_effects_toggle',
						'operator' => '==',
						'value'    => 'yes',
					),
					array(
						'field'    => $this->get_option_name( 'y_popover_start' ),
						'operator' => '==',
						'value'    => 'yes',
					),
				),
				'render_type'        => 'ui',
			),
			$this->get_option_name( 'y_css_unit' )         => array(
				'title'              => esc_html__( 'CSS Unit', 'profecient-essential' ),
				'description'        => esc_html__( 'Enter a CSS Unit for Start and End positions.', 'profecient-essential' ),
				'type'               => 'text',
				'segment'            => $this->get_option_name( 'segment' ),
				'default'            => 'px',
				'frontend_available' => true,
				'dependency'         => array(
					array(
						'field'    => 'profecient_background_motion_effects_toggle',
						'operator' => '==',
						'value'    => 'yes',
					),
					array(
						'field'    => $this->get_option_name( 'y_popover_start' ),
						'operator' => '==',
						'value'    => 'yes',
					),
				),
				'render_type'        => 'ui',
			),
			$this->get_option_name( 'y_animation_viewport' ) => array(
				'title'              => esc_html__( 'Viewport', 'profecient-essential' ),
				'type'               => 'slider',
				'segment'            => $this->get_option_name( 'segment' ),
				'default_unit'       => '%',
				'default_sizes'      => array(
					'start' => 0,
					'end'   => 100,
				),
				'labels'             => array(
					__( 'Bottom', 'profecient-essential' ),
					__( 'Top', 'profecient-essential' ),
				),
				'scales'             => 1,
				'handles'            => 'range',
				'frontend_available' => true,
				'options'            => array(
					'min'  => 0,
					'max'  => 100,
					'step' => 1,
				),
				'dependency'         => array(
					array(
						'field'    => 'profecient_background_motion_effects_toggle',
						'operator' => '==',
						'value'    => 'yes',
					),
					array(
						'field'    => $this->get_option_name( 'y_popover_start' ),
						'operator' => '==',
						'value'    => 'yes',
					),
				),
				'render_type'        => 'ui',
			),
			$this->get_option_name( 'y_popover_end' )      => array(
				'segment' => $this->get_option_name( 'segment' ),
				'type'    => 'control_popover_end',
			),
			// Opacity
			$this->get_option_name( 'opacity_popover_start' ) => array(
				'title'              => esc_html__( 'Opacity', 'profecient-essential' ),
				'type'               => 'control_popover_start',
				'segment'            => $this->get_option_name( 'segment' ),
				'return_value'       => 'yes',
				'frontend_available' => true,
				'dependency'         => array(
					array(
						'field'    => 'profecient_background_motion_effects_toggle',
						'operator' => '==',
						'value'    => 'yes',
					),
					array(
						'field'    => $this->get_option_name( 'toggle' ),
						'operator' => '==',
						'value'    => 'yes',
					),
				),
				'render_type'        => 'ui',
			),
			$this->get_option_name( 'opacity_start' )      => array(
				'title'              => esc_html__( 'Start', 'profecient-essential' ),
				'type'               => 'slider',
				'segment'            => $this->get_option_name( 'segment' ),
				'default'            => 0,
				'frontend_available' => true,
				'responsive'         => true,
				'options'            => array(
					'min'  => 0,
					'max'  => 1,
					'step' => 0.1,
				),
				'dependency'         => array(
					array(
						'field'    => 'profecient_background_motion_effects_toggle',
						'operator' => '==',
						'value'    => 'yes',
					),
					array(
						'field'    => $this->get_option_name( 'opacity_popover_start' ),
						'operator' => '==',
						'value'    => 'yes',
					),
				),
				'render_type'        => 'ui',
			),
			$this->get_option_name( 'opacity_end' )        => array(
				'title'              => esc_html__( 'End', 'profecient-essential' ),
				'type'               => 'slider',
				'segment'            => $this->get_option_name( 'segment' ),
				'default'            => 1,
				'frontend_available' => true,
				'responsive'         => true,
				'options'            => array(
					'min'  => 0,
					'max'  => 1,
					'step' => 0.1,
				),
				'dependency'         => array(
					array(
						'field'    => 'profecient_background_motion_effects_toggle',
						'operator' => '==',
						'value'    => 'yes',
					),
					array(
						'field'    => $this->get_option_name( 'opacity_popover_start' ),
						'operator' => '==',
						'value'    => 'yes',
					),
				),
				'render_type'        => 'ui',
			),
			$this->get_option_name( 'opacity_animation_viewport' ) => array(
				'title'              => esc_html__( 'Viewport', 'profecient-essential' ),
				'type'               => 'slider',
				'segment'            => $this->get_option_name( 'segment' ),
				'default_unit'       => '%',
				'default_sizes'      => array(
					'start' => 0,
					'end'   => 100,
				),
				'labels'             => array(
					__( 'Bottom', 'profecient-essential' ),
					__( 'Top', 'profecient-essential' ),
				),
				'scales'             => 1,
				'handles'            => 'range',
				'frontend_available' => true,
				'options'            => array(
					'min'  => 0,
					'max'  => 100,
					'step' => 1,
				),
				'dependency'         => array(
					array(
						'field'    => 'profecient_background_motion_effects_toggle',
						'operator' => '==',
						'value'    => 'yes',
					),
					array(
						'field'    => $this->get_option_name( 'opacity_popover_start' ),
						'operator' => '==',
						'value'    => 'yes',
					),
				),
				'render_type'        => 'ui',
			),
			$this->get_option_name( 'opacity_popover_end' ) => array(
				'segment' => $this->get_option_name( 'segment' ),
				'type'    => 'control_popover_end',
			),
			// Blur
			$this->get_option_name( 'blur_popover_start' ) => array(
				'title'              => esc_html__( 'Blur', 'profecient-essential' ),
				'type'               => 'control_popover_start',
				'segment'            => $this->get_option_name( 'segment' ),
				'return_value'       => 'yes',
				'frontend_available' => true,
				'dependency'         => array(
					array(
						'field'    => 'profecient_background_motion_effects_toggle',
						'operator' => '==',
						'value'    => 'yes',
					),
					array(
						'field'    => $this->get_option_name( 'toggle' ),
						'operator' => '==',
						'value'    => 'yes',
					),
				),
				'render_type'        => 'ui',
			),
			$this->get_option_name( 'blur_start' )         => array(
				'title'              => esc_html__( 'Start', 'profecient-essential' ),
				'type'               => 'slider',
				'segment'            => $this->get_option_name( 'segment' ),
				'default_unit'       => 'px',
				'default'            => 0,
				'frontend_available' => true,
				'responsive'         => true,
				'options'            => array(
					'min'  => 0,
					'max'  => 100,
					'step' => 1,
				),
				'dependency'         => array(
					array(
						'field'    => 'profecient_background_motion_effects_toggle',
						'operator' => '==',
						'value'    => 'yes',
					),
					array(
						'field'    => $this->get_option_name( 'blur_popover_start' ),
						'operator' => '==',
						'value'    => 'yes',
					),
				),
				'render_type'        => 'ui',
			),
			$this->get_option_name( 'blur_end' )           => array(
				'title'              => esc_html__( 'End', 'profecient-essential' ),
				'type'               => 'slider',
				'segment'            => $this->get_option_name( 'segment' ),
				'default_unit'       => 'px',
				'default'            => 0,
				'frontend_available' => true,
				'responsive'         => true,
				'options'            => array(
					'min'  => 0,
					'max'  => 100,
					'step' => 1,
				),
				'dependency'         => array(
					array(
						'field'    => 'profecient_background_motion_effects_toggle',
						'operator' => '==',
						'value'    => 'yes',
					),
					array(
						'field'    => $this->get_option_name( 'blur_popover_start' ),
						'operator' => '==',
						'value'    => 'yes',
					),
				),
				'render_type'        => 'ui',
			),
			$this->get_option_name( 'blur_css_unit' )      => array(
				'title'              => esc_html__( 'CSS Unit', 'profecient-essential' ),
				'description'        => esc_html__( 'Enter a CSS Unit for Start and End positions.', 'profecient-essential' ),
				'type'               => 'text',
				'segment'            => $this->get_option_name( 'segment' ),
				'default'            => 'px',
				'frontend_available' => true,
				'dependency'         => array(
					array(
						'field'    => 'profecient_background_motion_effects_toggle',
						'operator' => '==',
						'value'    => 'yes',
					),
					array(
						'field'    => $this->get_option_name( 'blur_popover_start' ),
						'operator' => '==',
						'value'    => 'yes',
					),
				),
				'render_type'        => 'ui',
			),
			$this->get_option_name( 'blur_animation_viewport' ) => array(
				'title'              => esc_html__( 'Viewport', 'profecient-essential' ),
				'type'               => 'slider',
				'segment'            => $this->get_option_name( 'segment' ),
				'default_unit'       => '%',
				'default_sizes'      => array(
					'start' => 0,
					'end'   => 100,
				),
				'labels'             => array(
					__( 'Bottom', 'profecient-essential' ),
					__( 'Top', 'profecient-essential' ),
				),
				'scales'             => 1,
				'handles'            => 'range',
				'frontend_available' => true,
				'options'            => array(
					'min'  => 0,
					'max'  => 100,
					'step' => 1,
				),
				'dependency'         => array(
					array(
						'field'    => 'profecient_background_motion_effects_toggle',
						'operator' => '==',
						'value'    => 'yes',
					),
					array(
						'field'    => $this->get_option_name( 'blur_popover_start' ),
						'operator' => '==',
						'value'    => 'yes',
					),
				),
				'render_type'        => 'ui',
			),
			$this->get_option_name( 'blur_popover_end' )   => array(
				'segment' => $this->get_option_name( 'segment' ),
				'type'    => 'control_popover_end',
			),
			// Scale
			$this->get_option_name( 'scale_popover_start' ) => array(
				'title'              => esc_html__( 'Scale', 'profecient-essential' ),
				'type'               => 'control_popover_start',
				'segment'            => $this->get_option_name( 'segment' ),
				'return_value'       => 'yes',
				'frontend_available' => true,
				'dependency'         => array(
					array(
						'field'    => 'profecient_background_motion_effects_toggle',
						'operator' => '==',
						'value'    => 'yes',
					),
					array(
						'field'    => $this->get_option_name( 'toggle' ),
						'operator' => '==',
						'value'    => 'yes',
					),
				),
				'render_type'        => 'ui',
			),
			$this->get_option_name( 'scale_start' )        => array(
				'title'              => esc_html__( 'Start', 'profecient-essential' ),
				'type'               => 'slider',
				'segment'            => $this->get_option_name( 'segment' ),
				'default_unit'       => 'px',
				'default'            => 1,
				'frontend_available' => true,
				'responsive'         => true,
				'options'            => array(
					'min'  => -10,
					'max'  => 10,
					'step' => 0.1,
				),
				'dependency'         => array(
					array(
						'field'    => 'profecient_background_motion_effects_toggle',
						'operator' => '==',
						'value'    => 'yes',
					),
					array(
						'field'    => $this->get_option_name( 'scale_popover_start' ),
						'operator' => '==',
						'value'    => 'yes',
					),
				),
				'render_type'        => 'ui',
			),
			$this->get_option_name( 'scale_end' )          => array(
				'title'              => esc_html__( 'End', 'profecient-essential' ),
				'type'               => 'slider',
				'segment'            => $this->get_option_name( 'segment' ),
				'default'            => 1,
				'frontend_available' => true,
				'responsive'         => true,
				'options'            => array(
					'min'  => -10,
					'max'  => 10,
					'step' => 0.1,
				),
				'dependency'         => array(
					array(
						'field'    => 'profecient_background_motion_effects_toggle',
						'operator' => '==',
						'value'    => 'yes',
					),
					array(
						'field'    => $this->get_option_name( 'scale_popover_start' ),
						'operator' => '==',
						'value'    => 'yes',
					),
				),
				'render_type'        => 'ui',
			),
			$this->get_option_name( 'scale_animation_viewport' ) => array(
				'title'              => esc_html__( 'Viewport', 'profecient-essential' ),
				'type'               => 'slider',
				'segment'            => $this->get_option_name( 'segment' ),
				'default_unit'       => '%',
				'default_sizes'      => array(
					'start' => 0,
					'end'   => 100,
				),
				'labels'             => array(
					__( 'Bottom', 'profecient-essential' ),
					__( 'Top', 'profecient-essential' ),
				),
				'scales'             => 1,
				'handles'            => 'range',
				'frontend_available' => true,
				'options'            => array(
					'min'  => 0,
					'max'  => 100,
					'step' => 1,
				),
				'dependency'         => array(
					array(
						'field'    => 'profecient_background_motion_effects_toggle',
						'operator' => '==',
						'value'    => 'yes',
					),
					array(
						'field'    => $this->get_option_name( 'scale_popover_start' ),
						'operator' => '==',
						'value'    => 'yes',
					),
				),
				'render_type'        => 'ui',
			),
			$this->get_option_name( 'scale_popover_end' )  => array(
				'segment' => $this->get_option_name( 'segment' ),
				'type'    => 'control_popover_end',
			),
			// Hue
			$this->get_option_name( 'hue_popover_start' )  => array(
				'title'              => esc_html__( 'Hue', 'profecient-essential' ),
				'type'               => 'control_popover_start',
				'segment'            => $this->get_option_name( 'segment' ),
				'return_value'       => 'yes',
				'frontend_available' => true,
				'dependency'         => array(
					array(
						'field'    => 'profecient_background_motion_effects_toggle',
						'operator' => '==',
						'value'    => 'yes',
					),
					array(
						'field'    => $this->get_option_name( 'toggle' ),
						'operator' => '==',
						'value'    => 'yes',
					),
				),
				'render_type'        => 'ui',
			),
			$this->get_option_name( 'hue_start' )          => array(
				'title'              => esc_html__( 'Start', 'profecient-essential' ),
				'type'               => 'slider',
				'segment'            => $this->get_option_name( 'segment' ),
				'default_unit'       => 'deg',
				'default'            => 0,
				'frontend_available' => true,
				'responsive'         => true,
				'options'            => array(
					'min'  => -360,
					'max'  => 360,
					'step' => 1,
				),
				'dependency'         => array(
					array(
						'field'    => 'profecient_background_motion_effects_toggle',
						'operator' => '==',
						'value'    => 'yes',
					),
					array(
						'field'    => $this->get_option_name( 'hue_popover_start' ),
						'operator' => '==',
						'value'    => 'yes',
					),
				),
				'render_type'        => 'ui',
			),
			$this->get_option_name( 'hue_end' )            => array(
				'title'              => esc_html__( 'End', 'profecient-essential' ),
				'type'               => 'slider',
				'segment'            => $this->get_option_name( 'segment' ),
				'default_unit'       => 'deg',
				'default'            => 0,
				'frontend_available' => true,
				'responsive'         => true,
				'options'            => array(
					'min'  => -360,
					'max'  => 360,
					'step' => 1,
				),
				'dependency'         => array(
					array(
						'field'    => 'profecient_background_motion_effects_toggle',
						'operator' => '==',
						'value'    => 'yes',
					),
					array(
						'field'    => $this->get_option_name( 'hue_popover_start' ),
						'operator' => '==',
						'value'    => 'yes',
					),
				),
				'render_type'        => 'ui',
			),
			$this->get_option_name( 'hue_css_unit' )       => array(
				'title'              => esc_html__( 'CSS Unit', 'profecient-essential' ),
				'description'        => esc_html__( 'Enter a CSS Unit for Start and End. Ex: deg, grad, rad, turn.', 'profecient-essential' ),
				'type'               => 'text',
				'segment'            => $this->get_option_name( 'segment' ),
				'default'            => 'deg',
				'frontend_available' => true,
				'dependency'         => array(
					array(
						'field'    => 'profecient_background_motion_effects_toggle',
						'operator' => '==',
						'value'    => 'yes',
					),
					array(
						'field'    => $this->get_option_name( 'hue_popover_start' ),
						'operator' => '==',
						'value'    => 'yes',
					),
				),
				'render_type'        => 'ui',
			),
			$this->get_option_name( 'hue_animation_viewport' ) => array(
				'title'              => esc_html__( 'Viewport', 'profecient-essential' ),
				'type'               => 'slider',
				'segment'            => $this->get_option_name( 'segment' ),
				'default_unit'       => '%',
				'default_sizes'      => array(
					'start' => 0,
					'end'   => 100,
				),
				'labels'             => array(
					__( 'Bottom', 'profecient-essential' ),
					__( 'Top', 'profecient-essential' ),
				),
				'scales'             => 1,
				'handles'            => 'range',
				'frontend_available' => true,
				'options'            => array(
					'min'  => 0,
					'max'  => 100,
					'step' => 1,
				),
				'dependency'         => array(
					array(
						'field'    => 'profecient_background_motion_effects_toggle',
						'operator' => '==',
						'value'    => 'yes',
					),
					array(
						'field'    => $this->get_option_name( 'hue_popover_start' ),
						'operator' => '==',
						'value'    => 'yes',
					),
				),
				'render_type'        => 'ui',
			),
			$this->get_option_name( 'hue_popover_end' )    => array(
				'segment' => $this->get_option_name( 'segment' ),
				'type'    => 'control_popover_end',
			),
			// Sepia
			$this->get_option_name( 'sepia_popover_start' ) => array(
				'title'              => esc_html__( 'Sepia', 'profecient-essential' ),
				'type'               => 'control_popover_start',
				'segment'            => $this->get_option_name( 'segment' ),
				'return_value'       => 'yes',
				'frontend_available' => true,
				'dependency'         => array(
					array(
						'field'    => 'profecient_background_motion_effects_toggle',
						'operator' => '==',
						'value'    => 'yes',
					),
					array(
						'field'    => $this->get_option_name( 'toggle' ),
						'operator' => '==',
						'value'    => 'yes',
					),
				),
				'render_type'        => 'ui',
			),
			$this->get_option_name( 'sepia_start' )        => array(
				'title'              => esc_html__( 'Start', 'profecient-essential' ),
				'type'               => 'slider',
				'segment'            => $this->get_option_name( 'segment' ),
				'default'            => 0,
				'frontend_available' => true,
				'responsive'         => true,
				'options'            => array(
					'min'  => 0,
					'max'  => 1,
					'step' => 0.1,
				),
				'dependency'         => array(
					array(
						'field'    => 'profecient_background_motion_effects_toggle',
						'operator' => '==',
						'value'    => 'yes',
					),
					array(
						'field'    => $this->get_option_name( 'sepia_popover_start' ),
						'operator' => '==',
						'value'    => 'yes',
					),
				),
				'render_type'        => 'ui',
			),
			$this->get_option_name( 'sepia_end' )          => array(
				'title'              => esc_html__( 'End', 'profecient-essential' ),
				'type'               => 'slider',
				'segment'            => $this->get_option_name( 'segment' ),
				'default'            => 0,
				'frontend_available' => true,
				'responsive'         => true,
				'options'            => array(
					'min'  => 0,
					'max'  => 1,
					'step' => 0.1,
				),
				'dependency'         => array(
					array(
						'field'    => 'profecient_background_motion_effects_toggle',
						'operator' => '==',
						'value'    => 'yes',
					),
					array(
						'field'    => $this->get_option_name( 'sepia_popover_start' ),
						'operator' => '==',
						'value'    => 'yes',
					),
				),
				'render_type'        => 'ui',
			),
			$this->get_option_name( 'sepia_animation_viewport' ) => array(
				'title'              => esc_html__( 'Viewport', 'profecient-essential' ),
				'type'               => 'slider',
				'segment'            => $this->get_option_name( 'segment' ),
				'default_unit'       => '%',
				'default_sizes'      => array(
					'start' => 0,
					'end'   => 100,
				),
				'labels'             => array(
					__( 'Bottom', 'profecient-essential' ),
					__( 'Top', 'profecient-essential' ),
				),
				'scales'             => 1,
				'handles'            => 'range',
				'frontend_available' => true,
				'options'            => array(
					'min'  => 0,
					'max'  => 100,
					'step' => 1,
				),
				'dependency'         => array(
					array(
						'field'    => 'profecient_background_motion_effects_toggle',
						'operator' => '==',
						'value'    => 'yes',
					),
					array(
						'field'    => $this->get_option_name( 'sepia_popover_start' ),
						'operator' => '==',
						'value'    => 'yes',
					),
				),
				'render_type'        => 'ui',
			),
			$this->get_option_name( 'sepia_popover_end' )  => array(
				'segment' => $this->get_option_name( 'segment' ),
				'type'    => 'control_popover_end',
			),
			// Colors popover
			$this->get_option_name( 'background_color_popover_start' ) => array(
				'title'              => esc_html__( 'Background Color', 'profecient-essential' ),
				'type'               => 'control_popover_start',
				'segment'            => $this->get_option_name( 'segment' ),
				'return_value'       => 'yes',
				'frontend_available' => true,
				'dependency'         => array(
					array(
						'field'    => 'profecient_background_motion_effects_toggle',
						'operator' => '==',
						'value'    => 'yes',
					),
					array(
						'field'    => $this->get_option_name( 'toggle' ),
						'operator' => '==',
						'value'    => 'yes',
					),
				),
				'render_type'        => 'ui',
			),
			// Background Color Start
			$this->get_option_name( 'background_color_start' ) => array(
				'title'              => esc_html__( 'Background Color (Start)', 'profecient-essential' ),
				'description'        => esc_html__( 'Set background color start.', 'profecient-essential' ),
				'type'               => 'color',
				'segment'            => $this->get_option_name( 'segment' ),
				'default'            => '#000000',
				'frontend_available' => true,
				'dependency'         => array(
					array(
						'field'    => 'profecient_background_motion_effects_toggle',
						'operator' => '==',
						'value'    => 'yes',
					),
					array(
						'field'    => $this->get_option_name( 'toggle' ),
						'operator' => '==',
						'value'    => 'yes',
					),
				),
				'render_type'        => 'ui',
			),
			// Background Color End
			$this->get_option_name( 'background_color_end' ) => array(
				'title'              => esc_html__( 'Background Color (End)', 'profecient-essential' ),
				'description'        => esc_html__( 'Set background color end.', 'profecient-essential' ),
				'type'               => 'color',
				'segment'            => $this->get_option_name( 'segment' ),
				'default'            => '#000000',
				'frontend_available' => true,
				'dependency'         => array(
					array(
						'field'    => 'profecient_background_motion_effects_toggle',
						'operator' => '==',
						'value'    => 'yes',
					),
					array(
						'field'    => $this->get_option_name( 'toggle' ),
						'operator' => '==',
						'value'    => 'yes',
					),
				),
				'render_type'        => 'ui',
			),
			$this->get_option_name( 'background_color_animation_viewport' ) => array(
				'title'              => esc_html__( 'Viewport', 'profecient-essential' ),
				'type'               => 'slider',
				'segment'            => $this->get_option_name( 'segment' ),
				'default_unit'       => '%',
				'default_sizes'      => array(
					'start' => 0,
					'end'   => 100,
				),
				'labels'             => array(
					__( 'Bottom', 'profecient-essential' ),
					__( 'Top', 'profecient-essential' ),
				),
				'scales'             => 1,
				'handles'            => 'range',
				'frontend_available' => true,
				'options'            => array(
					'min'  => 0,
					'max'  => 100,
					'step' => 1,
				),
				'dependency'         => array(
					array(
						'field'    => 'profecient_background_motion_effects_toggle',
						'operator' => '==',
						'value'    => 'yes',
					),
				),
				'render_type'        => 'ui',
			),
			$this->get_option_name( 'background_color_popover_end' ) => array(
				'segment' => $this->get_option_name( 'segment' ),
				'type'    => 'control_popover_end',
			),
			// Colors popover
			$this->get_option_name( 'border_color_popover_start' ) => array(
				'title'              => esc_html__( 'Border Color', 'profecient-essential' ),
				'type'               => 'control_popover_start',
				'segment'            => $this->get_option_name( 'segment' ),
				'return_value'       => 'yes',
				'frontend_available' => true,
				'dependency'         => array(
					array(
						'field'    => 'profecient_background_motion_effects_toggle',
						'operator' => '==',
						'value'    => 'yes',
					),
					array(
						'field'    => $this->get_option_name( 'toggle' ),
						'operator' => '==',
						'value'    => 'yes',
					),
				),
				'render_type'        => 'ui',
			),
			// Border Color Start
			$this->get_option_name( 'border_color_start' ) => array(
				'title'              => esc_html__( 'Border Color (Start)', 'profecient-essential' ),
				'description'        => esc_html__( 'Set border color start.', 'profecient-essential' ),
				'type'               => 'color',
				'segment'            => $this->get_option_name( 'segment' ),
				'default'            => '#000000',
				'frontend_available' => true,
				'dependency'         => array(
					array(
						'field'    => 'profecient_background_motion_effects_toggle',
						'operator' => '==',
						'value'    => 'yes',
					),
					array(
						'field'    => $this->get_option_name( 'toggle' ),
						'operator' => '==',
						'value'    => 'yes',
					),
				),
				'render_type'        => 'ui',
			),
			// Border Color End
			$this->get_option_name( 'border_color_end' )   => array(
				'title'              => esc_html__( 'Border Color (End)', 'profecient-essential' ),
				'description'        => esc_html__( 'Set border color end.', 'profecient-essential' ),
				'type'               => 'color',
				'segment'            => $this->get_option_name( 'segment' ),
				'default'            => '#000000',
				'frontend_available' => true,
				'dependency'         => array(
					array(
						'field'    => 'profecient_background_motion_effects_toggle',
						'operator' => '==',
						'value'    => 'yes',
					),
					array(
						'field'    => $this->get_option_name( 'toggle' ),
						'operator' => '==',
						'value'    => 'yes',
					),
				),
				'render_type'        => 'ui',
			),
			$this->get_option_name( 'border_color_animation_viewport' ) => array(
				'title'              => esc_html__( 'Viewport', 'profecient-essential' ),
				'type'               => 'slider',
				'segment'            => $this->get_option_name( 'segment' ),
				'default_unit'       => '%',
				'default_sizes'      => array(
					'start' => 0,
					'end'   => 100,
				),
				'labels'             => array(
					__( 'Bottom', 'profecient-essential' ),
					__( 'Top', 'profecient-essential' ),
				),
				'scales'             => 1,
				'handles'            => 'range',
				'frontend_available' => true,
				'options'            => array(
					'min'  => 0,
					'max'  => 100,
					'step' => 1,
				),
				'dependency'         => array(
					array(
						'field'    => 'profecient_background_motion_effects_toggle',
						'operator' => '==',
						'value'    => 'yes',
					),
					array(
						'field'    => $this->get_option_name( 'border_color_popover_start' ),
						'operator' => '==',
						'value'    => 'yes',
					),
				),
				'render_type'        => 'ui',
			),
			$this->get_option_name( 'border_color_popover_end' ) => array(
				'segment' => $this->get_option_name( 'segment' ),
				'type'    => 'control_popover_end',
			),
			// Transition
			$this->get_option_name( 'transition_popover_start' ) => array(
				'title'              => esc_html__( 'Transition', 'profecient-essential' ),
				'type'               => 'control_popover_start',
				'segment'            => $this->get_option_name( 'segment' ),
				'return_value'       => 'yes',
				'frontend_available' => true,
				'dependency'         => array(
					array(
						'field'    => 'profecient_background_motion_effects_toggle',
						'operator' => '==',
						'value'    => 'yes',
					),
					array(
						'field'    => $this->get_option_name( 'toggle' ),
						'operator' => '==',
						'value'    => 'yes',
					),
					array(
						'field'    => 'profecient_background_mouse_effects_transition_popover_start!',
						'operator' => '==',
						'value'    => 'yes',
					),
				),
				'render_type'        => 'ui',
			),
			// Transition For
			$this->get_option_name( 'transition_property' ) => array(
				'title'              => esc_html__( 'Property', 'profecient-essential' ),
				'type'               => 'text',
				'label_block'        => false,
				'segment'            => $this->get_option_name( 'segment' ),
				'default'            => 'transform, filter',
				'frontend_available' => true,
				'description'        => esc_html__( 'Enter the CSS property to which the transition effect should be applied. Default is `transform, fitler`.', 'profecient-essential' ),
				'dependency'         => array(
					array(
						'field'    => 'profecient_background_motion_effects_toggle',
						'operator' => '==',
						'value'    => 'yes',
					),
					array(
						'field'    => $this->get_option_name( 'transition_popover_start' ),
						'operator' => '==',
						'value'    => 'yes',
					),
					array(
						'field'    => 'profecient_background_mouse_effects_transition_popover_start!',
						'operator' => '==',
						'value'    => 'yes',
					),
				),
				'render_type'        => 'ui',
			),
			// Transition Duration
			$this->get_option_name( 'transition_duration' ) => array(
				'title'              => esc_html__( 'Duration', 'profecient-essential' ),
				'type'               => 'text',
				'label_block'        => false,
				'segment'            => $this->get_option_name( 'segment' ),
				'default'            => '400ms',
				'frontend_available' => true,
				'description'        => esc_html__( 'Enter the duration of the transition effect. Default is 400 millisecond.', 'profecient-essential' ),
				'dependency'         => array(
					array(
						'field'    => 'profecient_background_motion_effects_toggle',
						'operator' => '==',
						'value'    => 'yes',
					),
					array(
						'field'    => $this->get_option_name( 'transition_popover_start' ),
						'operator' => '==',
						'value'    => 'yes',
					),
					array(
						'field'    => 'profecient_background_mouse_effects_transition_popover_start!',
						'operator' => '==',
						'value'    => 'yes',
					),
				),
				'render_type'        => 'ui',
			),
			// Transition Easing
			$this->get_option_name( 'transition_easing' )  => array(
				'title'              => esc_html__( 'Easing', 'profecient-essential' ),
				'type'               => 'text',
				'label_block'        => false,
				'segment'            => $this->get_option_name( 'segment' ),
				'default'            => 'linear',
				'frontend_available' => true,
				'description'        => esc_html__( 'Enter the easing function of the transition effect. Default is linear. If you want to use cubic-bezier, please enter the cubic-bezier value. For example, cubic-bezier(0.42, 0, 0.58, 1) or Go to the website below and create a cubic-bezier value.', 'profecient-essential' ) . '<br><a href="https://cubic-bezier.com/" target="_blank">https://cubic-bezier.com/</a>',
				'dependency'         => array(
					array(
						'field'    => 'profecient_background_motion_effects_toggle',
						'operator' => '==',
						'value'    => 'yes',
					),
					array(
						'field'    => $this->get_option_name( 'transition_popover_start' ),
						'operator' => '==',
						'value'    => 'yes',
					),
					array(
						'field'    => 'profecient_background_mouse_effects_transition_popover_start!',
						'operator' => '==',
						'value'    => 'yes',
					),
				),
				'render_type'        => 'ui',
			),
			$this->get_option_name( 'transition_popover_end' ) => array(
				'segment' => $this->get_option_name( 'segment' ),
				'type'    => 'control_popover_end',
			),
		);
		/**
		 * Filters the location of the option.
		 *
		 * @param array $location Location of the option. Default is array( 'elementor/element/wp-page/document_settings/after_section_end' ).
		 * @param string $id ID of the option. Default is $this->id.
		 */
		$this->controls['location'] = apply_filters( $this->get_option_name( 'control_location' ), $location, $this->id );

		/**
		 * Filters the show location of the option.
		 *
		 * @param array $show_location Show location of the option. Default is array( 'Core\DocumentTypes\Page' ).
		 * @param string $id ID of the option. Default is $this->id.
		 */
		$this->controls['show_location'] = apply_filters( $this->get_option_name( 'control_show_location' ), $show_location, $this->id );

		/**
		 * Filters the segment of the option.
		 *
		 * @param array $segment Segment of the option. Default is array( $this->get_option_name('segment') => array( 'name' => '<i class="profecient-option-additional"></i> ' . esc_html__( 'Sample Option', 'profecient-essential' ), 'priority' => 10 ) ).
		 * @param string $id ID of the option. Default is $this->id.
		 */
		$this->controls['segment'] = apply_filters( $this->get_option_name( 'control_segment' ), $segment, $this->id );

		/**
		 * Filters the options of the option.
		 *
		 * @param array $options Options of the option. Default is array( $this->get_option_name('toggle') => array( 'title' => esc_html__( 'Enable Sample Option', 'profecient-essential' ), 'type' => 'checkbox', 'default' => false, 'segment' => $this->get_option_name('segment'), 'return_value' => 'yes', 'prefix_class' => 'profecient-sample-option-' ) ).
		 * @param string $id ID of the option. Default is $this->id.
		 */
		$this->controls['options'] = apply_filters( $this->get_option_name( 'control_options' ), $options, $this->id );
	}

	/**
	 * Register styles
	 */
	public function register_styles() {
		wp_register_style( 'profecient-background-motion-effect', PROFECIENT_ESSENTIAL_URL . '/assets/css/extra/background-motion-effect.css', array(), PROFECIENT_ESSENTIAL_VERSION, 'all' );
	}

	/**
	 * Enqueue styles
	 */
	public function enqueue_styles() {
		wp_enqueue_style( 'profecient-background-motion-effect' );
	}

	/**
	 * Enqueue global styles
	 */
	public function enqueue_global_styles() {
	}

	/**
	 * Should style enqueue
	 */
	public function should_style_enqueue() {
	}

	/**
	 * Register scripts
	 */
	public function register_scripts() {
		wp_register_script( 'profecient-background-parallax', PROFECIENT_ESSENTIAL_URL . '/assets/js/extra/background-parallax.js', array( 'elementor-frontend' ), PROFECIENT_ESSENTIAL_VERSION, true );
	}

	/**
	 * Enqueue scripts
	 */
	public function enqueue_scripts() {
		wp_enqueue_script( 'profecient-background-parallax' );
	}

	/**
	 * Enqueue global scripts
	 */
	public function enqueue_global_scripts() {
	}

	/**
	 * Should script enqueue
	 */
	public function should_script_enqueue() {
	}

	/**
	 * After common render.
	 *
	 * @param $element \Elementor\Element_Base Element.
	 */
	public function after_common_render( $element ) {
		$this->after_render( $element );
	}

	/**
	 * After section render.
	 *
	 * @param $element \Elementor\Element_Base Element.
	 */
	public function after_section_render( $element ) {
		$this->after_render( $element );
	}

	/**
	 * After column render.
	 *
	 * @param $element \Elementor\Element_Base Element.
	 */
	public function after_column_render( $element ) {
		$this->after_render( $element );
	}

	/**
	 * After container render.
	 *
	 * @param $element \Elementor\Element_Base Element.
	 */
	public function after_container_render( $element ) {
		$this->after_render( $element );
	}

	/**
	 * After render.
	 *
	 * @param $element \Elementor\Element_Base Element.
	 */
	public function after_render( $element ) {
		if ( $element->get_settings( $this->get_option_name( 'toggle' ) ) === 'yes' ) {
			wp_enqueue_script( 'profecient-background-parallax' );
			wp_enqueue_style( 'profecient-background-motion-effect' );
		}
	}
}
