<?php
namespace Profecient\Essential\JKit\Extra_Option\Options\Blend_Mode;

use Profecient\Essential\JKit\Extra_Option\Options\Abstract_Option;

/**
 * Class Module
 */
class Module extends Abstract_Option {
	/**
	 * Set Options
	 */
	public function set_options() {
		$location      = array(
			'elementor/element/container/section_layout/after_section_end',
			'elementor/element/section/section_advanced/after_section_end',
			'elementor/element/column/section_advanced/after_section_end',
			'elementor/element/common/_section_style/after_section_end',
		);
		$show_location = array(
			'Includes\Elements\Container',
			'Element_Section',
			'Element_Column',
			'Widget_Common',
		);
		$segment       = array(
			$this->get_option_name( 'segment' ) => array(
				'name'     => '<i class="profecient-option-additional"></i> ' . esc_html__( 'Blend Mode', 'profecient-essential' ),
				'priority' => 10,
			),
		);
		$options       = array(
			$this->get_option_name( 'toggle' )    => array(
				'title'        => esc_html__( 'Enable Blend Mode', 'profecient-essential' ),
				'type'         => 'checkbox',
				'default'      => false,
				'segment'      => $this->get_option_name( 'segment' ),
				'return_value' => 'yes',
				'prefix_class' => 'profecient-sample-option-',
			),
			$this->get_option_name( 'mix_blend' ) => array(
				'title'      => esc_html__( 'Blend Mode', 'profecient-essential' ),
				'type'       => 'select',
				'segment'    => $this->get_option_name( 'segment' ),
				'default'    => 'difference',
				'options'    => array(
					'normal'      => esc_html__( 'Normal', 'profecient-essential' ),
					'multiply'    => esc_html__( 'Multiply', 'profecient-essential' ),
					'screen'      => esc_html__( 'Screen', 'profecient-essential' ),
					'overlay'     => esc_html__( 'Overlay', 'profecient-essential' ),
					'darken'      => esc_html__( 'Darken', 'profecient-essential' ),
					'lighten'     => esc_html__( 'Lighten', 'profecient-essential' ),
					'color-dodge' => esc_html__( 'Color Dodge', 'profecient-essential' ),
					'color-burn'  => esc_html__( 'Color Burn', 'profecient-essential' ),
					'hard-light'  => esc_html__( 'Hard Light', 'profecient-essential' ),
					'soft-light'  => esc_html__( 'Soft Light', 'profecient-essential' ),
					'difference'  => esc_html__( 'Difference', 'profecient-essential' ),
					'exclusion'   => esc_html__( 'Exclusion', 'profecient-essential' ),
					'hue'         => esc_html__( 'Hue', 'profecient-essential' ),
					'saturation'  => esc_html__( 'Saturation', 'profecient-essential' ),
					'color'       => esc_html__( 'Color', 'profecient-essential' ),
					'luminosity'  => esc_html__( 'Luminosity', 'profecient-essential' ),
				),
				'selectors'  => '',
				'attribute'  => 'mix-blend-mode',
				'dependency' => array(
					array(
						'field'    => $this->get_option_name( 'toggle' ),
						'operator' => '==',
						'value'    => 'yes',
					),
				),
			),
		);

		/**
		 * Filters the location of the option.
		 *
		 * @param array $location Location of the option. Default is array( 'elementor/element/wp-page/document_settings/after_section_end' ).
		 * @param string $id ID of the option. Default is $this->id.
		 */
		$this->controls['location'] = apply_filters( $this->get_option_name( 'control_location' ), $location, $this->id );

		/**
		 * Filters the show location of the option.
		 *
		 * @param array $show_location Show location of the option. Default is array( 'Core\DocumentTypes\Page' ).
		 * @param string $id ID of the option. Default is $this->id.
		 */
		$this->controls['show_location'] = apply_filters( $this->get_option_name( 'control_show_location' ), $show_location, $this->id );

		/**
		 * Filters the segment of the option.
		 *
		 * @param array $segment Segment of the option. Default is array( $this->get_option_name( 'segment' ) => array( 'name' => '<i class="profecient-option-additional"></i> ' . esc_html__( 'Sample Option', 'profecient-essential' ), 'priority' => 10 ) ).
		 * @param string $id ID of the option. Default is $this->id.
		 */
		$this->controls['segment'] = apply_filters( $this->get_option_name( 'control_segment' ), $segment, $this->id );

		/**
		 * Filters the options of the option.
		 *
		 * @param array $options Options of the option. Default is array( $this->get_option_name( 'toggle' ) => array( 'title' => esc_html__( 'Enable Sample Option', 'profecient-essential' ), 'type' => 'checkbox', 'default' => false, 'segment' => $this->get_option_name( 'segment' ), 'return_value' => 'yes', 'prefix_class' => 'profecient-sample-option-' ) ).
		 * @param string $id ID of the option. Default is $this->id.
		 */
		$this->controls['options'] = apply_filters( $this->get_option_name( 'control_options' ), $options, $this->id );
	}

	/**
	 * Register styles
	 */
	public function register_styles() {
	}

	/**
	 * Enqueue styles
	 */
	public function enqueue_styles() {
	}

	/**
	 * Enqueue global styles
	 */
	public function enqueue_global_styles() {
	}

	/**
	 * Should style enqueue
	 */
	public function should_style_enqueue() {
	}

	/**
	 * Register scripts
	 */
	public function register_scripts() {
	}

	/**
	 * Enqueue scripts
	 */
	public function enqueue_scripts() {
	}

	/**
	 * Enqueue global scripts
	 */
	public function enqueue_global_scripts() {
	}

	/**
	 * Should script enqueue
	 */
	public function should_script_enqueue() {
	}
}
