<?php
namespace Profecient\Essential\JKit\Extra_Option\Options\Custom_Cursor;

use Profecient\Essential\JKit\Extra_Option\Options\Abstract_Option;
use \Elementor\Controls_Manager;

/**
 * Class Module
 */
class Module extends Abstract_Option {

	public function add_action( $register = true ) {
		$this->register();
		parent::add_action( false );
		add_action( 'elementor/frontend/widget/before_render', array( $this, 'before_common_render' ), 10, 1 );
		add_action( 'elementor/frontend/section/before_render', array( $this, 'before_section_render' ), 10, 1 );
		add_action( 'elementor/frontend/column/before_render', array( $this, 'before_column_render' ), 10, 1 );

		add_action( 'elementor/frontend/widget/after_render', array( $this, 'after_common_render' ), 10, 1 );
		add_action( 'elementor/frontend/section/after_render', array( $this, 'after_section_render' ), 10, 1 );
		add_action( 'elementor/frontend/column/after_render', array( $this, 'after_column_render' ), 10, 1 );
		add_action( 'elementor/frontend/container/after_render', array( $this, 'after_container_render' ), 10, 1 );
	}

	/**
	 * Register
	 */
	public function register() {
		if ( is_array( $this->controls['location'] ) ) {
			foreach ( $this->controls['location'] as $location ) {
				add_action( $location, array( $this, 'register_control' ), 10, 2 );
			}
		} else {
			add_action( $this->controls['location'], array( $this, 'register_control' ), 10, 3 );
		}
	}

	/**
	 * Register control
	 *
	 * @param \Elementor\Widget_Common|\Elementor\Element_Column|\Elementor\Element_Section Elementor $element element.
	 * @param  array                                                                                   $args Arguments.
	 *
	 * @return void
	 */
	public function register_control( $element, $args ) {
		$current_class = get_class( $element );
		if ( isset( $this->controls['show_location'] ) ) {
			$show_location = $this->controls['show_location'];
			$current_class = str_replace( 'Elementor\\', '', $current_class );
			if ( ! in_array( $current_class, $show_location, true ) ) {
				return;
			}
		}
		foreach ( $this->controls['segment'] as $id => $segment ) {
			$section = array(
				'label'     => $segment['name'],
				'tab'       => Controls_Manager::TAB_ADVANCED,
				'condition' => isset( $segment['dependency'] ) ? $this->parse_dependency_option( $segment['dependency'] ) : '',
			);
			$options = $this->handle_replace_selector( $this->controls['options'], $current_class );
			$element->start_controls_section( $id, $section );
			$this->parse_control_option( $element, $options, $id );
			$element->end_controls_section();
		}
	}

	private function handle_replace_selector( $options, $current_class ) {
		if ( 'Core\\DocumentTypes\\Page' === $current_class ) {
			foreach ( $options as $option_name => $option ) {
				if ( isset( $option['selectors'] ) ) {
					if ( is_array( $option['selectors'] ) ) {
						foreach ( $option['selectors'] as $selector => $value ) {
							if ( is_array( $value ) ) {
								foreach ( $value as $key => $val ) {
									unset( $options[ $option_name ]['selectors'][ $selector ][ $key ] );
									$key = str_replace( '{{ID}}', 'global', $key );
									$options[ $option_name ]['selectors'][ $selector ][ $key ] = $val;
								}
							} elseif ( is_string( $value ) ) {
								$key                 = str_replace( '{{ID}}', 'global', $value );
								$option['selectors'] = $key;
							}
						}
					} elseif ( is_string( $option['selectors'] ) ) {
						$key                 = str_replace( '{{ID}}', 'global', $option['selectors'] );
						$option['selectors'] = $key;
					}
				}
			}
		}
		return $options;
	}

	/**
	 * Set Options
	 */
	public function set_options() {
		$location      = array(
			'elementor/element/container/section_layout/after_section_end',
			'elementor/element/section/section_advanced/after_section_end',
			'elementor/element/column/section_advanced/after_section_end',
			'elementor/element/common/_section_style/after_section_end',
			'elementor/element/wp-page/document_settings/after_section_end',
		);
		$show_location = array(
			'Includes\Elements\Container',
			'Element_Section',
			'Element_Column',
			'Widget_Common',
			'Core\DocumentTypes\Page',
		);
		$segment       = array(
			$this->get_option_name( 'segment' ) => array(
				'name'     => '<i class="profecient-option-additional"></i> ' . esc_html__( 'Custom Cursor', 'profecient-essential' ),
				'priority' => 10,
			),
		);
		$options       = array(
			$this->get_option_name( 'css_cursor' )         => array(
				'title'     => esc_html__( 'CSS Cursor', 'profecient-essential' ),
				'type'      => 'select',
				'default'   => '',
				'options'   => array(
					''              => esc_html__( 'Not Selected', 'profecient-essential' ),
					'auto'          => esc_html__( 'Auto', 'profecient-essential' ),
					'default'       => esc_html__( 'Default', 'profecient-essential' ),
					'none'          => esc_html__( 'None', 'profecient-essential' ),
					'context-menu'  => esc_html__( 'Context Meni', 'profecient-essential' ),
					'help'          => esc_html__( 'Help', 'profecient-essential' ),
					'pointer'       => esc_html__( 'Pointer', 'profecient-essential' ),
					'progress'      => esc_html__( 'Progress', 'profecient-essential' ),
					'wait'          => esc_html__( 'Wait', 'profecient-essential' ),
					'cell'          => esc_html__( 'Cell', 'profecient-essential' ),
					'crosshair'     => esc_html__( 'Crosshair', 'profecient-essential' ),
					'text'          => esc_html__( 'Text', 'profecient-essential' ),
					'vertical-text' => esc_html__( 'Vertical Text', 'profecient-essential' ),
					'alias'         => esc_html__( 'Alias', 'profecient-essential' ),
					'copy'          => esc_html__( 'Copy', 'profecient-essential' ),
					'move'          => esc_html__( 'Move', 'profecient-essential' ),
					'no-drop'       => esc_html__( 'No Drop', 'profecient-essential' ),
					'not-allowed'   => esc_html__( 'Not Allowed', 'profecient-essential' ),
					'grab'          => esc_html__( 'Grab', 'profecient-essential' ),
					'grabbing'      => esc_html__( 'Grabbing', 'profecient-essential' ),
					'all-scroll'    => esc_html__( 'All Scroll', 'profecient-essential' ),
					'col-resize'    => esc_html__( 'Column Resize', 'profecient-essential' ),
					'row-resize'    => esc_html__( 'Row Resize', 'profecient-essential' ),
					'n-resize'      => esc_html__( 'North Resize', 'profecient-essential' ),
					'e-resize'      => esc_html__( 'East Resize', 'profecient-essential' ),
					's-resize'      => esc_html__( 'South Resize', 'profecient-essential' ),
					'w-resize'      => esc_html__( 'West Resize', 'profecient-essential' ),
					'ne-resize'     => esc_html__( 'North East Resize', 'profecient-essential' ),
					'nw-resize'     => esc_html__( 'North West Resize', 'profecient-essential' ),
					'se-resize'     => esc_html__( 'Sout East Resize', 'profecient-essential' ),
					'sw-resize'     => esc_html__( 'South West Resize', 'profecient-essential' ),
					'ew-resize'     => esc_html__( 'East West Resize', 'profecient-essential' ),
					'ns-resize'     => esc_html__( 'North South Resize', 'profecient-essential' ),
					'nesw-resize'   => esc_html__( 'North East - South West Resize', 'profecient-essential' ),
					'nwse-resize'   => esc_html__( 'North West - Sourh East Resize', 'profecient-essential' ),
					'zoom-in'       => esc_html__( 'Zoom In', 'profecient-essential' ),
					'zoom-out'      => esc_html__( 'Zoom Out', 'profecient-essential' ),
				),
				'segment'   => $this->get_option_name( 'segment' ),
				'selectors' => array(
					'custom' => array(
						'{{WRAPPER}}' => 'cursor: {{VALUE}};',
					),
				),
			),
			$this->get_option_name( 'toggle' )             => array(
				'title'              => esc_html__( 'Enable Custom Cursor', 'profecient-essential' ),
				'type'               => 'checkbox',
				'default'            => false,
				'segment'            => $this->get_option_name( 'segment' ),
				'return_value'       => 'yes',
				'prefix_class'       => 'profecient-custom-cursor-',
				'frontend_available' => true,
			),
			$this->get_option_name( 'type_tabs_start' )    => array(
				'type'       => 'control_tabs_start',
				'segment'    => $this->get_option_name( 'segment' ),
				'dependency' => array(
					array(
						'field'    => $this->get_option_name( 'toggle' ),
						'operator' => '==',
						'value'    => 'yes',
					),
				),
			),
			$this->get_option_name( 'inner_tab_start' )    => array(
				'type'       => 'control_tab_start',
				'title'      => esc_html__( 'Inner', 'profecient-essential' ),
				'segment'    => $this->get_option_name( 'segment' ),
				'dependency' => array(
					array(
						'field'    => $this->get_option_name( 'toggle' ),
						'operator' => '==',
						'value'    => 'yes',
					),
				),
			),
			$this->get_option_name( 'inner_text' )         => array(
				'title'              => esc_html__( 'Inner - Text', 'profecient-essential' ),
				'type'               => 'text',
				'frontend_available' => true,
				'options'            => array(
					'min'  => 0,
					'max'  => 100,
					'step' => 1,
				),
				'segment'            => $this->get_option_name( 'segment' ),
				'dependency'         => array(
					array(
						'field'    => $this->get_option_name( 'toggle' ),
						'operator' => '==',
						'value'    => 'yes',
					),
				),
				'render_type'        => 'ui',
			),
			$this->get_option_name( 'inner_typography' )   => array(
				'type'           => 'typography',
				'title'          => esc_html__( 'Inner - Typograhpy', 'profecient-essential' ),
				'segment'        => $this->get_option_name( 'segment' ),
				'dependency'     => array(
					array(
						'field'    => $this->get_option_name( 'toggle' ),
						'operator' => '==',
						'value'    => 'yes',
					),
				),
				'fields_options' => array(
					'font_family'     => array(
						'frontend_available' => true,
						'render_type'        => 'ui',
					),
					'font_size'       => array(
						'frontend_available' => true,
						'render_type'        => 'ui',
					),
					'font_weight'     => array(
						'frontend_available' => true,
						'render_type'        => 'ui',
					),
					'text_transform'  => array(
						'frontend_available' => true,
						'render_type'        => 'ui',
					),
					'font_style'      => array(
						'frontend_available' => true,
						'render_type'        => 'ui',
					),
					'text_decoration' => array(
						'frontend_available' => true,
						'render_type'        => 'ui',
					),
					'line_height'     => array(
						'frontend_available' => true,
						'render_type'        => 'ui',
					),
					'letter_spacing'  => array(
						'frontend_available' => true,
						'render_type'        => 'ui',
					),
					'word_spacing'    => array(
						'frontend_available' => true,
						'render_type'        => 'ui',
					),
				),
				'selectors'      => array(
					'custom' => ' ',
				),
			),
			$this->get_option_name( 'inner_text_color' )   => array(
				'type'               => 'color',
				'title'              => esc_html__( 'Inner - Text Color', 'profecient-essential' ),
				'segment'            => $this->get_option_name( 'segment' ),
				'render_type'        => 'ui',
				'frontend_available' => true,
				'dependency'         => array(
					array(
						'field'    => $this->get_option_name( 'toggle' ),
						'operator' => '==',
						'value'    => 'yes',
					),
				),
			),
			$this->get_option_name( 'inner_size' )         => array(
				'title'              => esc_html__( 'Inner - Size', 'profecient-essential' ),
				'type'               => 'slider',
				'default'            => 15,
				'default_unit'       => 'px',
				'units'              => array( 'px' ),
				'frontend_available' => true,
				'options'            => array(
					'min'  => 0,
					'max'  => 100,
					'step' => 1,
				),
				'segment'            => $this->get_option_name( 'segment' ),
				'dependency'         => array(
					array(
						'field'    => $this->get_option_name( 'toggle' ),
						'operator' => '==',
						'value'    => 'yes',
					),
				),
				'selectors'          => array(
					'custom' => array(
						'.custom-cursor__inner--custom-{{ID}}' => 'width: {{SIZE}}{{UNIT}}; height: {{SIZE}}{{UNIT}};',
					),
				),
				'render_type'        => 'ui',
			),
			$this->get_option_name( 'inner_color' )        => array(
				'type'               => 'color',
				'title'              => esc_html__( 'Inner - Color', 'profecient-essential' ),
				'segment'            => $this->get_option_name( 'segment' ),
				'default'            => '#FFFFFF',
				'frontend_available' => true,
				'dependency'         => array(
					array(
						'field'    => $this->get_option_name( 'toggle' ),
						'operator' => '==',
						'value'    => 'yes',
					),
				),
				'selectors'          => array(
					'custom' => array(
						'.custom-cursor__inner--custom-{{ID}}::before' => 'background: {{VALUE}}; border-color: {{VALUE}};',
					),
				),
				'render_type'        => 'ui',
			),
			$this->get_option_name( 'inner_blend' )        => array(
				'title'              => esc_html__( 'Inner - Blend Mode', 'profecient-essential' ),
				'type'               => 'select',
				'default'            => 'difference',
				'frontend_available' => true,
				'options'            => array(
					'normal'      => esc_html__( 'Normal', 'profecient-essential' ),
					'multiply'    => esc_html__( 'Multiply', 'profecient-essential' ),
					'screen'      => esc_html__( 'Screen', 'profecient-essential' ),
					'overlay'     => esc_html__( 'Overlay', 'profecient-essential' ),
					'darken'      => esc_html__( 'Darken', 'profecient-essential' ),
					'lighten'     => esc_html__( 'Lighten', 'profecient-essential' ),
					'color-dodge' => esc_html__( 'Color Dodge', 'profecient-essential' ),
					'color-burn'  => esc_html__( 'Color Burn', 'profecient-essential' ),
					'hard-light'  => esc_html__( 'Hard Light', 'profecient-essential' ),
					'soft-light'  => esc_html__( 'Soft Light', 'profecient-essential' ),
					'difference'  => esc_html__( 'Difference', 'profecient-essential' ),
					'exclusion'   => esc_html__( 'Exclusion', 'profecient-essential' ),
					'hue'         => esc_html__( 'Hue', 'profecient-essential' ),
					'saturation'  => esc_html__( 'Saturation', 'profecient-essential' ),
					'color'       => esc_html__( 'Color', 'profecient-essential' ),
					'luminosity'  => esc_html__( 'Luminosity', 'profecient-essential' ),
				),
				'segment'            => $this->get_option_name( 'segment' ),
				'dependency'         => array(
					array(
						'field'    => $this->get_option_name( 'toggle' ),
						'operator' => '==',
						'value'    => 'yes',
					),
				),
				'selectors'          => array(
					'custom' => array(
						'.custom-cursor__inner--custom-{{ID}}' => 'mix-blend-mode: {{VALUE}};',
					),
				),
				'render_type'        => 'ui',
			),
			$this->get_option_name( 'inner_type' )         => array(
				'type'               => 'select',
				'title'              => esc_html__( 'Inner - Type', 'profecient-essential' ),
				'segment'            => $this->get_option_name( 'segment' ),
				'default'            => 'none',
				'prefix_class'       => 'custom-cursor__inner--type-',
				'frontend_available' => true,
				'options'            => array(
					'none'   => esc_html__( 'Fill', 'profecient-essential' ),
					'solid'  => esc_html__( 'Border - Solid', 'profecient-essential' ),
					'dotted' => esc_html__( 'Border - Dotted', 'profecient-essential' ),
					'dashed' => esc_html__( 'Border - Dashed', 'profecient-essential' ),
					'groove' => esc_html__( 'Border - Groove', 'profecient-essential' ),
				),
				'dependency'         => array(
					array(
						'field'    => $this->get_option_name( 'toggle' ),
						'operator' => '==',
						'value'    => 'yes',
					),
				),
				'selectors'          => array(
					'custom' => array(
						'.custom-cursor__inner--custom-{{ID}}::before' => 'border-style: {{VALUE}};',
					),
				),
				'render_type'        => 'ui',
			),
			$this->get_option_name( 'inner_border_width' ) => array(
				'type'               => 'slider',
				'default'            => 1,
				'default_unit'       => 'px',
				'units'              => array( 'px' ),
				'frontend_available' => true,
				'options'            => array(
					'min'  => 0,
					'max'  => 100,
					'step' => 1,
				),
				'title'              => esc_html__( 'Inner - Border Width', 'profecient-essential' ),
				'segment'            => $this->get_option_name( 'segment' ),
				'dependency'         => array(
					array(
						'field'    => $this->get_option_name( 'toggle' ),
						'operator' => '==',
						'value'    => 'yes',
					),
					array(
						'field'    => $this->get_option_name( 'inner_type' ) . '!',
						'operator' => '==',
						'value'    => 'none',
					),
				),
				'selectors'          => array(
					'custom' => array(
						'.custom-cursor__inner--custom-{{ID}}::before' => 'border-width: {{SIZE}}{{UNIT}};',
					),
				),
				'render_type'        => 'ui',
			),
			$this->get_option_name( 'inner_backdrop_filter' ) => array(
				'type'           => 'backdrop_filter',
				'title'          => esc_html__( 'Inner - Backdrop Filter', 'profecient-essential' ),
				'segment'        => $this->get_option_name( 'segment' ),
				'dependency'     => array(
					array(
						'field'    => $this->get_option_name( 'toggle' ),
						'operator' => '==',
						'value'    => 'yes',
					),
				),
				'fields_options' => array(
					'blur'       => array(
						'frontend_available' => true,
					),
					'brightness' => array(
						'frontend_available' => true,
					),
					'contrast'   => array(
						'frontend_available' => true,
					),
					'grayscale'  => array(
						'frontend_available' => true,
					),
					'hue_rotate' => array(
						'frontend_available' => true,
					),
					'opacity'    => array(
						'frontend_available' => true,
					),
					'sepia'      => array(
						'frontend_available' => true,
					),
					'saturate'   => array(
						'frontend_available' => true,
					),
				),
				'selectors'      => array(
					'custom' => ' ',
				),
			),
			$this->get_option_name( 'inner_tab_end' )      => array(
				'type'    => 'control_tab_end',
				'segment' => $this->get_option_name( 'segment' ),
			),
			$this->get_option_name( 'outer_tab_start' )    => array(
				'type'       => 'control_tab_start',
				'title'      => esc_html__( 'Outer', 'profecient-essential' ),
				'segment'    => $this->get_option_name( 'segment' ),
				'dependency' => array(
					array(
						'field'    => $this->get_option_name( 'toggle' ),
						'operator' => '==',
						'value'    => 'yes',
					),
				),
			),
			$this->get_option_name( 'outer_text' )         => array(
				'title'              => esc_html__( 'Outer - Text', 'profecient-essential' ),
				'type'               => 'text',
				'frontend_available' => true,
				'options'            => array(
					'min'  => 0,
					'max'  => 100,
					'step' => 1,
				),
				'segment'            => $this->get_option_name( 'segment' ),
				'dependency'         => array(
					array(
						'field'    => $this->get_option_name( 'toggle' ),
						'operator' => '==',
						'value'    => 'yes',
					),
				),
				'render_type'        => 'ui',
			),
			$this->get_option_name( 'outer_typography' )   => array(
				'type'           => 'typography',
				'title'          => esc_html__( 'Outer - Typograhpy', 'profecient-essential' ),
				'segment'        => $this->get_option_name( 'segment' ),
				'dependency'     => array(
					array(
						'field'    => $this->get_option_name( 'toggle' ),
						'operator' => '==',
						'value'    => 'yes',
					),
				),
				'fields_options' => array(
					'font_family'     => array(
						'frontend_available' => true,
						'render_type'        => 'ui',
					),
					'font_size'       => array(
						'frontend_available' => true,
						'render_type'        => 'ui',
					),
					'font_weight'     => array(
						'frontend_available' => true,
						'render_type'        => 'ui',
					),
					'text_transform'  => array(
						'frontend_available' => true,
						'render_type'        => 'ui',
					),
					'font_style'      => array(
						'frontend_available' => true,
						'render_type'        => 'ui',
					),
					'text_decoration' => array(
						'frontend_available' => true,
						'render_type'        => 'ui',
					),
					'line_height'     => array(
						'frontend_available' => true,
						'render_type'        => 'ui',
					),
					'letter_spacing'  => array(
						'frontend_available' => true,
						'render_type'        => 'ui',
					),
					'word_spacing'    => array(
						'frontend_available' => true,
						'render_type'        => 'ui',
					),
				),
				'selectors'      => array(
					'custom' => ' ',
				),
			),
			$this->get_option_name( 'outer_text_color' )   => array(
				'type'               => 'color',
				'title'              => esc_html__( 'Outer - Text Color', 'profecient-essential' ),
				'segment'            => $this->get_option_name( 'segment' ),
				'render_type'        => 'ui',
				'frontend_available' => true,
				'dependency'         => array(
					array(
						'field'    => $this->get_option_name( 'toggle' ),
						'operator' => '==',
						'value'    => 'yes',
					),
				),
			),
			$this->get_option_name( 'outer_size' )         => array(
				'title'              => esc_html__( 'Outer - Size', 'profecient-essential' ),
				'type'               => 'slider',
				'default'            => 40,
				'default_unit'       => 'px',
				'units'              => array( 'px' ),
				'frontend_available' => true,
				'options'            => array(
					'min'  => 0,
					'max'  => 100,
					'step' => 1,
				),
				'segment'            => $this->get_option_name( 'segment' ),
				'dependency'         => array(
					array(
						'field'    => $this->get_option_name( 'toggle' ),
						'operator' => '==',
						'value'    => 'yes',
					),
				),
				'selectors'          => array(
					'custom' => array(
						'.custom-cursor__outer--custom-{{ID}}' => 'width: {{SIZE}}{{UNIT}}; height: {{SIZE}}{{UNIT}};',
					),
				),
				'render_type'        => 'ui',
			),
			$this->get_option_name( 'outer_color' )        => array(
				'type'               => 'color',
				'title'              => esc_html__( 'Outer - Color', 'profecient-essential' ),
				'segment'            => $this->get_option_name( 'segment' ),
				'default'            => '#ffffff',
				'frontend_available' => true,
				'dependency'         => array(
					array(
						'field'    => $this->get_option_name( 'toggle' ),
						'operator' => '==',
						'value'    => 'yes',
					),
				),
				'selectors'          => array(
					'custom' => array(
						'.custom-cursor__outer--custom-{{ID}}::before' => 'background: {{VALUE}}; border-color: {{VALUE}};',
					),
				),
				'render_type'        => 'ui',
			),
			$this->get_option_name( 'outer_blend' )        => array(
				'title'              => esc_html__( 'Outer - Blend Mode', 'profecient-essential' ),
				'type'               => 'select',
				'default'            => 'difference',
				'frontend_available' => true,
				'options'            => array(
					'normal'      => esc_html__( 'Normal', 'profecient-essential' ),
					'multiply'    => esc_html__( 'Multiply', 'profecient-essential' ),
					'screen'      => esc_html__( 'Screen', 'profecient-essential' ),
					'overlay'     => esc_html__( 'Overlay', 'profecient-essential' ),
					'darken'      => esc_html__( 'Darken', 'profecient-essential' ),
					'lighten'     => esc_html__( 'Lighten', 'profecient-essential' ),
					'color-dodge' => esc_html__( 'Color Dodge', 'profecient-essential' ),
					'color-burn'  => esc_html__( 'Color Burn', 'profecient-essential' ),
					'hard-light'  => esc_html__( 'Hard Light', 'profecient-essential' ),
					'soft-light'  => esc_html__( 'Soft Light', 'profecient-essential' ),
					'difference'  => esc_html__( 'Difference', 'profecient-essential' ),
					'exclusion'   => esc_html__( 'Exclusion', 'profecient-essential' ),
					'hue'         => esc_html__( 'Hue', 'profecient-essential' ),
					'saturation'  => esc_html__( 'Saturation', 'profecient-essential' ),
					'color'       => esc_html__( 'Color', 'profecient-essential' ),
					'luminosity'  => esc_html__( 'Luminosity', 'profecient-essential' ),
				),
				'segment'            => $this->get_option_name( 'segment' ),
				'dependency'         => array(
					array(
						'field'    => $this->get_option_name( 'toggle' ),
						'operator' => '==',
						'value'    => 'yes',
					),
				),
				'selectors'          => array(
					'custom' => array(
						'.custom-cursor__outer--custom-{{ID}}' => 'mix-blend-mode: {{VALUE}};',
					),
				),
				'render_type'        => 'ui',
			),
			$this->get_option_name( 'outer_type' )         => array(
				'type'               => 'select',
				'title'              => esc_html__( 'Outer - Type', 'profecient-essential' ),
				'segment'            => $this->get_option_name( 'segment' ),
				'default'            => 'none',
				'prefix_class'       => 'custom-cursor__outer--type-',
				'frontend_available' => true,
				'options'            => array(
					'none'   => esc_html__( 'Fill', 'profecient-essential' ),
					'solid'  => esc_html__( 'Border - Solid', 'profecient-essential' ),
					'dotted' => esc_html__( 'Border - Dotted', 'profecient-essential' ),
					'dashed' => esc_html__( 'Border - Dashed', 'profecient-essential' ),
					'groove' => esc_html__( 'Border - Groove', 'profecient-essential' ),
				),
				'dependency'         => array(
					array(
						'field'    => $this->get_option_name( 'toggle' ),
						'operator' => '==',
						'value'    => 'yes',
					),
				),
				'selectors'          => array(
					'custom' => array(
						'.custom-cursor__outer--custom-{{ID}}::before' => 'border-style: {{VALUE}};',
					),
				),
				'render_type'        => 'ui',
			),
			$this->get_option_name( 'outer_border_width' ) => array(
				'type'               => 'slider',
				'default'            => 1,
				'default_unit'       => 'px',
				'units'              => array( 'px' ),
				'frontend_available' => true,
				'options'            => array(
					'min'  => 0,
					'max'  => 100,
					'step' => 1,
				),
				'title'              => esc_html__( 'Outer - Border Width', 'profecient-essential' ),
				'segment'            => $this->get_option_name( 'segment' ),
				'dependency'         => array(
					array(
						'field'    => $this->get_option_name( 'toggle' ),
						'operator' => '==',
						'value'    => 'yes',
					),
					array(
						'field'    => $this->get_option_name( 'outer_type' ) . '!',
						'operator' => '==',
						'value'    => 'none',
					),
				),
				'selectors'          => array(
					'custom' => array(
						'.custom-cursor__outer--custom-{{ID}}::before' => 'border-width: {{SIZE}}{{UNIT}};',
					),
				),
				'render_type'        => 'ui',
			),
			$this->get_option_name( 'outer_backdrop_filter' ) => array(
				'type'           => 'backdrop_filter',
				'title'          => esc_html__( 'Outer - Backdrop Filter', 'profecient-essential' ),
				'segment'        => $this->get_option_name( 'segment' ),
				'dependency'     => array(
					array(
						'field'    => $this->get_option_name( 'toggle' ),
						'operator' => '==',
						'value'    => 'yes',
					),
				),
				'fields_options' => array(
					'blur'       => array(
						'frontend_available' => true,
					),
					'brightness' => array(
						'frontend_available' => true,
					),
					'contrast'   => array(
						'frontend_available' => true,
					),
					'grayscale'  => array(
						'frontend_available' => true,
					),
					'hue_rotate' => array(
						'frontend_available' => true,
					),
					'opacity'    => array(
						'frontend_available' => true,
					),
					'sepia'      => array(
						'frontend_available' => true,
					),
					'saturate'   => array(
						'frontend_available' => true,
					),
				),
				'selectors'      => array(
					'custom' => ' ',
				),
			),
			$this->get_option_name( 'outer_tab_end' )      => array(
				'type'    => 'control_tab_end',
				'segment' => $this->get_option_name( 'segment' ),
			),
			$this->get_option_name( 'type_tabs_end' )      => array(
				'type'    => 'control_tabs_end',
				'segment' => $this->get_option_name( 'segment' ),
			),
		);
		/**
		 * Filters the location of the option.
		 *
		 * @param array $location Location of the option. Default is array( 'elementor/element/wp-page/document_settings/after_section_end' ).
		 * @param string $id ID of the option. Default is $this->id.
		 */
		$this->controls['location'] = apply_filters( $this->get_option_name( 'control_location' ), $location, $this->id );

		/**
		 * Filters the show location of the option.
		 *
		 * @param array $show_location Show location of the option. Default is array( 'Core\DocumentTypes\Page' ).
		 * @param string $id ID of the option. Default is $this->id.
		 */
		$this->controls['show_location'] = apply_filters( $this->get_option_name( 'control_show_location' ), $show_location, $this->id );

		/**
		 * Filters the segment of the option.
		 *
		 * @param array $segment Segment of the option. Default is array( $this->get_option_name('segment') => array( 'name' => '<i class="profecient-option-additional"></i> ' . esc_html__( 'Sample Option', 'profecient-essential' ), 'priority' => 10 ) ).
		 * @param string $id ID of the option. Default is $this->id.
		 */
		$this->controls['segment'] = apply_filters( $this->get_option_name( 'control_segment' ), $segment, $this->id );

		/**
		 * Filters the options of the option.
		 *
		 * @param array $options Options of the option. Default is array( $this->get_option_name('toggle') => array( 'title' => esc_html__( 'Enable Sample Option', 'profecient-essential' ), 'type' => 'checkbox', 'default' => false, 'segment' => $this->get_option_name('segment'), 'return_value' => 'yes', 'prefix_class' => 'profecient-sample-option-' ) ).
		 * @param string $id ID of the option. Default is $this->id.
		 */
		$this->controls['options'] = apply_filters( $this->get_option_name( 'control_options' ), $options, $this->id );
	}

	/**
	 * Register styles
	 */
	public function register_styles() {
		// $this->register_style( 'sample-option', 'assets/css/sample-option.css' );
	}



	/**
	 * Enqueue styles
	 */
	public function enqueue_styles() {
		// $this->enqueue_style( 'sample-option' );
	}

	/**
	 * Enqueue global styles
	 */
	public function enqueue_global_styles() {
		// $this->enqueue_script( 'sample-option' );
	}

	/**
	 * Should style enqueue
	 */
	public function should_style_enqueue() {
		// return $this->should_enqueue_script( 'sample-option' );
	}

	/**
	 * Register scripts
	 */
	public function register_scripts() {
		wp_register_script( 'profecient-custom-cursor', PROFECIENT_ESSENTIAL_URL . '/assets/js/extra/custom-cursor.js', array( 'elementor-frontend' ), PROFECIENT_ESSENTIAL_VERSION, true );
	}

	/**
	 * Enqueue scripts
	 */
	public function enqueue_scripts() {
		wp_enqueue_script( 'profecient-custom-cursor' );
	}

	/**
	 * Enqueue global scripts
	 */
	public function enqueue_global_scripts() {
		$custom_cursor_settings = self::get_custom_settings( $this->id );
		if ( isset( $custom_cursor_settings[ $this->get_option_name( 'toggle' ) ] ) && $custom_cursor_settings[ $this->get_option_name( 'toggle' ) ] ) {
			wp_enqueue_script( 'profecient-custom-cursor' );
		}
	}

	/**
	 * Should script enqueue
	 */
	public function should_script_enqueue() {
		// return $this->should_enqueue_script( 'sample-option' );
	}

	/**
	 * Before common render.
	 *
	 * @param $element \Elementor\Element_Base Element.
	 */
	public function before_common_render( $element ) {
		$this->before_render( $element );
	}

	/**
	 * Before section render.
	 *
	 * @param $element \Elementor\Element_Base Element.
	 */
	public function before_section_render( $element ) {
		$this->before_render( $element );
	}

	/**
	 * Before column render.
	 *
	 * @param $element \Elementor\Element_Base Element.
	 */
	public function before_column_render( $element ) {
		$this->before_render( $element );
	}

	/**
	 * Before common render.
	 *
	 * @param $element \Elementor\Element_Base
	 */
	public function before_render( $element ) {
		// before render.
	}

	/**
	 * After common render.
	 *
	 * @param $element \Elementor\Element_Base Element.
	 */
	public function after_common_render( $element ) {
		$this->after_render( $element );
	}

	/**
	 * After section render.
	 *
	 * @param $element \Elementor\Element_Base Element.
	 */
	public function after_section_render( $element ) {
		$this->after_render( $element );
	}

	/**
	 * After column render.
	 *
	 * @param $element \Elementor\Element_Base Element.
	 */
	public function after_column_render( $element ) {
		$this->after_render( $element );
	}

	/**
	 * After container render.
	 *
	 * @param $element \Elementor\Element_Base Element.
	 */
	public function after_container_render( $element ) {
		$this->after_render( $element );
	}

	/**
	 * After render.
	 *
	 * @param $element \Elementor\Element_Base Element.
	 */
	public function after_render( $element ) {
		if ( $element->get_settings( $this->get_option_name( 'toggle' ) ) === 'yes' ) {
			wp_enqueue_script( 'profecient-custom-cursor' );
		}
	}
}
