<?php
namespace Profecient\Essential\JKit\Extra_Option\Options\Mouse_Effects;

use Profecient\Essential\JKit\Extra_Option\Options\Abstract_Option;

/**
 * Class Module
 */
class Module extends Abstract_Option {
	public function add_action( $register = true ) {
		parent::add_action( $register );

		add_action( 'elementor/frontend/widget/after_render', array( $this, 'after_common_render' ), 10, 1 );
		add_action( 'elementor/frontend/section/after_render', array( $this, 'after_section_render' ), 10, 1 );
		add_action( 'elementor/frontend/column/after_render', array( $this, 'after_column_render' ), 10, 1 );
		add_action( 'elementor/frontend/container/after_render', array( $this, 'after_container_render' ), 10, 1 );
	}
	/**
	 * Set Options
	 */
	public function set_options() {
		$location      = array(
			'elementor/element/container/section_layout/after_section_end',
			'elementor/element/section/section_advanced/after_section_end',
			'elementor/element/column/section_advanced/after_section_end',
			'elementor/element/common/_section_style/after_section_end',
		);
		$show_location = array(
			'Includes\Elements\Container',
			'Element_Section',
			'Element_Column',
			'Widget_Common',
		);
		$segment       = array(
			$this->get_option_name( 'segment' ) => array(
				'name'     => '<i class="profecient-option-additional"></i> ' . esc_html__( 'Mouse Effects', 'profecient-essential' ),
				'priority' => 10,
			),
		);
		$options       = array(
			$this->get_option_name( 'toggle' )             => array(
				'title'              => esc_html__( 'Enable Mouse Effects', 'profecient-essential' ),
				'type'               => 'checkbox',
				'segment'            => $this->get_option_name( 'segment' ),
				'return_value'       => 'yes',
				'frontend_available' => true,
				'prefix_class'       => 'profecient-mouse-effects-',
			),
			// Mouse Track
			$this->get_option_name( 'track_popover_start' ) => array(
				'title'              => esc_html__( 'Mouse Track', 'profecient-essential' ),
				'type'               => 'control_popover_start',
				'segment'            => $this->get_option_name( 'segment' ),
				'frontend_available' => true,
				'return_value'       => 'yes',
				'dependency'         => array(
					array(
						'field'    => $this->get_option_name( 'toggle' ),
						'operator' => '==',
						'value'    => 'yes',
					),
				),
				'render_type'        => 'ui',
			),
			// Mouse Track Direction : Direct or Opposite
			$this->get_option_name( 'track_direction' )    => array(
				'title'              => esc_html__( 'Direction', 'profecient-essential' ),
				'type'               => 'radio',
				'segment'            => $this->get_option_name( 'segment' ),
				'default'            => 'direct',
				'frontend_available' => true,
				'options'            => array(
					'direct'   => array(
						'title' => esc_html__( 'Direct', 'profecient-essential' ),
						'icon'  => 'fa fa-long-arrow-right',
					),
					'opposite' => array(
						'title' => esc_html__( 'Opposite', 'profecient-essential' ),
						'icon'  => 'fa fa-long-arrow-left',
					),
				),
				'dependency'         => array(
					array(
						'field'    => $this->get_option_name( 'track_popover_start' ),
						'operator' => '==',
						'value'    => 'yes',
					),
				),
				'render_type'        => 'ui',
			),
			// Mouse Track Speed
			$this->get_option_name( 'track_speed' )        => array(
				'title'              => esc_html__( 'Speed', 'profecient-essential' ),
				'type'               => 'slider',
				'segment'            => $this->get_option_name( 'segment' ),
				'default'            => 1,
				'frontend_available' => true,
				'options'            => array(
					'min'  => 0,
					'max'  => 10,
					'step' => 0.1,
				),
				'dependency'         => array(
					array(
						'field'    => $this->get_option_name( 'track_popover_start' ),
						'operator' => '==',
						'value'    => 'yes',
					),
				),
				'render_type'        => 'ui',
				'responsive'         => true,
			),
			// Mouse Track End popover
			$this->get_option_name( 'track_popover_end' )  => array(
				'segment' => $this->get_option_name( 'segment' ),
				'type'    => 'control_popover_end',
			),
			// 3D Tilt
			$this->get_option_name( 'tilt_popover_start' ) => array(
				'title'              => esc_html__( '3D Tilt', 'profecient-essential' ),
				'type'               => 'control_popover_start',
				'segment'            => $this->get_option_name( 'segment' ),
				'frontend_available' => true,
				'return_value'       => 'yes',
				'dependency'         => array(
					array(
						'field'    => $this->get_option_name( 'toggle' ),
						'operator' => '==',
						'value'    => 'yes',
					),
				),
				'render_type'        => 'ui',
			),
			// 3D Tilt Direction : Direct or Opposite
			$this->get_option_name( 'tilt_direction' )     => array(
				'title'              => esc_html__( 'Direction', 'profecient-essential' ),
				'type'               => 'radio',
				'segment'            => $this->get_option_name( 'segment' ),
				'default'            => 'direct',
				'frontend_available' => true,
				'options'            => array(
					'direct'   => array(
						'title' => esc_html__( 'Direct', 'profecient-essential' ),
						'icon'  => 'fa fa-long-arrow-right',
					),
					'opposite' => array(
						'title' => esc_html__( 'Opposite', 'profecient-essential' ),
						'icon'  => 'fa fa-long-arrow-left',
					),
				),
				'dependency'         => array(
					array(
						'field'    => $this->get_option_name( 'tilt_popover_start' ),
						'operator' => '==',
						'value'    => 'yes',
					),
				),
				'render_type'        => 'ui',
			),
			// 3D Tilt Speed
			$this->get_option_name( 'tilt_speed' )         => array(
				'title'              => esc_html__( 'Speed', 'profecient-essential' ),
				'type'               => 'slider',
				'segment'            => $this->get_option_name( 'segment' ),
				'default'            => 1,
				'frontend_available' => true,
				'options'            => array(
					'min'  => 0,
					'max'  => 10,
					'step' => 0.1,
				),
				'dependency'         => array(
					array(
						'field'    => $this->get_option_name( 'tilt_popover_start' ),
						'operator' => '==',
						'value'    => 'yes',
					),
				),
				'render_type'        => 'ui',
				'responsive'         => true,
			),
			// 3D Tilt End popover
			$this->get_option_name( 'tilt_popover_end' )   => array(
				'segment' => $this->get_option_name( 'segment' ),
				'type'    => 'control_popover_end',
			),
			// Transition
			$this->get_option_name( 'transition_popover_start' ) => array(
				'title'              => esc_html__( 'Transition', 'profecient-essential' ),
				'type'               => 'control_popover_start',
				'segment'            => $this->get_option_name( 'segment' ),
				'return_value'       => 'yes',
				'frontend_available' => true,
				'dependency'         => array(
					array(
						'field'    => $this->get_option_name( 'toggle' ),
						'operator' => '==',
						'value'    => 'yes',
					),
					array(
						'field'    => 'profecient_parallax_effects_transition_popover_start!',
						'operator' => '==',
						'value'    => 'yes',
					),
				),
				'render_type'        => 'ui',
			),
			// Transition For
			$this->get_option_name( 'transition_property' ) => array(
				'title'              => esc_html__( 'Property', 'profecient-essential' ),
				'type'               => 'text',
				'label_block'        => false,
				'segment'            => $this->get_option_name( 'segment' ),
				'default'            => 'transform, filter',
				'frontend_available' => true,
				'description'        => esc_html__( 'Enter the CSS property to which the transition effect should be applied. Default is `transform, fitler`.', 'profecient-essential' ),
				'dependency'         => array(
					array(
						'field'    => $this->get_option_name( 'transition_popover_start' ),
						'operator' => '==',
						'value'    => 'yes',
					),
					array(
						'field'    => 'profecient_parallax_effects_transition_popover_start!',
						'operator' => '==',
						'value'    => 'yes',
					),
				),
				'render_type'        => 'ui',
			),
			// Transition Duration
			$this->get_option_name( 'transition_duration' ) => array(
				'title'              => esc_html__( 'Duration', 'profecient-essential' ),
				'type'               => 'text',
				'label_block'        => false,
				'segment'            => $this->get_option_name( 'segment' ),
				'default'            => '400ms',
				'frontend_available' => true,
				'description'        => esc_html__( 'Enter the duration of the transition effect. Default is 400 millisecond.', 'profecient-essential' ),
				'dependency'         => array(
					array(
						'field'    => $this->get_option_name( 'transition_popover_start' ),
						'operator' => '==',
						'value'    => 'yes',
					),
					array(
						'field'    => 'profecient_parallax_effects_transition_popover_start!',
						'operator' => '==',
						'value'    => 'yes',
					),
				),
				'render_type'        => 'ui',
			),
			// Transition Easing
			$this->get_option_name( 'transition_easing' )  => array(
				'title'              => esc_html__( 'Easing', 'profecient-essential' ),
				'type'               => 'text',
				'label_block'        => false,
				'segment'            => $this->get_option_name( 'segment' ),
				'default'            => 'linear',
				'frontend_available' => true,
				'description'        => esc_html__( 'Enter the easing function of the transition effect. Default is linear. If you want to use cubic-bezier, please enter the cubic-bezier value. For example, cubic-bezier(0.42, 0, 0.58, 1) or Go to the website below and create a cubic-bezier value.', 'profecient-essential' ) . '<br><a href="https://cubic-bezier.com/" target="_blank">https://cubic-bezier.com/</a>',
				'dependency'         => array(
					array(
						'field'    => $this->get_option_name( 'transition_popover_start' ),
						'operator' => '==',
						'value'    => 'yes',
					),
					array(
						'field'    => 'profecient_parallax_effects_transition_popover_start!',
						'operator' => '==',
						'value'    => 'yes',
					),
				),
				'render_type'        => 'ui',
			),
			$this->get_option_name( 'transition_popover_end' ) => array(
				'segment' => $this->get_option_name( 'segment' ),
				'type'    => 'control_popover_end',
			),
		);

		/**
		 * Filters the location of the option.
		 *
		 * @param array $location Location of the option. Default is array( 'elementor/element/wp-page/document_settings/after_section_end' ).
		 * @param string $id ID of the option. Default is $this->id.
		 */
		$this->controls['location'] = apply_filters( $this->get_option_name( 'control_location' ), $location, $this->id );

		/**
		 * Filters the show location of the option.
		 *
		 * @param array $show_location Show location of the option. Default is array( 'Core\DocumentTypes\Page' ).
		 * @param string $id ID of the option. Default is $this->id.
		 */
		$this->controls['show_location'] = apply_filters( $this->get_option_name( 'control_show_location' ), $show_location, $this->id );

		/**
		 * Filters the segment of the option.
		 *
		 * @param array $segment Segment of the option. Default is array( $this->get_option_name( 'segment' ) => array( 'name' => '<i class="profecient-option-additional"></i> ' . esc_html__( 'Sample Option', 'profecient-essential' ), 'priority' => 10 ) ).
		 * @param string $id ID of the option. Default is $this->id.
		 */
		$this->controls['segment'] = apply_filters( $this->get_option_name( 'control_segment' ), $segment, $this->id );

		/**
		 * Filters the options of the option.
		 *
		 * @param array $options Options of the option. Default is array( $this->get_option_name( 'toggle' ) => array( 'title' => esc_html__( 'Enable Sample Option', 'profecient-essential' ), 'type' => 'checkbox', 'default' => false, 'segment' => $this->get_option_name( 'segment' ), 'return_value' => 'yes', 'prefix_class' => 'profecient-sample-option-' ) ).
		 * @param string $id ID of the option. Default is $this->id.
		 */
		$this->controls['options'] = apply_filters( $this->get_option_name( 'control_options' ), $options, $this->id );
	}

	/**
	 * Register styles
	 */
	public function register_styles() {
	}

	/**
	 * Enqueue styles
	 */
	public function enqueue_styles() {
	}

	/**
	 * Enqueue global styles
	 */
	public function enqueue_global_styles() {
	}

	/**
	 * Should style enqueue
	 */
	public function should_style_enqueue() {
	}

	/**
	 * Register scripts
	 */
	public function register_scripts() {
		wp_register_script( 'profecient-lib-mouse-effect', PROFECIENT_ESSENTIAL_URL . '/assets/js/lib/motion-effects/mouse-effect.js', array(), PROFECIENT_ESSENTIAL_VERSION, true );
		wp_register_script( 'profecient-mouse-effects', PROFECIENT_ESSENTIAL_URL . '/assets/js/extra/mouse-effects.js', array( 'elementor-frontend', 'profecient-lib-mouse-effect' ), PROFECIENT_ESSENTIAL_VERSION, true );
	}

	/**
	 * Enqueue scripts
	 */
	public function enqueue_scripts() {
		wp_enqueue_script( 'profecient-mouse-effects' );
	}

	/**
	 * Enqueue global scripts
	 */
	public function enqueue_global_scripts() {
	}

	/**
	 * Should script enqueue
	 */
	public function should_script_enqueue() {
	}

	/**
	 * After common render.
	 *
	 * @param $element \Elementor\Element_Base Element.
	 */
	public function after_common_render( $element ) {
		$this->after_render( $element );
	}

	/**
	 * After section render.
	 *
	 * @param $element \Elementor\Element_Base Element.
	 */
	public function after_section_render( $element ) {
		$this->after_render( $element );
	}

	/**
	 * After column render.
	 *
	 * @param $element \Elementor\Element_Base Element.
	 */
	public function after_column_render( $element ) {
		$this->after_render( $element );
	}

	/**
	 * After container render.
	 *
	 * @param $element \Elementor\Element_Base Element.
	 */
	public function after_container_render( $element ) {
		$this->after_render( $element );
	}

	/**
	 * After render.
	 *
	 * @param $element \Elementor\Element_Base Element.
	 */
	public function after_render( $element ) {
		if ( $element->get_settings( $this->get_option_name( 'toggle' ) ) === 'yes' ) {
			wp_enqueue_script( 'profecient-mouse-effects' );
		}
	}
}
