<?php
namespace Profecient\Essential\JKit\Extra_Option\Options\Parallax_Effects;

use Profecient\Essential\JKit\Extra_Option\Options\Abstract_Option;

/**
 * Class Module
 */
class Module extends Abstract_Option {

	public function add_action( $register = true ) {
		parent::add_action( $register );
		add_action( 'elementor/frontend/section/after_render', array( $this, 'after_common_render' ), 10, 1 );
		add_action( 'elementor/frontend/container/after_render', array( $this, 'after_container_render' ), 10, 1 );
		add_action( 'elementor/frontend/widget/after_render', array( $this, 'after_common_render' ), 10, 1 );
		add_action( 'elementor/frontend/column/after_render', array( $this, 'after_column_render' ), 10, 1 );
	}

	/**
	 * Set Options
	 */
	public function set_options() {
		$location      = array(
			'elementor/element/container/section_layout/after_section_end',
			'elementor/element/section/section_advanced/after_section_end',
			'elementor/element/column/section_advanced/after_section_end',
			'elementor/element/common/_section_style/after_section_end',
		);
		$show_location = array(
			'Includes\Elements\Container',
			'Element_Section',
			'Element_Column',
			'Widget_Common',
		);
		$segment       = array(
			$this->get_option_name( 'segment' ) => array(
				'name'     => '<i class="profecient-option-additional"></i> ' . esc_html__( 'Parallax/Scrolling Effects', 'profecient-essential' ),
				'priority' => 10,
			),
		);
		$options       = array(
			$this->get_option_name( 'toggle' )             => array(
				'title'              => esc_html__( 'Enable Parallax/Scrolling Effects', 'profecient-essential' ),
				'type'               => 'checkbox',
				'segment'            => $this->get_option_name( 'segment' ),
				'return_value'       => 'yes',
				'frontend_available' => true,
				'prefix_class'       => 'profecient-parallax-',
			),
			// Perspective
			$this->get_option_name( 'perspective_popover_start' ) => array(
				'title'              => esc_html__( 'Perspective', 'profecient-essential' ),
				'type'               => 'control_popover_start',
				'segment'            => $this->get_option_name( 'segment' ),
				'return_value'       => 'yes',
				'frontend_available' => true,
				'dependency'         => array(
					array(
						'field'    => $this->get_option_name( 'toggle' ),
						'operator' => '==',
						'value'    => 'yes',
					),
				),
				'render_type'        => 'ui',
			),
			$this->get_option_name( 'perspective_start' )  => array(
				'title'              => esc_html__( 'Start', 'profecient-essential' ),
				'type'               => 'slider',
				'segment'            => $this->get_option_name( 'segment' ),
				'default'            => 0,
				'frontend_available' => true,
				'responsive'         => true,
				'options'            => array(
					'min'  => 0,
					'max'  => 1000,
					'step' => 1,
				),
				'dependency'         => array(
					array(
						'field'    => $this->get_option_name( 'perspective_popover_start' ),
						'operator' => '==',
						'value'    => 'yes',
					),
				),
				'render_type'        => 'ui',
			),
			$this->get_option_name( 'perspective_end' )    => array(
				'title'              => esc_html__( 'End', 'profecient-essential' ),
				'type'               => 'slider',
				'segment'            => $this->get_option_name( 'segment' ),
				'default'            => 0,
				'frontend_available' => true,
				'responsive'         => true,
				'options'            => array(
					'min'  => 0,
					'max'  => 1000,
					'step' => 1,
				),
				'dependency'         => array(
					array(
						'field'    => $this->get_option_name( 'perspective_popover_start' ),
						'operator' => '==',
						'value'    => 'yes',
					),
				),
				'render_type'        => 'ui',
			),
			$this->get_option_name( 'perspective_css_unit' ) => array(
				'title'              => esc_html__( 'CSS Unit', 'profecient-essential' ),
				'description'        => esc_html__( 'Enter a CSS Unit for Start and End positions.', 'profecient-essential' ),
				'type'               => 'text',
				'segment'            => $this->get_option_name( 'segment' ),
				'default'            => 'px',
				'frontend_available' => true,
				'dependency'         => array(
					array(
						'field'    => $this->get_option_name( 'perspective_popover_start' ),
						'operator' => '==',
						'value'    => 'yes',
					),
				),
				'render_type'        => 'ui',
			),
			$this->get_option_name( 'perspective_animation_viewport' ) => array(
				'title'              => esc_html__( 'Viewport', 'profecient-essential' ),
				'type'               => 'slider',
				'segment'            => $this->get_option_name( 'segment' ),
				'default_unit'       => '%',
				'default_sizes'      => array(
					'start' => 0,
					'end'   => 100,
				),
				'labels'             => array(
					__( 'Bottom', 'profecient-essential' ),
					__( 'Top', 'profecient-essential' ),
				),
				'scales'             => 1,
				'handles'            => 'range',
				'frontend_available' => true,
				'options'            => array(
					'min'  => 0,
					'max'  => 100,
					'step' => 1,
				),
				'dependency'         => array(
					array(
						'field'    => $this->get_option_name( 'perspective_popover_start' ),
						'operator' => '==',
						'value'    => 'yes',
					),
				),
				'render_type'        => 'ui',
			),
			$this->get_option_name( 'perspective_relative_animation_viewport' ) => array(
				'title'              => esc_html__( 'Relative Viewport', 'profecient-essential' ),
				'type'               => 'select',
				'segment'            => $this->get_option_name( 'segment' ),
				'label_block'        => true,
				'default'            => 'element',
				'options'            => array(
					'element' => esc_html__( 'Element', 'profecient-essential' ),
					'page'    => esc_html__( 'Page', 'profecient-essential' ),
				),
				'frontend_available' => true,
				'render_type'        => 'ui',
				'dependency'         => array(
					array(
						'field'    => $this->get_option_name( 'perspective_popover_start' ),
						'operator' => '==',
						'value'    => 'yes',
					),
				),
				'description'        => esc_html__( 'Learn more about Perspective with this link below.', 'profecient-essential' ) . '<br><a href="https://css-tricks.com/almanac/properties/p/perspective/" target="_blank">https://css-tricks.com/almanac/properties/p/perspective/</a>',
			),
			$this->get_option_name( 'perspective_popover_end' ) => array(
				'segment' => $this->get_option_name( 'segment' ),
				'type'    => 'control_popover_end',
			),
			// Horizontal Parallax(X)
			$this->get_option_name( 'x_popover_start' )    => array(
				'title'              => esc_html__( 'Horizontal Parallax(X)', 'profecient-essential' ),
				'type'               => 'control_popover_start',
				'segment'            => $this->get_option_name( 'segment' ),
				'return_value'       => 'yes',
				'frontend_available' => true,
				'dependency'         => array(
					array(
						'field'    => $this->get_option_name( 'toggle' ),
						'operator' => '==',
						'value'    => 'yes',
					),
				),
				'render_type'        => 'ui',
			),
			$this->get_option_name( 'x_start' )            => array(
				'title'              => esc_html__( 'Start', 'profecient-essential' ),
				'type'               => 'slider',
				'segment'            => $this->get_option_name( 'segment' ),
				'default'            => 0,
				'frontend_available' => true,
				'responsive'         => true,
				'options'            => array(
					'min'  => -1000,
					'max'  => 1000,
					'step' => 1,
				),
				'dependency'         => array(
					array(
						'field'    => $this->get_option_name( 'x_popover_start' ),
						'operator' => '==',
						'value'    => 'yes',
					),
				),
				'render_type'        => 'ui',
			),
			$this->get_option_name( 'x_end' )              => array(
				'title'              => esc_html__( 'End', 'profecient-essential' ),
				'type'               => 'slider',
				'segment'            => $this->get_option_name( 'segment' ),
				'default'            => 0,
				'frontend_available' => true,
				'responsive'         => true,
				'options'            => array(
					'min'  => -1000,
					'max'  => 1000,
					'step' => 1,
				),
				'dependency'         => array(
					array(
						'field'    => $this->get_option_name( 'x_popover_start' ),
						'operator' => '==',
						'value'    => 'yes',
					),
				),
				'render_type'        => 'ui',
			),
			$this->get_option_name( 'x_css_unit' )         => array(
				'title'              => esc_html__( 'CSS Unit', 'profecient-essential' ),
				'description'        => esc_html__( 'Enter a CSS Unit for Start and End positions.', 'profecient-essential' ),
				'type'               => 'text',
				'segment'            => $this->get_option_name( 'segment' ),
				'default'            => 'px',
				'frontend_available' => true,
				'dependency'         => array(
					array(
						'field'    => $this->get_option_name( 'x_popover_start' ),
						'operator' => '==',
						'value'    => 'yes',
					),
				),
				'render_type'        => 'ui',
			),
			$this->get_option_name( 'x_animation_viewport' ) => array(
				'title'              => esc_html__( 'Viewport', 'profecient-essential' ),
				'type'               => 'slider',
				'segment'            => $this->get_option_name( 'segment' ),
				'default_unit'       => '%',
				'default_sizes'      => array(
					'start' => 0,
					'end'   => 100,
				),
				'labels'             => array(
					__( 'Bottom', 'profecient-essential' ),
					__( 'Top', 'profecient-essential' ),
				),
				'scales'             => 1,
				'handles'            => 'range',
				'frontend_available' => true,
				'options'            => array(
					'min'  => 0,
					'max'  => 100,
					'step' => 1,
				),
				'dependency'         => array(
					array(
						'field'    => $this->get_option_name( 'x_popover_start' ),
						'operator' => '==',
						'value'    => 'yes',
					),
				),
				'render_type'        => 'ui',
			),
			$this->get_option_name( 'x_relative_animation_viewport' ) => array(
				'title'              => esc_html__( 'Relative Viewport', 'profecient-essential' ),
				'type'               => 'select',
				'segment'            => $this->get_option_name( 'segment' ),
				'label_block'        => true,
				'default'            => 'element',
				'options'            => array(
					'element' => esc_html__( 'Element', 'profecient-essential' ),
					'page'    => esc_html__( 'Page', 'profecient-essential' ),
				),
				'frontend_available' => true,
				'render_type'        => 'ui',
				'dependency'         => array(
					array(
						'field'    => $this->get_option_name( 'x_popover_start' ),
						'operator' => '==',
						'value'    => 'yes',
					),
				),
			),
			$this->get_option_name( 'x_popover_end' )      => array(
				'segment' => $this->get_option_name( 'segment' ),
				'type'    => 'control_popover_end',
			),
			// Horizontal Parallax(Y)
			$this->get_option_name( 'y_popover_start' )    => array(
				'title'              => esc_html__( 'Vertical Parallax(Y)', 'profecient-essential' ),
				'type'               => 'control_popover_start',
				'segment'            => $this->get_option_name( 'segment' ),
				'return_value'       => 'yes',
				'frontend_available' => true,
				'dependency'         => array(
					array(
						'field'    => $this->get_option_name( 'toggle' ),
						'operator' => '==',
						'value'    => 'yes',
					),
				),
				'render_type'        => 'ui',
			),
			$this->get_option_name( 'y_start' )            => array(
				'title'              => esc_html__( 'Start', 'profecient-essential' ),
				'type'               => 'slider',
				'segment'            => $this->get_option_name( 'segment' ),
				'default'            => 0,
				'frontend_available' => true,
				'responsive'         => true,
				'options'            => array(
					'min'  => -1000,
					'max'  => 1000,
					'step' => 1,
				),
				'dependency'         => array(
					array(
						'field'    => $this->get_option_name( 'y_popover_start' ),
						'operator' => '==',
						'value'    => 'yes',
					),
				),
				'render_type'        => 'ui',
			),
			$this->get_option_name( 'y_end' )              => array(
				'title'              => esc_html__( 'End', 'profecient-essential' ),
				'type'               => 'slider',
				'segment'            => $this->get_option_name( 'segment' ),
				'default'            => 0,
				'frontend_available' => true,
				'responsive'         => true,
				'options'            => array(
					'min'  => -1000,
					'max'  => 1000,
					'step' => 1,
				),
				'dependency'         => array(
					array(
						'field'    => $this->get_option_name( 'y_popover_start' ),
						'operator' => '==',
						'value'    => 'yes',
					),
				),
				'render_type'        => 'ui',
			),
			$this->get_option_name( 'y_css_unit' )         => array(
				'title'              => esc_html__( 'CSS Unit', 'profecient-essential' ),
				'description'        => esc_html__( 'Enter a CSS Unit for Start and End positions.', 'profecient-essential' ),
				'type'               => 'text',
				'segment'            => $this->get_option_name( 'segment' ),
				'default'            => 'px',
				'frontend_available' => true,
				'dependency'         => array(
					array(
						'field'    => $this->get_option_name( 'y_popover_start' ),
						'operator' => '==',
						'value'    => 'yes',
					),
				),
				'render_type'        => 'ui',
			),
			$this->get_option_name( 'y_animation_viewport' ) => array(
				'title'              => esc_html__( 'Viewport', 'profecient-essential' ),
				'type'               => 'slider',
				'segment'            => $this->get_option_name( 'segment' ),
				'default_unit'       => '%',
				'default_sizes'      => array(
					'start' => 0,
					'end'   => 100,
				),
				'labels'             => array(
					__( 'Bottom', 'profecient-essential' ),
					__( 'Top', 'profecient-essential' ),
				),
				'scales'             => 1,
				'handles'            => 'range',
				'frontend_available' => true,
				'options'            => array(
					'min'  => 0,
					'max'  => 100,
					'step' => 1,
				),
				'dependency'         => array(
					array(
						'field'    => $this->get_option_name( 'y_popover_start' ),
						'operator' => '==',
						'value'    => 'yes',
					),
				),
				'render_type'        => 'ui',
			),
			$this->get_option_name( 'y_relative_animation_viewport' ) => array(
				'title'              => esc_html__( 'Relative Viewport', 'profecient-essential' ),
				'type'               => 'select',
				'segment'            => $this->get_option_name( 'segment' ),
				'label_block'        => true,
				'default'            => 'element',
				'options'            => array(
					'element' => esc_html__( 'Element', 'profecient-essential' ),
					'page'    => esc_html__( 'Page', 'profecient-essential' ),
				),
				'frontend_available' => true,
				'render_type'        => 'ui',
				'dependency'         => array(
					array(
						'field'    => $this->get_option_name( 'y_popover_start' ),
						'operator' => '==',
						'value'    => 'yes',
					),
				),
			),
			$this->get_option_name( 'y_popover_end' )      => array(
				'segment' => $this->get_option_name( 'segment' ),
				'type'    => 'control_popover_end',
			),
			// Opacity
			$this->get_option_name( 'opacity_popover_start' ) => array(
				'title'              => esc_html__( 'Opacity', 'profecient-essential' ),
				'type'               => 'control_popover_start',
				'segment'            => $this->get_option_name( 'segment' ),
				'return_value'       => 'yes',
				'frontend_available' => true,
				'dependency'         => array(
					array(
						'field'    => $this->get_option_name( 'toggle' ),
						'operator' => '==',
						'value'    => 'yes',
					),
				),
				'render_type'        => 'ui',
			),
			$this->get_option_name( 'opacity_start' )      => array(
				'title'              => esc_html__( 'Start', 'profecient-essential' ),
				'type'               => 'slider',
				'segment'            => $this->get_option_name( 'segment' ),
				'default'            => 0,
				'frontend_available' => true,
				'responsive'         => true,
				'options'            => array(
					'min'  => 0,
					'max'  => 1,
					'step' => 0.1,
				),
				'dependency'         => array(
					array(
						'field'    => $this->get_option_name( 'opacity_popover_start' ),
						'operator' => '==',
						'value'    => 'yes',
					),
				),
				'render_type'        => 'ui',
			),
			$this->get_option_name( 'opacity_end' )        => array(
				'title'              => esc_html__( 'End', 'profecient-essential' ),
				'type'               => 'slider',
				'segment'            => $this->get_option_name( 'segment' ),
				'default'            => 1,
				'frontend_available' => true,
				'responsive'         => true,
				'options'            => array(
					'min'  => 0,
					'max'  => 1,
					'step' => 0.1,
				),
				'dependency'         => array(
					array(
						'field'    => $this->get_option_name( 'opacity_popover_start' ),
						'operator' => '==',
						'value'    => 'yes',
					),
				),
				'render_type'        => 'ui',
			),
			$this->get_option_name( 'opacity_animation_viewport' ) => array(
				'title'              => esc_html__( 'Viewport', 'profecient-essential' ),
				'type'               => 'slider',
				'segment'            => $this->get_option_name( 'segment' ),
				'default_unit'       => '%',
				'default_sizes'      => array(
					'start' => 0,
					'end'   => 100,
				),
				'labels'             => array(
					__( 'Bottom', 'profecient-essential' ),
					__( 'Top', 'profecient-essential' ),
				),
				'scales'             => 1,
				'handles'            => 'range',
				'frontend_available' => true,
				'options'            => array(
					'min'  => 0,
					'max'  => 100,
					'step' => 1,
				),
				'dependency'         => array(
					array(
						'field'    => $this->get_option_name( 'opacity_popover_start' ),
						'operator' => '==',
						'value'    => 'yes',
					),
				),
				'render_type'        => 'ui',
			),
			$this->get_option_name( 'opacity_relative_animation_viewport' ) => array(
				'title'              => esc_html__( 'Relative Viewport', 'profecient-essential' ),
				'type'               => 'select',
				'segment'            => $this->get_option_name( 'segment' ),
				'label_block'        => true,
				'default'            => 'element',
				'options'            => array(
					'element' => esc_html__( 'Element', 'profecient-essential' ),
					'page'    => esc_html__( 'Page', 'profecient-essential' ),
				),
				'frontend_available' => true,
				'render_type'        => 'ui',
				'dependency'         => array(
					array(
						'field'    => $this->get_option_name( 'opacity_popover_start' ),
						'operator' => '==',
						'value'    => 'yes',
					),
				),
			),
			$this->get_option_name( 'opacity_popover_end' ) => array(
				'segment' => $this->get_option_name( 'segment' ),
				'type'    => 'control_popover_end',
			),
			// Blur
			$this->get_option_name( 'blur_popover_start' ) => array(
				'title'              => esc_html__( 'Blur', 'profecient-essential' ),
				'type'               => 'control_popover_start',
				'segment'            => $this->get_option_name( 'segment' ),
				'return_value'       => 'yes',
				'frontend_available' => true,
				'dependency'         => array(
					array(
						'field'    => $this->get_option_name( 'toggle' ),
						'operator' => '==',
						'value'    => 'yes',
					),
				),
				'render_type'        => 'ui',
			),
			$this->get_option_name( 'blur_start' )         => array(
				'title'              => esc_html__( 'Start', 'profecient-essential' ),
				'type'               => 'slider',
				'segment'            => $this->get_option_name( 'segment' ),
				'default_unit'       => 'px',
				'default'            => 0,
				'frontend_available' => true,
				'responsive'         => true,
				'options'            => array(
					'min'  => 0,
					'max'  => 100,
					'step' => 1,
				),
				'dependency'         => array(
					array(
						'field'    => $this->get_option_name( 'blur_popover_start' ),
						'operator' => '==',
						'value'    => 'yes',
					),
				),
				'render_type'        => 'ui',
			),
			$this->get_option_name( 'blur_end' )           => array(
				'title'              => esc_html__( 'End', 'profecient-essential' ),
				'type'               => 'slider',
				'segment'            => $this->get_option_name( 'segment' ),
				'default_unit'       => 'px',
				'default'            => 0,
				'frontend_available' => true,
				'responsive'         => true,
				'options'            => array(
					'min'  => 0,
					'max'  => 100,
					'step' => 1,
				),
				'dependency'         => array(
					array(
						'field'    => $this->get_option_name( 'blur_popover_start' ),
						'operator' => '==',
						'value'    => 'yes',
					),
				),
				'render_type'        => 'ui',
			),
			$this->get_option_name( 'blur_css_unit' )      => array(
				'title'              => esc_html__( 'CSS Unit', 'profecient-essential' ),
				'description'        => esc_html__( 'Enter a CSS Unit for Start and End positions.', 'profecient-essential' ),
				'type'               => 'text',
				'segment'            => $this->get_option_name( 'segment' ),
				'default'            => 'px',
				'frontend_available' => true,
				'dependency'         => array(
					array(
						'field'    => $this->get_option_name( 'blur_popover_start' ),
						'operator' => '==',
						'value'    => 'yes',
					),
				),
				'render_type'        => 'ui',
			),
			$this->get_option_name( 'blur_animation_viewport' ) => array(
				'title'              => esc_html__( 'Viewport', 'profecient-essential' ),
				'type'               => 'slider',
				'segment'            => $this->get_option_name( 'segment' ),
				'default_unit'       => '%',
				'default_sizes'      => array(
					'start' => 0,
					'end'   => 100,
				),
				'labels'             => array(
					__( 'Bottom', 'profecient-essential' ),
					__( 'Top', 'profecient-essential' ),
				),
				'scales'             => 1,
				'handles'            => 'range',
				'frontend_available' => true,
				'options'            => array(
					'min'  => 0,
					'max'  => 100,
					'step' => 1,
				),
				'dependency'         => array(
					array(
						'field'    => $this->get_option_name( 'blur_popover_start' ),
						'operator' => '==',
						'value'    => 'yes',
					),
				),
				'render_type'        => 'ui',
			),
			$this->get_option_name( 'blur_relative_animation_viewport' ) => array(
				'title'              => esc_html__( 'Relative Viewport', 'profecient-essential' ),
				'type'               => 'select',
				'segment'            => $this->get_option_name( 'segment' ),
				'label_block'        => true,
				'default'            => 'element',
				'options'            => array(
					'element' => esc_html__( 'Element', 'profecient-essential' ),
					'page'    => esc_html__( 'Page', 'profecient-essential' ),
				),
				'frontend_available' => true,
				'render_type'        => 'ui',
				'dependency'         => array(
					array(
						'field'    => $this->get_option_name( 'blur_popover_start' ),
						'operator' => '==',
						'value'    => 'yes',
					),
				),
			),
			$this->get_option_name( 'blur_popover_end' )   => array(
				'segment' => $this->get_option_name( 'segment' ),
				'type'    => 'control_popover_end',
			),
			// Rotate Z
			$this->get_option_name( 'rotate_popover_start' ) => array(
				'title'              => esc_html__( 'Rotate', 'profecient-essential' ),
				'type'               => 'control_popover_start',
				'segment'            => $this->get_option_name( 'segment' ),
				'return_value'       => 'yes',
				'frontend_available' => true,
				'dependency'         => array(
					array(
						'field'    => $this->get_option_name( 'toggle' ),
						'operator' => '==',
						'value'    => 'yes',
					),
				),
				'render_type'        => 'ui',
			),
			$this->get_option_name( 'rotate_start' )       => array(
				'title'              => esc_html__( 'Start', 'profecient-essential' ),
				'type'               => 'slider',
				'segment'            => $this->get_option_name( 'segment' ),
				'default_unit'       => 'px',
				'default'            => 0,
				'frontend_available' => true,
				'responsive'         => true,
				'options'            => array(
					'min'  => -360,
					'max'  => 360,
					'step' => 1,
				),
				'dependency'         => array(
					array(
						'field'    => $this->get_option_name( 'rotate_popover_start' ),
						'operator' => '==',
						'value'    => 'yes',
					),
				),
				'render_type'        => 'ui',
			),
			$this->get_option_name( 'rotate_end' )         => array(
				'title'              => esc_html__( 'End', 'profecient-essential' ),
				'type'               => 'slider',
				'segment'            => $this->get_option_name( 'segment' ),
				'default_unit'       => 'px',
				'default'            => 0,
				'frontend_available' => true,
				'responsive'         => true,
				'options'            => array(
					'min'  => -360,
					'max'  => 360,
					'step' => 1,
				),
				'dependency'         => array(
					array(
						'field'    => $this->get_option_name( 'rotate_popover_start' ),
						'operator' => '==',
						'value'    => 'yes',
					),
				),
				'render_type'        => 'ui',
			),
			$this->get_option_name( 'rotate_css_unit' )    => array(
				'title'              => esc_html__( 'CSS Unit', 'profecient-essential' ),
				'description'        => esc_html__( 'Enter a CSS Unit for Start and End. Ex: deg, grad, rad, turn.', 'profecient-essential' ),
				'type'               => 'text',
				'segment'            => $this->get_option_name( 'segment' ),
				'default'            => 'deg',
				'frontend_available' => true,
				'dependency'         => array(
					array(
						'field'    => $this->get_option_name( 'rotate_popover_start' ),
						'operator' => '==',
						'value'    => 'yes',
					),
				),
				'render_type'        => 'ui',
			),
			$this->get_option_name( 'x_transform_origin' ) => array(
				'title'              => esc_html__( 'Horizontal Transform Origin(X)', 'profecient-essential' ),
				'type'               => 'slider',
				'segment'            => $this->get_option_name( 'segment' ),
				'units'              => array( '%', 'px', 'custom' ),
				'default_unit'       => '%',
				'default'            => 50,
				'frontend_available' => true,
				'responsive'         => true,
				'options'            => array(
					'min'  => 0,
					'max'  => 100,
					'step' => 1,
				),
				'dependency'         => array(
					array(
						'field'    => $this->get_option_name( 'rotate_popover_start' ),
						'operator' => '==',
						'value'    => 'yes',
					),
				),
				'render_type'        => 'ui',
			),
			$this->get_option_name( 'y_transform_origin' ) => array(
				'title'              => esc_html__( 'Vertical Transform Origin(Y)', 'profecient-essential' ),
				'type'               => 'slider',
				'segment'            => $this->get_option_name( 'segment' ),
				'units'              => array( '%', 'px', 'custom' ),
				'default_unit'       => '%',
				'default'            => 50,
				'frontend_available' => true,
				'responsive'         => true,
				'options'            => array(
					'min'  => 0,
					'max'  => 100,
					'step' => 1,
				),
				'dependency'         => array(
					array(
						'field'    => $this->get_option_name( 'rotate_popover_start' ),
						'operator' => '==',
						'value'    => 'yes',
					),
				),
				'render_type'        => 'ui',
			),
			$this->get_option_name( 'rotate_animation_viewport' ) => array(
				'title'              => esc_html__( 'Viewport', 'profecient-essential' ),
				'type'               => 'slider',
				'segment'            => $this->get_option_name( 'segment' ),
				'default_unit'       => '%',
				'default_sizes'      => array(
					'start' => 0,
					'end'   => 100,
				),
				'labels'             => array(
					__( 'Bottom', 'profecient-essential' ),
					__( 'Top', 'profecient-essential' ),
				),
				'scales'             => 1,
				'handles'            => 'range',
				'frontend_available' => true,
				'options'            => array(
					'min'  => 0,
					'max'  => 100,
					'step' => 1,
				),
				'dependency'         => array(
					array(
						'field'    => $this->get_option_name( 'rotate_popover_start' ),
						'operator' => '==',
						'value'    => 'yes',
					),
				),
				'render_type'        => 'ui',
			),
			$this->get_option_name( 'rotate_relative_animation_viewport' ) => array(
				'title'              => esc_html__( 'Relative Viewport', 'profecient-essential' ),
				'type'               => 'select',
				'segment'            => $this->get_option_name( 'segment' ),
				'label_block'        => true,
				'default'            => 'element',
				'options'            => array(
					'element' => esc_html__( 'Element', 'profecient-essential' ),
					'page'    => esc_html__( 'Page', 'profecient-essential' ),
				),
				'frontend_available' => true,
				'render_type'        => 'ui',
				'dependency'         => array(
					array(
						'field'    => $this->get_option_name( 'rotate_popover_start' ),
						'operator' => '==',
						'value'    => 'yes',
					),
				),
			),
			$this->get_option_name( 'rotate_popover_end' ) => array(
				'segment' => $this->get_option_name( 'segment' ),
				'type'    => 'control_popover_end',
			),
			// Rotate X
			$this->get_option_name( 'rotate_x_popover_start' ) => array(
				'title'              => esc_html__( 'Horizontal Rotate(X)', 'profecient-essential' ),
				'type'               => 'control_popover_start',
				'segment'            => $this->get_option_name( 'segment' ),
				'return_value'       => 'yes',
				'frontend_available' => true,
				'dependency'         => array(
					array(
						'field'    => $this->get_option_name( 'toggle' ),
						'operator' => '==',
						'value'    => 'yes',
					),
				),
				'render_type'        => 'ui',
			),
			$this->get_option_name( 'rotate_x_start' )     => array(
				'title'              => esc_html__( 'Start', 'profecient-essential' ),
				'type'               => 'slider',
				'segment'            => $this->get_option_name( 'segment' ),
				'default_unit'       => 'px',
				'default'            => 0,
				'frontend_available' => true,
				'responsive'         => true,
				'options'            => array(
					'min'  => -360,
					'max'  => 360,
					'step' => 1,
				),
				'dependency'         => array(
					array(
						'field'    => $this->get_option_name( 'rotate_x_popover_start' ),
						'operator' => '==',
						'value'    => 'yes',
					),
				),
				'render_type'        => 'ui',
			),
			$this->get_option_name( 'rotate_x_end' )       => array(
				'title'              => esc_html__( 'End', 'profecient-essential' ),
				'type'               => 'slider',
				'segment'            => $this->get_option_name( 'segment' ),
				'default_unit'       => 'px',
				'default'            => 0,
				'frontend_available' => true,
				'responsive'         => true,
				'options'            => array(
					'min'  => -360,
					'max'  => 360,
					'step' => 1,
				),
				'dependency'         => array(
					array(
						'field'    => $this->get_option_name( 'rotate_x_popover_start' ),
						'operator' => '==',
						'value'    => 'yes',
					),
				),
				'render_type'        => 'ui',
			),
			$this->get_option_name( 'rotate_x_css_unit' )  => array(
				'title'              => esc_html__( 'CSS Unit', 'profecient-essential' ),
				'description'        => esc_html__( 'Enter a CSS Unit for Start and End. Ex: deg, grad, rad, turn.', 'profecient-essential' ),
				'type'               => 'text',
				'segment'            => $this->get_option_name( 'segment' ),
				'default'            => 'deg',
				'frontend_available' => true,
				'dependency'         => array(
					array(
						'field'    => $this->get_option_name( 'rotate_x_popover_start' ),
						'operator' => '==',
						'value'    => 'yes',
					),
				),
				'render_type'        => 'ui',
			),
			$this->get_option_name( 'rotate_x_animation_viewport' ) => array(
				'title'              => esc_html__( 'Viewport', 'profecient-essential' ),
				'type'               => 'slider',
				'segment'            => $this->get_option_name( 'segment' ),
				'default_unit'       => '%',
				'default_sizes'      => array(
					'start' => 0,
					'end'   => 100,
				),
				'labels'             => array(
					__( 'Bottom', 'profecient-essential' ),
					__( 'Top', 'profecient-essential' ),
				),
				'scales'             => 1,
				'handles'            => 'range',
				'frontend_available' => true,
				'options'            => array(
					'min'  => 0,
					'max'  => 100,
					'step' => 1,
				),
				'dependency'         => array(
					array(
						'field'    => $this->get_option_name( 'rotate_x_popover_start' ),
						'operator' => '==',
						'value'    => 'yes',
					),
				),
				'render_type'        => 'ui',
			),
			$this->get_option_name( 'rotate_x_relative_animation_viewport' ) => array(
				'title'              => esc_html__( 'Relative Viewport', 'profecient-essential' ),
				'type'               => 'select',
				'segment'            => $this->get_option_name( 'segment' ),
				'label_block'        => true,
				'default'            => 'element',
				'options'            => array(
					'element' => esc_html__( 'Element', 'profecient-essential' ),
					'page'    => esc_html__( 'Page', 'profecient-essential' ),
				),
				'frontend_available' => true,
				'render_type'        => 'ui',
				'dependency'         => array(
					array(
						'field'    => $this->get_option_name( 'rotate_x_popover_start' ),
						'operator' => '==',
						'value'    => 'yes',
					),
				),
			),
			$this->get_option_name( 'rotate_x_popover_end' ) => array(
				'segment' => $this->get_option_name( 'segment' ),
				'type'    => 'control_popover_end',
			),
			// Rotate Y
			$this->get_option_name( 'rotate_y_popover_start' ) => array(
				'title'              => esc_html__( 'Vertical Rotate(Y)', 'profecient-essential' ),
				'type'               => 'control_popover_start',
				'segment'            => $this->get_option_name( 'segment' ),
				'return_value'       => 'yes',
				'frontend_available' => true,
				'dependency'         => array(
					array(
						'field'    => $this->get_option_name( 'toggle' ),
						'operator' => '==',
						'value'    => 'yes',
					),
				),
				'render_type'        => 'ui',
			),
			$this->get_option_name( 'rotate_y_start' )     => array(
				'title'              => esc_html__( 'Start', 'profecient-essential' ),
				'type'               => 'slider',
				'segment'            => $this->get_option_name( 'segment' ),
				'default_unit'       => 'px',
				'default'            => 0,
				'frontend_available' => true,
				'responsive'         => true,
				'options'            => array(
					'min'  => -360,
					'max'  => 360,
					'step' => 1,
				),
				'dependency'         => array(
					array(
						'field'    => $this->get_option_name( 'rotate_y_popover_start' ),
						'operator' => '==',
						'value'    => 'yes',
					),
				),
				'render_type'        => 'ui',
			),
			$this->get_option_name( 'rotate_y_end' )       => array(
				'title'              => esc_html__( 'End', 'profecient-essential' ),
				'type'               => 'slider',
				'segment'            => $this->get_option_name( 'segment' ),
				'default_unit'       => 'px',
				'default'            => 0,
				'frontend_available' => true,
				'responsive'         => true,
				'options'            => array(
					'min'  => -360,
					'max'  => 360,
					'step' => 1,
				),
				'dependency'         => array(
					array(
						'field'    => $this->get_option_name( 'rotate_y_popover_start' ),
						'operator' => '==',
						'value'    => 'yes',
					),
				),
				'render_type'        => 'ui',
			),
			$this->get_option_name( 'rotate_y_css_unit' )  => array(
				'title'              => esc_html__( 'CSS Unit', 'profecient-essential' ),
				'description'        => esc_html__( 'Enter a CSS Unit for Start and End. Ex: deg, grad, rad, turn.', 'profecient-essential' ),
				'type'               => 'text',
				'segment'            => $this->get_option_name( 'segment' ),
				'default'            => 'deg',
				'frontend_available' => true,
				'dependency'         => array(
					array(
						'field'    => $this->get_option_name( 'rotate_y_popover_start' ),
						'operator' => '==',
						'value'    => 'yes',
					),
				),
				'render_type'        => 'ui',
			),
			$this->get_option_name( 'rotate_y_animation_viewport' ) => array(
				'title'              => esc_html__( 'Viewport', 'profecient-essential' ),
				'type'               => 'slider',
				'segment'            => $this->get_option_name( 'segment' ),
				'default_unit'       => '%',
				'default_sizes'      => array(
					'start' => 0,
					'end'   => 100,
				),
				'labels'             => array(
					__( 'Bottom', 'profecient-essential' ),
					__( 'Top', 'profecient-essential' ),
				),
				'scales'             => 1,
				'handles'            => 'range',
				'frontend_available' => true,
				'options'            => array(
					'min'  => 0,
					'max'  => 100,
					'step' => 1,
				),
				'dependency'         => array(
					array(
						'field'    => $this->get_option_name( 'rotate_y_popover_start' ),
						'operator' => '==',
						'value'    => 'yes',
					),
				),
				'render_type'        => 'ui',
			),
			$this->get_option_name( 'rotate_y_relative_animation_viewport' ) => array(
				'title'              => esc_html__( 'Relative Viewport', 'profecient-essential' ),
				'type'               => 'select',
				'segment'            => $this->get_option_name( 'segment' ),
				'label_block'        => true,
				'default'            => 'element',
				'options'            => array(
					'element' => esc_html__( 'Element', 'profecient-essential' ),
					'page'    => esc_html__( 'Page', 'profecient-essential' ),
				),
				'frontend_available' => true,
				'render_type'        => 'ui',
				'dependency'         => array(
					array(
						'field'    => $this->get_option_name( 'rotate_y_popover_start' ),
						'operator' => '==',
						'value'    => 'yes',
					),
				),
			),
			$this->get_option_name( 'rotate_y_popover_end' ) => array(
				'segment' => $this->get_option_name( 'segment' ),
				'type'    => 'control_popover_end',
			),
			// Scale
			$this->get_option_name( 'scale_popover_start' ) => array(
				'title'              => esc_html__( 'Scale', 'profecient-essential' ),
				'type'               => 'control_popover_start',
				'segment'            => $this->get_option_name( 'segment' ),
				'return_value'       => 'yes',
				'frontend_available' => true,
				'dependency'         => array(
					array(
						'field'    => $this->get_option_name( 'toggle' ),
						'operator' => '==',
						'value'    => 'yes',
					),
				),
				'render_type'        => 'ui',
			),
			$this->get_option_name( 'scale_start' )        => array(
				'title'              => esc_html__( 'Start', 'profecient-essential' ),
				'type'               => 'slider',
				'segment'            => $this->get_option_name( 'segment' ),
				'default_unit'       => 'px',
				'default'            => 1,
				'frontend_available' => true,
				'responsive'         => true,
				'options'            => array(
					'min'  => -10,
					'max'  => 10,
					'step' => 0.1,
				),
				'dependency'         => array(
					array(
						'field'    => $this->get_option_name( 'scale_popover_start' ),
						'operator' => '==',
						'value'    => 'yes',
					),
				),
				'render_type'        => 'ui',
			),
			$this->get_option_name( 'scale_end' )          => array(
				'title'              => esc_html__( 'End', 'profecient-essential' ),
				'type'               => 'slider',
				'segment'            => $this->get_option_name( 'segment' ),
				'default'            => 1,
				'frontend_available' => true,
				'responsive'         => true,
				'options'            => array(
					'min'  => -10,
					'max'  => 10,
					'step' => 0.1,
				),
				'dependency'         => array(
					array(
						'field'    => $this->get_option_name( 'scale_popover_start' ),
						'operator' => '==',
						'value'    => 'yes',
					),
				),
				'render_type'        => 'ui',
			),
			$this->get_option_name( 'scale_animation_viewport' ) => array(
				'title'              => esc_html__( 'Viewport', 'profecient-essential' ),
				'type'               => 'slider',
				'segment'            => $this->get_option_name( 'segment' ),
				'default_unit'       => '%',
				'default_sizes'      => array(
					'start' => 0,
					'end'   => 100,
				),
				'labels'             => array(
					__( 'Bottom', 'profecient-essential' ),
					__( 'Top', 'profecient-essential' ),
				),
				'scales'             => 1,
				'handles'            => 'range',
				'frontend_available' => true,
				'options'            => array(
					'min'  => 0,
					'max'  => 100,
					'step' => 1,
				),
				'dependency'         => array(
					array(
						'field'    => $this->get_option_name( 'scale_popover_start' ),
						'operator' => '==',
						'value'    => 'yes',
					),
				),
				'render_type'        => 'ui',
			),
			$this->get_option_name( 'scale_relative_animation_viewport' ) => array(
				'title'              => esc_html__( 'Relative Viewport', 'profecient-essential' ),
				'type'               => 'select',
				'segment'            => $this->get_option_name( 'segment' ),
				'label_block'        => true,
				'default'            => 'element',
				'options'            => array(
					'element' => esc_html__( 'Element', 'profecient-essential' ),
					'page'    => esc_html__( 'Page', 'profecient-essential' ),
				),
				'frontend_available' => true,
				'render_type'        => 'ui',
				'dependency'         => array(
					array(
						'field'    => $this->get_option_name( 'scale_popover_start' ),
						'operator' => '==',
						'value'    => 'yes',
					),
				),
			),
			$this->get_option_name( 'scale_popover_end' )  => array(
				'segment' => $this->get_option_name( 'segment' ),
				'type'    => 'control_popover_end',
			),
			// Hue
			$this->get_option_name( 'hue_popover_start' )  => array(
				'title'              => esc_html__( 'Hue', 'profecient-essential' ),
				'type'               => 'control_popover_start',
				'segment'            => $this->get_option_name( 'segment' ),
				'return_value'       => 'yes',
				'frontend_available' => true,
				'dependency'         => array(
					array(
						'field'    => $this->get_option_name( 'toggle' ),
						'operator' => '==',
						'value'    => 'yes',
					),
				),
				'render_type'        => 'ui',
			),
			$this->get_option_name( 'hue_start' )          => array(
				'title'              => esc_html__( 'Start', 'profecient-essential' ),
				'type'               => 'slider',
				'segment'            => $this->get_option_name( 'segment' ),
				'default_unit'       => 'deg',
				'default'            => 0,
				'frontend_available' => true,
				'responsive'         => true,
				'options'            => array(
					'min'  => -360,
					'max'  => 360,
					'step' => 1,
				),
				'dependency'         => array(
					array(
						'field'    => $this->get_option_name( 'hue_popover_start' ),
						'operator' => '==',
						'value'    => 'yes',
					),
				),
				'render_type'        => 'ui',
			),
			$this->get_option_name( 'hue_end' )            => array(
				'title'              => esc_html__( 'End', 'profecient-essential' ),
				'type'               => 'slider',
				'segment'            => $this->get_option_name( 'segment' ),
				'default_unit'       => 'deg',
				'default'            => 0,
				'frontend_available' => true,
				'responsive'         => true,
				'options'            => array(
					'min'  => -360,
					'max'  => 360,
					'step' => 1,
				),
				'dependency'         => array(
					array(
						'field'    => $this->get_option_name( 'hue_popover_start' ),
						'operator' => '==',
						'value'    => 'yes',
					),
				),
				'render_type'        => 'ui',
			),
			$this->get_option_name( 'hue_css_unit' )       => array(
				'title'              => esc_html__( 'CSS Unit', 'profecient-essential' ),
				'description'        => esc_html__( 'Enter a CSS Unit for Start and End. Ex: deg, grad, rad, turn.', 'profecient-essential' ),
				'type'               => 'text',
				'segment'            => $this->get_option_name( 'segment' ),
				'default'            => 'deg',
				'frontend_available' => true,
				'dependency'         => array(
					array(
						'field'    => $this->get_option_name( 'hue_popover_start' ),
						'operator' => '==',
						'value'    => 'yes',
					),
				),
				'render_type'        => 'ui',
			),
			$this->get_option_name( 'hue_animation_viewport' ) => array(
				'title'              => esc_html__( 'Viewport', 'profecient-essential' ),
				'type'               => 'slider',
				'segment'            => $this->get_option_name( 'segment' ),
				'default_unit'       => '%',
				'default_sizes'      => array(
					'start' => 0,
					'end'   => 100,
				),
				'labels'             => array(
					__( 'Bottom', 'profecient-essential' ),
					__( 'Top', 'profecient-essential' ),
				),
				'scales'             => 1,
				'handles'            => 'range',
				'frontend_available' => true,
				'options'            => array(
					'min'  => 0,
					'max'  => 100,
					'step' => 1,
				),
				'dependency'         => array(
					array(
						'field'    => $this->get_option_name( 'hue_popover_start' ),
						'operator' => '==',
						'value'    => 'yes',
					),
				),
				'render_type'        => 'ui',
			),
			$this->get_option_name( 'hue_relative_animation_viewport' ) => array(
				'title'              => esc_html__( 'Relative Viewport', 'profecient-essential' ),
				'type'               => 'select',
				'segment'            => $this->get_option_name( 'segment' ),
				'label_block'        => true,
				'default'            => 'element',
				'options'            => array(
					'element' => esc_html__( 'Element', 'profecient-essential' ),
					'page'    => esc_html__( 'Page', 'profecient-essential' ),
				),
				'frontend_available' => true,
				'render_type'        => 'ui',
				'dependency'         => array(
					array(
						'field'    => $this->get_option_name( 'hue_popover_start' ),
						'operator' => '==',
						'value'    => 'yes',
					),
				),
			),
			$this->get_option_name( 'hue_popover_end' )    => array(
				'segment' => $this->get_option_name( 'segment' ),
				'type'    => 'control_popover_end',
			),
			// Sepia
			$this->get_option_name( 'sepia_popover_start' ) => array(
				'title'              => esc_html__( 'Sepia', 'profecient-essential' ),
				'type'               => 'control_popover_start',
				'segment'            => $this->get_option_name( 'segment' ),
				'return_value'       => 'yes',
				'frontend_available' => true,
				'dependency'         => array(
					array(
						'field'    => $this->get_option_name( 'toggle' ),
						'operator' => '==',
						'value'    => 'yes',
					),
				),
				'render_type'        => 'ui',
			),
			$this->get_option_name( 'sepia_start' )        => array(
				'title'              => esc_html__( 'Start', 'profecient-essential' ),
				'type'               => 'slider',
				'segment'            => $this->get_option_name( 'segment' ),
				'default'            => 0,
				'frontend_available' => true,
				'responsive'         => true,
				'options'            => array(
					'min'  => 0,
					'max'  => 1,
					'step' => 0.1,
				),
				'dependency'         => array(
					array(
						'field'    => $this->get_option_name( 'sepia_popover_start' ),
						'operator' => '==',
						'value'    => 'yes',
					),
				),
				'render_type'        => 'ui',
			),
			$this->get_option_name( 'sepia_end' )          => array(
				'title'              => esc_html__( 'End', 'profecient-essential' ),
				'type'               => 'slider',
				'segment'            => $this->get_option_name( 'segment' ),
				'default'            => 0,
				'frontend_available' => true,
				'responsive'         => true,
				'options'            => array(
					'min'  => 0,
					'max'  => 1,
					'step' => 0.1,
				),
				'dependency'         => array(
					array(
						'field'    => $this->get_option_name( 'sepia_popover_start' ),
						'operator' => '==',
						'value'    => 'yes',
					),
				),
				'render_type'        => 'ui',
			),
			$this->get_option_name( 'sepia_animation_viewport' ) => array(
				'title'              => esc_html__( 'Viewport', 'profecient-essential' ),
				'type'               => 'slider',
				'segment'            => $this->get_option_name( 'segment' ),
				'default_unit'       => '%',
				'default_sizes'      => array(
					'start' => 0,
					'end'   => 100,
				),
				'labels'             => array(
					__( 'Bottom', 'profecient-essential' ),
					__( 'Top', 'profecient-essential' ),
				),
				'scales'             => 1,
				'handles'            => 'range',
				'frontend_available' => true,
				'options'            => array(
					'min'  => 0,
					'max'  => 100,
					'step' => 1,
				),
				'dependency'         => array(
					array(
						'field'    => $this->get_option_name( 'sepia_popover_start' ),
						'operator' => '==',
						'value'    => 'yes',
					),
				),
				'render_type'        => 'ui',
			),
			$this->get_option_name( 'sepia_relative_animation_viewport' ) => array(
				'title'              => esc_html__( 'Relative Viewport', 'profecient-essential' ),
				'type'               => 'select',
				'segment'            => $this->get_option_name( 'segment' ),
				'label_block'        => true,
				'default'            => 'element',
				'options'            => array(
					'element' => esc_html__( 'Element', 'profecient-essential' ),
					'page'    => esc_html__( 'Page', 'profecient-essential' ),
				),
				'frontend_available' => true,
				'render_type'        => 'ui',
				'dependency'         => array(
					array(
						'field'    => $this->get_option_name( 'sepia_popover_start' ),
						'operator' => '==',
						'value'    => 'yes',
					),
				),
			),
			$this->get_option_name( 'sepia_popover_end' )  => array(
				'segment' => $this->get_option_name( 'segment' ),
				'type'    => 'control_popover_end',
			),
			// Transition
			$this->get_option_name( 'transition_popover_start' ) => array(
				'title'              => esc_html__( 'Transition', 'profecient-essential' ),
				'type'               => 'control_popover_start',
				'segment'            => $this->get_option_name( 'segment' ),
				'return_value'       => 'yes',
				'frontend_available' => true,
				'dependency'         => array(
					array(
						'field'    => $this->get_option_name( 'toggle' ),
						'operator' => '==',
						'value'    => 'yes',
					),
					array(
						'field'    => 'profecient_mouse_effects_transition_popover_start!',
						'operator' => '==',
						'value'    => 'yes',
					),
				),
				'render_type'        => 'ui',
			),
			// Transition For
			$this->get_option_name( 'transition_property' ) => array(
				'title'              => esc_html__( 'Property', 'profecient-essential' ),
				'type'               => 'text',
				'label_block'        => false,
				'segment'            => $this->get_option_name( 'segment' ),
				'default'            => 'transform, filter',
				'frontend_available' => true,
				'description'        => esc_html__( 'Enter the CSS property to which the transition effect should be applied. Default is `transform, fitler`.', 'profecient-essential' ),
				'dependency'         => array(
					array(
						'field'    => $this->get_option_name( 'transition_popover_start' ),
						'operator' => '==',
						'value'    => 'yes',
					),
					array(
						'field'    => 'profecient_mouse_effects_transition_popover_start!',
						'operator' => '==',
						'value'    => 'yes',
					),
				),
				'render_type'        => 'ui',
			),
			// Transition Duration
			$this->get_option_name( 'transition_duration' ) => array(
				'title'              => esc_html__( 'Duration', 'profecient-essential' ),
				'type'               => 'text',
				'label_block'        => false,
				'segment'            => $this->get_option_name( 'segment' ),
				'default'            => '400ms',
				'frontend_available' => true,
				'description'        => esc_html__( 'Enter the duration of the transition effect. Default is 400 millisecond.', 'profecient-essential' ),
				'dependency'         => array(
					array(
						'field'    => $this->get_option_name( 'transition_popover_start' ),
						'operator' => '==',
						'value'    => 'yes',
					),
					array(
						'field'    => 'profecient_mouse_effects_transition_popover_start!',
						'operator' => '==',
						'value'    => 'yes',
					),
				),
				'render_type'        => 'ui',
			),
			// Transition Easing
			$this->get_option_name( 'transition_easing' )  => array(
				'title'              => esc_html__( 'Easing', 'profecient-essential' ),
				'type'               => 'text',
				'label_block'        => false,
				'segment'            => $this->get_option_name( 'segment' ),
				'default'            => 'linear',
				'frontend_available' => true,
				'description'        => esc_html__( 'Enter the easing function of the transition effect. Default is linear. If you want to use cubic-bezier, please enter the cubic-bezier value. For example, cubic-bezier(0.42, 0, 0.58, 1) or Go to the website below and create a cubic-bezier value.', 'profecient-essential' ) . '<br><a href="https://cubic-bezier.com/" target="_blank">https://cubic-bezier.com/</a>',
				'dependency'         => array(
					array(
						'field'    => $this->get_option_name( 'transition_popover_start' ),
						'operator' => '==',
						'value'    => 'yes',
					),
					array(
						'field'    => 'profecient_mouse_effects_transition_popover_start!',
						'operator' => '==',
						'value'    => 'yes',
					),
				),
				'render_type'        => 'ui',
			),
			$this->get_option_name( 'transition_popover_end' ) => array(
				'segment' => $this->get_option_name( 'segment' ),
				'type'    => 'control_popover_end',
			),
		);
		/**
		 * Filters the location of the option.
		 *
		 * @param array $location Location of the option. Default is array( 'elementor/element/wp-page/document_settings/after_section_end' ).
		 * @param string $id ID of the option. Default is $this->id.
		 */
		$this->controls['location'] = apply_filters( $this->get_option_name( 'control_location' ), $location, $this->id );

		/**
		 * Filters the show location of the option.
		 *
		 * @param array $show_location Show location of the option. Default is array( 'Core\DocumentTypes\Page' ).
		 * @param string $id ID of the option. Default is $this->id.
		 */
		$this->controls['show_location'] = apply_filters( $this->get_option_name( 'control_show_location' ), $show_location, $this->id );

		/**
		 * Filters the segment of the option.
		 *
		 * @param array $segment Segment of the option. Default is array( $this->get_option_name('segment') => array( 'name' => '<i class="profecient-option-additional"></i> ' . esc_html__( 'Sample Option', 'profecient-essential' ), 'priority' => 10 ) ).
		 * @param string $id ID of the option. Default is $this->id.
		 */
		$this->controls['segment'] = apply_filters( $this->get_option_name( 'control_segment' ), $segment, $this->id );

		/**
		 * Filters the options of the option.
		 *
		 * @param array $options Options of the option. Default is array( $this->get_option_name('toggle') => array( 'title' => esc_html__( 'Enable Sample Option', 'profecient-essential' ), 'type' => 'checkbox', 'default' => false, 'segment' => $this->get_option_name('segment'), 'return_value' => 'yes', 'prefix_class' => 'profecient-sample-option-' ) ).
		 * @param string $id ID of the option. Default is $this->id.
		 */
		$this->controls['options'] = apply_filters( $this->get_option_name( 'control_options' ), $options, $this->id );
	}

	/**
	 * Register styles
	 */
	public function register_styles() {
	}

	/**
	 * Enqueue styles
	 */
	public function enqueue_styles() {
	}

	/**
	 * Enqueue global styles
	 */
	public function enqueue_global_styles() {
	}

	/**
	 * Should style enqueue
	 */
	public function should_style_enqueue() {
	}

	/**
	 * Register scripts
	 */
	public function register_scripts() {
		wp_register_script( 'profecient-parallax', PROFECIENT_ESSENTIAL_URL . '/assets/js/extra/parallax-effect.js', array( 'elementor-frontend', 'jquery' ), PROFECIENT_ESSENTIAL_VERSION, true );
	}

	/**
	 * Enqueue scripts
	 */
	public function enqueue_scripts() {
		wp_enqueue_script( 'profecient-parallax' );
	}

	/**
	 * Enqueue global scripts
	 */
	public function enqueue_global_scripts() {
	}

	/**
	 * Should script enqueue
	 */
	public function should_script_enqueue() {
	}

	/**
	 * After common render.
	 *
	 * @param $element \Elementor\Element_Base Element.
	 */
	public function after_common_render( $element ) {
		$this->after_render( $element );
	}

	/**
	 * After section render.
	 *
	 * @param $element \Elementor\Element_Base Element.
	 */
	public function after_section_render( $element ) {
		$this->after_render( $element );
	}

	/**
	 * After column render.
	 *
	 * @param $element \Elementor\Element_Base Element.
	 */
	public function after_column_render( $element ) {
		$this->after_render( $element );
	}

	/**
	 * After container render.
	 *
	 * @param $element \Elementor\Element_Base Element.
	 */
	public function after_container_render( $element ) {
		$this->after_render( $element );
	}

	/**
	 * After render.
	 *
	 * @param $element \Elementor\Element_Base Element.
	 */
	public function after_render( $element ) {
		if ( $element->get_settings( $this->get_option_name( 'toggle' ) ) === 'yes' ) {
			wp_enqueue_script( 'profecient-parallax' );
		}
	}
}
