<?php
namespace Profecient\Essential\JKit\Extra_Option\Options\Popup_Template;

use Profecient\Essential\JKit\Extra_Option\Options\Abstract_Option;
use \Elementor\Controls_Manager;

/**
 * Class Module
 */
class Module extends Abstract_Option {

	public function add_action( $register = true ) {
		$this->register();
		parent::add_action( false );
	}

	/**
	 * Register
	 */
	public function register() {
		if ( is_array( $this->controls['location'] ) ) {
			foreach ( $this->controls['location'] as $location ) {
				add_action( $location, array( $this, 'register_control' ), 10, 2 );
			}
		} else {
			add_action( $this->controls['location'], array( $this, 'register_control' ), 10, 3 );
		}
	}

	/**
	 * Register control
	 *
	 * @param \Elementor\Widget_Common|\Elementor\Element_Column|\Elementor\Element_Section Elementor $element element.
	 * @param  array                                                                                   $args Arguments.
	 *
	 * @return void
	 */
	public function register_control( $element, $args ) {
		$current_class = get_class( $element );
		if ( isset( $this->controls['show_location'] ) ) {
			$show_location = $this->controls['show_location'];
			$current_class = str_replace( 'Elementor\\', '', $current_class );
			if ( ! in_array( $current_class, $show_location, true ) ) {
				return;
			}
		}
		foreach ( $this->controls['segment'] as $id => $segment ) {
			if ( isset( $segment['tab'] ) ) {
				$section = array(
					'label'     => $segment['name'],
					'tab'       => $segment['tab'],
					'condition' => isset( $segment['dependency'] ) ? $this->parse_dependency_option( $segment['dependency'] ) : '',
				);
			} else {
				$section = array(
					'label'     => $segment['name'],
					'tab'       => Controls_Manager::TAB_SETTINGS,
					'condition' => isset( $segment['dependency'] ) ? $this->parse_dependency_option( $segment['dependency'] ) : '',
				);
			}
			$options = $this->handle_replace_selector( $this->controls['options'], $current_class );
			$element->start_controls_section( $id, $section );
			$this->parse_control_option( $element, $options, $id );
			$element->end_controls_section();
		}
	}

	private function handle_replace_selector( $options, $current_class ) {
		if ( 'Core\\DocumentTypes\\Page' === $current_class ) {
			foreach ( $options as $option_name => $option ) {
				if ( isset( $option['selectors'] ) ) {
					if ( is_array( $option['selectors'] ) ) {
						foreach ( $option['selectors'] as $selector => $value ) {
							if ( is_array( $value ) ) {
								foreach ( $value as $key => $val ) {
									unset( $options[ $option_name ]['selectors'][ $selector ][ $key ] );
									$key = str_replace( '{{ID}}', 'global', $key );
									$options[ $option_name ]['selectors'][ $selector ][ $key ] = $val;
								}
							} elseif ( is_string( $value ) ) {
								$key                 = str_replace( '{{ID}}', 'global', $value );
								$option['selectors'] = $key;
							}
						}
					} elseif ( is_string( $option['selectors'] ) ) {
						$key                 = str_replace( '{{ID}}', 'global', $option['selectors'] );
						$option['selectors'] = $key;
					}
				}
			}
		}
		return $options;
	}

	/**
	 * Set Options
	 */
	public function set_options() {
		$location      = array(
			'elementor/element/page/document_settings/after_section_end',
		);
		$show_location = array(
			'Modules\Library\Documents\Page',
		);
		$segment       = array(
			$this->get_option_name( 'settings_segment' )   => array(
				'name'     => '<i class="profecient-option-additional"></i> ' . esc_html__( 'Popup - Settings', 'profecient-essential' ),
				'priority' => 10,
			),
			$this->get_option_name( 'trigger_segment' )    => array(
				'name'     => '<i class="profecient-option-additional"></i> ' . esc_html__( 'Popup - Trigger Settings', 'profecient-essential' ),
				'priority' => 20,
			),
			// $this->get_option_name( 'advanced_segment' )   => array(
			// 'name'     => '<i class="profecient-option-additional"></i> ' . esc_html__( 'Popup - Advanced Settings', 'profecient-essential' ),
			// 'priority' => 30,
			// ),
			$this->get_option_name( 'content_style' )      => array(
				'name'     => '<i class="profecient-option-additional"></i> ' . esc_html__( 'Popup - Content', 'profecient-essential' ),
				'priority' => 10,
				'tab'      => Controls_Manager::TAB_STYLE,
			),
			$this->get_option_name( 'overlay_style' )      => array(
				'name'     => '<i class="profecient-option-additional"></i> ' . esc_html__( 'Popup - Overlay', 'profecient-essential' ),
				'priority' => 10,
				'tab'      => Controls_Manager::TAB_STYLE,
			),
			$this->get_option_name( 'close_button_style' ) => array(
				'name'     => '<i class="profecient-option-additional"></i> ' . esc_html__( 'Popup - Close Button', 'profecient-essential' ),
				'priority' => 20,
				'tab'      => Controls_Manager::TAB_STYLE,
			),
		);
		$options = array(
			$this->get_option_name( 'entrance_animation' ) => array(
				'title'              => esc_html__( 'Entrance Animation', 'profecient-essential' ),
				'type'               => 'entranceanimation',
				'segment'            => $this->get_option_name( 'settings_segment' ),
				'frontend_available' => true,
			),
			$this->get_option_name( 'exit_animation' )     => array(
				'title'              => esc_html__( 'Exit Animation', 'profecient-essential' ),
				'type'               => 'exitanimation',
				'segment'            => $this->get_option_name( 'settings_segment' ),
				'frontend_available' => true,
			),
			$this->get_option_name( 'animation_duration' ) => array(
				'title'              => esc_html__( 'Animation Duration', 'profecient-essential' ),
				'type'               => 'slider',
				'segment'            => $this->get_option_name( 'settings_segment' ),
				'options'            => array(
					'min'  => 0,
					'max'  => 10,
					'step' => 0.1,
				),
				'selectors'          => array(
					'custom' => array(
						'.profecient-popup .popup-wrapper .popup-content' => 'animation-duration: {{SIZE}}s;',
					),
				),
				'frontend_available' => true,
			),
			$this->get_option_name( 'on_page_load' )       => array(
				'title'              => esc_html__( 'On Page Load', 'profecient-essential' ),
				'type'               => 'checkbox',
				'default'            => false,
				'segment'            => $this->get_option_name( 'trigger_segment' ),
				'frontend_available' => true,
			),
			$this->get_option_name( 'on_page_load_within_sec' ) => array(
				'title'              => esc_html__( 'Within (Sec)', 'profecient-essential' ),
				'type'               => 'number',
				'segment'            => $this->get_option_name( 'trigger_segment' ),
				'frontend_available' => true,
				'dependency'         => array(
					array(
						'field'    => $this->get_option_name( 'on_page_load' ),
						'operator' => '==',
						'value'    => true,
					),
				),
			),
			$this->get_option_name( 'on_scroll' )          => array(
				'title'              => esc_html__( 'On Scroll', 'profecient-essential' ),
				'type'               => 'checkbox',
				'default'            => false,
				'segment'            => $this->get_option_name( 'trigger_segment' ),
				'frontend_available' => true,
				'separator'          => 'before',
			),
			$this->get_option_name( 'on_scroll_direction' ) => array(
				'title'              => esc_html__( 'Direction', 'profecient-essential' ),
				'type'               => 'select',
				'default'            => 'down',
				'frontend_available' => true,
				'options'            => array(
					'up'   => esc_html__( 'Up', 'profecient-essential' ),
					'down' => esc_html__( 'Down', 'profecient-essential' ),
				),
				'segment'            => $this->get_option_name( 'trigger_segment' ),
				'dependency'         => array(
					array(
						'field'    => $this->get_option_name( 'on_scroll' ),
						'operator' => '==',
						'value'    => true,
					),
				),
			),
			$this->get_option_name( 'on_scroll_within_percent' ) => array(
				'title'              => esc_html__( 'Within (%)', 'profecient-essential' ),
				'type'               => 'number',
				'segment'            => $this->get_option_name( 'trigger_segment' ),
				'frontend_available' => true,
				'dependency'         => array(
					array(
						'field'    => $this->get_option_name( 'on_scroll' ),
						'operator' => '==',
						'value'    => true,
					),
					array(
						'field'    => $this->get_option_name( 'on_scroll_direction' ),
						'operator' => '==',
						'value'    => 'down',
					),
				),
			),
			$this->get_option_name( 'on_scroll_to_element' ) => array(
				'title'              => esc_html__( 'On Scroll To Element', 'profecient-essential' ),
				'type'               => 'checkbox',
				'default'            => false,
				'segment'            => $this->get_option_name( 'trigger_segment' ),
				'frontend_available' => true,
				'separator'          => 'before',
			),
			$this->get_option_name( 'on_scroll_to_element_selector' ) => array(
				'title'              => esc_html__( 'Element Selector', 'profecient-essential' ),
				'type'               => 'text',
				'frontend_available' => true,
				'segment'            => $this->get_option_name( 'trigger_segment' ),
				'placeholder'        => '.selectors',
				'description'        => esc_html__( 'Enter the CSS selectors to determine the Element.', 'profecient-essential' ),
				'dependency'         => array(
					array(
						'field'    => $this->get_option_name( 'on_scroll_to_element' ),
						'operator' => '==',
						'value'    => true,
					),
				),
			),
			$this->get_option_name( 'on_click' )           => array(
				'title'              => esc_html__( 'On Click', 'profecient-essential' ),
				'type'               => 'checkbox',
				'default'            => false,
				'segment'            => $this->get_option_name( 'trigger_segment' ),
				'frontend_available' => true,
				'separator'          => 'before',
			),
			$this->get_option_name( 'on_click_times' )     => array(
				'title'              => esc_html__( 'Times', 'profecient-essential' ),
				'type'               => 'number',
				'segment'            => $this->get_option_name( 'trigger_segment' ),
				'options'            => array(
					'min' => 0,
				),
				'frontend_available' => true,
				'dependency'         => array(
					array(
						'field'    => $this->get_option_name( 'on_click' ),
						'operator' => '==',
						'value'    => true,
					),
				),
			),
			$this->get_option_name( 'on_click_element' )   => array(
				'title'              => esc_html__( 'Element Selector', 'profecient-essential' ),
				'type'               => 'text',
				'frontend_available' => true,
				'segment'            => $this->get_option_name( 'trigger_segment' ),
				'placeholder'        => 'body',
				'description'        => esc_html__( 'Enter the CSS selectors to determine the Element. Default is whole page.', 'profecient-essential' ),
				'dependency'         => array(
					array(
						'field'    => $this->get_option_name( 'on_click' ),
						'operator' => '==',
						'value'    => true,
					),
				),
			),
			$this->get_option_name( 'after_inactivity' )   => array(
				'title'              => esc_html__( 'After Inactivity', 'profecient-essential' ),
				'type'               => 'checkbox',
				'default'            => false,
				'segment'            => $this->get_option_name( 'trigger_segment' ),
				'frontend_available' => true,
				'separator'          => 'before',
			),
			$this->get_option_name( 'after_inactivity_within_sec' ) => array(
				'title'              => esc_html__( 'Within (Sec)', 'profecient-essential' ),
				'type'               => 'number',
				'segment'            => $this->get_option_name( 'trigger_segment' ),
				'frontend_available' => true,
				'dependency'         => array(
					array(
						'field'    => $this->get_option_name( 'after_inactivity' ),
						'operator' => '==',
						'value'    => true,
					),
				),
			),
			$this->get_option_name( 'on_page_exit_intent' ) => array(
				'title'              => esc_html__( 'On Page Exit Intent', 'profecient-essential' ),
				'type'               => 'checkbox',
				'default'            => false,
				'segment'            => $this->get_option_name( 'trigger_segment' ),
				'frontend_available' => true,
				'separator'          => 'before',
			),
			// Wrapper Style.
			$this->get_option_name( 'st_content_width' )   => array(
				'type'       => 'slider',
				'title'      => esc_html__( 'Width', 'profecient-essential' ),
				'segment'    => $this->get_option_name( 'content_style' ),
				'responsive' => true,
				'units'      => array( 'px', '%', 'em' ),
				'options'    => array(
					'min'  => 0,
					'max'  => 1000,
					'step' => 1,
				),
				'selectors'  => array(
					'custom' => array(
						'.profecient-popup .popup-wrapper .popup-content' => 'width: {{SIZE}}{{UNIT}};',
					),
				),
			),
			$this->get_option_name( 'st_content_height' )  => array(
				'type'       => 'slider',
				'title'      => esc_html__( 'Height', 'profecient-essential' ),
				'segment'    => $this->get_option_name( 'content_style' ),
				'responsive' => true,
				'units'      => array( 'px', '%', 'em', 'custom' ),
				'options'    => array(
					'min'  => 0,
					'max'  => 1000,
					'step' => 1,
				),
				'selectors'  => array(
					'custom' => array(
						'.profecient-popup .popup-wrapper .popup-content' => 'height: {{SIZE}}{{UNIT}};',
					),
				),
			),
			$this->get_option_name( 'st_content_position' ) => array(
				'type'      => 'heading',
				'title'     => esc_html__( 'Position', 'profecient-essential' ),
				'segment'   => $this->get_option_name( 'content_style' ),
				'separator' => 'before',
			),
			$this->get_option_name( 'st_content_position_horizontal' ) => array(
				'type'       => 'radio',
				'title'      => esc_html__( 'Horizontal Orientation', 'profecient-essential' ),
				'segment'    => $this->get_option_name( 'content_style' ),
				'responsive' => true,
				'options'    => array(
					'flex-start' => array(
						'title' => esc_html__( 'Start', 'profecient-essential' ),
						'icon'  => 'eicon-h-align-left',
					),
					'center'     => array(
						'title' => esc_html__( 'Center', 'profecient-essential' ),
						'icon'  => 'eicon-h-align-center',
					),
					'flex-end'   => array(
						'title' => esc_html__( 'End', 'profecient-essential' ),
						'icon'  => 'eicon-h-align-right',
					),
				),
				'selectors'  => array(
					'custom' => array(
						'.profecient-popup .popup-wrapper' => 'justify-content: {{VALUE}};',
					),
				),
			),
			$this->get_option_name( 'st_content_position_vertical' ) => array(
				'type'       => 'radio',
				'title'      => esc_html__( 'Vertical Orientation', 'profecient-essential' ),
				'segment'    => $this->get_option_name( 'content_style' ),
				'responsive' => true,
				'options'    => array(
					'flex-start' => array(
						'title' => esc_html__( 'Start', 'profecient-essential' ),
						'icon'  => 'eicon-v-align-top',
					),
					'center'     => array(
						'title' => esc_html__( 'Center', 'profecient-essential' ),
						'icon'  => 'eicon-v-align-middle',
					),
					'flex-end'   => array(
						'title' => esc_html__( 'End', 'profecient-essential' ),
						'icon'  => 'eicon-v-align-bottom',
					),
				),
				'selectors'  => array(
					'custom' => array(
						'.profecient-popup .popup-wrapper' => 'align-items: {{VALUE}};',
					),
				),
			),
			$this->get_option_name( 'st_content_position_content' ) => array(
				'type'      => 'heading',
				'title'     => esc_html__( 'Position Content', 'profecient-essential' ),
				'segment'   => $this->get_option_name( 'content_style' ),
				'separator' => 'before',
			),
			$this->get_option_name( 'st_content_position_content_horizontal' ) => array(
				'type'       => 'radio',
				'title'      => esc_html__( 'Horizontal Orientation', 'profecient-essential' ),
				'segment'    => $this->get_option_name( 'content_style' ),
				'responsive' => true,
				'options'    => array(
					'flex-start' => array(
						'title' => esc_html__( 'Start', 'profecient-essential' ),
						'icon'  => 'eicon-h-align-left',
					),
					'center'     => array(
						'title' => esc_html__( 'Center', 'profecient-essential' ),
						'icon'  => 'eicon-h-align-center',
					),
					'flex-end'   => array(
						'title' => esc_html__( 'End', 'profecient-essential' ),
						'icon'  => 'eicon-h-align-right',
					),
				),
				'selectors'  => array(
					'custom' => array(
						'.profecient-popup .popup-wrapper .popup-content' => 'justify-content: {{VALUE}};',
					),
				),
			),
			$this->get_option_name( 'st_content_position_content_vertical' ) => array(
				'type'       => 'radio',
				'title'      => esc_html__( 'Vertical Orientation', 'profecient-essential' ),
				'segment'    => $this->get_option_name( 'content_style' ),
				'responsive' => true,
				'options'    => array(
					'flex-start' => array(
						'title' => esc_html__( 'Start', 'profecient-essential' ),
						'icon'  => 'eicon-v-align-top',
					),
					'center'     => array(
						'title' => esc_html__( 'Center', 'profecient-essential' ),
						'icon'  => 'eicon-v-align-middle',
					),
					'flex-end'   => array(
						'title' => esc_html__( 'End', 'profecient-essential' ),
						'icon'  => 'eicon-v-align-bottom',
					),
				),
				'selectors'  => array(
					'custom' => array(
						'.profecient-popup .popup-wrapper .popup-content' => 'align-items: {{VALUE}};',
					),
				),
			),
			$this->get_option_name( 'st_content_margin' )  => array(
				'title'     => esc_html__( 'Margin', 'profecient-essential' ),
				'type'      => 'dimension',
				'segment'   => $this->get_option_name( 'content_style' ),
				'units'     => array( 'px', '%', 'em' ),
				'selectors' => array(
					'custom' => array(
						'.profecient-popup .popup-wrapper .popup-content' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					),
				),
				'separator' => 'before',
			),
			$this->get_option_name( 'st_content_padding' ) => array(
				'title'     => esc_html__( 'Padding', 'profecient-essential' ),
				'type'      => 'dimension',
				'segment'   => $this->get_option_name( 'content_style' ),
				'units'     => array( 'px', '%', 'em' ),
				'selectors' => array(
					'custom' => array(
						'.profecient-popup .popup-wrapper .popup-content' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					),
				),
			),
			$this->get_option_name( 'st_content_background' ) => array(
				'title'     => esc_html__( 'Background Content', 'profecient-essential' ),
				'type'      => 'background',
				'segment'   => $this->get_option_name( 'content_style' ),
				'options'   => array(
					'classic',
					'gradient',
				),
				'selectors' => array(
					'custom' => '.profecient-popup .popup-content',
				),
			),
			$this->get_option_name( 'st_content_border' )  => array(
				'title'     => esc_html__( 'Border', 'profecient-essential' ),
				'type'      => 'border',
				'segment'   => $this->get_option_name( 'content_style' ),
				'selectors' => array(
					'custom' => '.profecient-popup .popup-content',
				),
			),
			$this->get_option_name( 'st_content_border_radius' ) => array(
				'title'     => esc_html__( 'Border Radius', 'profecient-essential' ),
				'type'      => 'dimension',
				'segment'   => $this->get_option_name( 'content_style' ),
				'units'     => array( 'px', '%', 'em' ),
				'selectors' => array(
					'custom' => array(
						'.profecient-popup .popup-wrapper .popup-content' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					),
				),
			),
			// Overlay Style
			$this->get_option_name( 'st_overlay_background' ) => array(
				'title'     => esc_html__( 'Background Overlay', 'profecient-essential' ),
				'type'      => 'background',
				'segment'   => $this->get_option_name( 'overlay_style' ),
				'options'   => array(
					'classic',
					'gradient',
				),
				'selectors' => array(
					'custom' => '.profecient-popup',
				),
			),
			$this->get_option_name( 'st_overlay_backdrop_filter' ) => array(
				'type'      => 'backdrop_filter',
				'title'     => esc_html__( 'Backdrop Filter', 'profecient-essential' ),
				'segment'   => $this->get_option_name( 'overlay_style' ),
				'selectors' => array(
					'custom' => '.profecient-popup',
				),
			),
			// Button Close Style.
			$this->get_option_name( 'st_close_button_text' ) => array(
				'title'       => esc_html__( 'Text', 'profecient-essential' ),
				'type'        => 'text',
				'segment'     => $this->get_option_name( 'close_button_style' ),
				'render_type' => 'template',
			),
			$this->get_option_name( 'st_close_button_typography' ) => array(
				'type'      => 'typography',
				'title'     => esc_html__( 'Typography', 'profecient-essential' ),
				'segment'   => $this->get_option_name( 'close_button_style' ),
				'selectors' => array(
					'custom' => '.profecient-popup .popup-wrapper .popup-close',
				),
			),
			$this->get_option_name( 'st_close_button_icon' ) => array(
				'type'        => 'iconpicker',
				'title'       => esc_html__( 'Icon', 'profecient-essential' ),
				'segment'     => $this->get_option_name( 'close_button_style' ),
				'default'     => array(
					'value'   => 'jki jki-x-circle-line',
					'library' => 'jkiticon',
				),
				'render_type' => 'template',
			),
			$this->get_option_name( 'st_close_button_icon_size' ) => array(
				'type'       => 'slider',
				'title'      => esc_html__( 'Icon Size', 'profecient-essential' ),
				'segment'    => $this->get_option_name( 'close_button_style' ),
				'options'    => array(
					'min'  => 0,
					'max'  => 300,
					'step' => 1,
				),
				'responsive' => true,
				'selectors'  => array(
					'custom' => array(
						'.profecient-popup .popup-wrapper .popup-close > i'   => 'font-size: {{SIZE}}{{UNIT}};',
						'.profecient-popup .popup-wrapper .popup-close > svg' => 'width: {{SIZE}}{{UNIT}};',
					),
				),
			),
			$this->get_option_name( 'st_close_button_icon_position' ) => array(
				'type'       => 'radio',
				'title'      => esc_html__( 'Icon Position', 'profecient-essential' ),
				'segment'    => $this->get_option_name( 'close_button_style' ),
				'options'    => array(
					'row'            => array(
						'title' => esc_html__( 'Left', 'profecient-essential' ),
						'icon'  => 'eicon-h-align-left',
					),
					'column'         => array(
						'title' => esc_html__( 'Top', 'profecient-essential' ),
						'icon'  => 'eicon-v-align-top',
					),
					'row-reverse'    => array(
						'title' => esc_html__( 'right', 'profecient-essential' ),
						'icon'  => 'eicon-h-align-right',
					),
					'column-reverse' => array(
						'title' => esc_html__( 'Bottom', 'profecient-essential' ),
						'icon'  => 'eicon-v-align-bottom',
					),
				),
				'responsive' => true,
				'selectors'  => array(
					'custom' => array(
						'.profecient-popup .popup-wrapper .popup-close' => 'flex-direction: {{VALUE}};',
					),
				),
			),
			$this->get_option_name( 'st_close_button_position' ) => array(
				'type'               => 'select',
				'title'              => esc_html__( 'Direction', 'profecient-essential' ),
				'segment'            => $this->get_option_name( 'close_button_style' ),
				'default'            => 'inside',
				'frontend_available' => true,
				'options'            => array(
					'inside'  => esc_html__( 'Inside', 'profecient-essential' ),
					'outside' => esc_html__( 'Outside', 'profecient-essential' ),
				),
				'render_type'        => 'template',
				'separator'          => 'before',
			),
			$this->get_option_name( 'st_close_button_position_horizontal_orientation' ) => array(
				'type'    => 'radio',
				'title'   => esc_html__( 'Horizontal Orientation', 'profecient-essential' ),
				'segment' => $this->get_option_name( 'close_button_style' ),
				'options' => array(
					'left'  => array(
						'title' => esc_html__( 'Left', 'profecient-essential' ),
						'icon'  => 'eicon-h-align-left',
					),
					'right' => array(
						'title' => esc_html__( 'Right', 'profecient-essential' ),
						'icon'  => 'eicon-h-align-right',
					),
				),
				'default' => 'right',
				'toggle'  => false,
			),
			$this->get_option_name( 'st_close_button_position_horizontal_offset' ) => array(
				'type'       => 'slider',
				'title'      => esc_html__( 'Offset', 'profecient-essential' ),
				'segment'    => $this->get_option_name( 'close_button_style' ),
				'responsive' => true,
				'units'      => array( 'px', '%', 'em' ),
				'options'    => array(
					'min'  => 0,
					'max'  => 100,
					'step' => 1,
				),
				'selectors'  => array(
					'custom' => array(
						'.profecient-popup .popup-wrapper .popup-close' => 'left: auto; right: auto; {{' . $this->get_option_name( 'st_close_button_position_horizontal_orientation' ) . '.VALUE}}: {{SIZE}}{{UNIT}};',
					),
				),
			),
			$this->get_option_name( 'st_close_button_position_vertical_orientation' ) => array(
				'type'    => 'radio',
				'title'   => esc_html__( 'Vertical Orientation', 'profecient-essential' ),
				'segment' => $this->get_option_name( 'close_button_style' ),
				'options' => array(
					'top'    => array(
						'title' => esc_html__( 'Top', 'profecient-essential' ),
						'icon'  => 'eicon-v-align-top',
					),
					'bottom' => array(
						'title' => esc_html__( 'Bottom', 'profecient-essential' ),
						'icon'  => 'eicon-v-align-bottom',
					),
				),
				'default' => 'top',
				'toggle'  => false,
			),
			$this->get_option_name( 'st_close_button_position_vertical_offset' ) => array(
				'type'       => 'slider',
				'title'      => esc_html__( 'Offset', 'profecient-essential' ),
				'segment'    => $this->get_option_name( 'close_button_style' ),
				'responsive' => true,
				'units'      => array( 'px', '%', 'em' ),
				'options'    => array(
					'min'  => 0,
					'max'  => 100,
					'step' => 1,
				),
				'selectors'  => array(
					'custom' => array(
						'.profecient-popup .popup-wrapper .popup-close' => 'top: auto; bottom: auto; {{' . $this->get_option_name( 'st_close_button_position_vertical_orientation' ) . '.VALUE}}: {{SIZE}}{{UNIT}};',
					),
				),
			),
			$this->get_option_name( 'st_close_button_padding' ) => array(
				'title'     => esc_html__( 'Padding', 'profecient-essential' ),
				'type'      => 'dimension',
				'segment'   => $this->get_option_name( 'close_button_style' ),
				'units'     => array( 'px', '%', 'em' ),
				'selectors' => array(
					'custom' => array(
						'.profecient-popup .popup-wrapper .popup-close' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					),
				),
				'separator' => 'before',
			),
			$this->get_option_name( 'st_close_button_tabs_start' ) => array(
				'type'    => 'control_tabs_start',
				'segment' => $this->get_option_name( 'close_button_style' ),
			),
			$this->get_option_name( 'st_close_button_normal_tab_start' ) => array(
				'title'   => esc_html__( 'Normal', 'profecient-essential' ),
				'type'    => 'control_tab_start',
				'segment' => $this->get_option_name( 'close_button_style' ),
			),
			$this->get_option_name( 'st_close_button_icon_color' ) => array(
				'type'       => 'color',
				'title'      => esc_html__( 'Icon Color', 'profecient-essential' ),
				'segment'    => $this->get_option_name( 'close_button_style' ),
				'responsive' => true,
				'selectors'  => array(
					'custom' => array(
						'.profecient-popup .popup-wrapper .popup-close > i'   => 'color: {{VALUE}};',
						'.profecient-popup .popup-wrapper .popup-close > svg path' => 'fill: {{VALUE}};',
					),
				),
			),
			$this->get_option_name( 'st_close_button_background' ) => array(
				'title'     => esc_html__( 'Background', 'profecient-essential' ),
				'type'      => 'background',
				'segment'   => $this->get_option_name( 'close_button_style' ),
				'options'   => array(
					'classic',
					'gradient',
				),
				'selectors' => array(
					'custom' => '.profecient-popup .popup-wrapper .popup-close',
				),
			),
			$this->get_option_name( 'st_close_button_border' ) => array(
				'title'     => esc_html__( 'Border', 'profecient-essential' ),
				'type'      => 'border',
				'segment'   => $this->get_option_name( 'close_button_style' ),
				'selectors' => array(
					'custom' => '.profecient-popup .popup-wrapper .popup-close',
				),
			),
			$this->get_option_name( 'st_close_button_border_radius' ) => array(
				'title'     => esc_html__( 'Border Radius', 'profecient-essential' ),
				'type'      => 'dimension',
				'segment'   => $this->get_option_name( 'close_button_style' ),
				'units'     => array( 'px', '%', 'em' ),
				'selectors' => array(
					'custom' => array(
						'.profecient-popup .popup-wrapper .popup-close' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					),
				),
			),
			$this->get_option_name( 'st_close_button_box_shadow' ) => array(
				'title'     => esc_html__( 'Box Shadow', 'profecient-essential' ),
				'type'      => 'boxshadow',
				'segment'   => $this->get_option_name( 'close_button_style' ),
				'units'     => array( 'px', '%', 'em' ),
				'selectors' => array(
					'custom' => '.profecient-popup .popup-wrapper .popup-close',
				),
			),
			$this->get_option_name( 'st_close_button_tab_end' ) => array(
				'type'    => 'control_tab_end',
				'segment' => $this->get_option_name( 'close_button_style' ),
			),
			$this->get_option_name( 'st_close_button_hover_tab_start' ) => array(
				'title'   => esc_html__( 'Hover', 'profecient-essential' ),
				'type'    => 'control_tab_start',
				'segment' => $this->get_option_name( 'close_button_style' ),
			),
			$this->get_option_name( 'st_close_button_hover_transition_duration' ) => array(
				'title'     => esc_html__( 'Transition Duration', 'profecient-essential' ),
				'type'      => 'slider',
				'segment'   => $this->get_option_name( 'close_button_style' ),
				'options'   => array(
					'min'  => 0,
					'max'  => 10,
					'step' => 0.1,
				),
				'selectors' => array(
					'custom' => array(
						'.profecient-popup .popup-wrapper .popup-close' => 'transition-duration: {{SIZE}}s;',
					),
				),
			),
			$this->get_option_name( 'st_close_button_hover_icon_color' ) => array(
				'type'       => 'color',
				'title'      => esc_html__( 'Icon Color', 'profecient-essential' ),
				'segment'    => $this->get_option_name( 'close_button_style' ),
				'responsive' => true,
				'selectors'  => array(
					'custom' => array(
						'.profecient-popup .popup-wrapper .popup-close:hover > i'   => 'color: {{VALUE}};',
						'.profecient-popup .popup-wrapper .popup-close:hover > svg path' => 'fill: {{VALUE}};',
					),
				),
			),
			$this->get_option_name( 'st_close_button_hover_background' ) => array(
				'title'     => esc_html__( 'Background', 'profecient-essential' ),
				'type'      => 'background',
				'segment'   => $this->get_option_name( 'close_button_style' ),
				'options'   => array(
					'classic',
					'gradient',
				),
				'selectors' => array(
					'custom' => '.profecient-popup .popup-wrapper .popup-close:hover',
				),
			),
			$this->get_option_name( 'st_close_button_hover_border' ) => array(
				'title'     => esc_html__( 'Border', 'profecient-essential' ),
				'type'      => 'border',
				'segment'   => $this->get_option_name( 'close_button_style' ),
				'selectors' => array(
					'custom' => '.profecient-popup .popup-wrapper .popup-close:hover',
				),
			),
			$this->get_option_name( 'st_close_button_hover_border_radius' ) => array(
				'title'     => esc_html__( 'Border Radius', 'profecient-essential' ),
				'type'      => 'dimension',
				'segment'   => $this->get_option_name( 'close_button_style' ),
				'units'     => array( 'px', '%', 'em' ),
				'selectors' => array(
					'custom' => array(
						'.profecient-popup .popup-wrapper .popup-close:hover' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					),
				),
			),
			$this->get_option_name( 'st_close_button_hover_box_shadow' ) => array(
				'title'     => esc_html__( 'Box Shadow', 'profecient-essential' ),
				'type'      => 'boxshadow',
				'segment'   => $this->get_option_name( 'close_button_style' ),
				'units'     => array( 'px', '%', 'em' ),
				'selectors' => array(
					'custom' => '.profecient-popup .popup-wrapper .popup-close:hover',
				),
			),
			$this->get_option_name( 'st_close_button_hover_tab_end' ) => array(
				'type'    => 'control_tab_end',
				'segment' => $this->get_option_name( 'close_button_style' ),
			),
			$this->get_option_name( 'st_close_button_tabs_end' ) => array(
				'type'    => 'control_tabs_end',
				'segment' => $this->get_option_name( 'close_button_style' ),
			),
		);

		/**
		 * Filters the location of the option.
		 *
		 * @param array $location Location of the option. Default is array( 'elementor/element/wp-page/document_settings/after_section_end' ).
		 * @param string $id ID of the option. Default is $this->id.
		 */
		$this->controls['location'] = apply_filters( $this->get_option_name( 'control_location' ), $location, $this->id );

		/**
		 * Filters the show location of the option.
		 *
		 * @param array $show_location Show location of the option. Default is array( 'Core\DocumentTypes\Page' ).
		 * @param string $id ID of the option. Default is $this->id.
		 */
		$this->controls['show_location'] = apply_filters( $this->get_option_name( 'control_show_location' ), $show_location, $this->id );

		/**
		 * Filters the segment of the option.
		 *
		 * @param array $segment Segment of the option. Default is array( $this->get_option_name('segment') => array( 'name' => '<i class="profecient-option-additional"></i> ' . esc_html__( 'Sample Option', 'profecient-essential' ), 'priority' => 10 ) ).
		 * @param string $id ID of the option. Default is $this->id.
		 */
		$this->controls['segment'] = apply_filters( $this->get_option_name( 'control_segment' ), $segment, $this->id );

		/**
		 * Filters the options of the option.
		 *
		 * @param array $options Options of the option. Default is array( $this->get_option_name('toggle') => array( 'title' => esc_html__( 'Enable Sample Option', 'profecient-essential' ), 'type' => 'checkbox', 'default' => false, 'segment' => $this->get_option_name('segment'), 'return_value' => 'yes', 'prefix_class' => 'profecient-sample-option-' ) ).
		 * @param string $id ID of the option. Default is $this->id.
		 */
		$this->controls['options'] = apply_filters( $this->get_option_name( 'control_options' ), $options, $this->id );
	}

	/**
	 * Register styles
	 */
	public function register_styles() {
		// $this->register_style( 'sample-option', 'assets/css/sample-option.css' );
	}



	/**
	 * Enqueue styles
	 */
	public function enqueue_styles() {
		wp_enqueue_style( 'profecient-essential-templates' );
	}

	/**
	 * Enqueue global styles
	 */
	public function enqueue_global_styles() {
		// $this->enqueue_script( 'sample-option' );
	}

	/**
	 * Should style enqueue
	 */
	public function should_style_enqueue() {
		// return $this->should_enqueue_script( 'sample-option' );
	}

	/**
	 * Register scripts
	 */
	public function register_scripts() {
		// wp_register_script( 'profecient-custom-cursor', PROFECIENT_ESSENTIAL_URL . '/assets/js/extra/custom-cursor.js', array( 'elementor-frontend' ), PROFECIENT_ESSENTIAL_VERSION, true );
	}

	/**
	 * Enqueue scripts
	 */
	public function enqueue_scripts() {
		wp_enqueue_script( 'profecient-essential-templates' );
	}

	/**
	 * Enqueue global scripts
	 */
	public function enqueue_global_scripts() {
		// $page_settings = self::get_custom_settings( $this->id );
		// if ( $page_settings[ $this->get_option_name( 'on_page_load' ) ] === 'yes' || $page_settings[ $this->get_option_name( 'on_scroll' ) ] === 'yes' || $page_settings[ $this->get_option_name( 'on_scroll_to_element' ) ] === 'yes' || $page_settings[ $this->get_option_name( 'on_click' ) ] === 'yes' || $page_settings[ $this->get_option_name( 'after_inactivity' ) ] === 'yes' || $page_settings[ $this->get_option_name( 'on_page_exit_intent' ) ] === 'yes' ) {
			// wp_enqueue_script( 'profecient-essential-templates' );
		// }
	}

	/**
	 * Should script enqueue
	 */
	public function should_script_enqueue() {
		// return $this->should_enqueue_script( 'sample-option' );
	}

	/**
	 * Before common render.
	 *
	 * @param $element \Elementor\Element_Base Element.
	 */
	public function before_common_render( $element ) {
		$this->before_render( $element );
	}

	/**
	 * Before section render.
	 *
	 * @param $element \Elementor\Element_Base Element.
	 */
	public function before_section_render( $element ) {
		$this->before_render( $element );
	}

	/**
	 * Before column render.
	 *
	 * @param $element \Elementor\Element_Base Element.
	 */
	public function before_column_render( $element ) {
		$this->before_render( $element );
	}

	/**
	 * Before common render.
	 *
	 * @param $element \Elementor\Element_Base
	 */
	public function before_render( $element ) {
		// before render.
	}

	/**
	 * After common render.
	 *
	 * @param $element \Elementor\Element_Base Element.
	 */
	public function after_common_render( $element ) {
		$this->after_render( $element );
	}

	/**
	 * After section render.
	 *
	 * @param $element \Elementor\Element_Base Element.
	 */
	public function after_section_render( $element ) {
		$this->after_render( $element );
	}

	/**
	 * After column render.
	 *
	 * @param $element \Elementor\Element_Base Element.
	 */
	public function after_column_render( $element ) {
		$this->after_render( $element );
	}

	/**
	 * After container render.
	 *
	 * @param $element \Elementor\Element_Base Element.
	 */
	public function after_container_render( $element ) {
		$this->after_render( $element );
	}

	/**
	 * After render.
	 *
	 * @param $element \Elementor\Element_Base Element.
	 */
	public function after_render( $element ) {
		// if ( $element->get_settings( $this->get_option_name( 'on_page_load' ) ) === 'yes' ) {
		// wp_enqueue_script( 'profecient-essential-templates' );
		// }
	}
}
