<?php
namespace Profecient\Essential\JKit\Extra_Option\Options\Sample_Option;

use Profecient\Essential\JKit\Extra_Option\Options\Abstract_Option;

/**
 * Class Module
 */
class Module extends Abstract_Option {

	/**
	 * Set Options
	 */
	public function set_options() {
		$location      = array(
			'elementor/element/wp-page/document_settings/after_section_end',
		);
		$show_location = array(
			'Core\DocumentTypes\Page',
		);
		$segment       = array(
			$this->get_option_name( 'segment' ) => array(
				'name'     => '<i class="profecient-option-additional"></i> ' . esc_html__( 'Sample Option', 'profecient-essential' ),
				'priority' => 10,
			),
		);
		$options       = array(
			$this->get_option_name( 'toggle' ) => array(
				'title'        => esc_html__( 'Enable Sample Option', 'profecient-essential' ),
				'type'         => 'checkbox',
				'default'      => false,
				'segment'      => $this->get_option_name( 'segment' ),
				'return_value' => 'yes',
				'prefix_class' => 'profecient-sample-option-',
			),
		);
		/**
		 * Filters the location of the option.
		 *
		 * @param array $location Location of the option. Default is array( 'elementor/element/wp-page/document_settings/after_section_end' ).
		 * @param string $id ID of the option. Default is $this->id.
		 */
		$this->controls['location'] = apply_filters( $this->get_option_name( 'control_location' ), $location, $this->id );

		/**
		 * Filters the show location of the option.
		 *
		 * @param array $show_location Show location of the option. Default is array( 'Core\DocumentTypes\Page' ).
		 * @param string $id ID of the option. Default is $this->id.
		 */
		$this->controls['show_location'] = apply_filters( $this->get_option_name( 'control_show_location' ), $show_location, $this->id );

		/**
		 * Filters the segment of the option.
		 *
		 * @param array $segment Segment of the option. Default is array( $this->get_option_name( 'segment' ) => array( 'name' => '<i class="profecient-option-additional"></i> ' . esc_html__( 'Sample Option', 'profecient-essential' ), 'priority' => 10 ) ).
		 * @param string $id ID of the option. Default is $this->id.
		 */
		$this->controls['segment'] = apply_filters( $this->get_option_name( 'control_segment' ), $segment, $this->id );

		/**
		 * Filters the options of the option.
		 *
		 * @param array $options Options of the option. Default is array( $this->get_option_name( 'toggle' ) => array( 'title' => esc_html__( 'Enable Sample Option', 'profecient-essential' ), 'type' => 'checkbox', 'default' => false, 'segment' => $this->get_option_name( 'segment' ), 'return_value' => 'yes', 'prefix_class' => 'profecient-sample-option-' ) ).
		 * @param string $id ID of the option. Default is $this->id.
		 */
		$this->controls['options'] = apply_filters( $this->get_option_name( 'control_options' ), $options, $this->id );
	}

	/**
	 * Register styles
	 */
	public function register_styles() {
		// $this->register_style( 'sample-option', 'assets/css/sample-option.css' );
	}



	/**
	 * Enqueue styles
	 */
	public function enqueue_styles() {
		// $this->enqueue_style( 'sample-option' );
	}

	/**
	 * Enqueue global styles
	 */
	public function enqueue_global_styles() {
		// $this->enqueue_script( 'sample-option' );
	}

	/**
	 * Should style enqueue
	 */
	public function should_style_enqueue() {
		// return $this->should_enqueue_script( 'sample-option' );
	}

	/**
	 * Register scripts
	 */
	public function register_scripts() {
		// $this->register_script( 'sample-option', 'assets/js/sample-option.js' );
	}

	/**
	 * Enqueue scripts
	 */
	public function enqueue_scripts() {
		// $this->enqueue_script( 'sample-option' );
	}

	/**
	 * Enqueue global scripts
	 */
	public function enqueue_global_scripts() {
		// $this->enqueue_global_script( 'sample-option' );
	}

	/**
	 * Should script enqueue
	 */
	public function should_script_enqueue() {
		// return $this->should_enqueue_script( 'sample-option' );
	}
}
