<?php
namespace Profecient\Essential\JKit\Extra_Option\Options\Smooth_Scroll;

use Profecient\Essential\JKit\Extra_Option\Options\Abstract_Option;

/**
 * Class Module
 */
class Module extends Abstract_Option {

	/**
	 * Set Options
	 */
	public function set_options() {
		$location      = array(
			'elementor/element/wp-page/document_settings/after_section_end',
		);
		$show_location = array(
			'Core\DocumentTypes\Page',
		);
		$segment       = array(
			$this->get_option_name( 'segment' ) => array(
				'name'     => '<i class="profecient-option-additional"></i> ' . esc_html__( 'Smooth Scroll', 'profecient-essential' ),
				'priority' => 10,
			),
		);
		$options       = array(
			$this->get_option_name( 'toggle' )             => array(
				'title'        => esc_html__( 'Enable Smooth Scroll', 'profecient-essential' ),
				'type'         => 'checkbox',
				'segment'      => $this->get_option_name( 'segment' ),
				'return_value' => 'yes',
			),
			$this->get_option_name( 'core_header' )        => array(
				'title'      => esc_html__( 'Scrolling Core', 'profecient-essential' ),
				'type'       => 'heading',
				'segment'    => $this->get_option_name( 'segment' ),
				'dependency' => array(
					array(
						'field'    => $this->get_option_name( 'toggle' ),
						'operator' => '==',
						'value'    => 'yes',
					),
				),
			),
			$this->get_option_name( 'core_framerate' )     => array(
				'title'        => esc_html__( 'Scrolling Core - Frame Rate', 'profecient-essential' ),
				'type'         => 'slider',
				'default'      => 150,
				'default_unit' => 'Hz',
				'units'        => array( 'Hz' ),
				'options'      => array(
					'min'  => 0,
					'max'  => 1000,
					'step' => 2,
				),
				'segment'      => $this->get_option_name( 'segment' ),
				'dependency'   => array(
					array(
						'field'    => $this->get_option_name( 'toggle' ),
						'operator' => '==',
						'value'    => 'yes',
					),
				),
			),
			$this->get_option_name( 'core_animation_time' ) => array(
				'title'        => esc_html__( 'Scrolling Core - Animation Time', 'profecient-essential' ),
				'type'         => 'slider',
				'default'      => 1000,
				'default_unit' => 'ms',
				'units'        => array( 'ms' ),
				'options'      => array(
					'min'  => 300,
					'max'  => 10000,
					'step' => 100,
				),
				'segment'      => $this->get_option_name( 'segment' ),
				'dependency'   => array(
					array(
						'field'    => $this->get_option_name( 'toggle' ),
						'operator' => '==',
						'value'    => 'yes',
					),
				),
			),
			$this->get_option_name( 'core_step_size' )     => array(
				'title'        => esc_html__( 'Scrolling Core - Step Size', 'profecient-essential' ),
				'type'         => 'slider',
				'default'      => 100,
				'default_unit' => 'px',
				'units'        => array( 'px' ),
				'options'      => array(
					'min'  => 0,
					'max'  => 1000,
					'step' => 1,
				),
				'segment'      => $this->get_option_name( 'segment' ),
				'dependency'   => array(
					array(
						'field'    => $this->get_option_name( 'toggle' ),
						'operator' => '==',
						'value'    => 'yes',
					),
				),
			),
			$this->get_option_name( 'pulse_header' )       => array(
				'title'      => esc_html__( 'Pulse ratio of "tail" to "acceleration', 'profecient-essential' ),
				'type'       => 'heading',
				'segment'    => $this->get_option_name( 'segment' ),
				'separator'  => 'before',
				'dependency' => array(
					array(
						'field'    => $this->get_option_name( 'toggle' ),
						'operator' => '==',
						'value'    => 'yes',
					),
				),
			),
			$this->get_option_name( 'pulse_algorithm' )    => array(
				'title'        => esc_html__( 'Pulse - Algorithm', 'profecient-essential' ),
				'type'         => 'checkbox',
				'default'      => 'yes',
				'segment'      => $this->get_option_name( 'segment' ),
				'return_value' => 'yes',
				'dependency'   => array(
					array(
						'field'    => $this->get_option_name( 'toggle' ),
						'operator' => '==',
						'value'    => 'yes',
					),
				),
			),
			$this->get_option_name( 'pulse_scale' )        => array(
				'title'        => esc_html__( 'Pulse - Scale', 'profecient-essential' ),
				'type'         => 'slider',
				'default'      => 4,
				'default_unit' => '',
				'units'        => array( '' ),
				'options'      => array(
					'min'  => 0,
					'max'  => 10,
					'step' => 0.1,
				),
				'segment'      => $this->get_option_name( 'segment' ),
				'dependency'   => array(
					array(
						'field'    => $this->get_option_name( 'toggle' ),
						'operator' => '==',
						'value'    => 'yes',
					),
					array(
						'field'    => $this->get_option_name( 'pulse_algorithm' ),
						'operator' => '==',
						'value'    => 'yes',
					),
				),
			),
			// heading acceleration
			$this->get_option_name( 'acceleration_header' ) => array(
				'title'      => esc_html__( 'Acceleration', 'profecient-essential' ),
				'type'       => 'heading',
				'segment'    => $this->get_option_name( 'segment' ),
				'separator'  => 'before',
				'dependency' => array(
					array(
						'field'    => $this->get_option_name( 'toggle' ),
						'operator' => '==',
						'value'    => 'yes',
					),
				),
			),
			$this->get_option_name( 'acceleration_delta' ) => array(
				'title'        => esc_html__( 'Acceleration - Delta', 'profecient-essential' ),
				'type'         => 'slider',
				'default'      => 50,
				'default_unit' => 'px',
				'units'        => array( 'px' ),
				'options'      => array(
					'min'  => 0,
					'max'  => 100,
					'step' => 1,
				),
				'segment'      => $this->get_option_name( 'segment' ),
				'dependency'   => array(
					array(
						'field'    => $this->get_option_name( 'toggle' ),
						'operator' => '!=',
						'value'    => 'yes',
					),
				),
			),
			$this->get_option_name( 'acceleration_max' )   => array(
				'title'        => esc_html__( 'Acceleration - Max', 'profecient-essential' ),
				'type'         => 'slider',
				'default'      => 3,
				'default_unit' => 'px',
				'units'        => array( 'px' ),
				'options'      => array(
					'min'  => 0,
					'max'  => 50,
					'step' => 1,
				),
				'segment'      => $this->get_option_name( 'segment' ),
				'dependency'   => array(
					array(
						'field'    => $this->get_option_name( 'toggle' ),
						'operator' => '==',
						'value'    => 'yes',
					),
				),
			),
			// heading keyboard
			$this->get_option_name( 'keyboard_header' )    => array(
				'title'      => esc_html__( 'Keyboard', 'profecient-essential' ),
				'type'       => 'heading',
				'segment'    => $this->get_option_name( 'segment' ),
				'separator'  => 'before',
				'dependency' => array(
					array(
						'field'    => $this->get_option_name( 'toggle' ),
						'operator' => '!=',
						'value'    => 'yes',
					),
				),
			),
			$this->get_option_name( 'keyboard_enable' )    => array(
				'title'        => esc_html__( 'Keyboard - Enable', 'profecient-essential' ),
				'type'         => 'checkbox',
				'default'      => 'yes',
				'segment'      => $this->get_option_name( 'segment' ),
				'return_value' => 'yes',
				'dependency'   => array(
					array(
						'field'    => $this->get_option_name( 'toggle' ),
						'operator' => '!=',
						'value'    => 'yes',
					),
				),
			),
			$this->get_option_name( 'keyboard_arrow_scroll' ) => array(
				'title'        => esc_html__( 'Keyboard - Arrow Scroll', 'profecient-essential' ),
				'type'         => 'slider',
				'default'      => 50,
				'default_unit' => 'px',
				'units'        => array( 'px' ),
				'options'      => array(
					'min'  => 0,
					'max'  => 100,
					'step' => 1,
				),
				'segment'      => $this->get_option_name( 'segment' ),
				'dependency'   => array(
					array(
						'field'    => $this->get_option_name( 'toggle' ),
						'operator' => '!=',
						'value'    => 'yes',
					),
					array(
						'field'    => $this->get_option_name( 'keyboard_enable' ),
						'operator' => '==',
						'value'    => 'yes',
					),
				),
			),
			// heading other settings
			$this->get_option_name( 'other_header' )       => array(
				'title'      => esc_html__( 'Other Settings', 'profecient-essential' ),
				'type'       => 'heading',
				'segment'    => $this->get_option_name( 'segment' ),
				'separator'  => 'before',
				'dependency' => array(
					array(
						'field'    => $this->get_option_name( 'toggle' ),
						'operator' => '!=',
						'value'    => 'yes',
					),
				),
			),
			$this->get_option_name( 'other_touchpad_support' ) => array(
				'title'        => esc_html__( 'Other Settings - Touchpad Support', 'profecient-essential' ),
				'type'         => 'checkbox',
				'segment'      => $this->get_option_name( 'segment' ),
				'return_value' => 'yes',
				'dependency'   => array(
					array(
						'field'    => $this->get_option_name( 'toggle' ),
						'operator' => '!=',
						'value'    => 'yes',
					),
				),
			),
			$this->get_option_name( 'other_fixed_background' ) => array(
				'title'        => esc_html__( 'Other Settings - Fixed Background', 'profecient-essential' ),
				'type'         => 'checkbox',
				'default'      => 'yes',
				'segment'      => $this->get_option_name( 'segment' ),
				'return_value' => 'yes',
				'dependency'   => array(
					array(
						'field'    => $this->get_option_name( 'toggle' ),
						'operator' => '!=',
						'value'    => 'yes',
					),
				),
			),
		);
		/**
		 * Filters the location of the option.
		 *
		 * @param array $location Location of the option. Default is array( 'elementor/element/wp-page/document_settings/after_section_end' ).
		 * @param string $id ID of the option. Default is $this->id.
		 */
		$this->controls['location'] = apply_filters( $this->get_option_name( 'control_location' ), $location, $this->id );

		/**
		 * Filters the show location of the option.
		 *
		 * @param array $show_location Show location of the option. Default is array( 'Core\DocumentTypes\Page' ).
		 * @param string $id ID of the option. Default is $this->id.
		 */
		$this->controls['show_location'] = apply_filters( $this->get_option_name( 'control_show_location' ), $show_location, $this->id );

		/**
		 * Filters the segment of the option.
		 *
		 * @param array $segment Segment of the option. Default is array( $this->get_option_name('segment') => array( 'name' => '<i class="profecient-option-additional"></i> ' . esc_html__( 'Sample Option', 'profecient-essential' ), 'priority' => 10 ) ).
		 * @param string $id ID of the option. Default is $this->id.
		 */
		$this->controls['segment'] = apply_filters( $this->get_option_name( 'control_segment' ), $segment, $this->id );

		/**
		 * Filters the options of the option.
		 *
		 * @param array $options Options of the option. Default is array( $this->get_option_name('toggle') => array( 'title' => esc_html__( 'Enable Sample Option', 'profecient-essential' ), 'type' => 'checkbox', 'default' => false, 'segment' => $this->get_option_name('segment'), 'return_value' => 'yes', 'prefix_class' => 'profecient-sample-option-' ) ).
		 * @param string $id ID of the option. Default is $this->id.
		 */
		$this->controls['options'] = apply_filters( $this->get_option_name( 'control_options' ), $options, $this->id );
	}

	/**
	 * Register styles
	 */
	public function register_styles() {
	}



	/**
	 * Enqueue styles
	 */
	public function enqueue_styles() {
	}

	/**
	 * Enqueue global styles
	 */
	public function enqueue_global_styles() {
	}

	/**
	 * Should style enqueue
	 */
	public function should_style_enqueue() {
	}

	/**
	 * Register scripts
	 */
	public function register_scripts() {
		$smooth_scroll_settings = self::get_custom_settings( $this->id );

		wp_register_script( 'smoothscroll', PROFECIENT_ESSENTIAL_URL . '/assets/js/lib/SmoothScroll.js', array(), '1.4.10', true );
		wp_register_script( 'profecient-smooth-scroll', PROFECIENT_ESSENTIAL_URL . '/assets/js/extra/smooth-scroll.js', array( 'elementor-frontend', 'smoothscroll' ), PROFECIENT_ESSENTIAL_VERSION, true );

		if ( isset( $smooth_scroll_settings[ $this->get_option_name( 'toggle' ) ] ) && $smooth_scroll_settings[ $this->get_option_name( 'toggle' ) ] ) {
			wp_add_inline_script( 'profecient-smooth-scroll', 'var profecientSmoothScrollSettings = ' . wp_json_encode( $smooth_scroll_settings ) . ';' );
		}
	}

	/**
	 * Enqueue scripts
	 */
	public function enqueue_scripts() {
		wp_enqueue_script( 'profecient-smooth-scroll' );
	}

	/**
	 * Enqueue global scripts
	 */
	public function enqueue_global_scripts() {
		$smooth_scroll_settings = self::get_custom_settings( $this->id );
		if ( isset( $smooth_scroll_settings[ $this->get_option_name( 'toggle' ) ] ) && $smooth_scroll_settings[ $this->get_option_name( 'toggle' ) ] ) {
			wp_enqueue_script( 'profecient-smooth-scroll' );
		}
	}

	/**
	 * Should script enqueue
	 */
	public function should_script_enqueue() {
	}
}
