<?php
/**
 * Jeg Elementor Kit class
 *
 * @package profecient-essential
 * @author jegtheme
 * @since 1.0.0
 */

namespace Profecient\Essential\JKit\Global_Option;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

use Profecient\Essential\JKit\Global_Option\Options\Abstract_Option;

/**
 * Class Global_Option
 */
class Global_Option {
	/**
	 * Class instance
	 *
	 * @var Extra_Option
	 */
	private static $instance;

	/**
	 * Return class instance
	 *
	 * @return Extra_Option
	 */
	public static function instance() {
		if ( null === static::$instance ) {
			static::$instance = new static();
		}

		return static::$instance;
	}

	/**
	 * Extra_Option constructor.
	 */
	private function __construct() {
		$this->setup_hook();
	}

	/**
	 * Setup Hooks
	 */
	public function setup_hook() {
		add_action( 'elementor/kit/register_tabs', array( $this, 'register_global_options' ) );
	}

	/**
	 * Register Global Options
	 *
	 * @param \Elementor\Core\Kits\Documents\Kit $kit Class Instance.
	 */
	public function register_global_options( $kit ) {
		$options = $this->list_option();

		foreach ( $options as $option ) {
			$id        = 'profecient_' . strtolower( $option );
			$namespace = '\Profecient\Essential\JKit\Global_Option\Options';
			$class     = $namespace . '\\' . $option . '\Module';

			$kit->register_tab( $id, $class );
		}
	}

	/**
	 * All Global Options
	 *
	 * @param array $options List Option.
	 */
	public function list_option( $options = array() ) {
		array_push(
			$options,
			'Custom_Cursor',
			'Smooth_Scroll',
		);

		$options = apply_filters( 'profecient_global_options', $options );

		return $options;
	}
}
