<?php
namespace Profecient\Essential\JKit\Global_Option\Options\Smooth_Scroll;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

use Profecient\Essential\JKit\Global_Option\Options\Abstract_Option;

/**
 * Class Module
 */
class Module extends Abstract_Option {
	/**
	 * Module ID
	 */
	public function get_id() {
		return 'profecient_smooth_scroll';
	}

	/**
	 * Get The Module Title
	 */
	public function get_title() {
		return esc_html__( 'Smooth Scroll', 'profecient-essential' );
	}

	/**
	 * Set Options
	 */
	public function register_tab_controls() {
		$segment = array(
			$this->get_option_name( 'segment' ) => array(
				'name'     => '<i class="profecient-option-additional"></i> ' . esc_html__( 'Smooth Scroll', 'profecient-essential' ),
				'priority' => 10,
			),
		);

		$options = array(
			$this->get_option_name( 'toggle' )             => array(
				'title'              => esc_html__( 'Enable Smooth Scroll', 'profecient-essential' ),
				'type'               => 'checkbox',
				'segment'            => $this->get_option_name( 'segment' ),
				'return_value'       => 'yes',
				'frontend_available' => true,
			),
			$this->get_option_name( 'core_header' )        => array(
				'title'              => esc_html__( 'Scrolling Core', 'profecient-essential' ),
				'type'               => 'heading',
				'segment'            => $this->get_option_name( 'segment' ),
				'dependency'         => array(
					array(
						'field'    => $this->get_option_name( 'toggle' ),
						'operator' => '==',
						'value'    => 'yes',
					),
				),
				'frontend_available' => true,
			),
			$this->get_option_name( 'core_framerate' )     => array(
				'title'              => esc_html__( 'Scrolling Core - Frame Rate', 'profecient-essential' ),
				'type'               => 'slider',
				'default'            => 150,
				'default_unit'       => 'Hz',
				'units'              => array( 'Hz' ),
				'options'            => array(
					'min'  => 0,
					'max'  => 1000,
					'step' => 2,
				),
				'segment'            => $this->get_option_name( 'segment' ),
				'dependency'         => array(
					array(
						'field'    => $this->get_option_name( 'toggle' ),
						'operator' => '==',
						'value'    => 'yes',
					),
				),
				'frontend_available' => true,
			),
			$this->get_option_name( 'core_animation_time' ) => array(
				'title'              => esc_html__( 'Scrolling Core - Animation Time', 'profecient-essential' ),
				'type'               => 'slider',
				'default'            => 1000,
				'default_unit'       => 'ms',
				'units'              => array( 'ms' ),
				'options'            => array(
					'min'  => 300,
					'max'  => 10000,
					'step' => 100,
				),
				'segment'            => $this->get_option_name( 'segment' ),
				'dependency'         => array(
					array(
						'field'    => $this->get_option_name( 'toggle' ),
						'operator' => '==',
						'value'    => 'yes',
					),
				),
				'frontend_available' => true,
			),
			$this->get_option_name( 'core_step_size' )     => array(
				'title'              => esc_html__( 'Scrolling Core - Step Size', 'profecient-essential' ),
				'type'               => 'slider',
				'default'            => 100,
				'default_unit'       => 'px',
				'units'              => array( 'px' ),
				'options'            => array(
					'min'  => 0,
					'max'  => 1000,
					'step' => 1,
				),
				'segment'            => $this->get_option_name( 'segment' ),
				'dependency'         => array(
					array(
						'field'    => $this->get_option_name( 'toggle' ),
						'operator' => '==',
						'value'    => 'yes',
					),
				),
				'frontend_available' => true,
			),
			$this->get_option_name( 'pulse_header' )       => array(
				'title'              => esc_html__( 'Pulse ratio of "tail" to "acceleration', 'profecient-essential' ),
				'type'               => 'heading',
				'segment'            => $this->get_option_name( 'segment' ),
				'separator'          => 'before',
				'dependency'         => array(
					array(
						'field'    => $this->get_option_name( 'toggle' ),
						'operator' => '==',
						'value'    => 'yes',
					),
				),
				'frontend_available' => true,
			),
			$this->get_option_name( 'pulse_algorithm' )    => array(
				'title'              => esc_html__( 'Pulse - Algorithm', 'profecient-essential' ),
				'type'               => 'checkbox',
				'default'            => 'yes',
				'segment'            => $this->get_option_name( 'segment' ),
				'return_value'       => 'yes',
				'dependency'         => array(
					array(
						'field'    => $this->get_option_name( 'toggle' ),
						'operator' => '==',
						'value'    => 'yes',
					),
				),
				'frontend_available' => true,
			),
			$this->get_option_name( 'pulse_scale' )        => array(
				'title'              => esc_html__( 'Pulse - Scale', 'profecient-essential' ),
				'type'               => 'slider',
				'default'            => 4,
				'default_unit'       => '',
				'units'              => array( '' ),
				'options'            => array(
					'min'  => 0,
					'max'  => 10,
					'step' => 0.1,
				),
				'segment'            => $this->get_option_name( 'segment' ),
				'dependency'         => array(
					array(
						'field'    => $this->get_option_name( 'toggle' ),
						'operator' => '==',
						'value'    => 'yes',
					),
					array(
						'field'    => $this->get_option_name( 'pulse_algorithm' ),
						'operator' => '==',
						'value'    => 'yes',
					),
				),
				'frontend_available' => true,
			),
			// heading acceleration
			$this->get_option_name( 'acceleration_header' ) => array(
				'title'              => esc_html__( 'Acceleration', 'profecient-essential' ),
				'type'               => 'heading',
				'segment'            => $this->get_option_name( 'segment' ),
				'separator'          => 'before',
				'dependency'         => array(
					array(
						'field'    => $this->get_option_name( 'toggle' ),
						'operator' => '==',
						'value'    => 'yes',
					),
				),
				'frontend_available' => true,
			),
			$this->get_option_name( 'acceleration_delta' ) => array(
				'title'              => esc_html__( 'Acceleration - Delta', 'profecient-essential' ),
				'type'               => 'slider',
				'default'            => 50,
				'default_unit'       => 'px',
				'units'              => array( 'px' ),
				'options'            => array(
					'min'  => 0,
					'max'  => 100,
					'step' => 1,
				),
				'segment'            => $this->get_option_name( 'segment' ),
				'dependency'         => array(
					array(
						'field'    => $this->get_option_name( 'toggle' ),
						'operator' => '!=',
						'value'    => 'yes',
					),
				),
				'frontend_available' => true,
			),
			$this->get_option_name( 'acceleration_max' )   => array(
				'title'              => esc_html__( 'Acceleration - Max', 'profecient-essential' ),
				'type'               => 'slider',
				'default'            => 3,
				'default_unit'       => 'px',
				'units'              => array( 'px' ),
				'options'            => array(
					'min'  => 0,
					'max'  => 50,
					'step' => 1,
				),
				'segment'            => $this->get_option_name( 'segment' ),
				'dependency'         => array(
					array(
						'field'    => $this->get_option_name( 'toggle' ),
						'operator' => '==',
						'value'    => 'yes',
					),
				),
				'frontend_available' => true,
			),
			// heading keyboard
			$this->get_option_name( 'keyboard_header' )    => array(
				'title'              => esc_html__( 'Keyboard', 'profecient-essential' ),
				'type'               => 'heading',
				'segment'            => $this->get_option_name( 'segment' ),
				'separator'          => 'before',
				'dependency'         => array(
					array(
						'field'    => $this->get_option_name( 'toggle' ),
						'operator' => '!=',
						'value'    => 'yes',
					),
				),
				'frontend_available' => true,
			),
			$this->get_option_name( 'keyboard_enable' )    => array(
				'title'              => esc_html__( 'Keyboard - Enable', 'profecient-essential' ),
				'type'               => 'checkbox',
				'default'            => 'yes',
				'segment'            => $this->get_option_name( 'segment' ),
				'return_value'       => 'yes',
				'dependency'         => array(
					array(
						'field'    => $this->get_option_name( 'toggle' ),
						'operator' => '!=',
						'value'    => 'yes',
					),
				),
				'frontend_available' => true,
			),
			$this->get_option_name( 'keyboard_arrow_scroll' ) => array(
				'title'              => esc_html__( 'Keyboard - Arrow Scroll', 'profecient-essential' ),
				'type'               => 'slider',
				'default'            => 50,
				'default_unit'       => 'px',
				'units'              => array( 'px' ),
				'options'            => array(
					'min'  => 0,
					'max'  => 100,
					'step' => 1,
				),
				'segment'            => $this->get_option_name( 'segment' ),
				'dependency'         => array(
					array(
						'field'    => $this->get_option_name( 'toggle' ),
						'operator' => '!=',
						'value'    => 'yes',
					),
					array(
						'field'    => $this->get_option_name( 'keyboard_enable' ),
						'operator' => '==',
						'value'    => 'yes',
					),
				),
				'frontend_available' => true,
			),
			// heading other settings
			$this->get_option_name( 'other_header' )       => array(
				'title'              => esc_html__( 'Other Settings', 'profecient-essential' ),
				'type'               => 'heading',
				'segment'            => $this->get_option_name( 'segment' ),
				'separator'          => 'before',
				'dependency'         => array(
					array(
						'field'    => $this->get_option_name( 'toggle' ),
						'operator' => '!=',
						'value'    => 'yes',
					),
				),
				'frontend_available' => true,
			),
			$this->get_option_name( 'other_touchpad_support' ) => array(
				'title'              => esc_html__( 'Other Settings - Touchpad Support', 'profecient-essential' ),
				'type'               => 'checkbox',
				'segment'            => $this->get_option_name( 'segment' ),
				'return_value'       => 'yes',
				'dependency'         => array(
					array(
						'field'    => $this->get_option_name( 'toggle' ),
						'operator' => '!=',
						'value'    => 'yes',
					),
				),
				'frontend_available' => true,
			),
			$this->get_option_name( 'other_fixed_background' ) => array(
				'title'              => esc_html__( 'Other Settings - Fixed Background', 'profecient-essential' ),
				'type'               => 'checkbox',
				'default'            => 'yes',
				'segment'            => $this->get_option_name( 'segment' ),
				'return_value'       => 'yes',
				'dependency'         => array(
					array(
						'field'    => $this->get_option_name( 'toggle' ),
						'operator' => '!=',
						'value'    => 'yes',
					),
				),
				'frontend_available' => true,
			),
		);

		/**
		 * Filters the segment of the option.
		 *
		 * @param array $segment Segment of the option. Default is array( $this->get_option_name('segment') => array( 'name' => '<i class="profecient-option-additional"></i> ' . esc_html__( 'Sample Option', 'profecient-essential' ), 'priority' => 10 ) ).
		 * @param string $id ID of the option. Default is $this->id.
		 */
		$this->controls['segment'] = apply_filters( $this->get_option_name( 'control_segment' ), $segment, $this->get_id() );

		/**
		 * Filters the options of the option.
		 *
		 * @param array $options Options of the option. Default is array( $this->get_option_name('toggle') => array( 'title' => esc_html__( 'Enable Sample Option', 'profecient-essential' ), 'type' => 'checkbox', 'default' => false, 'segment' => $this->get_option_name('segment'), 'return_value' => 'yes', 'prefix_class' => 'profecient-sample-option-' ) ).
		 * @param string $id ID of the option. Default is $this->id.
		 */
		$this->controls['options'] = apply_filters( $this->get_option_name( 'control_options' ), $options, $this->get_id() );
	}

	/**
	 * Register styles
	 */
	public function register_styles() {
	}

	/**
	 * Enqueue styles
	 */
	public function enqueue_styles() {
	}

	/**
	 * Register scripts
	 */
	public function register_scripts() {
		$this->set_settings();
		$settings = $this->get_settings( $this->get_id() );

		wp_register_script( 'smoothscroll', PROFECIENT_ESSENTIAL_URL . '/assets/js/lib/SmoothScroll.js', array(), '1.4.10', true );
		wp_register_script( 'profecient-smooth-scroll', PROFECIENT_ESSENTIAL_URL . '/assets/js/extra/smooth-scroll.js', array( 'elementor-frontend', 'smoothscroll' ), PROFECIENT_ESSENTIAL_VERSION, true );

		if ( $settings[ $this->get_option_name( 'toggle' ) ] ) {
			wp_add_inline_script( 'profecient-smooth-scroll', 'var profecientSmoothScrollSettings = ' . wp_json_encode( $settings ) . ';' );
		}
	}

	/**
	 * Enqueue scripts
	 */
	public function enqueue_scripts() {
		$settings = $this->get_settings( $this->get_id() );

		if ( $settings[ $this->get_option_name( 'toggle' ) ] ) {
			wp_enqueue_script( 'profecient-smooth-scroll' );
		}
	}
}
