<?php
/**
 * Popuop Template class
 *
 * @package profecient-essential
 * @author jegtheme
 * @since 1.1.0
 */

namespace Profecient\Essential\JKit\Templates;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

use \Profecient\Essential\JKit\Dashboard\Template as Dashboard_Template;

/**
 * Class Popup Template
 *
 * @package profecient-essential
 */
class Popup_Template extends Template {
	/**
	 * Class instance
	 *
	 * @var Popup_Template
	 */
	private static $instance;

	/**
	 * Return class instance
	 *
	 * @return Popup_Template
	 */
	public static function instance() {
		if ( null === static::$instance ) {
			static::$instance = new static();
		}

		return static::$instance;
	}

	/**
	 * Class constructor.
	 */
	private function __construct() {
		$this->setup_hook();
	}

	/**
	 * Setup Hooks
	 */
	private function setup_hook() {
		add_action( 'wp_footer', array( $this, 'render_popups' ) );
		add_action( 'wp_enqueue_scripts', array( $this, 'enqueue_scripts' ) );

		add_filter( 'profecient_register_custom_options', array( $this, 'register_elementor_custom_options' ) );
		add_filter( 'elementor/document/wrapper_attributes', array( $this, 'check_popup_attribute' ), 10, 2 );

		add_action( 'profecient_elements_ajax_elementor_profecient_rerender_close_button', array( $this, 'ajax_rerender_close_button' ) );
	}

	/**
	 * Check Popup Attribute for non-Popup Templates
	 *
	 * @param array                         $attributes    Container Attributes.
	 * @param \Elementor\Core\Base\Document $document Elementor Document.
	 *
	 * @return array
	 */
	public function check_popup_attribute( $attributes, $document ) {
		$post_id       = $document->get_main_id();
		$template_type = get_post_meta( $post_id, 'jkit-template-type', true );

		if ( 'jkit-popup-template' !== $template_type && isset( $attributes['data-elementor-settings'] ) ) {
			$elementor_settings = json_decode( $attributes['data-elementor-settings'], true );

			foreach ( $elementor_settings as $key => $val ) {
				if ( strpos( $key, 'profecient_popup_template' ) !== false ) {
					unset( $elementor_settings[ $key ] );
				}
			}

			$attributes['data-elementor-settings'] = json_encode( $elementor_settings );
		}

		if ( 'jkit-popup-template' === $template_type ) {
			$attributes['class'] .= ' jkit-popup-template';
		}

		return $attributes;
	}

	/**
	 * Get Popup Template ID
	 *
	 * @return number
	 */
	public function get_popup_template_id() {
		$post_id  = get_the_ID();
		$popups   = $this->get_list_template( Dashboard_Template\Popup_Template::$template_slug );
		$popup_id = null;

		foreach ( $popups as $popup ) {
			$flag = $this->check_conditions( $post_id, $popup['id'] );

			if ( $flag ) {
				$popup_id = $popup['id'];
				break;
			}
		}

		if ( empty( $$popup_id ) ) {
			if ( \Elementor\Plugin::$instance->preview->is_preview_mode() || is_preview() ) {
				$template_type = get_post_meta( $post_id, 'jkit-template-type', true );

				if ( 'jkit-popup-template' === $template_type ) {
					$popup_id = $post_id;
				}
			}
		}

		return $popup_id;
	}

	/**
	 * Enqueue Scripts
	 */
	public function enqueue_scripts() {
		$popup_id = $this->get_popup_template_id();

		if ( $popup_id ) {
			wp_enqueue_style( 'profecient-essential-templates' );
			wp_enqueue_script( 'profecient-essential-templates' );
		}
	}

	/**
	 * Register All Elementor Options
	 *
	 * @param array $options Options.
	 *
	 * @return array
	 */
	public function register_elementor_custom_options( $options ) {
		$flag = false;

		if ( isset( $_REQUEST['post'] ) && ! empty( $_REQUEST['post'] ) ) {
			$template_type = get_post_meta( $_REQUEST['post'], 'jkit-template-type', true );

			if ( 'jkit-popup-template' === $template_type ) {
				$flag = true;
			}
		} else {
			$popup_id = $this->get_popup_template_id();

			if ( $popup_id ) {
				$flag = true;
			}
		}

		if ( ! is_admin() ) {
			$flag = true;
		}

		if ( $flag ) {
			$item                 = 'Popup_Template';
			$item_key             = 'profecient_' . strtolower( $item );
			$namespace            = '\Profecient\Essential\JKit\Extra_Option\Options';
			$options[ $item_key ] = array(
				'option' => $namespace . '\\' . $item . '\Module',
			);
		}

		return $options;
	}

	/**
	 * Render Popups
	 */
	public function render_popups() {
		$popup_id = $this->get_popup_template_id();

		if ( $popup_id ) {
			$page_settings = \Elementor\Plugin::instance()->documents->get( $popup_id );
			$settings      = $page_settings->get_settings();

			if ( ! \Elementor\Plugin::$instance->preview->is_preview_mode() ) {
				$this->print_css( $popup_id );
			}
			?>
				<div class="profecient-popup" style="display: none;">
					<div class="popup-wrapper">
						<?php
						if ( isset( $settings['profecient_popup_template_st_close_button_position'] ) && 'outside' === $settings['profecient_popup_template_st_close_button_position'] ) :
							echo $this->render_close_button( $settings );
						endif;
						?>
						<div class="popup-content animated">
							<?php
							if ( isset( $settings['profecient_popup_template_st_close_button_position'] ) && 'inside' === $settings['profecient_popup_template_st_close_button_position'] ) :
								echo $this->render_close_button( $settings );
							endif;
							?>
							<?php $this->get_template_content( $popup_id, false ); ?>
						</div>
					</div>
				</div>
			<?php
		}
	}

	/**
	 * Render Close Button
	 */
	public function render_close_button( $settings ) {
		$text = esc_html( $settings['profecient_popup_template_st_close_button_text'] );
		$icon = $this->render_icon_element( $settings['profecient_popup_template_st_close_button_icon'] );
		?>
			<div class="popup-close"><?php echo $icon . $text; ?></div>
		<?php
	}

	/**
	 * Build icon element from given setting. Use Elementor Icon Manager. Render as string
	 *
	 * @param array $icon Icon options from the setting.
	 * @param array $attr Additonal attribute. Default: aria-hidden true.
	 *
	 * @return string
	 */
	protected function render_icon_element( $icon, $attr = array() ) {
		$attr = array_merge( $attr, array( 'aria-hidden' => 'true' ) );

		ob_start();
		\Elementor\Icons_Manager::render_icon( $icon, $attr );
		$output = ob_get_contents();
		ob_end_clean();

		return $output;
	}

	/**
	 * AJAX Handle for Re Render Close Button in Elementor Editor
	 */
	public function ajax_rerender_close_button() {
		if ( isset( $_POST['data'] ) && is_array( $_POST['data'] ) ) {
			ob_start();

			echo $this->render_close_button( $_POST['data'] );

			wp_send_json( ob_get_clean() );
		}
	}
}
