<?php
/**
 * Template class
 *
 * @package profecient-essential
 * @author jegtheme
 * @since 1.0.0
 */

namespace Profecient\Essential\JKit\Templates;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}


use \Jeg\Elementor_Kit\Templates\Template as JKit_Template;

/**
 * Class Template
 */
class Template extends JKit_Template {
	/**
	 * Class instance
	 *
	 * @var Template
	 */
	private static $instance;

	/**
	 * Template List
	 *
	 * @var array
	 */
	private $template_list = array();

	/**
	 * Return class instance
	 *
	 * @return Init
	 */
	public static function instance() {
		if ( null === static::$instance ) {
			static::$instance = new static();
		}

		return static::$instance;
	}

	/**
	 * Class constructor.
	 */
	private function __construct() {
		$this->setup_hook();

		Popup_Template::instance();
	}

	/**
	 * Setup Hooks
	 */
	private function setup_hook() {
		add_filter( 'template_include', array( $this, 'custom_template' ), 11 );
	}

	/**
	 * Get content of custom header template
	 *
	 * @param int  $template_id Template ID.
	 * @param bool $with_css Optional. Whether to retrieve the content with CSS or not. Default is false.
	 */
	protected function get_template_content( $template_id, $with_css = true ) {
		/** Handled by Elementor self */
		echo \Elementor\Plugin::instance()->frontend->get_builder_content_for_display( $template_id, $with_css );
	}

	/**
	 * Print CSS
	 *
	 * @param int $template_id Template ID.
	 */
	public function print_css( $template_id ) {
		$css_file = \Elementor\Core\Files\CSS\Post::create( $template_id );
		$css_file->enqueue();
		/** Handled by Elementor self */
		echo $css_file->print_css();
	}

	/**
	 * Get custom template
	 *
	 * @param string $template Template location.
	 *
	 * @return string
	 */
	public function custom_template( $template ) {
		if ( class_exists( 'WooCommerce' ) && is_product() ) {
			if ( profecient_essential_get_single_product_template() ) {
				return PROFECIENT_ESSENTIAL_DIR . 'template-parts/single-product-template.php';
			}
		}

		if ( is_archive() ) {
			$archive_template = profecient_essential_get_archive_template();

			if ( $archive_template && function_exists( 'is_shop' ) && is_shop() ) {
				return PROFECIENT_ESSENTIAL_DIR . 'template-parts/shop-page.php';
			}

			if ( $archive_template && ( isset( get_queried_object()->term_id ) || is_category() || is_tag() || is_author() || is_date() || is_post_type_archive() || is_tax() || is_search() ) ) {
				return PROFECIENT_ESSENTIAL_DIR . 'template-parts/archive-template.php';
			}
		}

		if ( is_search() && profecient_essential_get_archive_template() ) {
			return PROFECIENT_ESSENTIAL_DIR . 'template-parts/archive-template.php';
		}

		if ( is_singular( 'post' ) ) {
			if ( profecient_essential_get_single_post_template() ) {
				return PROFECIENT_ESSENTIAL_DIR . 'template-parts/single-post-template.php';
			}
		}

		return $template;
	}

	/**
	 * Get List Templates
	 *
	 * @param string $type Template Slug.
	 *
	 * @return array
	 */
	public function get_list_template( $type ) {
		if ( ! isset( $this->template_list[ $type ] ) ) {
			$this->template_list[ $type ] = jkit_get_element( 'publish', 'jkit-template', $type );
		}

		return $this->template_list[ $type ];
	}
}
