<?php
/**
 * Helper functions
 *
 * @package profecient-essential
 * @author jegtheme
 * @since 1.0.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

if ( ! function_exists( 'profecient_essential_get_template_part' ) ) {
	/**
	 * Load Template Part
	 *
	 * @param string $slug The slug name for the generic template.
	 * @param string $name The name of the specialized template.
	 */
	function profecient_essential_load_template_part( $slug, $name = null ) {
		$name      = (string) $name;
		$file_name = "{$slug}.php";

		if ( '' !== $name ) {
			$file_name = "{$slug}-{$name}.php";
		}

		$file_path = realpath( PROFECIENT_ESSENTIAL_DIR . $file_name );

		if ( file_exists( $file_path ) ) {
			require_once $file_path;
		}
	}
}

if ( ! function_exists( 'profecient_create_global_nonce' ) ) {
	/**
	 * Create Profecient Nonce
	 *
	 * @return string
	 */
	function profecient_create_global_nonce() {
		return wp_create_nonce( profecient_get_nonce_identifier() );
	}
}

if ( ! function_exists( 'profecient_get_nonce_identifier' ) ) {
	/**
	 * Get Profecient Nonce Identifier
	 *
	 * @return string
	 */
	function profecient_get_nonce_identifier() {
		return 'profecient-nonce';
	}
}

if ( ! function_exists( 'dummy_products' ) ) {
	/**
	 * Dummy products for WooCommerce
	 *
	 * @return array
	 */
	function dummy_products() {
		return array(
			array(
				'id'             => 'crew-neck-sweatshirt',
				'name'           => 'Crew Neck Sweatshirt',
				'image'          => '<img width="300" height="300" src="' . PROFECIENT_ESSENTIAL_URL . '/assets/img/products/crew-neck-sweatshirt.jpg' . '" class="attachment-woocommerce_thumbnail size-woocommerce_thumbnail" alt="" loading="lazy">',
				'rating'         => 4.52,
				'price'          => 45.00,
				'currency'       => '$',
				'sku'            => 'crew-neck-sweatshirt',
				'visible'        => true,
				'quantity'       => array(
					'min_value' => 0,
					'max_value' => 10,
				),
				'is_purchasable' => false,
			),
			array(
				'id'                => 'jacket-sweatshirt',
				'name'              => 'Jacket Sweatshirt',
				'image'             => '<img width="300" height="300" src="' . PROFECIENT_ESSENTIAL_URL . '/assets/img/products/jacket-sweatshirt.jpg' . '" class="attachment-woocommerce_thumbnail size-woocommerce_thumbnail" alt="" loading="lazy">',
				'rating'            => 3.52,
				'price'             => 39.99,
				'currency'          => '$',
				'sku'               => 'jacket-sweatshirt',
				'visible'           => true,
				'sold_individually' => true,
			),
			array(
				'id'       => 'sweatshirt-hoodie',
				'name'     => 'Sweatshirt Hoodie',
				'image'    => '<img width="300" height="300" src="' . PROFECIENT_ESSENTIAL_URL . '/assets/img/products/sweatshirt-hoodie.jpg' . '" class="attachment-woocommerce_thumbnail size-woocommerce_thumbnail" alt="" loading="lazy">',
				'rating'   => 4.12,
				'price'    => 42.12,
				'currency' => '$',
				'onsale'   => 32.11,
				'sku'      => 'sweatshirt-hoodie',
				'visible'  => true,
				'quantity' => array(
					'min_value' => 0,
					'max_value' => 5,
				),
			),
			array(
				'id'       => 'sweatshirt-hoodie-zipper',
				'name'     => 'Sweatshirt Hoodie Zipper',
				'image'    => '<img width="300" height="300" src="' . PROFECIENT_ESSENTIAL_URL . '/assets/img/products/sweatshirt-hoodie-with-zipper.jpg' . '" class="attachment-woocommerce_thumbnail size-woocommerce_thumbnail" alt="" loading="lazy">',
				'rating'   => 4.86,
				'price'    => 52.11,
				'currency' => '$',
				'sku'      => 'sweatshirt-hoodie-zipper',
				'visible'  => false,
				'quantity' => array(
					'min_value' => 0,
					'max_value' => 10,
				),
			),
		);
	}
}

if ( ! function_exists( 'profecient_essential_get_single_product_template' ) ) {
	/**
	 * Get template id for single product template
	 *
	 * @return int|null
	 */
	function profecient_essential_get_single_product_template() {
		if ( function_exists( 'jkit_get_element' ) ) {
			global $post;

			$templates         = jkit_get_element( 'publish', \Jeg\Elementor_Kit\Dashboard\Dashboard::$jkit_template, \Profecient\Essential\JKit\Dashboard\Template\Single_Product::$template_slug );
			$template_id       = null;
			$template_instance = \Jeg\Elementor_Kit\Templates\Template::instance();

			if ( $post ) {
				foreach ( $templates as $template ) {
					$flag = $template_instance->check_conditions( $post->ID, $template['id'] );

					if ( $flag ) {
						$template_id = $template['id'];
						break;
					}
				}
			}

			return $template_id;
		}

		return false;
	}
}

if ( ! function_exists( 'profecient_essential_get_archive_template' ) ) {
	/**
	 * Get template id for archive template
	 *
	 * @return int|null
	 */
	function profecient_essential_get_archive_template() {
		if ( function_exists( 'jkit_get_element' ) ) {
			global $post;

			$templates         = jkit_get_element( 'publish', \Jeg\Elementor_Kit\Dashboard\Dashboard::$jkit_template, \Profecient\Essential\JKit\Dashboard\Template\Archive_Template::$template_slug );
			$template_id       = null;
			$template_instance = \Jeg\Elementor_Kit\Templates\Template::instance();
			$post_id           = isset( $post->ID ) ? $post->ID : '';

			foreach ( $templates as $template ) {
				$flag = $template_instance->check_conditions( $post_id, $template['id'] );

				if ( $flag ) {
					$template_id = $template['id'];
					break;
				}
			}

			return $template_id;
		}
		return false;
	}
}

if ( ! function_exists( 'profecient_essential_get_single_post_template' ) ) {
	/**
	 * Get template id for single post template
	 *
	 * @return int|null
	 */
	function profecient_essential_get_single_post_template() {
		if ( function_exists( 'jkit_get_element' ) ) {
			global $post;

			$templates         = jkit_get_element( 'publish', \Jeg\Elementor_Kit\Dashboard\Dashboard::$jkit_template, \Profecient\Essential\JKit\Dashboard\Template\Single_Post::$template_slug );
			$template_id       = null;
			$template_instance = \Jeg\Elementor_Kit\Templates\Template::instance();

			if ( $post ) {
				foreach ( $templates as $template ) {
					$flag = $template_instance->check_conditions( $post->ID, $template['id'] );

					if ( $flag ) {
						$template_id = $template['id'];
						break;
					}
				}
			}

			return $template_id;
		}

		return false;
	}
}

if ( ! function_exists( 'profecient_essential_wc_product_class' ) ) {
	/**
	 * Get product class
	 *
	 * @param string|array           $class
	 * @param int|WP_Post|WC_Product $product_id
	 *
	 * @return string
	 */
	function profecient_essential_wc_product_class( $class, $product_id ) {
		if ( class_exists( 'WooCommerce' ) ) {
			return 'class="' . esc_attr( implode( ' ', wc_get_product_class( $class, $product_id ) ) ) . '"';
		}

		return false;
	}
}

if ( ! function_exists( 'profecient_essential_server_software' ) ) {
	/**
	 * Get server software info
	 *
	 * @return mix
	 */
	function profecient_essential_server_software() {
		return $_SERVER['SERVER_SOFTWARE'];
	}
}

if ( ! function_exists( 'profecient_essential_add_meta_description' ) ) {
	/**
	 * Add meta description to head
	 */
	function profecient_essential_add_meta_description() {
		if ( class_exists( 'RankMath' ) || class_exists( 'WPSEO_Options' ) ) {
			return;
		}

		$site_tagline = get_bloginfo( 'description' );

		if ( $site_tagline ) {
			echo '<meta name="description" content="' . get_bloginfo( 'description' ) . '">';
		}
	}

	add_action( 'wp_head', 'profecient_essential_add_meta_description' );
}
