<?php
/**
 * WordPress Asset class
 *
 * @package profecient
 * @author jegtheme
 * @since 1.0.0
 */

namespace Profecient\Assets;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class Asset {
	/**
	 * Class instance
	 *
	 * @var Widget
	 */
	private static $instance;

	/**
	 * Return class instance
	 *
	 * @return Widget
	 */
	public static function instance() {
		if ( null === static::$instance ) {
			static::$instance = new static();
		}

		return static::$instance;
	}

	/**
	 * Class constructor
	 */
	private function __construct() {
		$this->setup_hook();
	}

	/**
	 * Setup Hooks
	 */
	private function setup_hook() {
		add_action( 'wp_enqueue_scripts', array( $this, 'enqueue_scripts' ) );
		add_action( 'admin_enqueue_scripts', array( $this, 'load_assets' ) );
		add_action( 'elementor/frontend/after_enqueue_styles', array( $this, 'load_template_library_styles' ) );
		add_action( 'elementor/editor/after_enqueue_scripts', array( $this, 'load_template_library_scripts' ) );
	}

	/**
	 * Enqueue scripts and styles.
	 */
	public function enqueue_scripts() {
		wp_enqueue_style( 'profecient-style', get_stylesheet_uri(), array(), profecient_get_theme_version() );

		if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
			wp_enqueue_script( 'comment-reply' );
		}

		wp_enqueue_script( 'profecient-script', PROFECIENT_URL . '/assets/js/frontend.js', array( 'jquery' ), profecient_get_theme_version(), true );

		wp_dequeue_style( 'wp-block-library' );
	}

	/**
	 * Load admin assets
	 */
	public function load_assets() {
		$theme_version = profecient_get_theme_version();
		wp_enqueue_style( 'profecient-dashboard', PROFECIENT_URL . '/assets/css/dashboard.css', null, $theme_version );
		$include = include PROFECIENT_DIR . '/lib/dependencies/dashboard.asset.php';
		wp_enqueue_script( 'profecient-dashboard', PROFECIENT_URL . '/assets/js/dashboard.js', $include['dependencies'], $theme_version, true );
		wp_localize_script(
			'profecient-dashboard',
			'profecientDashboard',
			array(
				'homeUrl'          => get_home_url(),
				'imgDir'           => PROFECIENT_URL . '/assets/img/',
				'themeVersion'     => profecient_get_theme_version(),
				'ratingUrl'        => 'https://profecient.jegtheme.com/', // TODO
				'getLicense'       => 'https://profecient.jegtheme.com/', // TODO
				'forumUrl'         => 'https://themeforest.net/user/jegtheme',
				'demoUrl'          => menu_page_url( 'demos' ),
				'documentationUrl' => 'https://profecient.jegtheme.com/', // TODO
			)
		);
	}

	/**
	 * Load template library
	 */
	public function load_template_library_styles() {
		wp_enqueue_style( 'profecient-template-library', PROFECIENT_URL . '/assets/css/library.css', null, profecient_get_theme_version() );
	}

	/**
	 * Load template library
	 */
	public function load_template_library_scripts() {
		$include = include PROFECIENT_DIR . '/lib/dependencies/library.asset.php';

		wp_enqueue_script( 'profecient-template-library', PROFECIENT_URL . '/assets/js/library.js', array_merge( $include['dependencies'], array( ESSENTIAL_FRAMEWORK . '-template-library' ) ), profecient_get_theme_version(), true );
	}
}
