<?php
/**
 * Init class
 *
 * @package profecient
 * @author jegtheme
 * @since 1.0.0
 */

namespace Profecient;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

use Profecient\Widgets\Widget;
use Profecient\Api\Api;
use Profecient\Assets\Asset;

class Init {
	/**
	 * Class instance
	 *
	 * @var Init
	 */
	private static $instance;

	/**
	 * Widget instance
	 *
	 * @var Widget
	 */
	public $widget;

	/**
	 * API instance
	 *
	 * @var Api
	 */
	public $api;

	/**
	 * Asset instance
	 *
	 * @var Api
	 */
	public $asset;

	/**
	 * Return class instance
	 *
	 * @return Init
	 */
	public static function instance() {
		if ( null === static::$instance ) {
			static::$instance = new static();
		}

		return static::$instance;
	}

	/**
	 * Class constructor
	 */
	private function __construct() {
		$this->setup_helper();
		$this->setup_hooks();
		$this->setup_init();
	}

	/**
	 * Setup helper
	 */
	private function setup_helper() {
		require_once get_parent_theme_file_path( 'lib/helper.php' );
	}

	/**
	 * Setup hooks
	 */
	private function setup_hooks() {
		add_action( 'after_setup_theme', array( $this, 'setup_theme' ) );
		add_action( 'admin_notices', array( $this, 'essential_plugin_notices' ) );
	}

	/**
	 * Setup Init
	 */
	private function setup_init() {
		$this->widget = Widget::instance();
		$this->api    = Api::instance();
		$this->asset  = Asset::instance();
	}

	/**
	 * Setup theme
	 */
	public function setup_theme() {
		load_theme_textdomain( 'profecient-theme', get_template_directory() . '/languages' );

		add_theme_support( 'wp-block-styles' );
		add_theme_support( 'automatic-feed-links' );
		add_theme_support( 'title-tag' );
		add_theme_support( 'post-thumbnails' );
		add_theme_support( 'widgets' );
		add_theme_support( 'customize-selective-refresh-widgets' );

		register_nav_menus(
			array(
				'primary' => __( 'Primary Menu', 'profecient-theme' ),
			)
		);

		add_theme_support(
			'html5',
			array(
				'search-form',
				'comment-form',
				'comment-list',
				'gallery',
				'caption',
				'style',
				'script',
			)
		);

		add_theme_support( 'responsive-embeds' );
		add_theme_support( 'editor-styles' );

		$GLOBALS['content_width'] = apply_filters( 'profecient_content_width', 960 );

		add_theme_support( 'woocommerce' );
		add_theme_support( 'wc-product-gallery-zoom' );
		add_theme_support( 'wc-product-gallery-lightbox' );
		add_theme_support( 'wc-product-gallery-slider' );

		add_post_type_support( 'page', 'excerpt' );

		remove_theme_support( 'widgets-block-editor' );
	}

	/**
	 * Show Essential Plugin Notices
	 */
	public function essential_plugin_notices() {
		$essential_plugins = array(
			'profecient'        => array(
				'name'    => 'Profecient Essential',
				'slug'    => 'profecient-essential',
				'file'    => 'profecient-essential/profecient-essential.php',
				'type'    => 'server',
				'version' => 'PROFECIENT_ESSENTIAL_VERSION',
			),
			'elementor'         => array(
				'name'    => 'Elementor',
				'slug'    => 'elementor',
				'file'    => 'elementor/elementor.php',
				'version' => 'ELEMENTOR_VERSION',
			),
			'jeg-elementor-kit' => array(
				'name'    => 'Jeg Elementor Kit',
				'slug'    => 'jeg-elementor-kit',
				'file'    => 'jeg-elementor-kit/jeg-elementor-kit.php',
				'version' => 'JEG_ELEMENTOR_KIT_VERSION',
			),
		);

		foreach ( $essential_plugins as $plugin ) {
			if ( essential_plugin_notice( $plugin ) ) {
				break;
			}
		}
	}
}
