<?php
/**
 * WordPress Widget class
 *
 * @package profecient
 * @author jegtheme
 * @since 1.0.0
 */

namespace Profecient\Widgets;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class Widget {
	/**
	 * Class instance
	 *
	 * @var Widget
	 */
	private static $instance;

	/**
	 * Return class instance
	 *
	 * @return Widget
	 */
	public static function instance() {
		if ( null === static::$instance ) {
			static::$instance = new static();
		}

		return static::$instance;
	}

	/**
	 * Class constructor
	 */
	private function __construct() {
		$this->setup_hook();
	}

	/**
	 * Get Sidebar
	 *
	 * @return array
	 */
	private function get_sidebar_args() {
		$args = array(
			array(
				'name'          => 'Default Sidebar',
				'id'            => 'default-sidebar',
				'description'   => 'Here you can add widgets to the default sidebar.',
				'class'         => 'profecient-default-sidebar',
				'before_widget' => '<div id="%1$s" class="widget %2$s">',
				'after_widget'  => '</div>',
				'before_title'  => '<h5 id="widget-heading">',
				'after_title'   => '</h5>',
			),
		);

		return apply_filters( 'profecient_sidebar_args', $args );
	}

	/**
	 * Setup Hooks
	 */
	private function setup_hook() {
		add_action( 'widgets_init', array( $this, 'register_sidebar' ) );
		add_action( 'widget_tag_cloud_args', array( $this, 'profecient_widget_tag_cloud_args' ), 10, 2 );
	}

	/**
	 * Register Sidebar
	 */
	public function register_sidebar() {
		foreach ( $this->get_sidebar_args() as $sidebar ) {
			register_sidebar( $sidebar );
		}
	}

	/**
	 * Filters the taxonomy used in the Tag Cloud widget.
	 *
	 * @param array $args     Args used for the tag cloud widget.
	 * @param array $instance Array of settings for the current widget.
	 */
	public function profecient_widget_tag_cloud_args( $args, $instance ) {
		$args['smallest'] = '14';
		$args['largest']  = '14';
		$args['unit']     = 'px';

		return $args;
	}
}
