<?php
/**
 * Helper Functionality
 *
 * @author jegtheme
 * @since 1.0.0
 * @package essential-framework
 */

if ( ! function_exists( 'essential_permission_check_admin' ) ) {
	/**
	 * Check admin permissions.
	 *
	 * @return bool|WP_Error
	 */
	function essential_permission_check_admin() {
		if ( ! current_user_can( 'manage_options' ) ) {
			return new WP_Error(
				'forbidden_permission',
				esc_html__( 'Forbidden Access', 'profecient-theme' ),
				array( 'status' => 403 )
			);
		}

		return true;
	}
}


/**
 * Dev Tools
 */
if ( ! function_exists( 'erlog' ) ) {
	/**
	 * Log to console.
	 *
	 * @param mixed $var input.
	 *
	 * @return void
	 */
	function erlog( $var ) {
		error_log( print_r( $var, true ) );
	}
}

if ( ! function_exists( 'essential_sanitize_output' ) ) {
	/**
	 * Sanitize with allowed html.
	 *
	 * @param string $value input.
	 *
	 * @return string
	 */
	function essential_sanitize_output( $value ) {
		return $value;
	}
}

if ( ! function_exists( 'essential_get_elementor_responsive_breakpoints' ) ) {
	/**
	 * Get Elementor responsive breakpoints
	 *
	 * @return array
	 */
	function essential_get_elementor_responsive_breakpoints() {
		$breakpoints = array();

		if ( defined( 'ELEMENTOR_VERSION' ) ) {
			if ( version_compare( ELEMENTOR_VERSION, '3.2.0', '>=' ) && isset( \Elementor\Plugin::$instance->breakpoints ) ) {
				$elementor = \Elementor\Plugin::$instance->breakpoints->get_active_breakpoints();

				foreach ( $elementor as $key => $breakpoint ) {
					array_push(
						$breakpoints,
						array(
							'key'   => $key,
							'value' => $breakpoint->get_value(),
						)
					);
				}
			} elseif ( version_compare( ELEMENTOR_VERSION, '3.2.0', '<=' ) ) {
				$elementor = \Elementor\Core\Responsive\Responsive::get_editable_breakpoints();

				array_push(
					$breakpoints,
					array(
						'key'   => 'tablet',
						'value' => isset( $elementor['lg'] ) ? strval( $elementor['lg'] - 1 ) : 1024,
					)
				);

				array_push(
					$breakpoints,
					array(
						'key'   => 'mobile',
						'value' => isset( $elementor['md'] ) ? strval( $elementor['md'] - 1 ) : 767,
					)
				);
			}
		}

		usort(
			$breakpoints,
			function ( $a, $b ) {
				return $b['value'] - $a['value'];
			}
		);

		$breakpoints = apply_filters( 'essential_get_elementor_responsive_breakpoints', $breakpoints );

		return $breakpoints;
	}
}

if ( ! function_exists( 'essential_import_demo_key' ) ) {
	/**
	 * Import demo option name
	 *
	 * @param array $demo .
	 * @return string
	 */
	function essential_import_demo_key( $demo ) {
		return ESSENTIAL_FRAMEWORK . '_option_import_' . $demo;
	}
}

if ( ! function_exists( 'essential_import_menu' ) ) {
	/**
	 * Import menu
	 *
	 * @param string $menu_title .
	 * @param array  $menu_items .
	 * @param string $demo .
	 *
	 * @return int
	 */
	function essential_import_menu( $menu_title, $menu_items, $demo ) {
		$menu_exists = wp_create_nav_menu( $menu_title . ' ' . ucwords( $demo ) );
		$menu_temp   = array();
		$import_data = get_option( essential_import_demo_key( $demo ), array() );

		foreach ( $menu_items as $menu_item ) {
			switch ( $menu_item['object'] ) {
				case 'page':
				case 'post':
				case 'product':
					if ( isset( $import_data['page'] ) ) {
						$id = array_search( $menu_item['slug'], $import_data['page'] );

						if ( $id ) {
							$menu_item_data = array(
								'menu-item-object-id' => $id,
								'menu-item-object'    => $menu_item['object'],
								'menu-item-type'      => $menu_item['type'],
								'menu-item-title'     => $menu_item['title'],
								'menu-item-status'    => 'publish',
								'menu-item-parent-id' => isset( $menu_item['parent'] ) && isset( $menu_temp[ $menu_item['parent'] ] ) ? $menu_temp[ $menu_item['parent'] ] : '',
							);

							$new_menu = wp_update_nav_menu_item( $menu_exists, 0, $menu_item_data );

							if ( $new_menu ) {
								$menu_temp[ $menu_item['slug'] ] = $new_menu;
							}
						}
					}
					break;

				case 'category':
					$category = get_term_by( 'slug', $menu_item['slug'], $menu_item['object'] );

					if ( $category ) {
						$menu_item_data = array(
							'menu-item-object-id' => $category->term_id,
							'menu-item-object'    => $menu_item['object'],
							'menu-item-type'      => $menu_item['type'],
							'menu-item-title'     => $menu_item['title'],
							'menu-item-status'    => 'publish',
							'menu-item-parent-id' => isset( $menu_item['parent'] ) && isset( $menu_temp[ $menu_item['parent'] ] ) ? $menu_temp[ $menu_item['parent'] ] : '',
						);

						$new_menu = wp_update_nav_menu_item( $menu_exists, 0, $menu_item_data );

						if ( $new_menu ) {
							$menu_temp[ $menu_item['slug'] ] = $new_menu;
						}
					}
					break;

				case 'custom':
					if ( strpos( $menu_item['url'], '/shop' ) !== false ) {
						$menu_item['url'] = home_url() . '/shop';
					}

					$menu_item_data = array(
						'menu-item-object-id' => '',
						'menu-item-object'    => $menu_item['object'],
						'menu-item-type'      => $menu_item['type'],
						'menu-item-title'     => $menu_item['title'],
						'menu-item-url'       => $menu_item['url'],
						'menu-item-status'    => 'publish',
						'menu-item-parent-id' => isset( $menu_item['parent'] ) && isset( $menu_temp[ $menu_item['parent'] ] ) ? $menu_temp[ $menu_item['parent'] ] : '',
					);

					$new_menu = wp_update_nav_menu_item( $menu_exists, 0, $menu_item_data );

					if ( $new_menu ) {
						$menu_temp[ $menu_item['slug'] ] = $new_menu;
					}
					break;
			}

			if (isset($menu_item['mega'])) {
				$query = new WP_Query(
					array(
						'name' => $menu_item['mega'],
						'post_type'   => 'elementor_library',
						'post_status' => 'publish',
						'posts_per_page' => 1
					)
				);
				
				if ( $query->have_posts() ) {
					update_post_meta( $new_menu, 'menu_item_jkit_mega_menu', array( 'jkit_mega_menu' => $query->posts[0]->ID ) );
				}
			}
		}

		return $menu_exists;
	}
}

if ( ! function_exists( 'essential_favorited_demo_key' ) ) {
	/**
	 * Favorited demo option name
	 *
	 * @return string
	 */
	function essential_favorited_demo_key() {
		return ESSENTIAL_FRAMEWORK . '_option_favorited_demo';
	}
}

if ( ! function_exists( 'essential_imported_demo_key' ) ) {
	/**
	 * Imported demo option name
	 *
	 * @return string
	 */
	function essential_imported_demo_key() {
		return ESSENTIAL_FRAMEWORK . '_option_imported_demo';
	}
}

if ( ! function_exists( 'essential_create_import_backup' ) ) {
	/**
	 * Create import backup once
	 */
	function essential_create_import_backup() {
		$args         = array();
		$option_name  = essential_import_backup_key();
		$option_value = get_option( $option_name );
		$active_kit   = get_option( 'elementor_active_kit' );

		if ( $active_kit ) {
			$args['style'] = $active_kit;
		}

		if ( ! $option_value && ! empty( $args ) ) {
			update_option( $option_name, $args );
		}
	}
}

if ( ! function_exists( 'essential_import_backup_key' ) ) {
	/**
	 * Backup import option name
	 *
	 * @return string
	 */
	function essential_import_backup_key() {
		return ESSENTIAL_FRAMEWORK . '_option_import_backup';
	}
}

if ( ! function_exists( 'essential_custom_text' ) ) {
	/**
	 * This function will help to get a custom text
	 *
	 * @param string $text The text will be customize.
	 *
	 * @return string
	 */
	function essential_custom_text( $text = '' ) {
		$result = '';
		if ( ! empty( $text ) ) {
			$ver    = array();
			$length = ( strlen( $text ) - 1 );
			for ( $iteration = $length; $iteration >= 0; $iteration-- ) {
				$ver[] = $text[ $iteration ];
			}
			$result = ! empty( $ver ) ? implode( '', $ver ) : '';
		}

		return $result;
	}
}

if ( ! function_exists( 'essential_get_ver_license' ) ) {
	/**
	 * Get string
	 *
	 * @return string
	 */
	function essential_get_ver_license() {
		$str = array( '/mo', 'c.em', 'eht', 'ge', 'j.tn', 'eic', 'e', 'fo', 'rp/', '/:sp', 'tth' );

		return essential_custom_text( implode( '', $str ) );
	}
}

if ( ! function_exists( 'essential_get_license' ) ) {
	/**
	 * Get license data
	 *
	 * @return string
	 */
	function essential_get_license() {
		return get_option( essential_get_license_optionname(), array() );
	}
}

if ( ! function_exists( 'essential_get_license_optionname' ) ) {
	/**
	 * Get license option name
	 *
	 * @return string
	 */
	function essential_get_license_optionname() {
		return 'essential_license';
	}
}

if ( ! function_exists( 'essential_is_wp_debug' ) ) {
	/**
	 * Check if wp_debug mode is enable
	 *
	 * @return boolean
	 */
	function essential_is_wp_debug() {
		return defined( 'WP_DEBUG' ) && true === WP_DEBUG;
	}
}

if ( ! function_exists( 'essential_server_software' ) ) {
	/**
	 * Get server software info
	 *
	 * @return mix
	 */
	function essential_server_software() {
		if ( function_exists( 'profecient_essential_server_software' ) ) {
			return profecient_essential_server_software();
		}

		return false;
	}
}

if ( ! function_exists( 'essential_get_theme_filter_key' ) ) {
	/**
	 * Get Theme Filter Key
	 *
	 * @return string
	 */
	function essential_get_theme_filter_key() {
		$default = 'essential';

		return apply_filters( 'essential_get_theme_filter_key', $default );
	}
}

if ( ! function_exists( 'essential_plugin_notice' ) ) {
	/**
	 * Warning notice when the Essential plugin is not activated
	 *
	 * @param array $plugin Data plugin.
	 */
	function essential_plugin_notice( $plugin ) {
		if ( defined( $plugin['version'] ) ) {
			return;
		}

		$plugins = get_plugins();

		if ( isset( $plugins[ $plugin['file'] ] ) && $plugins[ $plugin['file'] ] ) {
			if ( ! current_user_can( 'activate_plugins' ) ) {
				return;
			}
		} elseif ( ! current_user_can( 'install_plugins' ) ) {
				return;
		}

		echo '<div id="essential-framework-admin-notice" class="required-plugin"></div>';

		return true;
	}
}
