<?php
/**
 * Essential Framework API Class.
 *
 * @package essential-framework
 * @author jegtheme
 * @since 1.0.0
 */

namespace Essential\Framework;

use Essential\Framework\Options\Settings;
use Essential\Framework\Meta;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Class API.
 *
 * @package essential-framework
 */
class Api {
	/**
	 * Class instance
	 *
	 * @var Api
	 */
	private static $instance;

	/**
	 * Endpoint Path
	 *
	 * @var string
	 */
	const ENDPOINT = 'essential-framework/v1/demos';

	/**
	 * Endpoint Path
	 *
	 * @var string
	 */
	const ENDPOINT_CLIENT = 'essential-client/v1';

	/**
	 * Hold demo slug when doing import
	 *
	 * @var string
	 */
	private $demo;

	/**
	 * Return class instance
	 *
	 * @return Api_Demos
	 */
	public static function instance() {
		if ( null === static::$instance ) {
			static::$instance = new static();
		}

		return static::$instance;
	}

	/**
	 * Class constructor
	 */
	private function __construct() {
		if ( did_action( 'rest_api_init' ) ) {
			$this->register_routes();
		} else {
			add_action( 'rest_api_init', array( $this, 'register_routes' ) );
			add_action( 'elementor/ajax/register_actions', array( $this, 'register_elementor_ajax_actions' ) );
		}
	}

	/**
	 * Register API
	 */
	public function register_routes() {
		register_rest_route(
			self::ENDPOINT,
			'getDemos',
			array(
				'methods'             => 'POST',
				'callback'            => array( $this, 'get_demos' ),
				'permission_callback' => 'essential_permission_check_admin',
			)
		);

		register_rest_route(
			self::ENDPOINT,
			'getConfig',
			array(
				'methods'             => 'POST',
				'callback'            => array( $this, 'get_config' ),
				'permission_callback' => 'essential_permission_check_admin',
			)
		);

		register_rest_route(
			self::ENDPOINT,
			'getContent',
			array(
				'methods'             => 'POST',
				'callback'            => array( $this, 'get_content' ),
				'permission_callback' => 'essential_permission_check_admin',
			)
		);

		register_rest_route(
			self::ENDPOINT,
			'managePlugin',
			array(
				'methods'             => 'POST',
				'callback'            => array( $this, 'install_plugin' ),
				'permission_callback' => 'essential_permission_check_admin',
			)
		);

		register_rest_route(
			self::ENDPOINT,
			'manageContent',
			array(
				'methods'             => 'POST',
				'callback'            => array( $this, 'manage_content' ),
				'permission_callback' => 'essential_permission_check_admin',
			)
		);

		register_rest_route(
			self::ENDPOINT,
			'manageImage',
			array(
				'methods'             => 'POST',
				'callback'            => array( $this, 'import_image' ),
				'permission_callback' => 'essential_permission_check_admin',
			)
		);

		register_rest_route(
			self::ENDPOINT,
			'manageDemo',
			array(
				'methods'             => 'POST',
				'callback'            => array( $this, 'manage_demo' ),
				'permission_callback' => 'essential_permission_check_admin',
			)
		);

		register_rest_route(
			self::ENDPOINT,
			'manageFavorite',
			array(
				'methods'             => 'POST',
				'callback'            => array( $this, 'manage_favorite' ),
				'permission_callback' => 'essential_permission_check_admin',
			)
		);

		// register_rest_route(
		// self::ENDPOINT,
		// 'resetLicense',
		// array(
		// 'methods'             => 'GET',
		// 'callback'            => 'essential_reset_license',
		// 'permission_callback' => array( $this, 'essential_permission_check_admin' ),
		// )
		// );

		register_rest_route(
			self::ENDPOINT_CLIENT,
			'newsletter-subscribe',
			array(
				'methods'             => 'POST',
				'callback'            => array( $this, 'newsletter_subscribe_handler' ),
				'permission_callback' => 'essential_permission_check_admin',
			)
		);
		/**
		 * Backend routes.
		 */
		register_rest_route(
			self::ENDPOINT_CLIENT,
			'dashboard/save',
			array(
				'methods'             => 'POST',
				'callback'            => array( $this, 'dashboard_save' ),
				'permission_callback' => 'essential_permission_check_admin',
			)
		);
		register_rest_route(
			self::ENDPOINT_CLIENT,
			'demo/data',
			array(
				'methods'             => 'GET',
				'callback'            => array( $this, 'fetch_demo_data' ),
				'permission_callback' => 'essential_permission_check_admin',
			)
		);
		register_rest_route(
			self::ENDPOINT_CLIENT,
			'demo/like-state',
			array(
				'methods'             => 'POST',
				'callback'            => array( $this, 'demo_like_state' ),
				'permission_callback' => 'essential_permission_check_admin',
			)
		);
		register_rest_route(
			self::ENDPOINT_CLIENT,
			'demo/import-state',
			array(
				'methods'             => 'POST',
				'callback'            => array( $this, 'demo_import_state' ),
				'permission_callback' => 'essential_permission_check_admin',
			)
		);
	}

	/**
	 * Register Elementor AJAX Actions
	 *
	 * @param \Elementor\Core\Common\Modules\Ajax $ajax ajax.
	 *
	 * @return void
	 */
	public function register_elementor_ajax_actions( \Elementor\Core\Common\Modules\Ajax\Module $ajax ) {
		$ajax->register_ajax_action( 'essential_template_library_data', array( $this, 'essential_template_library_data_handler' ) );
		$ajax->register_ajax_action( 'essential_template_favorite', array( $this, 'essential_template_favorite_handler' ) );
		$ajax->register_ajax_action( 'essential_template_library_manage_image', array( $this, 'essential_template_library_manage_image_handler' ) );
	}

	// /**
	// * Check user permissions
	// *
	// * @return boolean
	// */
	// public function permission_import_content() {
	// return current_user_can( 'manage_options' );
	// }

	// /**
	// * Check user permissions
	// *
	// * @return boolean
	// */
	// public function permission_install_plugin() {
	// return current_user_can( 'install_plugins' );
	// }

	/**
	 * Newsletter Subscribre Handler
	 *
	 * @param \WP_REST_Request $request The Request.
	 */
	public function newsletter_subscribe_handler( $request ) {
		$data     = json_decode( $request->get_body(), true );
		$response = array(
			'status'  => false,
			'message' => esc_html__( 'Bad Request', 'profecient-theme' ),
		);

		if ( isset( $data['email'] ) && isset( $data['site'] ) ) {
			add_filter( 'http_request_host_is_external', '__return_true' );
			if ( is_email( $data['email'] ) && wp_http_validate_url( $data['site'] ) ) {
				$save_request = wp_remote_request(
					essential_get_server_url() . '/v1/newsletter-subscribe',
					array(
						'method'  => 'POST',
						'timeout' => 10,
						'body'    => array(
							'email' => sanitize_email( $data['email'] ),
							'site'  => esc_url_raw( $data['site'] ),
						),
					)
				);

				$save_response = json_decode( wp_remote_retrieve_body( $save_request ), true );

				if ( ! $save_response['status'] ) {
					$response = array(
						'status'  => false,
						'message' => esc_html__( 'The email has been subscribed.', 'profecient-theme' ),
					);
				} else {
					$response = array(
						'status'  => true,
						'message' => esc_html__( 'Thank you for subscribing.', 'profecient-theme' ),
					);
				}
			}
			add_filter( 'http_request_host_is_external', '__return_false' );
		}

		return wp_send_json( $response );
	}

	/**
	 * Modify Settings
	 *
	 * @param object $request .
	 */
	public function dashboard_save( $request ) {

		$data = $request->get_param( 'setting' );
		// use this to debug
		// delete_option( ESSENTIAL_FRAMEWORK_OPTION );
		$status = Settings::update_settings( $data );
		Settings::clear_cache( true );

		return $status;
	}

	/**
	 * Modify Settings
	 *
	 * @param object $request .
	 */
	public function demo_like_state( $request ) {
		$slug  = $request->get_param( 'slug' );
		$state = $request->get_param( 'state' );
		$liked = Meta::instance()->get_option( 'liked_demo' );
		$liked = ! empty( $liked ) ? $liked : array();
		if ( $state ) {
			if ( ! in_array( $slug, $liked, true ) ) {
				$liked[] = $slug;
			}
		} elseif ( in_array( $slug, $liked, true ) ) {
				$liked = array_diff( $liked, array( $slug ) );
		}
		return Meta::instance()->set_option( 'liked_demo', $liked );
	}

	/**
	 * Modify Settings
	 *
	 * @param object $request .
	 */
	public function demo_import_state( $request ) {
		$slug     = $request->get_param( 'slug' );
		$state    = $request->get_param( 'state' );
		$imported = Meta::instance()->get_option( 'imported_demo' );
		$imported = ! empty( $imported ) ? $imported : array();
		if ( $state ) {
			if ( ! in_array( $slug, $imported, true ) ) {
				$imported[] = $slug;
			}
		} elseif ( in_array( $slug, $imported, true ) ) {
				$imported = array_diff( $imported, array( $slug ) );
		}

		return Meta::instance()->set_option( 'imported_demo', $imported );
	}

	/**
	 * Fetch Data
	 *
	 * @return WP_Rest
	 */
	public function fetch_demo_data() {
		$demo_time = Meta::instance()->get_option( 'fetch_demo_time' );
		$now       = time();

		if ( null === $demo_time || $demo_time < $now || apply_filters( 'fetch_demo_data', false ) ) {
			if ( $this->update_demo_data() ) {
				$next_fetch = $now + ( 24 * 60 * 60 );
				Meta::instance()->set_option( 'fetch_demo_time', $next_fetch );
			}
		}

		return $this->demo_data();
	}

	/**
	 * Update Data.
	 */
	public function update_demo_data() {
		$api_url  = essential_get_server_url() . '/v1/getDemos';
		$args     = array(
			'sslverify' => false,
			'body'      => array(
				'debug' => essential_is_wp_debug(),
			),
		);
		$response = wp_remote_post( $api_url, $args );
		if ( is_wp_error( $response ) ) {
			return false;
		}
		$data = wp_remote_retrieve_body( $response );

		$data = $this->filter_demo_data( $data );

		if ( ! $data || ! isset( $data['demos'] ) || empty( $data['demos'] ) ) {
			return false;
		}

		Meta::instance()->set_option( 'demo_data', $data );

		return true;
	}

	/**
	 * Demo Data.
	 *
	 * @return array
	 */
	public function demo_data() {
		$demo_data = Meta::instance()->get_option( 'demo_data', array() );
		$demo_data = $this->demo_like_filter( $demo_data );
		$demo_data = $this->demo_imported_filter( $demo_data );

		return $demo_data;
	}

	/**
	 * Demo Data.
	 *
	 * @param array $demo_data demo data.
	 * @return array
	 */
	public function demo_like_filter( $demo_data ) {
		$liked         = Meta::instance()->get_option( 'liked_demo' );
		$liked         = ! empty( $liked ) ? $liked : array();
		$filtered_demo = array();
		$id            = 0;

		if ( isset( $demo_data['demos'] ) ) {
			foreach ( $demo_data['demos'] as $demo ) {
				$filtered_demo[] = array(
					'id'   => $id,
					'name' => $demo['name'],
					'data' => $demo['data'],
					'like' => in_array( $demo['data']['slug'], $liked, true ),
				);
				$id++;
			}
		}

		$demo_data['demos'] = $filtered_demo;

		return $demo_data;
	}

	/**
	 * Filter Demo Data.
	 *
	 * @param array $demo_data demo data.
	 * @return array
	 */
	public function demo_imported_filter( $demo_data ) {
		$imported      = Meta::instance()->get_option( 'imported_demo' );
		$imported      = ! empty( $imported ) ? $imported : array();
		$filtered_demo = array();
		$id            = 0;

		if ( isset( $demo_data['demos'] ) ) {
			foreach ( $demo_data['demos'] as $demo ) {
				$filtered_demo[] = array(
					'id'       => $id,
					'name'     => $demo['name'],
					'data'     => $demo['data'],
					'like'     => $demo['like'],
					'imported' => in_array( $demo['data']['slug'], $imported, true ),
				);
				$id++;
			}
		}

		$demo_data['demos'] = $filtered_demo;

		return $demo_data;
	}

	/**
	 * Update Data.
	 *
	 * @param array $data demo data.
	 * @return array filtered data.
	 */
	public function filter_demo_data( $data ) {
		$data           = json_decode( $data, true );
		$demos          = array();
		$demos['demos'] = array();
		if ( $data['demos'] ) {
			foreach ( $data['demos'] as $demo ) {
				$demos['demos'][] = array(
					'name' => $demo['title'],
					'data' => array(
						'name'  => $demo['title'],
						'slug'  => $demo['demo'],
						'cover' => array(
							$demo['cover'],
						),
						'demo'  => $demo['url'],
						'slug'  => $demo['demo'],
						'new'   => $demo['new'],
					),
					'like' => false,
				);
			}
		} else {
			return false;
		}

		return $demos;
	}

	/**
	 * Manage content
	 *
	 * @param object $request data.
	 *
	 * @return WP_Error|array
	 */
	public function manage_content( $request ) {
		// if ( ! wp_verify_nonce( sanitize_text_field( $request->get_param( 'nonce' ) ), 'essential-dashboard', false ) ) {
		// return $this->response_error( esc_html__( 'You are not allowed to perform this action.', 'profecient-theme' ) );
		// }

		$demo   = sanitize_text_field( $request->get_param( 'demo' ) );
		$action = sanitize_text_field( $request->get_param( 'action' ) );

		if ( 'import' === $action || 'reinstall' === $action && ! empty( $request->get_param( 'data' ) ) ) {
			return $this->import_content( $demo, $request );
		} elseif ( 'uninstall' === $action || 'reinstall' === $action ) {
			$type = sanitize_text_field( $request->get_param( 'type' ) );
			return $this->uninstall_content( $demo, $type );
		}
	}

	/**
	 * Uninstall content
	 *
	 * @param object $demo slug.
	 * @param object $type install/uninstall.
	 *
	 * @return WP_Error|array
	 */
	public function uninstall_content( $demo, $type ) {
		$option_name  = essential_import_demo_key( $demo );
		$option_value = get_option( $option_name, array() );

		if ( 'uninstall-style' === $type ) {
			unset( $option_value['style'] );
		}

		if ( 'uninstall-image' === $type ) {
			$images = isset( $option_value['image'] ) ? $option_value['image'] : '';

			if ( $images && is_array( $images ) ) {
				foreach ( $images as $image ) {
					wp_delete_post( $image, true );
				}
				unset( $option_value['image'] );
			}
		}

		if ( 'uninstall-content' === $type ) {
			$pages = isset( $option_value['page'] ) ? $option_value['page'] : '';

			if ( $pages && is_array( $pages ) ) {
				$pages = array_flip( $pages );

				foreach ( $pages as $page ) {
					wp_delete_post( $page, true );
				}
				unset( $option_value['page'] );
			}

			$menus = isset( $option_value['menu'] ) ? $option_value['menu'] : '';

			if ( $menus && is_array( $menus ) ) {
				$menus = array_flip( $menus );

				foreach ( $menus as $menu ) {
					wp_delete_nav_menu( $menu, true );
				}
				unset( $option_value['menu'] );
			}

			$mega_menus = isset( $option_value['mega-menu'] ) ? $option_value['mega-menu'] : '';

			if ( $mega_menus && is_array( $mega_menus ) ) {
				$mega_menus = array_flip( $mega_menus );

				foreach ( $mega_menus as $mega_menu ) {
					wp_delete_post( $mega_menu, true );
				}
				unset( $option_value['mega-menu'] );
			}

			if ( isset( $option_value['term'] ) ) {
				wp_delete_term( $option_value['term'], 'product_cat' );
			}
		}

		update_option( $option_name, $option_value );

		return $this->response_success(
			array(
				'message' => esc_html__( 'Completed', 'profecient-theme' ),
			)
		);
	}

	/**
	 * Import content
	 *
	 * @param object $demo demo data.
	 * @param object $request demo data.
	 *
	 * @return WP_Error|array
	 */
	public function import_content( $demo, $request ) {
		$this->demo        = $demo;
		$option_name       = essential_import_demo_key( $demo );
		$import_data       = get_option( $option_name, array() );
		$data              = $request->get_param( 'data' );
		$elementor_version = defined( 'ELEMENTOR_VERSION' ) ? ELEMENTOR_VERSION : '3.0.0';
		$args              = array(
			'post_title'   => sanitize_text_field( $data['title'] ),
			'post_type'    => sanitize_text_field( $data['type'] ),
			'post_excerpt' => isset( $data['excerpt'] ) ? sanitize_text_field( $data['excerpt'] ) : '',
			'post_status'  => 'publish',
			'meta_input'   => array(
				'_elementor_edit_mode'     => 'builder',
				'_elementor_template_type' => $data['metadata']['template_type'],
				'_wp_page_template'        => $data['metadata']['wp_page_template'],
				'_elementor_page_settings' => $data['page_settings'],
				'_elementor_data'          => isset( $data['content'] ) ? $data['content'] : '',
				'_elementor_version'       => $elementor_version,
			),
		);

		if ( 'global-styles' === $data['metadata']['template_type'] ) {
			$args['post_title'] = sanitize_text_field( $data['title'] ) . ': ' . sanitize_text_field( $request->get_param( 'title' ) );
		}

		$args = $this->import_content_setup_custom_template( $data, $args );

		$args = $this->import_content_setup_metform( $data, $args );

		$args = $this->import_content_setup_tabs( $data, $args );

		if ( 'product' === sanitize_text_field( $data['type'] ) && $data['content'] ) {
			$args['post_content'] = $data['content'];
		}

		if ( 'post' === sanitize_text_field( $data['type'] ) && empty( $data['metadata']['wp_page_template'] ) && $data['content'] ) {
			$args['post_content'] = $data['content'];
			unset( $args['meta_input']['_elementor_edit_mode'] );
		}

		if ( isset( $data['metadata']['elementor_document'] ) && ! ! ! $data['metadata']['elementor_document'] ) {
			unset( $args['meta_input']['_elementor_edit_mode'] );
		}

		if ( 'jkit-mega-menu' === sanitize_text_field( $data['type'] ) ) {
			$args['post_type'] = 'elementor_library';
			$args['post_name'] = $data['slug'];
		}

		if ( 'nav_menu' === sanitize_text_field( $data['type'] ) ) {
			$post_id = essential_import_menu( $data['title'], $data['nav_menu_item_setting'], $demo );
		} else {
			if ( is_array( $args['meta_input']['_elementor_data'] ) ) {
				$args['meta_input']['_elementor_data'] = json_encode( $args['meta_input']['_elementor_data'] );
			}

			$post_id = wp_insert_post( wp_slash( $args ) );
		}

		if ( ! is_wp_error( $post_id ) ) {
			if ( 'global-styles' === $data['metadata']['template_type'] ) {
				$this->import_content_setup_global_styles( $post_id );

				$import_data['style'] = $post_id;
			} elseif ( 'nav_menu' === sanitize_text_field( $data['type'] ) ) {
				$import_data['menu'][ $post_id ] = isset( $data['slug'] ) ? $data['slug'] : $post_id;
			} elseif ( 'jkit-mega-menu' === sanitize_text_field( $data['type'] ) ) {
				$type = 'mega-menu';
				update_post_meta( $post_id, \Elementor\Core\Base\Document::TYPE_META_KEY, $type );
				wp_set_object_terms( $post_id, $type, \Elementor\TemplateLibrary\Source_Local::TAXONOMY_TYPE_SLUG );
				$import_data[ $type ][ $post_id ] = isset( $data['slug'] ) ? $data['slug'] : $post_id;
			} else {
				$import_data['page'][ $post_id ] = isset( $data['slug'] ) ? $data['slug'] : $post_id;

				$this->import_content_setup_404_template( $data, $post_id );
			}

			$import_data = $this->import_content_setup_featured_image( $data, $post_id, $import_data );
			$import_data = $this->import_content_setup_product_term( $data, $post_id, $import_data );

			$this->import_content_setup_pages( $data, $post_id );
			$this->import_content_setup_product_meta( $data, $post_id );
			$this->import_content_setup_header_footer_order( $data, $post_id );
		}

		update_option( $option_name, $import_data );

		return $this->response_success(
			array(
				'id'      => $post_id,
				'url'     => get_permalink( $post_id ),
				'message' => esc_html__( 'Completed', 'profecient-theme' ),
				'status'  => esc_html__( 'Importing contents', 'profecient-theme' ),
			)
		);
	}

	/**
	 * Setup product term
	 *
	 * @param array $data data.
	 * @param int   $product_id id.
	 * @param array $import_data imported.
	 *
	 * @return array $import_data imported.
	 */
	private function import_content_setup_product_term( $data, $product_id, $import_data ) {
		if ( 'product' === sanitize_text_field( $data['type'] ) ) {
			$term = term_exists( $this->demo, 'product_cat' );

			if ( ! $term ) {
				$term = wp_insert_term(
					ucfirst( $this->demo ),
					'product_cat',
					array(
						'description' => esc_html__( 'This is a dummy product category from the import demo.', 'profecient-theme' ),
						'slug'        => $this->demo,
					)
				);

				update_term_meta(
					$term['term_id'],
					'thumbnail_id',
					$data['thumbnail']
				);

				$import_data['term'] = $term['term_id'];
			}

			wp_set_post_terms( $product_id, $term['term_id'], 'product_cat' );
		}

		return $import_data;
	}

	/**
	 * Setup product meta
	 *
	 * @param array $data content.
	 * @param array $post_id post id.
	 *
	 * @return void
	 */
	private function import_content_setup_product_meta( $data, $post_id ) {
		if ( 'product' === sanitize_text_field( $data['type'] ) ) {
			if ( is_array( $data['product_meta'] ) ) {
				foreach ( $data['product_meta'] as $meta => $value ) {
					update_post_meta( $post_id, $meta, $value );
				}
			}

			if ( isset( $data['gallery'] ) ) {
				update_post_meta( $post_id, '_product_image_gallery', implode( ',', $data['gallery'] ) );
			}
		}
	}

	/**
	 * Setup condition for header and footer template order when import content
	 *
	 * @param array $data content.
	 * @param array $post_id post id.
	 *
	 * @return void
	 */
	private function import_content_setup_header_footer_order( $data, $post_id ) {
		if ( in_array( sanitize_text_field( $data['type'] ), array( 'jkit-header', 'jkit-footer' ) ) ) {
			$query = get_posts(
				array(
					'post_type'   => $data['type'],
					'orderby'     => 'menu_order',
					'order'       => 'ASC',
					'post_status' => 'publish',
				)
			);

			if ( $query ) {
				$index = 1;

				foreach ( $query as $post ) {
					wp_update_post(
						array(
							'ID'         => $post->ID,
							'menu_order' => $index,
						)
					);

					$index++;
				}
			}

			wp_update_post(
				array(
					'ID'         => $post_id,
					'menu_order' => 0,
				)
			);

			wp_reset_postdata();
		}
	}

	/**
	 * Setup condition for custom template when import content
	 *
	 * @param array $data data.
	 * @param array $args args.
	 *
	 * @return array
	 */
	private function import_content_setup_custom_template( $data, $args ) {
		if ( in_array( sanitize_text_field( $data['type'] ), array( 'jkit-header', 'jkit-footer', 'jkit-template' ) ) ) {
			$condition = array();

			if ( $data['jkit-condition'] ) {
				$condition = json_encode( $data['jkit-condition'], true );
				$condition = json_decode( $this->text_filter( $condition ), true );
			}

			$args['meta_input']['jkit-condition'] = $condition;

			if ( 'jkit-header' === $data['type'] ) {
				$elementor_data = json_encode( $args['meta_input']['_elementor_data'] );
				$elementor_data = $this->text_filter( $elementor_data );
				$elementor_data = $this->text_filter_menu( $elementor_data );

				$args['meta_input']['_elementor_data'] = json_decode( $elementor_data, true );
			}

			if ( 'jkit-template' === $data['type'] ) {
				$args['meta_input']['jkit-template-type'] = $data['metadata']['jkit-template-type'];
			}
		}

		return $args;
	}

	/**
	 * Setup metform when import content
	 *
	 * @param array $data data.
	 * @param array $args args.
	 *
	 * @return array
	 */
	private function import_content_setup_metform( $data, $args ) {
		if ( 'metform-form' === sanitize_text_field( $data['type'] ) ) {
			$args['meta_input']['metform_form__form_setting'] = $data['metform_form__form_setting'] ? $data['metform_form__form_setting'] : '';
			$args['meta_input']['_elementor_data']            = json_encode( $args['meta_input']['_elementor_data'] );
		}

		if ( 'page' === sanitize_text_field( $data['type'] ) || 'jkit-template' === sanitize_text_field( $data['type'] ) ) {
			$elementor_data = json_encode( $args['meta_input']['_elementor_data'] );

			if ( strpos( $elementor_data, 'mf_form_id' ) !== false ) {
				$args['meta_input']['_elementor_data'] = $this->text_filter( $elementor_data );
			}
		}

		return $args;
	}

	/**
	 * Setup tabs when import content
	 *
	 * @param array $data data.
	 * @param array $args args.
	 *
	 * @return array
	 */
	private function import_content_setup_tabs( $data, $args ) {
		if ( 'page' === sanitize_text_field( $data['type'] ) ) {
			$elementor_data = json_encode( $args['meta_input']['_elementor_data'] );

			if ( strpos( $elementor_data, 'jkit_tabs' ) !== false ) {
				$args['meta_input']['_elementor_data'] = json_decode( $this->text_filter( $elementor_data ), true );
			}
		}

		return $args;
	}

	/**
	 * Setup global styles template when import content
	 *
	 * @param int $post_id post id.
	 *
	 * @return void
	 */
	private function import_content_setup_global_styles( $post_id ) {
		update_option( 'elementor_active_kit', $post_id );
		update_post_meta( $post_id, '_elementor_template_type', 'kit' );
	}

	/**
	 * Setup 404 page template when import content
	 *
	 * @param array $data content.
	 * @param array $post_id post id.
	 *
	 * @return void
	 */
	private function import_content_setup_404_template( $data, $post_id ) {
		if ( strpos( $data['title'], '404' ) !== false ) {
			update_option( 'jkit_notfound_template', $post_id );
		}
	}

	/**
	 * Setup post featured image when import content
	 *
	 * @param array $data content.
	 * @param array $post_id post id.
	 * @param array $import_data import data.
	 *
	 * @return array
	 */
	private function import_content_setup_featured_image( $data, $post_id, $import_data ) {
		if ( in_array( sanitize_text_field( $data['type'] ), array( 'post', 'product' ) ) && isset( $data['thumbnail'] ) ) {
			$image_id = $this->manage_featured_image( $post_id, $data['thumbnail'] );

			if ( $image_id ) {
				$import_data['image'][ $image_id ] = $image_id;
			}
		}

		return $import_data;
	}

	/**
	 * Setup pages when import content
	 *
	 * @param array $data content.
	 * @param array $post_id post id.
	 *
	 * @return void
	 */
	private function import_content_setup_pages( $data, $post_id ) {
		if ( 'page' !== $data['type'] ) {
			return;
		}

		if ( isset( $data['homepage'] ) && $data['homepage'] ) {
			update_option( 'show_on_front', 'page' );
			update_option( 'page_on_front', $post_id );
		}

		if ( isset( $data['slug'] ) && 'cart' === $data['slug'] ) {
			update_option( 'woocommerce_cart_page_id', $post_id );
		}

		if ( isset( $data['slug'] ) && 'checkout' === $data['slug'] ) {
			update_option( 'woocommerce_checkout_page_id', $post_id );
		}

		if ( isset( $data['slug'] ) && 'my-account' === $data['slug'] ) {
			update_option( 'woocommerce_myaccount_page_id', $post_id );
		}

		if ( isset( $data['slug'] ) && strpos( $data['slug'], 'shop' ) !== false ) {
			update_option( 'woocommerce_shop_page_id', $post_id );
		}
	}

	/**
	 * Filter given text
	 *
	 * @param string $text text.
	 *
	 * @return string
	 */
	private function text_filter( $text ) {
		return preg_replace_callback( '/(\{{' . essential_get_theme_filter_key() . '.*?\}})/', array( $this, 'trim_convert_tag' ), $text );
	}

	/**
	 * Filter given text especially for menu
	 *
	 * @param string $text text.
	 *
	 * @return string
	 */
	private function text_filter_menu( $text ) {
		return preg_replace_callback( '/"sg_menu_choose":"(.*?)"/', array( $this, 'trim_menu_tag' ), $text );
	}

	/**
	 * Parse menu item slug
	 *
	 * @param string $matches text.
	 *
	 * @return string
	 */
	public function trim_menu_tag( $matches ) {
		$import_data = get_option( essential_import_demo_key( $this->demo ), array() );
		$menu_id     = array_search( $matches[1], $import_data['menu'] );

		if ( $menu_id ) {
			$menu_data = wp_get_nav_menu_object( $menu_id );

			return '"sg_menu_choose":"' . $menu_data->slug . '"';
		}

		return $matches[0];
	}

	/**
	 * Remove unused curly brace function
	 *
	 * @param string $content content.
	 *
	 * @return string
	 */
	public function trim_convert_tag( $content ) {
		return $this->convert_tag( trim( $content[1], '{}' ) );
	}

	/**
	 * Convert tag
	 *
	 * @param string $string slug.
	 *
	 * @return string
	 */
	private function convert_tag( $string ) {
		$tag = explode( ':', $string );

		if ( sizeof( $tag ) > 1 ) {
			switch ( $tag[1] ) {
				case 'metform':
					$result = $this->metform_tag( $tag );
					break;

				case 'offcanvas':
					$result = $this->offcanvas_tag( $tag );
					break;

				case 'condition':
					$result = $this->condition_tag( $tag );
					break;

				case 'tabs':
					$result = $this->tabs_tag( $tag );
					break;

				default:
					$result = $string;
					break;
			}
		} else {
			$result = $string;
		}

		return apply_filters( 'essential_convert_tag', $result, $tag );
	}

	/**
	 * Parse tabs tag
	 *
	 * Ex: get ID: essential:tabs:slug:id
	 *
	 * @param array $tag tag.
	 *
	 * @return int
	 */
	private function tabs_tag( $tag ) {
		$slug = $tag[2];
		$to   = $tag[3];

		if ( 'id' === $to ) {
			$import_data = get_option( essential_import_demo_key( $this->demo ), array() );

			if ( isset( $import_data['page'] ) ) {
				$page_id = array_search( $slug, $import_data['page'] );

				if ( $page_id ) {
					return $page_id;
				}
			}
		}

		return '';
	}

	/**
	 * Parse offcanvas tag
	 *
	 * Ex: get ID: essential:offcanvas:slug:id
	 *
	 * @param array $tag tag.
	 *
	 * @return int
	 */
	private function offcanvas_tag( $tag ) {
		$slug = $tag[2];
		$to   = $tag[3];

		if ( 'id' === $to ) {
			$import_data = get_option( essential_import_demo_key( $this->demo ), array() );

			if ( isset( $import_data['page'] ) ) {
				$offcanvas_id = array_search( $slug, $import_data['page'] );

				if ( $offcanvas_id ) {
					return $offcanvas_id;
				}
			}
		}

		return '';
	}

	/**
	 * Parse condition tag
	 *
	 * Ex: get ID: essential:condition:slug:id
	 *
	 * @param array $tag tag.
	 *
	 * @return int
	 */
	private function condition_tag( $tag ) {
		$slugs = $tag[2];
		$to    = $tag[3];

		if ( 'id' === $to ) {
			$import_data = get_option( essential_import_demo_key( $this->demo ), array() );
			$slugs       = explode( ',', $slugs );
			$ids         = array();

			if ( $slugs && is_array( $slugs ) ) {
				foreach ( $slugs as $slug ) {
					$id = array_search( $slug, $import_data['page'] );

					if ( $id ) {
						$ids[] = $id;
					}
				}
			}

			if ( $ids ) {
				return implode( ',', $ids );
			}
		}

		return '';
	}

	/**
	 * Parse metform tag
	 *
	 * Ex: get ID: essential:metform:slug:id
	 *
	 * @param array $tag tag.
	 *
	 * @return int
	 */
	private function metform_tag( $tag ) {
		$slug = $tag[2];
		$to   = $tag[3];

		if ( 'id' === $to ) {
			$import_data = get_option( essential_import_demo_key( $this->demo ), array() );

			if ( isset( $import_data['page'] ) ) {
				$metform_id = array_search( $slug, $import_data['page'] );

				if ( $metform_id ) {
					return $metform_id;
				}
			}
		}

		return '';
	}

	/**
	 * Manage post featured image
	 *
	 * @param int    $post_id post id.
	 * @param string $thumbnail thumbnail.
	 *
	 * @return int|bool
	 */
	private function manage_featured_image( $post_id, $thumbnail ) {
		if ( is_int( $thumbnail ) ) {
			$data = array( 'id' => $thumbnail );
		} else {
			$data = $this->image_exist( esc_url( $thumbnail ) );
		}

		if ( ! $data ) {
			$data = $this->add_image( $thumbnail );
		}

		if ( ! empty( $data['id'] ) ) {
			set_post_thumbnail( $post_id, $data['id'] );

			return $data['id'];
		}

		return false;
	}

	/**
	 * Manage demo favorite status
	 *
	 * @param object $request object.
	 *
	 * @return WP_Error|array
	 */
	public function manage_favorite( $request ) {
		// if ( ! wp_verify_nonce( sanitize_text_field( $request->get_param( 'nonce' ) ), 'essential-dashboard', false ) ) {
		// return $this->response_error( esc_html__( 'You are not allowed to perform this action.', 'profecient-theme' ) );
		// }

		$demo           = sanitize_text_field( $request->get_param( 'demo' ) );
		$action         = sanitize_text_field( $request->get_param( 'action' ) );
		$option_name    = essential_favorited_demo_key();
		$favorited_demo = get_option( $option_name, array() );

		if ( 'unset' === $action ) {
			unset( $favorited_demo[ $demo ] );
		} else {
			$favorited_demo[ $demo ] = $demo;
		}

		update_option( $option_name, $favorited_demo );

		return $this->response_success(
			array(
				'message' => esc_html__( 'Completed', 'profecient-theme' ),
			)
		);
	}

	/**
	 * Manage demo status if they have been imported or not
	 *
	 * @param object $request object.
	 *
	 * @return WP_Error|array
	 */
	public function manage_demo( $request ) {
		// if ( ! wp_verify_nonce( sanitize_text_field( $request->get_param( 'nonce' ) ), 'essential-dashboard', false ) ) {
		// return $this->response_error( esc_html__( 'You are not allowed to perform this action.', 'profecient-theme' ) );
		// }

		$demo          = sanitize_text_field( $request->get_param( 'demo' ) );
		$action        = sanitize_text_field( $request->get_param( 'action' ) );
		$option_name   = essential_imported_demo_key();
		$imported_demo = get_option( $option_name, array() );

		if ( 'uninstall' === $action ) {
			unset( $imported_demo[ $demo ] );
		} else {
			$imported_demo[ $demo ] = $demo;
		}

		update_option( $option_name, $imported_demo );

		// We need to create an import backup if not yet.
		essential_create_import_backup();

		return $this->response_success(
			array(
				'message' => esc_html__( 'Completed', 'profecient-theme' ),
			)
		);
	}

	/**
	 * Import image
	 *
	 * @param object $request object.
	 *
	 * @return WP_Error|array
	 */
	public function import_image( $request ) {
		// if ( ! wp_verify_nonce( sanitize_text_field( $request->get_param( 'nonce' ) ), 'essential-dashboard', false ) ) {
		// return $this->response_error( esc_html__( 'You are not allowed to perform this action.', 'profecient-theme' ) );
		// }

		$image        = esc_url( $request->get_param( 'image' ) );
		$demo         = sanitize_text_field( $request->get_param( 'demo' ) );
		$data         = $this->image_exist( $image );
		$option_name  = essential_import_demo_key( $demo );
		$option_value = get_option( $option_name, array() );

		if ( ! $data ) {
			$data          = $this->add_image( $image );
			$data['count'] = true;
		}

		if ( $data && isset( $data['id'] ) ) {
			$option_value['image'][ $data['id'] ] = $data['id'];

			update_option( $option_name, $option_value );
		}

		$data['status'] = esc_html__( 'Downloading images', 'profecient-theme' );

		return $this->response_success( $data );
	}

	/**
	 * Handle import image, and return file ID when process complete
	 *
	 * @param string $image image.
	 *
	 * @return int|null
	 */
	private function add_image( $image ) {
		$file_name = basename( $image );
		$upload    = wp_upload_bits( $file_name, null, '' );

		if ( isset( $upload['file'] ) ) {
			$this->fetch_file( $image, $upload['file'] );
		}

		if ( isset( $upload['file'] ) && $upload['file'] ) {
			$file_loc  = $upload['file'];
			$file_name = basename( $upload['file'] );
			$file_type = wp_check_filetype( $file_name );

			$attachment = array(
				'post_mime_type' => $file_type['type'],
				'post_title'     => preg_replace( '/\.[^.]+$/', '', basename( $file_name ) ),
				'post_content'   => '',
				'post_status'    => 'inherit',
			);

			include_once ABSPATH . 'wp-admin/includes/image.php';
			$attach_id             = wp_insert_attachment( $attachment, $file_loc );
			$attach_data           = wp_generate_attachment_metadata( $attach_id, $file_loc );
			$attach_data['source'] = $image;

			wp_update_attachment_metadata( $attach_id, $attach_data );

			return array(
				'id'  => $attach_id,
				'url' => $upload['url'],
			);
		} else {
			return null;
		}
	}

	/**
	 * Download file and save to file system
	 *
	 * @param string $url url.
	 * @param string $file_path file path.
	 *
	 * @return array|bool
	 */
	public function fetch_file( $url, $file_path ) {
		$http     = new \WP_Http();
		$response = $http->get( $url );

		if ( is_wp_error( $response ) ) {
			return false;
		}

		$headers             = wp_remote_retrieve_headers( $response );
		$headers['response'] = wp_remote_retrieve_response_code( $response );

		if ( false == $file_path ) {
			return $headers;
		}

		// GET request - write it to the supplied filename.
		require_once ABSPATH . 'wp-admin/includes/file.php';
		WP_Filesystem();
		global $wp_filesystem;
		$wp_filesystem->put_contents( $file_path, wp_remote_retrieve_body( $response ), FS_CHMOD_FILE );

		return $headers;
	}

	/**
	 * Check whetever image exists
	 *
	 * @param string $url url.
	 *
	 * @return array|boolean
	 */
	private function image_exist( $url ) {
		$file        = pathinfo( $url );
		$attachments = new \WP_Query(
			array(
				'post_type' => 'attachment',
				'name'      => $file['filename'],
			)
		);

		foreach ( $attachments->posts as $post ) {
			$metadata = wp_get_attachment_metadata( $post->ID );

			if ( $url === $metadata['source'] ) {
				$attachment_url = wp_get_attachment_url( $post->ID );
				return array(
					'id'  => $post->ID,
					'url' => $attachment_url,
				);
			}

			return false;
		}
	}

	/**
	 * Set Demos
	 *
	 * @param object $request args.
	 *
	 * @return WP_Error|array
	 */
	public function get_demos( $request ) {
		// if ( ! wp_verify_nonce( sanitize_text_field( $request->get_param( 'nonce' ) ), 'essential-dashboard', false ) ) {
		// return $this->response_error( esc_html__( 'You are not allowed to perform this action.', 'profecient-theme' ) );
		// }

		$remote_request = wp_remote_request(
			essential_get_server_url() . '/v1/getDemos',
			array(
				'method'  => 'POST',
				'timeout' => 10,
				'body'    => array(
					'debug' => $request->get_param( 'debug' ),
				),
			)
		);

		$response = wp_remote_retrieve_body( $remote_request );

		return $this->response_success( json_decode( $response ) );
	}

	/**
	 * Get Config of Demo
	 *
	 * @param object $request args.
	 *
	 * @return WP_Error|array
	 */
	public function get_config( $request ) {
		// if ( ! wp_verify_nonce( sanitize_text_field( $request->get_param( 'nonce' ) ), 'essential-dashboard', false ) ) {
		// return $this->response_error( esc_html__( 'You are not allowed to perform this action.', 'profecient-theme' ) );
		// }

		$remote_request = wp_remote_request(
			essential_get_server_url() . '/v1/getConfig',
			array(
				'method'  => 'POST',
				'timeout' => 10,
				'body'    => array(
					'demo'   => $request->get_param( 'demo' ),
					'domain' => $request->get_param( 'content' ),
					'code'   => $request->get_param( 'code' ),
				),
			)
		);

		$response = wp_remote_retrieve_body( $remote_request );

		return $this->response_success( json_decode( $response ) );
	}

	/**
	 * Get Content of Demo
	 *
	 * @param object $request args.
	 *
	 * @return WP_Error|array
	 */
	public function get_content( $request ) {
		// if ( ! wp_verify_nonce( sanitize_text_field( $request->get_param( 'nonce' ) ), 'essential-dashboard', false ) ) {
		// return $this->response_error( esc_html__( 'You are not allowed to perform this action.', 'profecient-theme' ) );
		// }

		$remote_request = wp_remote_request(
			essential_get_server_url() . '/v1/getContent',
			array(
				'method'  => 'POST',
				'timeout' => 10,
				'body'    => array(
					'demo'    => $request->get_param( 'demo' ),
					'content' => $request->get_param( 'content' ),
				),
			)
		);

		$response = wp_remote_retrieve_body( $remote_request );

		return $this->response_success( json_decode( $response ) );
	}

	/**
	 * Installing give plugin
	 *
	 * @param object $request args.
	 *
	 * @return WP_Error|array
	 */
	public function install_plugin( $request ) {
		// if ( ! wp_verify_nonce( sanitize_text_field( $request->get_param( 'nonce' ) ), 'essential-dashboard', false ) ) {
		// return $this->response_error( esc_html__( 'You are not allowed to perform this action.', 'profecient-theme' ) );
		// }

		require_once ABSPATH . 'wp-admin/includes/plugin.php';
		require_once ABSPATH . 'wp-admin/includes/file.php';
		require_once ABSPATH . 'wp-admin/includes/class-wp-upgrader.php';
		include_once ABSPATH . 'wp-admin/includes/plugin-install.php';

		$plugin_details              = array_map( 'sanitize_text_field', $request->get_param( 'plugin' ) );
		$all_plugins                 = get_plugins();
		$is_plugin_already_installed = $is_plugin_need_updated = false;

		foreach ( $all_plugins as $key => $item ) {
			if ( strpos( $key, $plugin_details['file'] ) !== false ) {
				if ( isset( $plugin_details['version'] ) && version_compare( $item['Version'], $plugin_details['version'], '<' ) ) {
					$is_plugin_need_updated = true;
				} else {
					$is_plugin_already_installed = true;
				}
			}
		}

		if ( $is_plugin_already_installed ) {
			$activate_status = $this->activate_plugin( $plugin_details['file'] );

			$status = array(
				'success' => true,
				'plugin'  => sanitize_key( wp_unslash( $plugin_details['slug'] ) ),
				'status'  => esc_html__( 'Installing plugins', 'profecient-theme' ),
			);
		} else {
			$status = array(
				'success' => false,
			);

			if ( isset( $plugin_details['type'] ) && 'server' === $plugin_details['type'] ) {
				$domain = home_url();
				$code   = sanitize_text_field( $request->get_param( 'code' ) );
				$args   = array(
					'method'    => 'POST',
					'sslverify' => false,
					'body'      => build_query(
						array(
							'code'   => $code,
							'domain' => $domain,
						)
					),
				);

				$status['plugin']         = $plugin_details['slug'];
				$license_data             = essential_get_license();
				$plugin_details['source'] = add_query_arg(
					array(
						'domain' => $domain,
						'code'   => isset( $license_data['purchase_code'] ) ? $license_data['purchase_code'] : '',
						'plugin' => $plugin_details['slug'],
					),
					essential_get_server_url() . '/v1/installPlugin'
				);
				$plugin_source            = $plugin_details['source'];

			} elseif ( isset( $plugin_details['type'] ) && 'bundle' === $plugin_details['type'] ) {
				// $status['plugin']         = $plugin_details['slug'];
				// $plugin_details['source'] = ESSENTIAL_DIR_PLUGIN . $plugin_details['source'];
				// $plugin_source            = $plugin_details['source'];
			} else {
				$api = plugins_api(
					'plugin_information',
					array(
						'slug'   => sanitize_key( wp_unslash( $plugin_details['slug'] ) ),
						'fields' => array(
							'sections' => false,
						),
					)
				);

				if ( is_wp_error( $api ) && essential_is_wp_debug() ) {
					return $this->response_error( $api->get_error_message() );
				}

				$status['plugin'] = $api->name;
				$plugin_source    = $api->download_link;
			}

			$skin     = new \WP_Ajax_Upgrader_Skin();
			$upgrader = new \Plugin_Upgrader( $skin );

			add_filter( 'http_request_args', array( $this, 'turn_off_reject_unsafe_urls' ) );

			if ( $is_plugin_need_updated ) {
				if ( isset( $plugin_details['type'] ) && 'bundle' === $plugin_details['type'] ) {
					$this->register_update_plugin( $plugin_details );
				}

				$result = $upgrader->upgrade( $plugin_details['file'] );
			} else {
				$result = $upgrader->install( $plugin_source );
			}

			// need to remove the core filter
			// remove_filter( 'http_request_args', array( $this, 'turn_off_reject_unsafe_urls' ) );

			if ( is_wp_error( $result ) && essential_is_wp_debug() ) {
				return $this->response_error( $result->get_error_message() );
			} elseif ( is_wp_error( $skin->result ) && essential_is_wp_debug() ) {
				return $this->response_error( $skin->result->get_error_message() );
			} elseif ( $skin->get_errors()->has_errors() && essential_is_wp_debug() ) {
				return $this->response_error( $skin->get_error_messages() );
			} elseif ( is_null( $result ) ) {
				global $wp_filesystem;

				$message = esc_html__( 'Unable to connect to the wp_filesystem.', 'profecient-theme' );

				if ( $wp_filesystem instanceof \WP_Filesystem_Base && is_wp_error( $wp_filesystem->errors ) && $wp_filesystem->errors->has_errors() ) {
					$message = esc_html( $wp_filesystem->errors->get_error_message() );
				}

				if ( essential_is_wp_debug() ) {
					return $this->response_error( $message );
				}
			}

			$activate_status = $this->activate_plugin( $plugin_details['file'] );
		}

		if ( $activate_status && ! is_wp_error( $activate_status ) ) {
			$status['success'] = true;
			$status['status']  = esc_html__( 'Installing plugins', 'profecient-theme' );
		}

		return $this->response_success( $status );
	}

	/**
	 * Turn off reject unsafe urls
	 *
	 * @param array $args Arguments used for the HTTP request.
	 *
	 * @return array
	 */
	public function turn_off_reject_unsafe_urls( $args ) {
		$args['reject_unsafe_urls'] = false;

		return $args;
	}

	/**
	 * Activate given plugin
	 *
	 * @param string $file file.
	 *
	 * @return WP_Error|boolean
	 */
	private function activate_plugin( $file ) {
		if ( current_user_can( 'activate_plugin', $file ) && is_plugin_inactive( $file ) ) {
			$result = activate_plugin( $file, false, false );

			if ( is_wp_error( $result ) ) {
				return $result;
			} else {
				return true;
			}
		}

		return false;
	}

	/**
	 * Register data for plugin update
	 *
	 * @param array $plugin plugin.
	 */
	private function register_update_plugin( $plugin ) {
		extract( $plugin );

		$repo_updates = get_site_transient( 'update_plugins' );

		if ( ! is_object( $repo_updates ) ) {
			$repo_updates = new \stdClass();
		}

		$file_path = $file;

		if ( empty( $repo_updates->response[ $file_path ] ) ) {
			$repo_updates->response[ $file_path ] = new \stdClass();
		}

		$repo_updates->response[ $file_path ]->slug        = $slug;
		$repo_updates->response[ $file_path ]->plugin      = $file_path;
		$repo_updates->response[ $file_path ]->new_version = $version;
		$repo_updates->response[ $file_path ]->package     = $source;
		$repo_updates->response[ $file_path ]->url         = '';

		set_site_transient( 'update_plugins', $repo_updates );
	}

	/**
	 * Template Library Data Handler
	 *
	 * @param array $data Parameter Requests.
	 *
	 * @throws \Exception Exception in case the WP_CLI::add_command fails.
	 */
	public function essential_template_library_data_handler( $data ) {
		if ( ! current_user_can( 'edit_posts' ) ) {
			throw new \Exception( 'Access Denied' );
		}

		if ( ! empty( $data['editor_post_id'] ) ) {
			$editor_post_id = absint( $data['editor_post_id'] );

			if ( ! get_post( $editor_post_id ) ) {
				throw new \Exception( __( 'Post not found', 'profecient-theme' ) );
			}

			\Elementor\Plugin::instance()->db->switch_to_post( $editor_post_id );
		}

		if ( empty( $data['template_id'] ) ) {
			throw new \Exception( __( 'Template id missing', 'profecient-theme' ) );
		}

		$template_name = $data['template_id'];
		$template_file = $data['file'];

		$data     = Meta::instance()->get_option( 'template_library_data' );
		$response = wp_remote_get( $data->paths->{$template_name} . '/' . $template_file );

		if ( is_array( $response ) && ! is_wp_error( $response ) ) {
			$json_data    = wp_remote_retrieve_body( $response );
			$decoded_data = json_decode( $json_data );

			if ( null !== $decoded_data ) {
				return $json_data;
			} else {
				throw new \Exception( __( 'Failed to decode JSON data.', 'profecient-theme' ) );
			}
		} else {
			throw new \Exception( __( 'HTTP request error: ', 'profecient-theme' ) . $response->get_error_message() );
		}
	}


	/**
	 * Template Library Favorite Handler
	 *
	 * @param array $data Parameter Requests.
	 *
	 * @throws \Exception Exception in case the WP_CLI::add_command fails.
	 */
	public function essential_template_favorite_handler( $data ) {
		if ( ! current_user_can( 'edit_posts' ) ) {
			throw new \Exception( 'Access Denied' );
		}

		if ( ! empty( $data['editor_post_id'] ) ) {
			$editor_post_id = absint( $data['editor_post_id'] );

			if ( ! get_post( $editor_post_id ) ) {
				throw new \Exception( __( 'Post not found', 'profecient-theme' ) );
			}

			\Elementor\Plugin::instance()->db->switch_to_post( $editor_post_id );
		}

		$key       = 'essential_template_favorite';
		$user_id   = get_current_user_id();
		$user_data = get_user_meta( $user_id, $key, true );

		if ( 'remove' === $data['action'] ) {
			unset( $user_data[ $data['template'] ][ $data['file'] ] );
		} elseif ( 'add' === $data['action'] ) {
			if ( ! is_array( $user_data ) ) {
				$user_data = array();
			}

			$user_data[ $data['template'] ][ $data['file'] ] = $data['file'];
		}

		update_user_meta( $user_id, $key, $user_data );

		return $user_data;
	}


	/**
	 * Template Library Image Handler
	 *
	 * @param array $data Parameter Requests.
	 *
	 * @throws \Exception Exception in case the WP_CLI::add_command fails.
	 */
	public function essential_template_library_manage_image_handler( $data ) {
		if ( ! current_user_can( 'edit_posts' ) ) {
			throw new \Exception( 'Access Denied' );
		}

		if ( ! empty( $data['editor_post_id'] ) ) {
			$editor_post_id = absint( $data['editor_post_id'] );

			if ( ! get_post( $editor_post_id ) ) {
				throw new \Exception( __( 'Post not found', 'profecient-theme' ) );
			}

			\Elementor\Plugin::instance()->db->switch_to_post( $editor_post_id );
		}

		$image        = esc_url( $data['image']['url'] );
		$demo         = sanitize_text_field( $data['template_id'] );
		$data         = $this->image_exist( $image );
		$option_name  = essential_import_demo_key( $demo );
		$option_value = get_option( $option_name );

		if ( ! $data ) {
			$data          = $this->add_image( $image );
			$data['count'] = true;
		}

		if ( $data && isset( $data['id'] ) ) {
			$option_value['image'][ $data['id'] ] = $data['id'];

			update_option( $option_name, $option_value );
		}

		$data['status'] = esc_html__( 'Downloading images', 'profecient-theme' );

		return $this->response_success( $data );
	}

	/**
	 * Load file content
	 *
	 * @param string $path path.
	 *
	 * @return string
	 */
	private function load_file_content( $path ) {
		ob_start();
		include $path;
		$content = ob_get_contents();
		ob_end_clean();

		return $content;
	}

	/**
	 * Return error response
	 *
	 * @param array $message args.
	 *
	 * @return \WP_REST_Response
	 */
	private function response_error( $message ) {
		return new \WP_REST_Response(
			array(
				'message' => $message,
			),
			500
		);
	}

	/**
	 * Return success response
	 *
	 * @param array $args args.
	 *
	 * @return \WP_REST_Response
	 */
	private function response_success( $args ) {
		return new \WP_REST_Response( $args, 200 );
	}
}
