<?php
/**
 * Essential Framework Main class
 *
 * @author jegtheme
 * @since 1.0.0
 * @package essential-framework
 */

namespace Essential\Framework;

use Essential\Framework\Asset;
use Essential\Framework\Dashboard;
use Essential\Framework\Api;
use Essential\Framework\Meta;
use Essential\Framework\Options\Options;
use Essential\Framework\Options\Settings;
use Essential\Framework\Elementor\Sync;

/**
 * Class Init
 *
 * @package essential-framework
 */
class Init {
	/**
	 * Instance of Init.
	 *
	 * @var Init
	 */
	private static $instance;

	/**
	 * Asset instance
	 *
	 * @var Asset
	 */
	public $asset;

	/**
	 * Dashboard instance
	 *
	 * @var Dashboard
	 */
	public $dashboard;

	/**
	 * Hold instance of meta options
	 *
	 * @var Meta
	 */
	public $meta;

	/**
	 * Dashboard instance
	 *
	 * @var API
	 */
	public $api;

	/**
	 * Sync instance
	 *
	 * @var Sync
	 */
	public $sync;

	/**
	 * Options instance
	 *
	 * @var Options
	 */
	public $options;

	/**
	 * Singleton page for Init Class
	 *
	 * @return Init
	 */
	public static function instance() {
		if ( null === static::$instance ) {
			static::$instance = new static();
		}

		return static::$instance;
	}

	/**
	 * Init constructor.
	 */
	private function __construct() {
		$this->init_instance();
		$this->init_class();
		$this->init_migration();
	}

	/**
	 * Init Migration
	 */
	public function init_migration() {
		$active_kit = get_option( 'elementor_active_kit' );

		$installed_data = array(
			'time'       => time(),
			'version'    => ESSENTIAL_FRAMEWORK_VERSION,
			'active_kit' => $active_kit,
		);

		$installed = get_option( 'essential_framework_installed' );

		// Migrate
		if ( $installed && isset( $installed['version'] ) ) {
			if ( $installed['version'] !== ESSENTIAL_FRAMEWORK_VERSION ) {
				Settings::clear_cache( true );
				update_option( 'essential_framework_installed', $installed_data );
				add_action( 'essential_framework_theme_options_defaults', array( $this, 'default_elementor' ) );
			}
			// First Time
		} else {
			Settings::clear_cache( true );
			update_option( 'essential_framework_installed', $installed_data );

		}

		if ( ( $installed && isset( $installed['active_kit'] ) ) && ( $installed['active_kit'] !== $active_kit ) ) {
			delete_option( ESSENTIAL_FRAMEWORK_OPTION );
			Settings::clear_cache( true );
			update_option( 'essential_framework_installed', $installed_data );
		}
	}

	/**
	 * Initialize Instances
	 */
	public function init_instance() {
		$this->meta = Meta::instance();
	}

	/**
	 * Initialize Classes
	 */
	public function init_class() {
		if ( is_admin() ) {
			$this->dashboard = Dashboard::instance();
		}
		$this->options = Options::instance();
		$this->asset   = Asset::instance();
		$this->api     = Api::instance();

		Fonts::instance();
	}
}
