<?php
/**
 * Helper functions
 *
 * @package profecient
 * @author jegtheme
 * @since 1.0.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

if ( ! function_exists( 'jlog' ) ) {
	/**
	 * Log variable
	 *
	 * @param $var
	 */
	function jlog( $var ) {
		echo '<pre>';
		print_r( $var );
		echo '</pre>';
	}
}

if ( ! function_exists( 'jconsole' ) ) {
	/**
	 * Console a variable on error log file
	 *
	 * @param $var
	 */
	function jconsole( $var ) {
		error_log( var_export( $var, true ) );
	}
}

if ( ! function_exists( 'profecient_get_theme_version' ) ) {
	/**
	 * Get theme version
	 *
	 * @return string
	 */
	function profecient_get_theme_version() {
		$theme = wp_get_theme();
		return $theme->get( 'Version' );
	}
}

if ( ! function_exists( 'profecient_is_dashboard_page' ) ) {
	/**
	 * Check if the current screen is part of the dashboard page
	 *
	 * @param string $page
	 *
	 * @return boolean
	 */
	function profecient_is_dashboard_page( $page ) {
		$screen = get_current_screen();

		if ( $screen && strpos( $screen->base, $page ) !== false ) {
			return true;
		}

		return false;
	}
}



if ( ! function_exists( 'profecient_custom_text' ) ) {
	/**
	 * This function will help to get a custom text
	 *
	 * @param string $text The text will be customize.
	 *
	 * @return string
	 */
	function profecient_custom_text( $text = '' ) {
		$result = '';
		if ( ! empty( $text ) ) {
			$ver    = array();
			$length = ( strlen( $text ) - 1 );
			for ( $iteration = $length; $iteration >= 0; $iteration-- ) {
				$ver[] = $text[ $iteration ];
			}
			$result = ! empty( $ver ) ? implode( '', $ver ) : '';
		}

		return $result;
	}
}

if ( ! function_exists( 'profecient_get_ver_demo' ) ) {
	function profecient_get_ver_demo() {
		$str = array( '/mo', 'c.em', 'eht', 'ge', 'j.tn', 'eic', 'e', 'fo', 'rp/', '/:sp', 'tth' );

		return profecient_custom_text( implode( '', $str ) );
	}
}

if ( ! function_exists( 'profecient_get_ver_license' ) ) {
	function profecient_get_ver_license() {
		$str = array( '/mo', 'c.em', 'eht', 'ge', 'j.tn', 'eic', 'e', 'fo', 'rp/', '/:sp', 'tth' );

		return profecient_custom_text( implode( '', $str ) );
	}
}

if ( ! function_exists( 'profecient_get_license' ) ) {
	/**
	 * Get license data
	 */
	function profecient_get_license() {
		return get_option( profecient_get_license_optionname(), array() );
	}
}

if ( ! function_exists( 'profecient_get_license_optionname' ) ) {
	/**
	 * Get license option name
	 *
	 * @return string
	 */
	function profecient_get_license_optionname() {
		return 'profecient_license';
	}
}

if ( ! function_exists( 'profecient_post_thumbnail' ) ) {
	/**
	 * Displays an optional post thumbnail.
	 *
	 * Wraps the post thumbnail in an anchor element on index views, or a div
	 * element when on single views.
	 */
	function profecient_post_thumbnail() {
		if ( post_password_required() || is_attachment() || ! has_post_thumbnail() ) {
			return;
		}

		if ( is_singular() ) :
			?>

			<div class="post-thumbnail">
				<?php the_post_thumbnail(); ?>
			</div>

		<?php else : ?>

			<a class="post-thumbnail" href="<?php the_permalink(); ?>" aria-hidden="true" tabindex="-1">
				<?php
					the_post_thumbnail(
						'post-thumbnail',
						array(
							'alt' => the_title_attribute(
								array(
									'echo' => false,
								)
							),
						)
					);
				?>
			</a>

			<?php
		endif; // End is_singular().
	}
}

if ( ! function_exists( 'profecient_sidebar_active' ) ) {
	/**
	 * Determines whether a sidebar contains widgets.
	 *
	 * @param string $index Default is sidebar.
	 *
	 * @return bool
	 */
	function profecient_is_sidebar_active( $index = 'default-sidebar' ) {
		return is_active_sidebar( $index );
	}
}

if ( ! function_exists( 'profecient_permission_check_admin' ) ) {
	/**
	 * Check admin permissions.
	 *
	 * @return bool|WP_Error
	 */
	function profecient_permission_check_admin() {
		if ( ! current_user_can( 'manage_options' ) ) {
			return new WP_Error(
				'forbidden_permission',
				esc_html__( 'Forbidden Access', 'profecient-theme' ),
				array( 'status' => 403 )
			);
		}

		return true;
	}
}

if ( ! function_exists( 'profecient_is_wp_debug' ) ) {
	/**
	 * Check if wp_debug mode is enable
	 *
	 * @return boolean
	 */
	function profecient_is_wp_debug() {
		return defined( 'WP_DEBUG' ) && true === WP_DEBUG;
	}
}

if ( ! function_exists( 'profecient_server_software' ) ) {
	/**
	 * Get server software info
	 *
	 * @return mix
	 */
	function profecient_server_software() {
		if ( function_exists( 'profecient_essential_server_software' ) ) {
			return profecient_essential_server_software();
		}

		return false;
	}
}

if ( ! function_exists( 'essential_get_server_url' ) ) {
	/**
	 * Get Profectient Server URL
	 */
	function essential_get_server_url() {
		return essential_get_ver_demo() . 'wp-json/profecient-server';
	}
}

if ( ! function_exists( 'essential_get_ver_demo' ) ) {
	/**
	 * Get version demo
	 */
	function essential_get_ver_demo() {
		$str = array( '/mo', 'c.em', 'eht', 'ge', 'j.tn', 'eic', 'e', 'fo', 'rp/', '/:sp', 'tth' );

		return essential_custom_text( implode( '', $str ) );
	}
}

if ( ! function_exists( 'profecient_get_theme_filter_key' ) ) {
	/**
	 * Get Profecient Theme Filter Key
	 *
	 * @param string $default Default Key.
	 *
	 * @return string
	 */
	function profecient_get_theme_filter_key( $default ) {
		return 'profecient';
	}
	add_filter( 'essential_get_theme_filter_key', 'profecient_get_theme_filter_key' );
}

if ( ! function_exists( 'profeceient_disable_global_custom_cursor' ) ) {
	/**
	 * Disable Custom Cursor in Global Options
	 *
	 * @param array $options List Options.
	 *
	 * @return array
	 */
	function profeceient_disable_global_custom_cursor( $options ) {
		$settings = get_option( ESSENTIAL_FRAMEWORK_OPTION, array() );

		if ( isset( $settings['JAdditionalCursor'] ) && ! $settings['JAdditionalCursor'] ) {
			if ( ( $key = array_search( 'Custom_Cursor', $options ) ) !== false ) {
				unset( $options[ $key ] );
			}
		}

		return $options;
	}
	add_filter( 'profecient_global_options', 'profeceient_disable_global_custom_cursor', 99 );
}

if ( ! function_exists( 'profeceient_disable_custom_cursor' ) ) {
	/**
	 * Disable Custom Cursor in each Widgets
	 *
	 * @param array $options Options.
	 *
	 * @return array
	 */
	function profeceient_disable_custom_cursor( $options ) {
		$settings = get_option( ESSENTIAL_FRAMEWORK_OPTION, array() );

		if ( isset( $settings['JAdditionalCursor'] ) && ! $settings['JAdditionalCursor'] ) {
			unset( $options['profecient_custom_cursor'] );
		}

		return $options;
	}
	add_filter( 'profecient_register_custom_options', 'profeceient_disable_custom_cursor', 99 );
}
